/**
 * @license
 * Copyright 2019 The Emscripten Authors
 * SPDX-License-Identifier: MIT
 */

// wasm2js.js - enough of a polyfill for the WebAssembly object so that we can load
// wasm2js code that way.

// Emit "var WebAssembly" if definitely using wasm2js. Otherwise, in MAYBE_WASM2JS
// mode, we can't use a "var" since it would prevent normal wasm from working.
/** @suppress{duplicate, const} */
var
WebAssembly = {
  // Note that we do not use closure quoting (this['buffer'], etc.) on these
  // functions, as they are just meant for internal use. In other words, this is
  // not a fully general polyfill.
  Memory: function(opts) {
    this.buffer = new ArrayBuffer(opts['initial'] * 65536);
  },

  Module: function(binary) {
    // TODO: use the binary and info somehow - right now the wasm2js output is embedded in
    // the main JS
  },

  Instance: function(module, info) {
    // TODO: use the module and info somehow - right now the wasm2js output is embedded in
    // the main JS
    // This will be replaced by the actual wasm2js code.
    this.exports = (
// EMSCRIPTEN_START_ASM
function instantiate(ub){function c(d){d.set=function(a,b){this[a]=b};d.get=function(a){return this[a]};return d}var e;var f=new ArrayBuffer(16);var g=new Int32Array(f);var h=new Float32Array(f);var i=new Float64Array(f);function j(k){return g[k]}function l(k,m){g[k]=m}function n(){return i[0]}function o(m){i[0]=m}function p(m){h[2]=m}function q(){return h[2]}function sb(tb){var r=tb.a;var s=r.buffer;r.grow=qb;var t=new Int8Array(s);var u=new Int16Array(s);var v=new Int32Array(s);var w=new Uint8Array(s);var x=new Uint16Array(s);var y=new Uint32Array(s);var z=new Float32Array(s);var A=new Float64Array(s);var B=Math.imul;var C=Math.fround;var D=Math.abs;var E=Math.clz32;var F=Math.min;var G=Math.max;var H=Math.floor;var I=Math.ceil;var J=Math.trunc;var K=Math.sqrt;var L=tb.abort;var M=NaN;var N=Infinity;var O=tb.b;var P=tb.c;var Q=tb.d;var R=tb.e;var S=tb.f;var T=tb.g;var U=tb.h;var V=tb.i;var W=tb.j;var X=tb.k;var Y=tb.l;var Z=tb.m;var _=tb.n;var $=tb.o;var aa=tb.p;var ba=tb.q;var ca=tb.r;var da=tb.s;var ea=tb.t;var fa=tb.u;var ga=tb.v;var ha=tb.w;var ia=tb.x;var ja=tb.y;var ka=tb.z;var la=tb.A;var ma=tb.B;var na=tb.C;var oa=tb.D;var pa=tb.E;var qa=tb.F;var ra=tb.G;var sa=tb.H;var ta=tb.I;var ua=tb.J;var va=tb.K;var wa=tb.L;var xa=tb.M;var ya=tb.N;var za=tb.O;var Aa=tb.P;var Ba=tb.Q;var Ca=tb.R;var Da=tb.S;var Ea=tb.T;var Fa=tb.U;var Ga=tb.V;var Ha=tb.W;var Ia=tb.X;var Ja=tb.Y;var Ka=tb.Z;var La=tb._;var Ma=tb.$;var Na=tb.aa;var Oa=tb.ba;var Pa=tb.ca;var Qa=tb.da;var Ra=tb.ea;var Sa=tb.fa;var Ta=tb.ga;var Ua=tb.ha;var Va=tb.ia;var Wa=tb.ja;var Xa=tb.ka;var Ya=tb.la;var Za=tb.ma;var _a=tb.na;var $a=tb.oa;var ab=tb.pa;var bb=tb.qa;var cb=tb.ra;var db=tb.sa;var eb=tb.ta;var fb=tb.ua;var gb=5709408;var hb=0;var ib=0;var jb=0;
// EMSCRIPTEN_START_FUNCS
function Ht(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,A=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,M=0,N=0,R=0,T=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,ca=C(0),da=0,ea=0,fa=0,ga=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=C(0),Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0,Qa=0,Ra=0,Sa=C(0),Ta=0;ia=gb-48|0;gb=ia;Ca=ia+40|0;v[Ca>>2]=55340;v[Ca>>2]=55240;h=lL(ia+32|0);f=lL(ia+24|0);d=v[h+4>>2];v[ia+16>>2]=v[h>>2];v[ia+20>>2]=d;d=v[f+4>>2];v[ia+8>>2]=v[f>>2];v[ia+12>>2]=d;ua=b;Da=c;W=gb-128|0;gb=W;N=a;Ea=a+24604|0;b=Ea;a:{if(!v[b+16>>2]){break a}a=v[b+20>>2];if(a>>>0>4|!(1<<a&22)){break a}a=v[b+28>>2];if(a>>>0>4){break a}e=23>>>a&1}if(!e){c=W+112|0;WO(c,6290,10346,200,45);e=gb-160|0;gb=e;v[e+88>>2]=0;b=iu(e+88|0);v[22656]=0;d=Q(2,e+120|0,14848)|0;a=v[22656];v[22656]=0;b:{c:{d:{e:{f:{g:{h:{if((a|0)!=1){v[22656]=0;U(6,e+104|0,1,14490);a=v[22656];v[22656]=0;if((a|0)==1){break h}v[22656]=0;U(3,e+136|0,d|0,e+104|0);a=v[22656];v[22656]=0;if((a|0)==1){break g}v[22656]=0;ha(33,b|0,c|0,1,10899,e+136|0);a=v[22656];v[22656]=0;if((a|0)==1){break f}vb(e+136|0);vb(e+104|0);vb(d);break b}b=P()|0;O()|0;break c}b=P()|0;O()|0;break d}b=P()|0;O()|0;break e}b=P()|0;O()|0;vb(e+136|0)}vb(e+104|0)}vb(d)}S(b|0);L()}gb=e+160|0}a=v[N+480208>>2];i:{if(!ua|a&512){break i}Ja=N+8204|0;Ka=N+1074332|0;La=N+397452|0;Ma=N+397448|0;Na=N+393352|0;Oa=N+397456|0;la=N+12|0;Fa=N+1298260|0;Pa=N+1074376|0;q=v[N+1074380>>2];while(1){j:{if(q){break j}T=N;b=a|512;k:{if(a&256){break k}q=0;p=gb-48|0;gb=p;K=gb-32|0;gb=K;k=N;f=k;a=f+1074392|0;b=v[a>>2]+1|0;v[a>>2]=b;l:{m:{i=f+1074376|0;n:{if(uk(i)>>>0>b>>>0){break n}l=f+1074312|0;d=f+1074992|0;e=f+1298224|0;j=f+1074424|0;m=f+484344|0;o=f+484360|0;r=f+1074448|0;g=f+480210|0;while(1){Wz(K+24|0,f,i,(v[f+480208>>2]&524288)>>>19|0);o:{p:{q:{r:{if(!(w[f+480208|0]&32)){b=x[r>>1];a=f;s:{if(tc(Sb(o))>>>0>b>>>0){b=x[sc(Sb(o),x[r>>1])>>1];break s}b=65535}u[a+1074446>>1]=b;t:{if(Te(m)>>>0<=(b&65535)>>>0){break t}if(hi(_b(m,x[f+1074446>>1]))){break t}u[f+1074446>>1]=65534}if(x[f+1074446>>1]>=Te(m)>>>0){while(1){u:{v:{w:{x:{if(x[f+1074446>>1]!=65535){a=x[r>>1];if(tc(Sb(o))>>>0>a>>>0){break x}}c=x[Sb(o)+28>>1];if(c){break v}a=x[r>>1];if(tc(Sb(o))>>>0<a>>>0){break w}b=x[r>>1];if(!b){break w}while(1){c=b;b=c-1|0;if(!b){break w}if(x[sc(Sb(o),b)>>1]!=65535){continue}break}break v}b=x[r>>1]+1|0;u[r>>1]=b;break u}c=0}u[f+1074448>>1]=c;v[f+480208>>2]=v[f+480208>>2]&-524289;y:{if(tc(Sb(o))>>>0<=(c&65535)>>>0){break y}while(1){if(x[sc(Sb(o),x[r>>1])>>1]!=65534){break y}a=x[r>>1]+1|0;u[r>>1]=a;if(tc(Sb(o))>>>0>(a&65535)>>>0){continue}break}}a=x[r>>1];if(tc(Sb(o))>>>0<=a>>>0){break r}if(!Po(Sb(o),x[r>>1])){break r}b=x[r>>1]}a=f;z:{if(tc(Sb(o))>>>0>(b&65535)>>>0){b=x[sc(Sb(o),x[r>>1])>>1];break z}b=65535}u[a+1074446>>1]=b;A:{if(Te(m)>>>0<=(b&65535)>>>0){break A}if(hi(_b(m,x[f+1074446>>1]))){break A}u[f+1074446>>1]=65534}if(x[f+1074446>>1]>=Te(m)>>>0){continue}break}}u[f+1074450>>1]=x[f+1074448>>1]}if(!me(m,x[f+1074446>>1])){break m}if(y[f+1074424>>2]>=y[_b(m,x[f+1074446>>1])+12>>2]){v[j>>2]=0}if(v[f+480208>>2]&32?v[f+480272>>2]!=-1:0){break o}if(!Du(e,x[r>>1],v[j>>2],Iq(K+16|0,d),w[K+24|0])){break o}a=v[f+480272>>2];if(a){if((a|0)>0){v[f+480272>>2]=a-1}Ko(e,1);Du(e,x[r>>1],v[j>>2],Iq(K+16|0,d),w[K+24|0]);break o}if(!(w[g|0]&64)){break r}if(oR(e,r,j,1)){break p}v[f+1074448>>2]=0;v[f+1074424>>2]=0;v[f+1074428>>2]=0;if(w[o+16|0]<(Pi(o)-1|0)){break q}Qi(o,0)}Ko(e,1);break m}Qi(o,w[o+16|0]+1&255);Ko(e,1)}b=0;while(1){$m((f+B(b,872)|0)+1074992|0,7,f,b&65535,134217728);b=b+1|0;if((b|0)!=256){continue}break}MO(f);v[f+1074416>>2]=v[f+480196>>2];v[f+1074420>>2]=v[f+480204>>2];v[f+1074456>>2]=v[f+480200>>2];u[f+1074450>>1]=x[f+1074448>>1];v[f+1074428>>2]=v[f+1074424>>2];b=e;c=tc(Sb(o));a=x[f+1074448>>1];if(c>>>0>a>>>0){Qa=f,Ra=x[sc(Sb(o),x[f+1074448>>1])>>1],u[Qa+1074446>>1]=Ra;a=x[f+1074448>>1]}Du(b,a&65535,v[f+1074424>>2],Iq(K+16|0,d),w[K+24|0]);if(!me(m,x[f+1074446>>1])){break m}}Vz(f,i,(v[f+480208>>2]&32)>>>5|0);c=Yc(_b(m,x[f+1074446>>1]),v[f+1074424>>2],0);a=x[f+480188>>1];if(a){h=(f+B(a,872)|0)+1074992|0;b=d;while(1){a=K+16|0;Db(a,l,82);B:{if(!Cb(a)|w[b+805|0]!=1){break B}a=w[c+3|0];if((a|0)!=2&(a|0)!=3){break B}Qa=b,Ra=_g(f,w[b+800|0],u[b+772>>1],v[b+704>>2]),v[Qa+700>>2]=Ra}a=K+16|0;Db(a,l,91);C:{if(!Cb(a)){break C}if(Rd(c)){break C}if(!Rd(b+788|0)|w[b+791|0]!=19){break C}a=w[b+793|0];if((a&240)!=208|y[f+1074416>>2]>(a&15)>>>0){break C}Qa=b,Ra=_g(f,w[b+788|0],u[b+772>>1],0),v[Qa+700>>2]=Ra}a=K+16|0;Db(a,l,92);D:{if(!Cb(a)){break D}a=K+8|0;Db(a,l,5);if(Cb(a)|v[f+1074416>>2]!=1|w[b+791|0]!=17){break D}v[f+1074420>>2]=B(w[b+793|0],1e4)}a=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);t[b+788|0]=a;t[b+789|0]=a>>>8;t[b+790|0]=a>>>16;t[b+791|0]=a>>>24;a=w[c+4|0]|w[c+5|0]<<8;t[b+792|0]=a;t[b+793|0]=a>>>8;a=v[b+676>>2];v[b+20>>2]=v[b+672>>2];v[b+24>>2]=a;v[b+88>>2]=v[b+88>>2]&-393217;a=K+16|0;Db(a,l,21);if(!Cb(a)){t[b+831|0]=0}v[b+860>>2]=0;t[b+805|0]=0;c=c+6|0;b=b+872|0;if((h|0)!=(b|0)){continue}break}}a=f;b=a+1074412|0;E:{F:{c=a+484344|0;if(dm(c,x[a+1074446>>1])){if(MP(_b(c,x[a+1074446>>1]))){break F}}v[a+1074408>>2]=v[a+480216>>2];a=v[a+480220>>2];break E}Qa=a+1074408|0,Ra=v[_b(c,x[a+1074446>>1])+16>>2],v[Qa>>2]=Ra;a=v[_b(c,x[a+1074446>>1])+20>>2]}v[b>>2]=a;if(!w[K+24|0]){break n}a=v[f+1074416>>2]+1|0;v[f+1074392>>2]=a;if(uk(i)>>>0<=a>>>0){continue}break}}if(!v[f+1074416>>2]){v[f+1074416>>2]=1}b=v[f+480208>>2];a=f;c=a;G:{H:{if(v[a+1074392>>2]){v[f+480208>>2]=b&-4097;if(v[f+480180>>2]&1048580|(w[f+480210|0]&32?0:v[f+480180>>2]==1)){break G}if(y[f+1074392>>2]>=uk(i)>>>0|y[f+1074392>>2]%(v[f+1074400>>2]+v[f+1074416>>2]>>>0)){break G}a=v[f+480208>>2];break H}a=b&-528385}v[c+480208>>2]=a|4096}H=0;G=gb-16|0;gb=G;u[f+1074444>>1]=65535;a=f+1074436|0;v[a>>2]=-1;v[a+4>>2]=-1;E=f+480208|0;X=f+1074376|0;if(x[f+480188>>1]){A=f+1075809|0;_=f+1298260|0;I=f+1074312|0;J=f+480210|0;while(1){F=f+B(H,872)|0;r=F+1075785|0;e=w[r|0];m=F+1075783|0;b=w[m|0];i=F+1075784|0;c=w[i|0];aa=F+1075782|0;h=w[aa|0];ba=F+1075781|0;d=w[ba|0];j=v[f+1074392>>2];g=v[f+1074400>>2];a=v[f+1074416>>2];Y=F+1075780|0;l=wu(Y);Z=F+1075843|0;t[Z|0]=v[f+480208>>2]>>>12&1|w[Z|0]&254;s=(j>>>0)%(a+g>>>0)|0;n=w[Y|0];if((n|0)==252){j=w[ba|0];g=Hq(Y);a=Go(Y);I:{if((j-1&255)>>>0>249){break I}j=v[(f+B(j,160)|0)+906140>>2];if(!j){break I}kb[v[v[j>>2]+44>>2]](j,g,C(C(a>>>0)/C(999)))}n=w[Y|0]}J:{if(b&255|z[F+1075852>>2]==C(0)?(n&255)!=251:0){break J}a=v[E>>2]&4096;K:{if(!a){j=w[F+1075862|0];break K}j=w[ba|0];t[F+1075862|0]=j}if((j-1&255)>>>0>249){break J}g=(f+B(j,160)|0)+906140|0;if(!v[g>>2]){break J}L:{if(!a){n=x[F+1075860>>1];break L}n=su(w[aa|0],w[i|0]);u[F+1075860>>1]=n;ca=C(C(su(w[m|0],w[r|0])>>>0)/C(999));z[F+1075856>>2]=ca;a=v[g>>2];Qa=F+1075852|0,Sa=C(C(ca-C(kb[v[v[a>>2]+48>>2]](a,n)))/C(uk(X)>>>0)),z[Qa>>2]=Sa}j=v[f+1074392>>2];a=uk(X);g=v[g>>2];a=(a|0)==(j+1|0);kb[v[v[g>>2]+(a?44:104)>>2]](g,n,z[(a?F+1075856|0:F+1075852|0)>>2]);n=w[Y|0]}m=F+1074992|0;M:{N:{O:{P:{Q:{if(!GP(n&255)){if(w[E+1|0]&16){break P}a=d;break Q}b=gb-16|0;gb=b;u[b+12>>1]=0;v[b+8>>2]=0;bj(b+8|0);a=x[b+12>>1];t[m+792|0]=a;t[m+793|0]=a>>>8;a=v[b+8>>2];t[m+788|0]=a;t[m+789|0]=a>>>8;t[m+790|0]=a>>>16;t[m+791|0]=a>>>24;gb=b+16|0;a=0;h=0;c=0;b=0;e=0;l=0;g=0;i=0;o=0;d=0;n=0;j=0;if(w[E+1|0]&16){break N}}zP(f,m);d=a;break O}if(!d){d=0;break O}v[F+1075752>>2]=0}R:{S:{if((b&255)==33){a=G+8|0;Db(a,I,30);n=e>>>4|0;vA(f,H&65535,n+(e&15)|0,Cb(a));b=33;break S}n=0;T:{if((b-19&255)>>>0>1){break T}U:{if(!(!(v[f+480180>>2]&16777250)|e)){e=w[F+1075825|0];break U}t[F+1075825|0]=e}a=e&240;if((a|0)==208){j=e&15;if(!j){if(v[f+480180>>2]&16777248){g=b;i=c;n=1;break R}a=l;g=b;i=c;o=h;j=e;if(v[f+480180>>2]!=2){break N}break M}V:{if(j>>>0<v[f+1074400>>2]+v[f+1074416>>2]>>>0){break V}a=G+8|0;Db(a,I,14);if(!Cb(a)){break V}if(!d){break M}t[F+1075795|0]=d;break M}g=b;i=c;n=j;break R}if(!(w[E+1|0]&16)|(a|0)!=224|(v[f+1074396>>2]?v[f+480180>>2]&16777250:0)){break T}a=e&15;if(a?0:v[f+480180>>2]&2){break T}v[f+1074396>>2]=a+1}}g=b;i=c}a=l;o=h;j=e}V=g&255;e=v[f+480180>>2]==16&(V|0)==19&(j&240)==208;R=e?0:n;W:{if(!R|w[Y|0]!=255|w[aa|0]!=2){break W}b=G+8|0;Db(b,I,74);if(!Cb(b)){break W}t[aa|0]=0}h=v[f+1074392>>2];b=G+8|0;Db(b,I,72);X:{if(Cb(b)){M=0;if(R>>>0>=y[f+1074416>>2]){break X}}c=G+8|0;Db(c,I,88);M=(s|0)==(R|0)|(h|0)==(R|0);if(!(!Cb(c)|!R)){break X}M=(h|0)==(R|0)}b=G+8|0;Db(b,I,44);if(Cb(b)){t[Z|0]=w[Z|0]&254|(s|0)==(R|0)}s=j&15;e=e?s|144:j;b=G+8|0;Db(b,I,66);b=(!R|Cb(b)^-1)&a;Y:{Z:{if(!(v[f+1074392>>2]|(!(w[J|0]&32)|!d))){v[F+1075652>>2]=0;if(M){break Z}if(!Mi(m)){break Y}t[F+1075795|0]=d;if(x[f+480190>>1]<d>>>0){break Y}a=f+B(d,104)|0;v[F+1075680>>2]=x[a+484410>>1];u[F+1075764>>1]=t[a+484417|0];break Y}if(!M){break Y}}j=w[Y|0];if(d){t[F+1075795|0]=d}_:{$:{if(!ve(j)){break $}a=G+8|0;Db(a,I,67);if(!Cb(a)){break $}a=u[F+1075762>>1];aa:{if(!d|b){break aa}c=fA(f,j,d);if(!c){break aa}a=t[Bk(f,c)+36|0]}j=(a+j|0)-12>>>0>119?0:j;break _}if(!(v[f+480180>>2]&25165856)|!x[f+480192>>1]){break _}a=j;if(a){a=ve(a)}else{a=1}if(!a){break _}a=d;ba:{if(!a){a=w[F+1075796|0];if(!a){break ba}}if(v[(f+(a<<2)|0)+900380>>2]?x[f+480192>>1]>=a>>>0:0){break _}j=0}d=0}if(!((V|0)!=25|e)){a=G+8|0;Db(a,I,55);a=Cb(a);d=a?0:d;j=a?0:j}a=G+8|0;Db(a,I,65);l=(d|0)!=0;h=!j;c=Cb(a);n=1;ca:{if(v[f+480180>>2]&16777248){break ca}a=G+8|0;Db(a,I,107);if(Cb(a)){break ca}Db(G,I,85);n=0;if(!Cb(G)){break ca}if(Mi(m)){break ca}n=1;a=v[F+1075096>>2];if(!a){break ca}n=Jd(a)^1}r=h&l;l=c&l;da:{ea:{fa:{ga:{ha:{ia:{if(!(v[f+480180>>2]&1048580)){break ia}ja:{if((j|0)!=255){break ja}if(!(!((o&255)==1|d)&(V|0)!=13)){a=G+8|0;Db(a,I,55);if(Cb(a)){break ja}}a=v[F+1075648>>2];if(t[a+60|0]&1?a:0){break ja}v[F+1075680>>2]=0;c=F+1075080|0;v[c>>2]=v[c>>2]|2097152;ka:{if(!(v[f+480208>>2]&4096)){break ka}a=G+8|0;Db(a,I,86);if(!Cb(a)){break ka}v[c>>2]=v[c>>2]|4096}d=0;j=0;h=0;a=0;c=0;r=1;if(l){break ea}break da}a=G+8|0;Db(a,I,59);if(!Cb(a)|v[E>>2]&4096){break ia}la:{if(!j){j=w[F+1075789|0]-w[F+1075762|0]|0;break la}if(j>>>0>250){n=0;l=1;j=0;break la}ma:{if(d){break ma}a=G+8|0;Db(a,I,98);if(!Cb(a)){break ma}d=0;break la}n=1;l=1}h=j;b=0;break ha}h=0;c=0;if(!r){break ga}}a=G+8|0;Db(a,I,65);if(!Cb(a)){break fa}j=h;c=1}a=j;h=c;r=1;if(l){break ea}break da}j=h;h=1;r=l}na:{oa:{if(!x[f+480192>>1]){if(x[f+480190>>1]<d>>>0){break na}a=(f+B(d,104)|0)+484380|0;break oa}a=v[F+1075096>>2];if(!a){break na}}pa:{if(u[a+34>>1]<0){break pa}if(v[f+480180>>2]==2){if(!Jd(a)){break pa}}v[F+1075680>>2]=x[a+30>>1]}if(!r){break na}Uo(m,x[a+28>>1],f)}a=j;c=h}h=G+8|0;Db(h,I,71);if(!(!Cb(h)|!d)){t[F+1075831|0]=32}qa:{if(!x[f+480192>>1]){break qa}h=G+8|0;Db(h,I,100);if(!Cb(h)|!d){break qa}if(ve(a&255)){break qa}h=v[E>>2];ra:{if(b){if(h&8){break ra}break qa}if(!(h&4)){break qa}}Nm(m);v[F+1075688>>2]=65536;h=F+1075080|0;v[h>>2]=v[h>>2]|2097152}if(c){c=G+8|0;Db(c,I,11);sa:{if(!Cb(c)&v[f+480180>>2]!=268435456){break sa}c=G+8|0;Db(c,I,87);j=0;if(Cb(c)){j=Mi(m)^1}ta:{if(x[f+480192>>1]){if(x[f+480192>>1]<d>>>0){break sa}if(v[F+1075648>>2]!=v[(f+(d<<2)|0)+900380>>2]|j){break ta}break sa}if((v[F+1075096>>2]!=((f+B(d,104)|0)+484380|0)|j)!=1){break sa}}a=w[F+1075789|0]}ua:{if(!x[f+480192>>1]|!(v[f+480180>>2]&1048588)){break ua}Nm(m);t[F+1075810|0]=0;v[F+1075748>>2]=0;v[F+1075688>>2]=65536;h=F+1075080|0;v[h>>2]=v[h>>2]&-2101249|2097152;c=G+8|0;Db(c,I,86);if(!Cb(c)){break ua}v[h>>2]=v[h>>2]&-2049}d=n?d:0}n=a&255;va:{if(n>>>0<251){break va}c=G+8|0;Db(c,I,50);wa:{if(!Cb(c)|!d){break wa}c=fA(f,w[F+1075791|0],d);if(!c){break wa}c=f+B(c,104)|0;if(u[c+484414>>1]<0){break wa}v[F+1075680>>2]=x[c+484410>>1]}c=G+8|0;Db(c,I,100);if(Qa=Cb(c),Ra=0,Ta=v[E>>2]&4,Ta?Qa:Ra){break va}d=0}xa:{if(!ve(n)){break xa}t[F+1075794|0]=a;t[F+1075791|0]=a;if(!b){CP(f,H&65535,d,n,0)}c=F+1075776|0;a=u[c>>1];if(a){v[F+1075684>>2]=(a&32767)-1;if((a|0)<0){a=F+1075080|0;v[a>>2]=v[a>>2]|256}u[c>>1]=0}c=F+1075787|0;a=w[c|0];if(a){t[F+1075830|0]=a-1;t[c|0]=0}c=F+1075788|0;a=w[c|0];if(!a){break xa}t[F+1075829|0]=a-1;t[c|0]=0}ya:{za:{Aa:{Ba:{Ca:{if(d){h=F+1075096|0;c=v[h>>2];Fo(f,m,d,b,1,1);a=v[h>>2];Da:{if(!a|!(w[a+35|0]&2)){break Da}if(!Dd(_)){break Da}Gu(v[_>>2],H&65535,v[h>>2]+68|0)}Ea:{Fa:{if(v[f+480180>>2]==1){if(!b){break Fa}a=G+8|0;Db(a,I,85);if(!Cb(a)){break Fa}break Ea}a=G+8|0;Db(a,I,50);if(!Cb(a)){break Fa}if(!ve(n)){break Ea}}t[F+1075795|0]=0}a=G+8|0;Db(a,I,42);if(Cb(a)){if(!ve(n)|(c|0)==v[h>>2]){break Ba}break Ca}if(!(!(v[f+480180>>2]&16777248)|(c|0)==v[h>>2])){a=0;if(ve(n)){break Aa}}a=G+8|0;Db(a,I,107);Ga:{if(!Cb(a)|(c|0)==v[h>>2]){break Ga}Ha:{if(!b){if(ve(n)){break Ha}}a=F+1075068|0;if(y[a>>2]>=y[m+4>>2]){break Ga}v[a>>2]=0;break Ba}b=0}a=G+8|0;Db(a,I,85);if(!Cb(a)){break Ba}if(!Mi(m)){break Ca}break Ba}if(!n){a=b;break ya}h=0;r=F+1075795|0;Ia:{if(!w[r|0]){break Ia}if(!ve(n)){break Ia}Fo(f,m,w[r|0],b,!(v[F+1075096>>2]?1:v[F+1075648>>2]),!(v[f+480180>>2]&1048580));t[r|0]=0;h=1}a=b;break za}v[m>>2]=0;v[m+4>>2]=0}a=b}h=0;if(!n){break ya}}c=F+1075096|0;b=v[c>>2];Ja:{if(!b|!(w[b+35|0]&2)){break Ja}if(!Dd(_)){break Ja}if(!h){if(DP(v[_>>2],H&65535)){break Ja}}Gu(v[_>>2],H&65535,v[c>>2]+68|0)}c=H&65535;tu(f,m,n,a,!(v[f+480180>>2]&1048580),0,c);if(!(!a|(!(v[f+480180>>2]&1048580)|!d))){b=F+1075080|0;v[b>>2]=v[b>>2]|2097152;Nm(m);t[F+1075810|0]=0;v[F+1075748>>2]=0}if(!(v[F+1075080>>2]&512)){break ya}if(!Dd(_)){break ya}if(n>>>0<=253){if((n|0)!=253){break ya}b=G+8|0;Db(b,I,99);if(Cb(b)){break ya}}b=G+8|0;Db(b,I,110);if(Cb(b)){$A(v[_>>2],c,0,1,0)}vk(v[_>>2],c)}Ka:{La:{switch((o&255)-1|0){case 0:i=i>>>0<64?i:64;v[F+1075680>>2]=i<<2;b=F+1075080|0;v[b>>2]=v[b>>2]|2097152;break Ka;case 1:break La;default:break Ka}}Pm(f,m,i,6)}if(x[f+480192>>1]){jO(f,H&65535)}b=a}a=G+8|0;Db(a,I,77);if(Qa=Cb(a),Ra=0,Ta=v[(f+(H<<5)|0)+480280>>2]&1024,Ta?Qa:Ra){break M}c=v[f+1074392>>2];a=G+8|0;Db(a,I,75);d=c>>>0>=R>>>0;Ma:{Na:{Oa:{Pa:{if(!Cb(a)|!R){break Pa}a=v[f+1074392>>2];if(!a){break Oa}d=1;if((a|0)!=(R|0)){break Pa}d=!w[ba|0]&(o&255)!=11}c=o&255;if(!d|c>>>0<3){break Oa}if((c|0)==11){c=G+8|0;DA(c,f,Y,R);a=w[Ve(c)|0];Bo(f,m,x[c>>1]);if(a){break Na}o=11;break Oa}a=G+8|0;Db(a,I,62);Qa:{Ra:{Sa:{Ta:{Ua:{Va:{Wa:{if(!(!Cb(a)|i)){i=0;o=0;Xa:{switch(c-8|0){case 0:break Wa;case 1:break Xa;default:break Oa}}if(w[E+1|0]&16){break Oa}v[F+1075684>>2]=0;break Oa}a=G+8|0;Db(a,I,41);Ya:{if(Cb(a)){break Ya}if(i){t[F+1075826|0]=i;break Ya}i=w[F+1075826|0]}Za:{switch(c-3|0){case 0:case 1:_a:{$a:{if(i){break $a}a=G+8|0;Db(a,I,41);if(!Cb(a)){break $a}i=w[F+1075826|0];if(i){break _a}i=0;break Oa}t[F+1075826|0]=i}Eo(f,m,((c|0)==3?i<<4:i)&255);break Oa;case 2:if((R|0)!=v[f+1074392>>2]){a=G+8|0;Db(a,I,41);o=5;if(Cb(a)){break Oa}}a=G+8|0;Db(a,I,41);Gq(f,m,i,Cb(a));o=5;break Oa;case 3:if((R|0)!=v[f+1074392>>2]){a=G+8|0;Db(a,I,41);o=6;if(Cb(a)){break Oa}}a=G+8|0;Db(a,I,41);Fq(f,m,i,Cb(a));o=6;break Oa;case 11:break Qa;case 12:break Ra;case 10:break Sa;case 9:break Ta;case 7:break Ua;case 6:break Va;case 5:break Wa;case 4:break Za;default:break Oa}}a=G+8|0;Db(a,I,53);if(Cb(a)){t[F+1075815|0]=i&15;o=7;break Oa}Il(m,i<<4);o=7;break Oa}Il(m,i);o=8;break Oa}a=G+8|0;Db(a,I,62);uA(f,m,i,Cb(a)^1);o=9;break Oa}a=G+8|0;Db(a,I,62);uA(f,m,i<<4&240,Cb(a)^1);o=10;break Oa}o=12;a=G+8|0;Db(a,I,12);yP(f,H&65535,i<<2&252,Cb(a));break Oa}a=G+8|0;Db(a,I,12);xP(f,H&65535,i<<2&252,Cb(a));o=13;break Oa}o=15;if(!M){break Oa}a=F+1075096|0;if(!v[a>>2]|i>>>0>9){break Oa}ab:{if(!i){d=v[F+1075656>>2];break ab}d=v[Fe(v[a>>2]+68|0,i-1|0)>>2];v[F+1075656>>2]=d}Om(f,m,d);break Oa}o=14;if(i>>>0>1){break Oa}t[Z|0]=w[Z|0]&251|!i<<2}d=e;bb:{cb:{db:{eb:{switch(V-1|0){case 12:if(!(w[E+1|0]&16)){break Na}a=f+B(H,872)|0;v[a+1075680>>2]=e>>>0<64?e<<2:256;a=a+1075080|0;v[a>>2]=v[a>>2]|2097152;break Na;case 1:if(!e){d=0;if(v[f+480180>>2]&1){break Ma}}yP(f,H&65535,e,0);break Na;case 2:if(!e){d=0;if(v[f+480180>>2]&1){break Ma}}xP(f,H&65535,e,0);break Na;case 10:if(!e){d=0;if(v[f+480180>>2]==1){break Ma}}Eo(f,m,e);break Na;case 3:Bo(f,m,e);break Na;case 5:if(!(!e&v[f+480180>>2]==1)){Eo(f,m,e)}Bo(f,m,0);break Na;case 4:Il(m,e);break Na;case 6:if(!(!e&v[f+480180>>2]==1)){Eo(f,m,e)}Il(m,0);break Na;case 15:if(!(w[E+1|0]&16)){break Na}break bb;case 16:a=G+8|0;Db(a,I,5);if(Cb(a)){if(!(w[E+1|0]&16)){break Na}if(e){break bb}break Na}d=Qm(f,x[f+1074446>>1],v[f+1074424>>2],H&65535,0);fb:{if(!(v[f+480180>>2]&16777250)){break fb}if(d){t[(f+B(H,872)|0)+1075827|0]=d;break fb}d=w[(f+B(H,872)|0)+1075827|0]}v[G+8>>2]=B(d,1e4);qc(G+8|0,B(v[v[f+8>>2]+24>>2],1e4));g=gb-16|0;gb=g;b=v[G+8>>2];v[g+8>>2]=b;a=f;h=v[a+8>>2];gb:{if(b>>>0>=(v[a+480180>>2]&16392?1e4:32e4)>>>0){b=v[a+480208>>2];Db(g,a+1074312|0,92);if((Cb(g)|0)==((b&4096)>>>12|0)){break gb}v[g>>2]=B(v[h+24>>2],1e4);b=a+1074420|0;a=g+8|0;Qa=b,Ra=v[(zn(g,a)?g:a)>>2],v[Qa>>2]=Ra;break gb}if(w[a+480209|0]&16){break gb}e=a+1074420|0;c=(b>>>0)/1e4|0;b=B(c&15,1e4);v[e>>2]=v[e>>2]+((c&240)==16?b:0-b|0);c=v[h+20>>2];b=v[h+24>>2];Db(g,a+1074312|0,8);Gp(e,B(c,1e4),Cb(g)?255e4:B(b,1e4))}gb=g+16|0;break Ma;case 9:if(!M|(v[f+480180>>2]==4?b:0)){break Na}LP(f,m,H&65535,X);break Na;case 43:if(!M){break Na}a=kqa(v[(f+B(H,872)|0)+1075068>>2],0,e,0);b=jb;c=b>>>8|0;Om(f,m,Qc((b&255)<<24|a>>>8,c));break Na;case 0:if(v[f+1074392>>2]){break Na}a=f+B(H,872)|0;hb:{if(w[a+1075789|0]?v[a+1075692>>2]:0){break hb}a=v[a+1075648>>2];if(a){if(Kj(a)){break hb}}a=G+8|0;Db(a,I,13);if(Cb(a)){break hb}if(v[f+480180>>2]&16777248){break Na}}if(!e){d=0;if(v[f+480180>>2]&5){break Ma}t[(f+B(H,872)|0)+1075797|0]=1;break Ma}a=f+B(H,872)|0;t[a+1075798|0]=e;t[a+1075797|0]=1;break Na;case 14:if(v[f+480180>>2]&1048580){e=e&240?e:w[(f+B(H,872)|0)+1075799|0]&240|e;if(!(e&15)){e=w[(f+B(H,872)|0)+1075799|0]&15|e}d=e|256}else{d=e}a=G+8|0;Db(a,I,23);if(Cb(a)){b=f;c=H&65535;if(d){t[(f+B(H,872)|0)+1075799|0]=d;a=d}else{a=w[(f+B(H,872)|0)+1075799|0]}tA(b,c,a&255,(o&255)==15?i+1|0:0);break Ma}ib:{if(d){t[(f+B(H,872)|0)+1075799|0]=d;break ib}d=w[(f+B(H,872)|0)+1075799|0]}tA(f,H&65535,d,(o&255)==15?i+1|0:0);break Ma;case 17:if(!(w[E+1|0]&16)){break Na}a=G+8|0;Db(a,I,22);jb:{kb:{if(Cb(a)){if(!e){e=0;break kb}if(w[E|0]&4){break kb}a=e&240?e-16|0:e;e=a-((a&15)!=0)|0;t[(f+B(H,872)|0)+1075832|0]=e;break kb}a=G+8|0;Db(a,I,71);if(!Cb(a)){break jb}}a=(f+B(H,872)|0)+1075831|0;t[a|0]=w[a|0]|128}a=f+B(H,872)|0;t[a+1075797|0]=18;if(!e){d=0;break Ma}t[a+1075832|0]=e;break Na;case 22:if(!(w[E+1|0]&16)){break Na}d=e<<!(v[f+480180>>2]&59593760);if(d>>>0<=128){v[f+1074456>>2]=d<<1;break Ma}if(v[f+480180>>2]&16777250){break Ma}v[f+1074456>>2]=256;break Ma;case 23:a=G+8|0;Db(a,I,9);if(Cb(a)){wP(f,e,(f+B(H,872)|0)+1075809|0);break Na}wP(f,e,A);break Na;case 8:if(!(w[E+1|0]&16)){break Na}Pm(f,m,e,8);break Na;case 28:uA(f,m,e,1);break Na;case 7:OP(m,e);break Na;case 25:PP(f,m,e);break Na;case 18:c=f;b=c+1074376|0;g=H&65535;d=B(g,872);h=(b+d|0)+616|0;a=e;j=a&15;lb:{mb:{switch(a>>>4|0){case 0:if(!x[c+480188>>1]){break lb}d=(a&1)<<14;b=0;while(1){a=(c+B(b,872)|0)+1075080|0;v[a>>2]=(d|v[a>>2]&-16385)^16384;b=b+1|0;if(b>>>0<x[c+480188>>1]){continue}break};break lb;case 1:if(!(v[c+480180>>2]&1048580?1:j)){break lb}oP(c,h,j);break lb;case 2:if(!(v[c+480180>>2]&1048580?1:j)){break lb}nP(c,h,j);break lb;case 3:a=(c+d|0)+1075080|0;v[a>>2]=v[a>>2]&-1048577|((j|0)!=0)<<20;break lb;case 4:t[(c+d|0)+1075814|0]=a&7;break lb;case 5:if(!(w[c+480209|0]&16)){break lb}if(v[c+480180>>2]&69206025){d=c+B(g,872)|0;b=d+1075764|0;u[b>>1]=j<<28>>24;a=d+1075692|0;if(!v[a>>2]){break lb}if(!Rd(d+1075780|0)){break lb}d=a;a=c+B(g,872)|0;Qa=d,Ra=_g(c,w[a+1075789|0],u[b>>1],v[a+1075696>>2]),v[Qa>>2]=Ra;break lb}b=v[c+480180>>2];d=Rd((c+B(g,872)|0)+1075780|0);if((b|0)==16){if(!d){break lb}b=c+B(g,872)|0;a=v[b+1075096>>2];if(!a){break lb}t[a+37|0]=j;u[b+1075764>>1]=j;a=b+1075692|0;if(!v[a>>2]){break lb}b=a;a=c+B(g,872)|0;Qa=b,Ra=_g(c,w[a+1075789|0],j,v[a+1075696>>2]),v[Qa>>2]=Ra;break lb}if(!d){break lb}d=c+B(g,872)|0;b=(a<<4^-128)<<24>>24;u[d+1075764>>1]=b;a=d+1075692|0;if(!v[a>>2]){break lb}Qa=a,Ra=_g(c,w[d+1075789|0],b,v[d+1075696>>2]),v[Qa>>2]=Ra;break lb;case 6:if(!(w[c+480209|0]&16)){break lb}uu(c,b,h,j);break lb;case 7:t[(c+d|0)+1075817|0]=a&7;break lb;case 8:if(!(w[c+480209|0]&16)){break lb}Pm(c,h,j,4);break lb;case 9:tA(c,g,j,0);break lb;case 10:if(!(v[c+480180>>2]&1048580?1:j)){break lb}Gq(c,h,j,0);break lb;case 11:if(!(v[c+480180>>2]&1048580?1:j)){break lb}Fq(c,h,j,0);break lb;case 12:vA(c,g,j,0);break lb;case 15:break mb;default:break lb}}if(v[c+480180>>2]==1){t[(c+B(g,872)|0)+1075838|0]=j;if(!(w[c+480209|0]&16)){break lb}zP(c,h);break lb}t[(c+B(g,872)|0)+1075836|0]=j}break Na;case 19:c=G+8|0;Db(c,I,78);b=f;g=H&65535;a=e;nb:{if(!Cb(c)){break nb}a=e;if(d){break nb}a=w[(f+B(H,872)|0)+1075798|0]}d=a;vP(b,g,d);break Ma;case 24:a=G+8|0;Db(a,I,55);if(Cb(a)){if(v[f+1074392>>2]!=(e|0)){break Na}a=v[(f+B(H,872)|0)+1075648>>2];if(t[a+60|0]&1?a:0){break cb}if(!(!(w[aa|0]?1:w[ba|0])|e)){a=(f+B(H,872)|0)+1075080|0;v[a>>2]=v[a>>2]|4096;break cb}a=f+B(H,872)|0;v[a+1075680>>2]=0;a=a+1075080|0;v[a>>2]=v[a>>2]|2097152;break cb}if(w[E+1|0]&16){break cb}break Na;case 27:a=(e&240)-16>>>4|0;if(a>>>0>9){break Na}if(!(1<<a&880)){if(!a){break db}if((a|0)!=1){break Na}uP(f,m,e&15);break Na}a=G+8|0;Db(a,I,58);if(Cb(a)){break Na}vP(f,H&65535,e);break Na;case 34:case 35:if(!(w[E+1|0]&16)&(g&255)!=36){break Na}b=H&65535;JP(f,b,X,(g&255)==36);a=pu(f,b);if(!a){break Na}kb[v[v[a>>2]+80>>2]](a,x[m+774>>1]>>>2^8192,b);break Na;case 20:if(!(w[E+1|0]&16)|e>>>0>64){break Na}a=f+B(H,872)|0;v[a+1075740>>2]=e;a=a+1075080|0;v[a>>2]=v[a>>2]|2097152;break Na;case 21:d=f;b=m;a=e;ob:{if(a){t[b+816|0]=a;break ob}a=w[b+816|0]}j=a&255;c=b;g=a&240;i=a&15;pb:{qb:{if(!(!g|(i|0)!=15)){if(!(w[d+480209|0]&16)){break pb}a=j>>>4|0;break qb}h=v[d+480208>>2]&4096;if(!(!i|(g|0)!=240)){if(!h){break pb}a=0-i|0;break qb}if(h){break pb}if(i){a=0-i|0;if(!(v[d+480180>>2]&25690144)|!g){break qb}break pb}if((a&255)>>>0<16){break pb}a=j>>>4|0}Qa=c,Ra=Lb(a+v[b+748>>2]|0,0,64),v[Qa+748>>2]=Ra}break Na;case 26:NP(m,e);break Na;case 29:if(!(w[E+1|0]&16)){break Na}b=f+B(H,872)|0;v[b+1075716>>2]=e;a=G+8|0;Db(a,I,60);if(Qa=0,Ra=Cb(a),Ta=w[b+1075722|0]&4,Ta?Qa:Ra){break Na}a=f+B(H,872)|0;v[a+1075732>>2]=e;v[a+1075724>>2]=e;break Na;case 11:CA(f,X,H&65535);break Na;case 13:a=BA(f,X,H&65535,e);if((a|0)==-1){break Na}v[f+1074436>>2]=a;if(!(w[f+480208|0]&32)){break Na}u[f+1074444>>1]=x[f+1074448>>1];break Na;case 37:case 38:case 39:case 40:b=m;a=g&255;j=(a|0)==38|(a|0)==40;a=f;if(w[a+480209|0]&16){c=w[b+848|0];h=d&240;if(h){c=h|c&15;t[b+848|0]=c}d=d&15;if(d){c=d|c&-16;t[b+848|0]=c}t[b+849|0]=(c&240)>>>4}d=(g&254)==40;rb:{sb:{if(v[a+480180>>2]==32768){c=w[b+848|0];if(w[a+480209|0]&16|(c&240)==16){break sb}break rb}if(w[a+480209|0]&16){break rb}c=w[b+849|0]-1|0;t[b+849|0]=c;if(c&255){break rb}c=w[b+848|0]}t[b+849|0]=(c&240)>>>4;c=c&15;c=j?c:0-c|0;tb:{if(Mj(b)){v[b+852>>2]=v[b+852>>2]+B(c,v[v[v[b+656>>2]+44>>2]+36>>2]);break tb}Qa=b,Ra=_g(a,ou(a,v[b+700>>2],u[b+772>>1],v[b+704>>2])+c|0,u[b+772>>1],v[b+704>>2]),v[Qa+700>>2]=Ra}if(!d){break rb}v[b>>2]=0;v[b+4>>2]=0}break Na;case 41:zA(m,e);break Na;case 42:break eb;default:break Ma}}if(v[f+1074392>>2]|s>>>0>1|e>>>0>47){break Na}a=(e&240)==16;d=a?0:H;c=(a?x[f+480188>>1]-1|0:H)&65535;if((d&65535)>>>0>c>>>0){break Na}h=((s|0)==1)<<26;while(1){b=d&65535;a=(f+(b<<5)|0)+480280|0;v[a>>2]=h|v[a>>2]&-67108865;a=(f+B(b,872)|0)+1075080|0;v[a>>2]=h|v[a>>2]&-67108865;d=d+1|0;if(c>>>0>=(d&65535)>>>0){continue}break}break Na}tP(f,m,e&15);break Na}Do(f,m);break Na}RP(f,X,e)}d=e}a=G+8|0;Db(a,I,78);if(!(!Cb(a)|!d)){a=d&255;t[m+840|0]=a;t[m+812|0]=a;t[m+811|0]=a;t[m+809|0]=a;t[m+807|0]=a;t[m+806|0]=a;t[m+826|0]=a>>>4;t[m+827|0]=a<<2&60}a=w[ba|0];if(!a){break M}t[F+1075796|0]=a}H=H+1|0;if(H>>>0<x[f+480188>>1]){continue}break}}ub:{if(!(w[E+1|0]&16)){break ub}if(!IP(f,X,1)){break ub}v[E>>2]=v[E>>2]|524288}gb=G+16|0;a=1;break l}a=0}gb=K+32|0;vb:{if(!a|!v[k+1074420>>2]){break vb}a=HO(k,k+1074376|0);v[k+1074380>>2]=a;v[k+1074404>>2]=a;b=Md(x[k+480188>>1],1,31);aa=k+1074332|0;wb:{if(w[aa+34|0]){a=v[k+24628>>2];if((a|0)>=129){a=((B(a-128|0,b+4|0)|0)/16|0)+128|0}j=((B(v[k+480228>>2],a)<<1&-128)>>>0)/w[(b>>>1|0)+38416|0]|0;break wb}j=v[k+480228>>2]}u[k+480212>>1]=0;_=k+1298260|0;X=k+1074312|0;J=k+480210|0;M=k+480209|0;l=0;while(1){E=k+B(l,872)|0;R=E+1075080|0;xb:{if(!(v[R>>2]&4096)|(v[E+1075016>>2]|(v[E+1075012>>2]|v[E+1075688>>2]))){break xb}a=p+16|0;Db(a,X,64);if(Cb(a)){break xb}v[E+1075068>>2]=0;a=E+1075084|0;v[a>>2]=0;v[a+4>>2]=0}c=x[k+480188>>1];a=v[R>>2];yb:{if(v[E+1075068>>2]|c>>>0>l>>>0?a&1024:1){if(c>>>0>l>>>0){rO(k,l&65535)}u[E+1075834>>1]=0;break yb}e=0;o=E+1075712|0;v[o>>2]=0;ba=E+1075672|0;v[ba>>2]=0;Z=E+1075e3|0;b=Z;v[b>>2]=0;v[b+4>>2]=0;v[E+1075092>>2]=0;v[p+44>>2]=1065353216;u[p+42>>1]=0;V=E+1075648|0;s=v[V>>2];v[p+36>>2]=0;q=0;Y=E+1075692|0;q=v[Y>>2]?v[E+1075068>>2]!=0:q;b=E+1074992|0;zb:{Ab:{Bb:{if(c>>>0<=l>>>0){break Bb}if(w[(k+(l<<5)|0)+480288|0]){break Ab}if(!s){break Bb}e=w[s+34|0]!=0}if((e|q)!=1){break zb}}v[p+8>>2]=v[E+1075680>>2];v[p+32>>2]=v[E+1075744>>2];d=p+16|0;Db(d,X,28);c=b;a=p+8|0;h=Cb(d)?p+32|0:a;f=gb-16|0;gb=f;d=f+8|0;e=k+1074312|0;Db(d,e,28);Cb:{if(Cb(d)){v[h>>2]=v[h>>2]+u[c+776>>1];Zd(h,0,64);break Cb}d=f+8|0;Db(d,e,1);d=Cb(d);e=u[c+776>>1];if(d){v[h>>2]=e+v[h>>2];Zd(h,0,256);break Cb}v[c+688>>2]=e+v[c+688>>2];Zd(c+688|0,0,256);v[h>>2]=v[c+688>>2];u[c+776>>1]=0}gb=f+16|0;f=gb-16|0;gb=f;e=f+8|0;d=k+1074312|0;Db(e,d,28);Db:{Eb:{if(!Cb(e)){Db(f,d,1);if(!Cb(f)){break Eb}}v[c+684>>2]=v[c+692>>2]+u[c+778>>1];Zd(c+684|0,0,256);break Db}v[c+692>>2]=v[c+692>>2]+u[c+778>>1];Zd(c+692|0,0,256);u[c+778>>1]=0;v[c+684>>2]=v[c+692>>2]}gb=f+16|0;c=a;m=gb-16|0;gb=m;f=b;h=k;Fb:{if(!(w[b+90|0]&4)|(v[h+480208>>2]&2101248)==2101248){break Fb}Gb:{if(v[c>>2]<=0){d=m+8|0;Db(d,h+1074312|0,21);if(!Cb(d)){break Gb}}e=5;if(!(v[h+480180>>2]&5)){d=m+8|0;Db(d,h+1074312|0,21);e=Cb(d)?5:6}g=Uz(h,w[f+825|0],w[f+820|0]);Hb:{if((w[f+825|0]&3)!=1){break Hb}d=m+8|0;Db(d,h+1074312|0,89);if(!Cb(d)){break Hb}g=w[f+819|0];i=w[f+820|0];d=i<<2&124;d=(!(w[f+90|0]&2)|w[h+480209|0]&16?g:w[f+823|0]+g|0)&32?d^127:d;g=i&32?0-d|0:d}d=c;if(v[h+480180>>2]!=131072){c=v[c>>2]+((B(w[f+827|0],g)|0)/(1<<e)|0)|0}else{c=v[c>>2];c=((B(w[f+827|0],B(c,64-g|0))|0)/-8192|0)+c|0}v[d>>2]=c}if(!(v[h+480180>>2]&16777248)|w[h+480208|0]&4?w[h+480209|0]&16:0){break Fb}c=m+8|0;Db(c,h+1074312|0,21);e=Cb(c);d=w[f+826|0];c=w[f+820|0];t[f+820|0]=(e?d<<2:c)+(e?c:d)}gb=m+16|0;K=l&65535;r=K;d=a;m=gb-16|0;gb=m;c=m+8|0;f=k;e=f+1074312|0;Db(c,e,71);Ib:{if(Cb(c)){c=(f+B(r,872)|0)+1075831|0;g=t[c|0];if((g|0)>=0){break Ib}if(!(w[f+480209|0]&16|w[(f+B(r,872)|0)+1075797|0]!=18)){e=g&-33;t[c|0]=e;Jb:{Kb:{if((e|0)!=-64){e=g&223;if((e|0)!=128){break Kb}g=w[(f+B(r,872)|0)+1075832|0]>>>4|-64;break Jb}g=w[(f+B(r,872)|0)+1075832|0]&15|-128;break Jb}g=e-1|0}t[c|0]=g;c=(f+B(r,872)|0)+1075080|0;v[c>>2]=v[c>>2]|2097152}if((g&224)!=128){break Ib}v[d>>2]=0;break Ib}if(w[(f+B(r,872)|0)+1075797|0]!=18){break Ib}c=m+8|0;Db(c,e,22);Lb:{if(Cb(c)){e=f+B(r,872)|0;c=e+1075831|0;h=w[c|0];g=h<<24>>24;if(!((g|0)>=0|!v[e+1075068>>2])){Mb:{Nb:{if((h|0)!=192){if((h|0)!=128){break Nb}g=w[(f+B(r,872)|0)+1075832|0]>>>4|-64;break Mb}g=w[(f+B(r,872)|0)+1075832|0]&15|-128;break Mb}g=g-1|0}t[c|0]=g}if((g&192)!=128){break Lb}v[d>>2]=0;break Lb}c=w[(f+B(r,872)|0)+1075832|0];e=c>>>4|0;i=e+(c&15)|0;if(!(w[f+480208|0]&4?0:v[f+480180>>2]&16777248)){i=i+2|0;e=e+1|0}h=(f+B(r,872)|0)+1075831|0;g=w[h|0];if(!(v[f+480180>>2]&4)){c=(g&255)>>>0<i>>>0?g:0;if((c&255)>>>0>=e>>>0){v[d>>2]=0}t[h|0]=c+1;break Lb}Ob:{if(w[f+480209|0]&16){g=g&255?g-1|0:0;break Ob}t[h|0]=g+1}if(((g&255)>>>0)%(i>>>0)>>>0<e>>>0){break Lb}v[d>>2]=0}c=(f+B(r,872)|0)+1075080|0;v[c>>2]=v[c>>2]|2097152}c=f+B(r,872)|0;Pb:{if(w[c+1075797|0]!=18){break Pb}e=c+1075648|0;c=v[e>>2];if(!c|!w[c+34|0]|w[c+15|0]&2){break Pb}c=f+B(r,872)|0;if(v[c+1075080>>2]&134218752){break Pb}g=c+1075791|0;if(!ve(w[g|0])){break Pb}h=v[e>>2];i=v[(f+B(w[h+34|0],160)|0)+906140>>2];if(!i){break Pb}e=kb[v[v[i>>2]+100>>2]](i,w[g|0],r)|0;c=v[d>>2];if(!(!e|c)){kb[v[v[i>>2]+92>>2]](i,h,w[g|0]+255|0,0,r);break Pb}if(e|!c){break Pb}kb[v[v[i>>2]+92>>2]](i,h,w[g|0],x[(f+B(r,872)|0)+1075680>>1],r)}gb=m+16|0;Zd(a,0,256);v[p+8>>2]=v[p+8>>2]<<6;Qb:{if(s){a=p+16|0;Db(a,X,31);if(Cb(a)){du(k,b)}e=p+8|0;r=e;A=gb-16|0;gb=A;a=b;Rb:{if(!Tz(k,a,0)){break Rb}n=v[a+656>>2];c=A+8|0;m=f+1074312|0;Db(c,m,31);Sb:{if(Cb(c)){i=v[a+724>>2];if(i){break Sb}break Rb}i=v[a+724>>2]}c=A+8|0;Db(c,m,31);f=n+48|0;d=i-Cb(c)|0;i=Vq(f,d,256,64);c=w[n+65|0];Tb:{if((c|0)==255){break Tb}g=u[a+728>>1];if((g|0)==-1){break Tb}h=w[Mb(f,c)+2|0];c=x[Mb(f,w[n+65|0])>>1];a=A+8|0;Db(a,m,94);f=h<<2;c=(c|0)==(d|0)?f:i;if(Cb(a)){i=g+(c-f<<1)|0;break Tb}if(!h){i=0;break Tb}i=(B(c,g)|0)/(f|0)|0}Qa=r,Ra=(B(v[r>>2],Lb(i,0,512))|0)/256|0,v[Qa>>2]=Ra}gb=A+16|0;qO(b,e);h=gb-16|0;gb=h;a=k;c=b;Ub:{if(!Tz(a,c,1)){break Ub}f=v[c+656>>2];e=h+8|0;d=a+1074312|0;Db(e,d,31);Vb:{if(Cb(e)){i=v[c+732>>2];if(i){break Vb}break Ub}i=v[c+732>>2]}a=h+8|0;Db(a,d,31);d=Vq(f+68|0,i-Cb(a)|0,64,64)-32|0;a=v[c+684>>2];Qa=c,Ra=Lb(((B(d,(a|0)>127?256-a|0:a)|0)/32|0)+a|0,0,256),v[Qa+684>>2]=Ra}gb=h+16|0;a=p+16|0;Db(a,X,115);if(Cb(a)){break Qb}a=w[E+1075789|0];if(!a){break Qb}c=v[V>>2];if(!c|!w[c+26|0]){break Qb}pO(E+1075676|0,a,c);break Qb}if(!(w[R+1|0]&16)){break Qb}v[E+1075688>>2]=0;v[p+8>>2]=0}Wb:{if(w[E+1075843|0]&4){v[p+8>>2]=0;break Wb}c=v[p+8>>2];if(!c){break Wb}if(w[R+3|0]&8){v[ba>>2]=0;break Wb}if(w[aa+33|0]){a=B(v[p+32>>2],v[E+1075740>>2]);d=a;e=a>>31;a=c<<8;Qa=ba,Ra=Ac(lqa(kqa(d,e,a,a>>31),jb,1048576,0),jb),v[Qa>>2]=Ra;break Wb}a=B(v[p+32>>2],v[E+1075740>>2]);d=a;e=a>>31;a=B(c,v[k+1074456>>2]);Qa=ba,Ra=Ac(lqa(kqa(d,e,a,a>>31),jb,1048576,0),jb),v[Qa>>2]=Ra}v[o>>2]=v[p+8>>2];Xb:{Yb:{if(v[k+480180>>2]==2|v[Y>>2]>=v[k+480260>>2]){break Yb}if(Hj(k)){break Yb}v[Y>>2]=v[k+480260>>2];break Xb}if(v[Y>>2]<v[k+480264>>2]){break Xb}a=p+16|0;Db(a,X,113);if(!Cb(a)){break Xb}if(Hj(k)){break Xb}v[Y>>2]=v[k+480264>>2]}a=p+16|0;Db(a,X,73);if(Cb(a)){Lb(v[Y>>2],1,31999)}a=v[Y>>2];v[p+36>>2]=a;Zb:{if((v[R>>2]&1572864)!=1572864){break Zb}if(w[J|0]&32){if(!wu(E+1075780|0)|w[M|0]&16){break Zb}a=v[p+36>>2]}c=E+1075704|0;_b:{if(v[c>>2]==(a|0)){a=v[E+1075708>>2];break _b}v[c>>2]=a;d=a;c=E+1075764|0;a=E+1075696|0;a=_g(k,ou(k,d,u[c>>1],v[a>>2]),u[c>>1],v[a>>2]);v[E+1075708>>2]=a}v[p+36>>2]=a}r=gb-16|0;gb=r;d=k;i=d+B(K,872)|0;g=v[i+1075648>>2];$b:{if(!g){break $b}a=w[g+34|0];if(!a|w[g+15|0]&2|(!v[(d+B(a,160)|0)+906140>>2]|v[(d+B(K,872)|0)+1075080>>2]&134218752)){break $b}e=d+B(K,872)|0;f=e+1075783|0;h=w[f|0];c=0;a=e+1075791|0;if(ve(w[a|0])){c=w[ic(g+108|0,w[a|0]-1|0)|0]}m=e+1075780|0;ac:{bc:{if((h|0)==1){g=0;cc:{dc:{switch((y[d+1074392>>2]%3|0)-1|0){case 0:g=w[(d+B(K,872)|0)+1075798|0]>>>4|0;break cc;case 1:break dc;default:break cc}}g=w[(d+B(K,872)|0)+1075798|0]&15}a=d+B(K,872)|0;t[a+1075793|0]=c;if(w[a+1075792|0]==(c+g|0)){break ac}if(!(w[d+480209|0]&16)){break bc}if(!Rd(m)){break bc}break ac}g=0;if(w[m|0]|!w[(d+B(K,872)|0)+1075792|0]){break ac}}a=d+B(K,872)|0;Mm(d,K,w[a+1075793|0]+g|0,x[a+1075680>>1])}e=(d+B(K,872)|0)+1075792|0;a=w[e|0];ec:{if(!a){if(!(w[d+480209|0]&16)|(h|0)!=1){break ec}if(Rd(m)){break ec}a=c;if(!ve(a)){break ec}}Mm(d,K,(a&255)+255|0,0)}t[e|0]=w[f|0]==1?w[(d+B(K,872)|0)+1075793|0]+g|0:0}fc:{if(w[i+1075797|0]!=1){break fc}if(Mj(i+1074992|0)){c=0;gc:{hc:{switch((y[d+1074392>>2]%3|0)-1|0){case 0:c=w[(d+B(K,872)|0)+1075798|0]>>>4|0;break gc;case 1:break hc;default:break gc}}c=w[(d+B(K,872)|0)+1075798|0]&15}u[p+42>>1]=c;a=(d+B(K,872)|0)+1075843|0;t[a|0]=w[a|0]|48;break fc}if(!(!(w[d+480209|0]&16)|v[d+480180>>2]!=1048576)){c=d+B(K,872)|0;a=_g(d,w[c+1075789|0],u[c+1075764>>1],v[c+1075696>>2]);v[p+36>>2]=a;v[c+1075692>>2]=a}a=r+8|0;f=d+1074312|0;Db(a,f,13);if(Cb(a)){c=w[(d+B(K,872)|0)+1075798|0];if(!c){break fc}a=65536;ic:{switch(((y[d+1074392>>2]%(v[d+1074400>>2]+v[d+1074416>>2]>>>0)>>>0)%3|0)-1|0){case 1:c=c<<4;case 0:a=v[((c&240)<<2)+43584>>2];break;default:break ic}}d=Hj(d);c=v[p+36>>2];g=c;c=c>>31;f=p;if(d){a=kqa(g,c,a,a>>31)+32768|0;e=jb;c=lqa(a,a>>>0<32768?e+1|0:e,65536,0)}else{e=(a|0)/2|0;d=e;h=d>>31;i=d;e=g;d=c<<16|e>>>16;e=e<<16;g=i+e|0;c=d+h|0;c=lqa(g,e>>>0>g>>>0?c+1|0:c,a,a>>31)}a=jb;Qa=f,Ra=Ac(c,a),v[Qa+36>>2]=Ra;break fc}a=r+8|0;Db(a,f,51);if(Cb(a)){if(w[d+480209|0]&16){break fc}jc:{kc:{a=v[d+1074416>>2];a=a-(y[d+1074392>>2]%(a>>>0)|0)|0;if((a|0)>16){break kc}if((a|0)==16){break fc}g=0;lc:{switch((a|0)%3|0){case 0:break fc;case 2:break kc;case 1:break lc;default:break jc}}g=w[(d+B(K,872)|0)+1075798|0]>>>4|0;break jc}g=w[(d+B(K,872)|0)+1075798|0]&15}c=d+B(K,872)|0;a=c+1075764|0;e=c+1075696|0;c=ou(d,v[p+36>>2],u[a>>1],v[e>>2])+g|0;a=_g(d,c,u[a>>1],v[e>>2]);v[p+36>>2]=a;if(c>>>0<109){break fc}v[r+8>>2]=a;Qa=r,Ra=_g(d,109,0,v[e>>2]),v[Qa+4>>2]=Ra;Qa=p,Ra=v[Lc(r+8|0,r+4|0)>>2],v[Qa+36>>2]=Ra;break fc}c=v[d+1074392>>2];if(v[d+480180>>2]!=1){g=w[(d+B(K,872)|0)+1075789|0]}else{a=d+B(K,872)|0;g=ou(d,v[p+36>>2],u[a+1075764>>1],v[a+1075696>>2])}mc:{nc:{switch((((v[d+480180>>2]&67633152?c+2|0:c)>>>0)%3|0)-1|0){case 0:g=(w[(d+B(K,872)|0)+1075798|0]>>>4|0)+g|0;break mc;case 1:break nc;default:break mc}}g=(w[(d+B(K,872)|0)+1075798|0]&15)+g|0}if(!(v[d+480180>>2]&67633408|w[(d+B(K,872)|0)+1075789|0]!=(g&255))){a=r+8|0;Db(a,f,82);if(!Cb(a)){break fc}}c=p;a=d;h=a;if(w[a+480210|0]&32){e=g&255;if((e|0)==85){v[p+36>>2]=2147483647;break fc}g=e>>>0>85?g-37|0:g}a=d+B(K,872)|0;Qa=c,Ra=_g(h,g&255,u[a+1075764>>1],v[a+1075696>>2]),v[Qa+36>>2]=Ra;if(v[d+480180>>2]&71860480){v[a+1075692>>2]=v[p+36>>2];break fc}a=r+8|0;Db(a,f,82);if(!Cb(a)){break fc}t[(d+B(K,872)|0)+1075792|0]=g}gb=r+16|0;if(!(!(w[J|0]&33)|v[p+36>>2]==2147483647)){oc:{if(v[k+480180>>2]==2){a=452;c=3424;break oc}c=B(x[E+1075764>>1]>>>4&15,24);a=x[c+39318>>1]>>>1|0;a=a>>>0>452?a:452;c=x[c+39296>>1]<<1}Zd(p+36|0,a,c);Zd(Y,a,c)}Yz(k,b);a=v[R>>2]}pc:{if(!(a&256)|w[M|0]&64){break pc}a=p+16|0;Db(a,X,37);if(!Cb(a)){break pc}v[E+1075676>>2]=128}n=l&65535;rO(k,n);qc:{if(!q){break qc}a=oO(k,b,p+36|0);if((a|0)<0|!(w[R+1|0]&2)){break qc}if(!Dd(_)){break qc}Qq(v[_>>2],n,a>>>2&255,1)}rc:{if(w[E+1075782|0]!=8){break rc}sc:{tc:{a=w[E+1075783|0];switch(a-5|0){case 1:break rc;case 0:case 2:break sc;default:break tc}}if((a|0)!=26){break rc}}if(v[k+480180>>2]==4){if(w[M|0]&16){break rc}a=E+1075811|0;t[a|0]=w[a|0]+w[E+1075815|0];break rc}if(!(v[k+480180>>2]&16777248)){break rc}Il(b,w[E+1075784|0]);nO(k,n,p+36|0,p+44|0)}nO(k,n,p+36|0,p+44|0);uc:{if(!q){break uc}v[p+32>>2]=0;d=k;h=p+36|0;r=gb-16|0;gb=r;g=b;A=v[b+104>>2];vc:{if(!A|!w[A+40|0]){break vc}i=Mj(g);m=Hj(d);a=r+8|0;Db(a,d+1074312|0,21);c=m?44608:43584;f=m?43584:44608;if(!(i|!Cb(a)|v[d+480180>>2]==1048576)){if(!w[A+41|0]){break vc}e=w[g+818|0];v[r+4>>2]=v[g+756>>2]+w[A+39|0];dk(r+4|0,w[A+40|0]<<8);a=v[r+4>>2];v[g+756>>2]=a;q=(a|0)/256|0;v[r+4>>2]=q;t[g+818|0]=w[g+818|0]+w[A+41|0];wc:{xc:{switch(w[A+38|0]-1|0){case 3:a=lO(Co(d))+-64|0;q=v[r+4>>2];break wc;case 2:a=64-(e+1>>>1|0)|0;break wc;case 1:a=(e+1>>>1|0)+-64|0;break wc;case 0:a=(e>>>1^-1)&64;break wc;default:break xc}}a=t[e+39888|0]}dk(h,8388607);i=v[h>>2]<<8;v[h>>2]=i;e=B(a,q);a=(e|0)/64|0;d=a>>31;g=d^a+d;a=g>>>2|0;d=h;yc:{if((e|0)<=-64){a=v[(a<<2)+c>>2];c=Ac(lqa(kqa(a,a>>31,i,i>>31),jb,65536,0),jb);a=v[h>>2];e=c-a|0;f=e;c=g&3;if(!c){break yc}c=v[(c<<2)+(m?43520:43456)>>2];c=Ac(lqa(kqa(c,c>>31,a,a>>31),jb,65536,0),jb)+e|0;a=v[h>>2];f=c-a|0;break yc}a=v[f+(a<<2)>>2];c=Ac(lqa(kqa(a,a>>31,i,i>>31),jb,65536,0),jb);a=v[h>>2];e=c-a|0;f=e;c=g&3;if(!c){break yc}c=v[(c<<2)+(m?43456:43520)>>2];c=Ac(lqa(kqa(c,c>>31,a,a>>31),jb,65536,0),jb)+e|0;a=v[h>>2];f=c-a|0}v[d>>2]=(a+f|0)/256;v[p+32>>2]=f&255;break vc}zc:{if(!(w[A+39|0]|v[d+480180>>2]&16777248)){v[g+756>>2]=w[A+40|0]<<8;break zc}Ac:{Bc:{if(v[d+480180>>2]&16777248){q=w[A+39|0]<<1;e=v[g+756>>2];a=g+756|0;break Bc}if(w[g+89|0]&8){break Ac}e=((w[A+40|0]<<8&65280)>>>0)/w[A+39|0]|0;q=v[g+756>>2];a=g+756|0}v[a>>2]=e+q}dk(g+756|0,w[A+40|0]<<8)}a=w[g+818|0]+w[A+41|0]|0;t[g+818|0]=a;a=a<<24>>24;Cc:{Dc:{switch(w[A+38|0]-1|0){case 3:t[g+818|0]=a+1;e=t[(a&63)+39824|0];break Cc;case 2:e=(64-(a>>>1|0)&127)+-64|0;break Cc;case 1:e=((a>>>1|0)- -64&127)+-64|0;break Cc;case 0:e=(a|0)>=0?-64:64;break Cc;default:break Dc}}a=w[g+818|0];e=0-t[a+39888|0]|0;if(v[d+480180>>2]!=1048576){break Cc}e=(64-t[(a+-64&255)+39888|0]|0)/2<<16>>16}a=e;q=B(a,v[g+756>>2]);e=(q|0)/256|0;if(i){z[p+44>>2]=z[p+44>>2]+C(C(C(C(w[A+40|0])*C(.05000000074505806))*C(a|0))*C(.000244140625));t[g+851|0]=w[g+851|0]|32;break vc}if(v[d+480180>>2]!=4){Ec:{if((q|0)<=-256){e=0-e|0;a=0-q>>>16|0;f=(a<<2)+c|0;break Ec}c=f;a=(q|0)/65536|0;f=c+(a<<2)|0}d=v[h>>2];c=v[((a<<2)+c|0)+4>>2];a=v[f>>2];a=((B(c-a|0,(e|0)/4&63)|0)/64|0)+a|0;a=Ac(lqa(kqa(d,d>>31,a,a>>31),jb,256,0),jb);v[h>>2]=a;v[p+32>>2]=a&255;v[h>>2]=v[h>>2]/256;break vc}v[h>>2]=v[h>>2]+((q|0)/16384|0)}gb=r+16|0;if(v[p+36>>2]<=v[k+480260>>2]){a=p+16|0;Db(a,X,81);if(Cb(a)){v[E+1075068>>2]=0}v[p+36>>2]=v[k+480260>>2]}Fc:{if(!Mj(b)){break Fc}c=E+1075843|0;a=w[c|0];if(!(v[k+1074392>>2]|!(a&16)?a&32:1)){break Fc}HS(b,z[p+44>>2],u[p+42>>1],k);a=w[c|0];t[c|0]=(a&32?-33:-17)&a}a=p+16|0;Xz(a,k,b,v[p+36>>2],v[p+32>>2]);h=wb(a);f=kqa(v[a>>2],v[a+4>>2],v[k+480240>>2],0);c=jb;d=lqa(f,c,65536,0);e=jb;g=d;d=f+65535|0;c=d>>>0<65535?c+1|0:c;d=!c&d>>>0<131071;c=d?1:g;v[a>>2]=c;f=a;a=d?0:e;v[f+4>>2]=a;v[Z>>2]=c;v[Z+4>>2]=a;if((v[R>>2]&134219264)!=512){break uc}if(!Dd(_)){break uc}a=p+8|0;Db(a,X,99);if(!(!(Cb(a)|!(w[R+1|0]&16))&v[k+480180>>2]!=2)){Gc:{if(w[R+1|0]&8?v[k+480180>>2]==2:0){break Gc}a=kqa(v[h>>2],0,261625,0)+66904|0;d=jb;e=Qc(nqa(a,a>>>0<66904?d+1|0:d,133808,0),jb);c=v[R>>2];a=1;Hc:{if(c&2048){break Hc}a=0;if(!(c&4096)){break Hc}a=!v[E+1075688>>2]}c=p+8|0;Db(c,X,110);if(Qa=Cb(c),Ra=0,Ta=a,Ta?Qa:Ra){break Gc}d=v[_>>2];c=p+8|0;Db(c,X,95);$A(d,n,e,a,Cb(c))}d=v[_>>2];a=kqa(B(v[E+1075744>>2],B(v[E+1075740>>2],v[o>>2])),0,63,0)+33554432|0;c=jb;c=a>>>0<33554432?c+1|0:c;Qq(d,n,Qc((c&67108863)<<6|a>>>26,c>>>26|0)&255,0);a=E+1075676|0;c=a;e=v[a>>2];a=0;f=v[_>>2];d=Ol(f,n);Ic:{if((d|0)==255){break Ic}if(wk(f)){break Ic}a=ic(aB(f+314|0,d),10);f=v[f>>2];d=Hu(d)|192;a=w[a|0]&-49;a=(e|0)<171?a|16:a;a=((e|0)>84?a|32:a)&255;Yh(f,d,a);a=(a>>>5&1)+(a<<27>>31)|0}v[c>>2]=(a<<7)+128}Jc:{a=v[V>>2];if(!a|(w[a+60|0]&7)!=1){break Jc}a=a+48|0;if(cd(a)){break Jc}c=v[mO(b,0)>>2];a=wo(a);if(c>>>0<x[a>>1]|w[a+2|0]){break Jc}Oi(v[_>>2],n,1);a=p+8|0;Db(a,X,109);c=Cb(a);a=v[R>>2];v[R>>2]=(c?a:a&-4609)|4096;v[E+1075688>>2]=0;break uc}a=p+8|0;Db(a,X,99);if(!Cb(a)|!(w[R+1|0]&16)|v[E+1075688>>2]){break uc}Oi(v[_>>2],n,1);v[R>>2]=v[R>>2]&-513}Kc:{if(!s){break Kc}a=p+16|0;Db(a,X,31);if(Cb(a)){break Kc}du(k,b)}a=v[R>>2];c=a&-65537;i=E+1075012|0;g=E+1075016|0;v[R>>2]=v[i>>2]|(v[g>>2]|v[ba>>2])?(c|a<<7&65536)^65536:c;f=E+1075664|0;v[f>>2]=0;v[f+4>>2]=0;m=E+1075834|0;a=w[m|0];c=a-4|0;t[m|0]=a>>>0<c>>>0?0:c;q=E+1075835|0;a=w[q|0];c=a-4|0;t[q|0]=a>>>0<c>>>0?0:c;Lc:{Mc:{Nc:{Oc:{Pc:{Qc:{c=E+1075096|0;a=v[c>>2];Rc:{if(!a){break Rc}if(!Jd(a)|!v[E+1075068>>2]){break Rc}if(Mi(b)){break Qc}}e=E+1075008|0;v[e>>2]=0;break Pc}e=E+1075008|0;a=v[v[c>>2]+20>>2];v[e>>2]=a;if(a){break Oc}}if(!tk(b)|w[R+1|0]&24){break Nc}}d=v[ba>>2];h=v[E+1075676>>2];a=(B(d,256-h|0)|0)/16384|0;c=a>>>0<127?a:127;a=t[m|0];if((a|0)<0){t[m|0]=c;r=c}else{r=a}a=c>>>1|0;if((r&255)>>>0<a>>>0){t[m|0]=a}a=(B(d,h)|0)/16384|0;d=a>>>0<127?a:127;a=d>>>1|0;h=a;c=t[q|0];if((c|0)<0){t[q|0]=d;c=d}if((c&255)>>>0<h>>>0){break Mc}break Lc}if(w[m|0]>=129){t[m|0]=0}a=0;if(w[q|0]<129){break Lc}}t[q|0]=a}Sc:{Tc:{if(v[e>>2]){q=128;if(y[k+24624>>2]>=2){q=Lb(v[E+1075676>>2],0,256)}v[p+16>>2]=q;h=B(j,v[ba>>2])>>>(w[aa+34|0]?7:8)|0;g=E+1075668|0;a=g;Uc:{Vc:{Wc:{switch(w[aa+32|0]){case 0:if(!(w[k+24616|0]&16)){break Vc}case 1:if((q|0)<=127){v[f>>2]=h>>>1;c=(B(h,q)|0)/256|0;break Uc}v[f>>2]=(B(h,256-q|0)|0)/256;c=h>>>1|0;break Uc;case 3:break Wc;default:break Vc}}dk(p+16|0,255);c=f;e=v[p+16>>2];if((e|0)<=0){d=65536}else{d=x[(0-e<<1)+46144>>1]}v[c>>2]=B(d,h)>>>16;c=B(h,x[(e<<1)+45632>>1])>>>16|0;break Uc}v[f>>2]=(B(h,256-q|0)|0)/256;c=(B(h,q)|0)/256|0}v[a>>2]=c;e=E+1075786|0;d=e;Xc:{Yc:{a=v[V>>2];if(!a){break Yc}if(!vp(w[a+14|0])){break Yc}c=w[v[V>>2]+14|0];break Xc}if(vp(w[k+480268|0])){c=w[k+480268|0];break Xc}a=w[k+24648|0];c=w[J|0]&128?v[k+24668>>2]?-1:a:a}t[d|0]=c;h=v[R>>2];a=v[Z>>2];d=v[Z+4>>2];if(!(h&131072|((a|0)!=0|(d|0)!=1)|(v[E+1075748>>2]|(c&255)==255))){t[e|0]=0}c=1<<v[aa+28>>2];v[f>>2]=v[f>>2]/(c|0);c=v[g>>2]/(c|0)|0;v[g>>2]=c;if(!(!(h&256)|v[k+24624>>2]!=2)){v[g>>2]=0-c}if(h&128){v[Z>>2]=0-a;v[Z+4>>2]=0-(((a|0)!=0)+d|0)}i=k;e=0;o=gb-16|0;gb=o;f=b;v[b+28>>2]=0;v[b+32>>2]=0;h=b;Zc:{_c:{g=v[b+88>>2];if(!(g&65536)){a=v[f+676>>2];b=v[f+672>>2];break _c}b=v[f+20>>2];c=v[f+672>>2];$c:{if((b|0)!=(c|0)){a=v[f+24>>2];d=v[f+676>>2];break $c}a=v[f+24>>2];d=v[f+676>>2];if((a|0)==(d|0)){break _c}}g=i+24604|0;d=(a|0)<(d|0)|(b|0)<(c|0);ad:{if(d){b=KS(g);break ad}b=JS(g)}Db(o,i+1074312|0,4);if(!(!Cb(o)|!(v[i+480180>>2]&4))){a=v[i+24620>>2];a=kqa(a,a>>31,5,0)+500|0;c=jb;b=Ac(lqa(a,a>>>0<500?c+1|0:c,1e3,0),jb)}c=v[f+656>>2];bd:{if(!c){a=b;break bd}a=b;if(!d){break bd}c=x[c+12>>1];if(c){a=(B(c,v[i+24620>>2])>>>0)/1e5|0}e=(c|0)!=0}g=a?a:1;c=v[f+676>>2];r=v[f+24>>2];m=c-r<<12;d=v[f+672>>2];q=v[f+20>>2];a=d-q<<12;if(!(w[f+90|0]&32|(!(c|d)|(!(q|r)|e)))){v[o+12>>2]=v[i+1074380>>2];Zd(o+12|0,b,2048);d=v[f+672>>2];g=v[o+12>>2];c=v[f+676>>2]}i=(m|0)/(g|0)|0;v[f+32>>2]=i;e=(a|0)/(g|0)|0;v[f+28>>2]=e;a=((B(g,i)|0)/-4096|0)+c|0;v[f+24>>2]=a;b=((B(e,g)|0)/-4096|0)+d|0;v[f+20>>2]=b;if(e|i){v[f+100>>2]=g;c=v[f+88>>2];break Zc}v[f+24>>2]=c;v[f+20>>2]=d;a=c;b=d;c=v[f+88>>2]&-65537;break Zc}v[f+24>>2]=a;v[f+20>>2]=b;c=g&-65537}v[h+88>>2]=c&-2097153;v[f+40>>2]=a<<12;v[f+36>>2]=b<<12;gb=o+16|0;if(!(w[R+1|0]&2)){break Tc}break Sc}v[i>>2]=0;v[g>>2]=0;v[E+1075068>>2]=0;if(v[E+1075088>>2]){break Tc}if(!v[E+1075084>>2]){break Sc}}a=x[k+480212>>1];u[k+480212>>1]=a+1;u[(k+(a<<1)|0)+1074478>>1]=l}v[E+1075660>>2]=v[R>>2]}l=l+1|0;if((l|0)!=256){continue}break}q=1;if(y[k+24608>>2]>x[k+480212>>1]){break vb}g=k+1074478|0;j=g;c=g+(v[k+24608>>2]<<1)|0;e=g+(x[k+480212>>1]<<1)|0;h=gb-16|0;gb=h;v[h+8>>2]=k;f=h+8|0;d=f;a=c-g|0;if((a|0)>=3){b=a>>1;i=(b-2|0)/2|0;while(1){Qz(g,d,b,g+(i<<1)|0);a=(i|0)>0;i=i-1|0;if(a){continue}break}}if((c|0)!=(e|0)){b=c-j>>1;a=c;while(1){if(vq(f,x[a>>1],x[j>>1])){Rz(a,j);Qz(j,f,b,j)}a=a+2|0;if((e|0)!=(a|0)){continue}break}}a=c-j|0;if((a|0)>=3){a=a>>>1|0;while(1){c=c-2|0;Rz(j,c);b=a-1|0;Qz(j,f,b,j);d=a>>>0>2;a=b;if(d){continue}break}}gb=h+16|0}gb=p+48|0;if(q){a=v[N+480208>>2];break j}b=v[N+480208>>2]|512;if(w[N+1298380|0]){break k}a=0;b=v[N+24620>>2]/10|0;h=Ac(b,b>>31);cd:{if(!h){break cd}f=h>>>0<1048576?h:1048576;v[k+1074380>>2]=f;d=x[k+480212>>1];if(!d){break cd}e=k+1074376|0;while(1){g=e+B(x[(e+(a<<1)|0)+102>>1],872)|0;b=g+1288|0;v[b>>2]=0;v[b+4>>2]=0;v[g+716>>2]=f;c=v[g+640>>2]<<12;v[g+656>>2]=c;b=v[g+636>>2]<<12;v[g+652>>2]=b;v[g+704>>2]=v[g+704>>2]|65536;v[g+644>>2]=(0-b|0)/(f|0);v[g+648>>2]=(0-c|0)/(f|0);a=a+1|0;if((d|0)!=(a|0)){continue}break}}a=v[N+480208>>2];b=a|256;if(h){break k}b=a|512}a=b;v[T+480208>>2]=a}if(a&512){Qa=N+1074392|0,Ra=uk(Pa),v[Qa>>2]=Ra;break i}v[W+112>>2]=512;a=v[N+1074380>>2];v[W+108>>2]=3;v[W+120>>2]=ua;v[W+116>>2]=a;v[W+104>>2]=W+112;a=v[W+108>>2];v[W+48>>2]=v[W+104>>2];v[W+52>>2]=a;f=PX(W+48|0);if(v[N+24632>>2]){c=N;b=Ca;i=0;j=gb-48|0;gb=j;a=f;g=a<<2;while(1){v[j+32>>2]=0;e=(c+(i<<11)|0)+16396|0;h=(e+g|0)-e>>2;if((h|0)>0){while(1){v[e>>2]=v[j+32>>2];e=e+4|0;d=h>>>0>1;h=h-1|0;if(d){continue}break}}i=i+1|0;if((i|0)!=4){continue}break}i=0;while(1){v[(j+32|0)+(i<<2)>>2]=(c+(i<<11)|0)+16396;i=i+1|0;if((i|0)!=4){continue}break}d=mg(j+16|0,j+32|0,v[c+24632>>2],a);c=v[v[b>>2]+8>>2];v[j+8>>2]=v[d+8>>2];a=v[d+4>>2];v[j>>2]=v[d>>2];v[j+4>>2]=a;kb[c|0](b,j);gb=j+48|0}if(w[ia+12|0]){a=0;while(1){v[(W+112|0)+(a<<2)>>2]=((a<<11)+N|0)+16396;a=a+1|0;if((a|0)!=4){continue}break}c=v[ia+8>>2];d=mg(W+88|0,W+112|0,v[N+24632>>2],f);b=v[v[c>>2]+8>>2];v[W+40>>2]=v[d+8>>2];a=v[d+4>>2];v[W+32>>2]=v[d>>2];v[W+36>>2]=a;kb[b|0](c,W+32|0)}A=N;ya=0;b=gb-112|0;gb=b;l=f;if(f){M=A+12|0;T=A+24592|0;n=A+24588|0;Vo(M,l,T,n);if(y[A+24624>>2]>=3){Vo(A+8204|0,l,A+24600|0,A+24596|0)}u[b+30>>1]=0;if(x[A+480212>>1]){Ga=A+1074312|0;G=A+24648|0;I=A+24596|0;E=A+24600|0;K=A+8204|0;o=A+397452|0;r=A+397448|0;m=A+393352|0;p=A+397456|0;$=A+1074376|0;while(1){J=$+(ya<<1)|0;c=B(x[J+102>>1],872);g=c+$|0;ka=g;dd:{ed:{if(v[g+632>>2]){break ed}a=c+A|0;if(v[a+1075088>>2]){break ed}if(!v[a+1075084>>2]){break dd}}s=c+A|0;a=w[s+1075786|0]+1|0;if((a&255)>>>0<=5){j=v[(a<<24>>24<<2)+34080>>2]}else{j=0}da=s+1075080|0;k=v[da>>2];fd:{if(!(!(k&16777216)&w[A+24612|0]>>>5)){d=n;c=M;q=k;a=T;if(!(k&8388608)){break fd}}h=m;e=r;d=o;c=l;a=p;if(!w[a+12|0]){Vo(h,c,e,d)}t[a+12|0]=1;q=v[da>>2];c=m;a=r}e=d;d=q>>>8&y[A+24624>>2]>2;H=d?I:e;ma=d?E:a;i=d?K:c;va=Lm(A,x[J+102>>1],2,1);gd:{if((va-1&255)>>>0>249){break gd}c=v[(A+B(va,160)|0)+906140>>2];if(!c){break gd}a=v[c+24>>2];if(!a){break gd}H=c+36|0;ma=c+40|0;if(!(t[c+28|0]&1)){Vo(a,l,ma,H);v[c+28>>2]=v[c+28>>2]|1}i=a}g=g+616|0;if(w[s+1075843|0]&4){LS(g,i,l);a=s+1075084|0;v[ma>>2]=v[ma>>2]+v[a>>2];v[H>>2]=v[H>>2]+v[s+1075088>>2];v[a>>2]=0;v[a+4>>2]=0;break dd}ea=0;q=gb-16|0;gb=q;za=b+8|0;d=za;v[d>>2]=0;v[d+4>>2]=0;v[d+8>>2]=0;v[d+12>>2]=0;c=q+8|0;a=A+1074312|0;Db(c,a,33);Qa=d,Ra=Cb(c),t[Qa+16|0]=Ra;Db(c,a,116);Qa=d,Ra=Cb(c)^1,t[Qa+17|0]=Ra;a=g;if(v[a+16>>2]){qF(za,a);e=v[a+12>>2];d=e;c=v[a+8>>2];a=d>>31;e=c+a|0;d=a+d|0;d=a>>>0>e>>>0?d+1|0:d;a=a^d;v[za+12>>2]=a>>>0>8191?2:16384/(a+1>>>0)|0}R=k>>>12&8|(k>>>5&2|(j|k&1));fa=s+1075795|0;X=s+1075778|0;_=s+1075688|0;Y=s+1075024|0;ba=s+1075020|0;Z=s+1075668|0;aa=s+1075664|0;ja=s+1075e3|0;na=s+1075088|0;oa=s+1075084|0;pa=s+1075016|0;qa=s+1075012|0;Aa=s+1075096|0;ra=s+1075076|0;ga=s+1075068|0;wa=s+1075072|0;sa=s+1075092|0;gb=q+16|0;a=l;while(1){hd:{c=v[sa>>2];Ba=c?a>>>0>c>>>0?c:a:a;v[b+68>>2]=Ba;V=v[wa>>2];d=v[da>>2];k=v[ja+4>>2];j=v[ja>>2];v[b+56>>2]=j;v[b+60>>2]=k;id:{jd:{if(!Ba|!(j|k)){break jd}J=v[ga>>2];if(!J){break jd}c=v[b+8>>2];if(!c){break jd}v[ka+632>>2]=c;c=v[g+4>>2];e=c;h=v[g>>2];kd:{ld:{q=V&d<<30>>31;if((q|0)>(c|0)){if((k|0)<0){v[b+104>>2]=0;c=q;v[b+108>>2]=c<<1;h=bg(b+104|0,g);d=jb;e=d;v[g>>2]=h;v[g+4>>2]=d;if(!(d>>>0<c+v[ga>>2]>>>1>>>0&(c|0)<=(d|0))){d=g;h=0;v[d>>2]=h;e=c;v[d+4>>2]=c}d=v[da>>2];md:{if(d&4){d=d&-129;v[da>>2]=d;k=0-(((j|0)!=0)+k|0)|0;j=0-j|0;v[b+56>>2]=j;v[b+60>>2]=k;v[ja>>2]=j;v[ja+4>>2]=k;break md}c=v[ga>>2]-1|0;e=c;v[g>>2]=h;v[g+4>>2]=c}nd:{if(!(d&2)){d=v[ga>>2];break nd}d=v[ga>>2];if(e>>>0<d>>>0){break kd}}e=g;v[e>>2]=0;v[e+4>>2]=d;break jd}if((e|0)>0|(e|0)>=0){break kd}e=0;break ld}if(c>>>0<J>>>0){break kd}if(!(d&2)){break jd}if(d&4){if(!!j&(k|0)>=0|(k|0)>0){k=0-(((j|0)!=0)+k|0)|0;j=0-j|0;v[b+56>>2]=j;v[b+60>>2]=k;v[ja>>2]=j;v[ja+4>>2]=k}v[da>>2]=d|128;if(w[b+25|0]){v[b+96>>2]=0;v[b+100>>2]=J;Qa=b,Ra=bg(g,b+96|0),v[Qa+104>>2]=Ra;d=jb;v[b+108>>2]=d;e=v[wa>>2];h=w[b+24|0];if(v[ra>>2]-(e+h|0)>>>0>d>>>0){e=v[ga>>2]-h|0;v[b+96>>2]=0;v[b+100>>2]=e;h=bg(b+96|0,b+104|0);e=jb;break ld}h=0;break ld}s=(J<<1)-((1-((h|0)!=0)|0)+c|0)|0;c=s;h=0-h|0;e=c;d=g;v[d>>2]=h;v[d+4>>2]=c;if(c>>>0<J>>>0&c>>>0>V>>>0){break kd}v[b+104>>2]=w[b+24|0]+1;c=J-v[Fb(ga,b+104|0)>>2]|0;h=v[g>>2];e=c;break ld}if((k|0)<0){k=0-(((j|0)!=0)+k|0)|0;j=0-j|0;v[b+56>>2]=j;v[b+60>>2]=k;v[ja>>2]=j;v[ja+4>>2]=k}v[b+104>>2]=0;v[b+108>>2]=q-J;Ub(g,b+104|0);v[da>>2]=v[da>>2]|8192;h=v[g>>2];e=v[g+4>>2];break kd}v[g>>2]=h;v[g+4>>2]=e}v[b+48>>2]=h;c=e;v[b+52>>2]=c;xa=c;od:{if((c|0)<(q|0)){if((e|0)<0){break jd}if((k|0)>0|(k|0)>=0){break od}break jd}if((e|0)<0){break jd}}if(xa>>>0>=y[ga>>2]){break jd}v[b+44>>2]=Ba;qc(b+68|0,v[b+20>>2]);Qa=b,Ra=Fw(b+56|0,v[b+68>>2]-1|0),v[Qa+32>>2]=Ra;v[b+36>>2]=jb;s=j;d=k;j=d>>31;c=j;V=c;J=s+c|0;j=c;d=c+d|0;d=c>>>0>J>>>0?d+1|0:d;s=J;J=v[wa>>2];ta=J+16|0;c=v[b+36>>2]+v[b+52>>2]|0;k=v[b+48>>2];F=k+v[b+32>>2]|0;c=k>>>0>F>>>0?c+1|0:c;k=J>>>0>xa>>>0;if(!(!k&ta>>>0>xa>>>0)){v[da>>2]=v[da>>2]&-8193}s=s^V;J=d^j;d=c;pd:{qd:{rd:{if(!v[b+12>>2]){k=v[b+60>>2];break rd}c=v[b+16>>2];if(c>>>0<=xa>>>0){j=b;sd:{if(v[b+60>>2]<0){v[b+96>>2]=h;v[b+100>>2]=e;v[b+104>>2]=0;v[b+108>>2]=c;Qa=b,Ra=bg(b+96|0,b+104|0),v[Qa+80>>2]=Ra;v[b+84>>2]=jb;v[b+72>>2]=1;v[b+76>>2]=0;Qa=b,Ra=bg(b+80|0,b+72|0),v[Qa+88>>2]=Ra;v[b+92>>2]=jb;c=Jn(b+88|0,s,J);break sd}d=v[ra>>2];v[b+104>>2]=h;v[b+108>>2]=e;v[b+96>>2]=0;v[b+100>>2]=d;Qa=b,Ra=bg(b+96|0,b+104|0),v[Qa+80>>2]=Ra;v[b+84>>2]=jb;v[b+72>>2]=1;v[b+76>>2]=0;Qa=b,Ra=bg(b+80|0,b+72|0),v[Qa+88>>2]=Ra;v[b+92>>2]=jb;c=Jn(b+88|0,s,J)}v[j+44>>2]=c+1;v[ka+632>>2]=v[b+12>>2];break pd}if(!(!(w[da+1|0]&32)|k|ta>>>0<=xa>>>0)){v[b+104>>2]=h;v[b+108>>2]=e;v[b+96>>2]=0;v[b+100>>2]=q+16;Qa=b,Ra=bg(b+96|0,b+104|0),v[Qa+80>>2]=Ra;v[b+84>>2]=jb;v[b+72>>2]=1;v[b+76>>2]=0;Qa=b,Ra=bg(b+80|0,b+72|0),v[Qa+88>>2]=Ra;v[b+92>>2]=jb;Qa=b,Ra=Jn(b+88|0,s,J)+1|0,v[Qa+44>>2]=Ra;Qa=ka,Ra=v[b+12>>2]+B(v[ra>>2]-q|0,jj(v[Aa>>2]))|0,v[Qa+632>>2]=Ra;break pd}j=v[b+60>>2];k=j;if(!v[b+56>>2]&(j|0)<=0|(j|0)<0){break rd}if(Ba>>>0<2|c>>>0>d>>>0){break qd}v[b+104>>2]=h;v[b+108>>2]=e;v[b+96>>2]=0;v[b+100>>2]=c;Qa=b,Ra=bg(b+96|0,b+104|0),v[Qa+80>>2]=Ra;v[b+84>>2]=jb;v[b+72>>2]=1;v[b+76>>2]=0;Qa=b,Ra=bg(b+80|0,b+72|0),v[Qa+88>>2]=Ra;v[b+92>>2]=jb;Qa=b,Ra=Jn(b+88|0,s,J)+1|0,v[Qa+44>>2]=Ra;break pd}if((k|0)>0|(k|0)>=0){break qd}if((d|0)>=(q|0)){break pd}v[b+96>>2]=h;v[b+100>>2]=e;v[b+104>>2]=0;v[b+108>>2]=q;Qa=b,Ra=bg(b+96|0,b+104|0),v[Qa+80>>2]=Ra;v[b+84>>2]=jb;v[b+72>>2]=1;v[b+76>>2]=0;Qa=b,Ra=bg(b+80|0,b+72|0),v[Qa+88>>2]=Ra;v[b+92>>2]=jb;Qa=b,Ra=Jn(b+88|0,s,J)+1|0,v[Qa+44>>2]=Ra;break pd}c=v[ga>>2];if((c|0)>(d|0)){break pd}v[b+104>>2]=h;v[b+108>>2]=e;v[b+96>>2]=0;v[b+100>>2]=c;Qa=b,Ra=bg(b+96|0,b+104|0),v[Qa+80>>2]=Ra;v[b+84>>2]=jb;v[b+72>>2]=1;v[b+76>>2]=0;Qa=b,Ra=bg(b+80|0,b+72|0),v[Qa+88>>2]=Ra;v[b+92>>2]=jb;Qa=b,Ra=Jn(b+88|0,s,J)+1|0,v[Qa+44>>2]=Ra}Gp(b+44|0,1,v[b+68>>2]);k=v[b+44>>2];if((k|0)>0){break id}}v[ka+632>>2]=0;v[ga>>2]=0;v[g>>2]=0;v[g+4>>2]=0;v[sa>>2]=0;LS(g,i,a);v[ma>>2]=v[ma>>2]+v[oa>>2];v[H>>2]=v[H>>2]+v[na>>2];v[na>>2]=0;v[oa>>2]=0;v[da>>2]=v[da>>2]&-129;j=x[b+30>>1];break hd}td:{ud:{j=x[b+30>>1];if(j>>>0<y[A+24608>>2]){ea=4;if(v[sa>>2]){break ud}ea=0;if(v[pa>>2]|v[qa>>2]){break ud}}Qa=b,Ra=kqa(v[ja>>2],v[ja+4>>2],k,k>>31),v[Qa+104>>2]=Ra;v[b+108>>2]=jb;Ub(g,b+104|0);ea=0;v[na>>2]=0;v[oa>>2]=0;c=(k<<3)+i|0;break td}c=(k<<3)+i|0;e=c-8|0;v[oa>>2]=0-v[e>>2];d=c-4|0;v[na>>2]=0-v[d>>2];kb[v[((R|ea)<<2)+33696>>2]](g,G,i,k);v[oa>>2]=v[oa>>2]+v[e>>2];v[na>>2]=v[na>>2]+v[d>>2];ea=1}i=c;c=v[sa>>2];vd:{if(!c){break vd}if(c>>>0<=k>>>0){v[sa>>2]=0;v[qa>>2]=v[aa>>2];v[pa>>2]=v[Z>>2];v[ba>>2]=0;v[Y>>2]=0;if(v[_>>2]|!(w[da+1|0]&16)){break vd}v[ga>>2]=0;v[ka+632>>2]=0;break vd}v[sa>>2]=c-k}h=0;d=0;c=v[g+4>>2];d=c>>>0>=y[ra>>2]?(w[da|0]&2)>>>1|0:d;e=c;c=v[ga>>2];h=e>>>0<c>>>0|(!c|w[da|0]&2)?h:!x[X>>1];a=a-k|0;c=b+104|0;Db(c,Ga,85);wd:{xd:{yd:{zd:{if(!Cb(c)){break zd}c=w[fa|0];if(!c|c>>>0>x[A+480190>>1]){break zd}k=A+B(w[fa|0],104)|0;e=k+484380|0;c=v[Aa>>2];if((e|0)==(c|0)|(d|h)!=1){break yd}v[Aa>>2]=e;v[ka+632>>2]=v[k+484400>>2];c=x[k+484414>>1];v[da>>2]=c|v[da>>2]&-768;d=v[k+484388>>2];v[ga>>2]=d&c<<30>>31;c=v[k+484384>>2];v[wa>>2]=c;v[ra>>2]=d;v[g+4>>2]=c;qF(za,g);if(!v[ka+632>>2]){break hd}if((a|0)>0){continue}break hd}if(d){break xd}break wd}if(!d|(c|0)!=(e|0)){break wd}}c=b+104|0;Db(c,Ga,83);if(!Cb(c)|v[wa>>2]){break wd}v[g>>2]=v[g>>2];v[g+4>>2]=0;c=v[v[Aa>>2]+8>>2];v[ga>>2]=c;v[ra>>2]=c}if((a|0)>0){continue}}break}v[ka+632>>2]=v[b+8>>2];u[b+30>>1]=j+ea;if(!ea|!va|va>>>0>250){break dd}a=v[(A+B(va,160)|0)+906140>>2];if(!a){break dd}kb[v[v[a>>2]+148>>2]](a)}ya=ya+1|0;if(ya>>>0<x[A+480212>>1]){continue}break}}Qa=A,Ra=x[Le(A+480214|0,b+30|0)>>1],u[Qa+480214>>1]=Ra}gb=b+112|0;if(Dd(Fa)){a=la;q=f;b=(B(v[N+480232>>2],v[N+480236>>2])>>>0)/48|0;A=gb-16|0;gb=A;r=v[Fa>>2];Ad:{if(!w[r+530|0]){break Ad}b=kqa(b,0,6169,0);d=jb;c=d>>>16|0;T=Qc((d&65535)<<16|b>>>16,c);if(!q){break Ad}while(1){l=v[r>>2];j=v[l>>2];c=v[l+4>>2];if((j|0)<=(c|0)){g=l+14|0;e=l+12|0;while(1){v[l+8>>2]=v[l+12>>2];i=l;d=e;c=g;h=0;J=0;ea=0;k=gb-16|0;gb=k;while(1){s=i+B(ea,44)|0;Bd:{if(!w[s+56|0]){u[k+12>>1]=0;u[k+14>>1]=0;break Bd}b=v[s+32>>2];j=x[b+3840>>1];if(j&3){b=(x[s+36>>1]>>>7&7)>>>(w[b+3844|0]^1)>>>(j&1)<<x[s+38>>1];j=j&4?0-b|0:b}else{j=0}b=k;m=v[s+52>>2];Cd:{if(m){m=x[m+32>>1];o=x[s+48>>1];M=kg(v[s+16>>2],v[s+40>>2],j<<16>>16,0,u[s+46>>1]);n=v[s+40>>2];p=v[s+20>>2];if(!m){if(!o){m=j<<16>>16;j=kg(p,n,m,M,0);j=kg(v[s+24>>2],v[s+40>>2],m,j,0);j=kg(v[s+28>>2],v[s+40>>2],m,j,0);break Cd}m=j<<16>>16;j=kg(p,n,m,0,0);j=kg(v[s+24>>2],v[s+40>>2],m,j,0);j=kg(v[s+28>>2],v[s+40>>2],m,j,0)+M|0;break Cd}if(!o){o=j<<16>>16;m=kg(p,n,o,M,0);j=kg(v[s+24>>2],v[s+40>>2],o,0,0);j=kg(v[s+28>>2],v[s+40>>2],o,j,0)+m|0;break Cd}m=j<<16>>16;j=kg(p,n,m,0,0);j=(kg(v[s+24>>2],v[s+40>>2],m,j,0)+M|0)+kg(v[s+28>>2],v[s+40>>2],m,0,0)|0;break Cd}m=x[s+48>>1];n=j<<16>>16;p=kg(v[s+16>>2],v[s+40>>2],n,0,u[s+46>>1]);o=v[s+40>>2];j=v[s+20>>2];if(!m){j=kg(j,o,n,p,0);break Cd}j=kg(j,o,n,0,0)+p|0}u[b+14>>1]=w[s+57|0]?j:0;u[k+12>>1]=w[s+58|0]?j:0}h=u[k+12>>1]+h|0;J=u[k+14>>1]+J|0;ea=ea+1|0;if((ea|0)!=18){continue}break}b=(J|0)<32767?J:32767;u[d>>1]=(b|0)>-32768?b:-32768;b=(h|0)<32767?h:32767;u[c>>1]=(b|0)>-32768?b:-32768;u[i+3832>>1]=x[i+3832>>1]+1;b=(x[i+3834>>1]+1>>>0)%13440|0;u[i+3834>>1]=b;b=b>>>0<6720?b:13440-b|0;u[i+3836>>1]=(b&65280)>>>8;if(!w[i+3843|0]){u[i+3836>>1]=(b&64512)>>>10}b=x[i+3838>>1]+1|0;u[i+3838>>1]=b;if((b&65535)>>>0>=1024){u[i+3838>>1]=0;u[i+3840>>1]=x[i+3840>>1]+1&7}gb=k+16|0;j=v[l>>2];c=v[l+4>>2]-j|0;v[l+4>>2]=c;if((c|0)>=(j|0)){continue}break}}b=j-c|0;u[A+14>>1]=(B(u[l+12>>1],c)+B(b,u[l+8>>1])|0)/(j|0);u[A+12>>1]=(B(u[l+14>>1],c)+B(b,u[l+10>>1])|0)/(j|0);v[l+4>>2]=c+49716;v[a>>2]=v[a>>2]+B(T,u[A+14>>1]);v[a+4>>2]=v[a+4>>2]+B(T,u[A+12>>1]);a=a+8|0;q=q-1|0;if(q){continue}break}}gb=A+16|0}c=la;b=Na;r=Ma;m=La;a=f;j=Oa;d=w[j+12|0];if(v[j+16>>2]?1:d){if(!d){Vo(b,a,r,m)}i=v[j>>2];k=v[j+80>>2];d=B(i,k)>>>4|0;d=d>>>0<32767?d:32767;u[j+98>>1]=d;u[j+96>>1]=d;g=v[j+49948>>2];d=B(g,i)>>>4|0;d=d>>>0<65536?d:65536;e=d+127>>>3|0;u[j+49946>>1]=e;d=d+255>>>4|0;u[j+49944>>1]=d;u[j+49942>>1]=d;u[j+49940>>1]=e;h=c;d=b;e=(g|0)<(k|0)?k:g;g=(e|0)<32768?e:32768;e=36-i>>>1|0;e=16-(e>>>0>8?e:8)|0;i=16-(B(g,e>>>0>16?0:e)>>15)|0;n=0;e=a;if(a){while(1){k=n<<3;g=k+h|0;v[g>>2]=v[g>>2]+B(i,v[d+k>>2]>>4);k=k|4;g=k+h|0;v[g>>2]=v[g>>2]+B(i,v[d+k>>2]>>4);n=n+1|0;if((e|0)!=(n|0)){continue}break}}g=0;h=j;l=v[h+40>>2];n=v[h+36>>2];if(a){k=u[h+84>>1];while(1){i=(g<<3)+d|0;e=v[i>>2]>>12;n=(B(k,e-n|0)>>15)+e|0;v[i>>2]=n;e=v[i+4>>2]>>12;l=(B(k,e-l|0)>>15)+e|0;v[i+4>>2]=l;g=g+1|0;if((g|0)!=(a|0)){continue}break}}e=j+68|0;v[h+40>>2]=l;v[h+36>>2]=n;h=a;Dd:{if(!a){d=v[e>>2];break Dd}k=j+49892|0;g=e;fa=v[e>>2]-1|0;i=x[e+22>>1];V=u[e+26>>1];T=u[e+18>>1];$=v[e+4>>2];n=x[e+20>>1];s=u[e+24>>1];p=u[e+16>>1];A=e+32928|0;while(1){o=Lb(v[d>>2],-32768,32767);q=Lb(v[d+4>>2],-32768,32767);l=Lb((n<<16>>16)-o|0,-32768,32767);i=Lb((i<<16>>16)-q|0,-32768,32767);n=Uc(Lb((B(l,p)|0)/65536<<1,-32768,32767)+o|0);i=Uc(Lb((B(i,T)|0)/65536<<1,-32768,32767)+q|0);l=A+($<<2)|0;J=u[l+2>>1];o=u[l>>1];M=Uc(((B(o,s)|0)/-65536|0)+n|0);$=$+1&127;l=A+($<<2)|0;q=Uc(((B(J,V)|0)/-65536|0)+i|0);u[l+2>>1]=q;u[l>>1]=M;fa=fa+1&8191;l=g+(fa<<2)|0;Qa=l,Ra=Uc(o+((B(s,M)|0)/65536|0)|0),u[Qa+160>>1]=Ra;Qa=l,Ra=Uc(J+((B(q,V)|0)/65536|0)|0),u[Qa+162>>1]=Ra;d=d+8|0;a=a-1|0;if(a){continue}break}u[g+22>>1]=i;u[g+20>>1]=n;v[g+4>>2]=$;l=v[j+76>>2];G=j+33508|0;a=b;n=h;while(1){g=l&4095;$=G+(g<<2)|0;d=a;i=4096-g|0;J=l-v[j+49892>>2]&4095;g=4096-J|0;g=g>>>0>i>>>0?i:g;g=g>>>0<n>>>0?g:n;q=g>>>0<64?g:64;fa=q;l=0;V=gb-32|0;gb=V;g=e;i=v[e>>2];while(1){v[V+(l<<2)>>2]=i+(v[(g+(l<<4)|0)+32>>2]^-1);l=l+1|0;if((l|0)!=7){continue}break}i=u[g+28>>1]/8|0;if(fa){A=i<<16>>16;while(1){i=0;ea=0;l=0;while(1){o=V+(l<<2)|0;p=v[o>>2]+1&8191;v[o>>2]=p;o=g+(p<<2)|0;p=u[o+160>>1];T=g+(l<<4)|0;o=u[o+162>>1];ea=(B(p,u[T+44>>1])+ea|0)+B(o,u[T+46>>1])|0;i=(B(p,u[T+40>>1])+i|0)+B(o,u[T+42>>1])|0;l=l+1|0;if((l|0)!=4){continue}break}H=0;l=4;M=Uc((i|0)/32768|0);T=Uc((ea|0)/32768|0);i=0;while(1){o=V+(l<<2)|0;p=v[o>>2]+1&8191;v[o>>2]=p;K=i;i=g+(p<<2)|0;p=u[i+160>>1];s=g+(l<<4)|0;o=u[i+162>>1];i=(K+B(p,u[s+44>>1])|0)+B(o,u[s+46>>1])|0;H=(B(p,u[s+40>>1])+H|0)+B(o,u[s+42>>1])|0;l=l+1|0;if((l|0)!=7){continue}break}l=Uc(M+((H|0)/32768|0)|0);u[$>>1]=l;v[d>>2]=B(l,A);i=Uc(T+((i|0)/32768|0)|0);u[$+2>>1]=i;v[d+4>>2]=B(i,A);d=d+8|0;$=$+4|0;fa=fa-1|0;if(fa){continue}break}}gb=V+32|0;$=G+(J<<2)|0;g=a;i=k;l=v[i+4>>2];fa=l&2047;d=q;if(d){pa=i+8256|0;qa=i- -64|0;ta=i+24640|0;F=i+16448|0;while(1){I=u[(pa+((l+754&2047)<<2)|0)+2>>1];E=u[pa+((l+1206&2047)<<2)>>1];K=u[(qa+((l+1602&2047)<<2)|0)+2>>1];R=u[qa+((l+1750&2047)<<2)>>1];o=ta+((l+22&2047)<<2)|0;X=u[o+2>>1];_=u[o>>1];o=ta+((l+502&2047)<<2)|0;Y=u[o+2>>1];ba=u[$>>1];Z=u[$+2>>1];aa=u[o>>1];V=Lb(u[i+32>>1]-aa|0,-32768,32767);s=u[i+24>>1];A=Lb(u[i+34>>1]-Y|0,-32768,32767);J=u[i+26>>1];M=Lb(u[i+36>>1]-_|0,-32768,32767);T=u[i+28>>1];p=Lb(u[i+38>>1]-X|0,-32768,32767);o=u[i+30>>1];Qa=i,Ra=Uc(Lb((B(s,V)|0)/65536<<1,-32768,32767)+aa|0),u[Qa+32>>1]=Ra;Qa=i,Ra=Uc(Lb((B(A,J)|0)/65536<<1,-32768,32767)+Y|0),u[Qa+34>>1]=Ra;Qa=i,Ra=Uc(Lb((B(M,T)|0)/65536<<1,-32768,32767)+_|0),u[Qa+36>>1]=Ra;Qa=i,Ra=Uc(Lb((B(p,o)|0)/65536<<1,-32768,32767)+X|0),u[Qa+38>>1]=Ra;p=Lb((B(u[i+32>>1],u[i+16>>1])|0)/32768|0,-32768,32767);o=Lb((B(u[i+38>>1],u[i+22>>1])|0)/32768|0,-32768,32767);J=Lb(p+((ba|0)/4<<16>>16)|0,-32768,32767);M=Lb(o+((Z|0)/4<<16>>16)|0,-32768,32767);T=Lb(J+((B(R,u[i+8>>1])|0)/-65536|0)|0,-32768,32767);Z=fa<<2;p=Z+qa|0;o=Lb(M+((B(K,u[i+10>>1])|0)/-65536|0)|0,-32768,32767);u[p+2>>1]=o;u[p>>1]=T;T=Lb(R+((B(T,u[i+8>>1])|0)/65536|0)|0,-32768,32767);p=F+Z|0;o=Lb(K+((B(o,u[i+10>>1])|0)/65536|0)|0,-32768,32767);u[p+2>>1]=o;u[p>>1]=T;J=Lb(J+T|0,-32768,32767);M=Lb(o+M|0,-32768,32767);o=F+((l+426&2047)<<2)|0;T=u[o+2>>1];p=u[o>>1];l=F+((l+682&2047)<<2)|0;o=u[l+2>>1];l=u[l>>1];V=Lb((B(o,u[i+42>>1])+B(l,u[i+40>>1])|0)/32768|0,-32768,32767);aa=Lb((B(T,u[i+46>>1])+B(p,u[i+44>>1])|0)/32768|0,-32768,32767);s=Lb(Lb(l+J|0,-32768,32767)-V|0,-32768,32767);A=Lb(Lb(o+M|0,-32768,32767)-aa|0,-32768,32767);J=Lb(Lb(p+J|0,-32768,32767)-V|0,-32768,32767);M=Lb(Lb(M+T|0,-32768,32767)-aa|0,-32768,32767);V=Lb(V+((B(E,u[i+8>>1])|0)/-65536|0)|0,-32768,32767);p=u[i+8>>1];T=u[i+10>>1];l=Z+pa|0;o=Lb(aa+((B(I,u[i+10>>1])|0)/-65536|0)|0,-32768,32767);u[l+2>>1]=o;u[l>>1]=V;p=(B(p,V)|0)/65536|0;V=Lb(p+E|0,-32768,32767);l=Z+ta|0;T=(B(o,T)|0)/65536|0;o=Lb(T+I|0,-32768,32767);u[l+2>>1]=o;u[l>>1]=V;l=Lb(s+V|0,-32768,32767);Qa=g,Ra=(v[g>>2]+B(l,u[i+48>>1])|0)+B(Lb(o+A|0,-32768,32767),u[i+50>>1])|0,v[Qa>>2]=Ra;p=Lb(Lb(p,-32768,32767)+J|0,-32768,32767);o=u[i+52>>1];l=Lb(T,-32768,32767);Qa=g,Ra=(v[g+4>>2]+B(p,o)|0)+B(Lb(l+M|0,-32768,32767),u[i+54>>1])|0,v[Qa+4>>2]=Ra;g=g+8|0;$=$+4|0;l=fa+1|0;fa=l&2047;d=d-1|0;if(d){continue}break}}v[i+4>>2]=fa;l=q+v[j+76>>2]&4095;v[j+76>>2]=l;d=q+v[j+68>>2]&8191;v[j+68>>2]=d;a=(q<<3)+a|0;n=n-q|0;if(n){continue}break}}v[j+68>>2]=d&8191;d=b;g=c;i=0;q=0;b=j;n=v[b+56>>2];l=v[b+52>>2];c=h;if(c){a=v[b+60>>2];e=v[b+64>>2];while(1){i=v[d>>2];q=v[d+4>>2];e=e-q|0;e=(((e|0)/1024|0)-e|0)+n|0;v[g+4>>2]=e+v[g+4>>2];a=a-i|0;a=(((a|0)/1024|0)-a|0)+l|0;v[g>>2]=a+v[g>>2];n=e+((e|0)/-512|0)|0;l=a+((a|0)/-512|0)|0;g=g+8|0;d=d+8|0;e=q;a=i;c=c-1|0;if(c){continue}break}}v[b+64>>2]=q;v[b+60>>2]=i;v[b+56>>2]=n;v[b+52>>2]=l;a=v[j+20>>2];Ed:{if(w[j+12|0]){break Ed}a=v[j+16>>2];if(a>>>0>h>>>0){a=a-h|0;break Ed}VL(j,r,m);a=0}t[j+12|0]=0;v[j+16>>2]=a}if(v[N+946300>>2]){n=0;h=0;k=f;c=f<<2;j=N;$=x[j+480214>>1]!=0;a=j+1074332|0;ca=z[a>>2];Ha=z[a+4>>2];while(1){b=(j+B(n,160)|0)+906300|0;a=v[b>>2];Fd:{if(!a|!v[a+24>>2]){break Fd}if(!mi(a+44|0)){break Fd}g=v[b>>2];if(!(kb[v[v[g>>2]+112>>2]](g)|0)){kb[v[v[g>>2]+108>>2]](g,1);kb[v[v[g>>2]+120>>2]](g)}a=g+44|0;e=Nd(a,0);d=Nd(a,1);Gd:{if(t[g+28|0]&1){rB(v[g+24>>2],e,d,k,ca);break Gd}a=g+40|0;if(v[g+36>>2]?1:v[a>>2]){Vo(v[g+24>>2],k,a,g+36|0);rB(v[g+24>>2],e,d,k,ca);break Gd}Qb(e,0,c);Qb(d,0,c)}v[g+28>>2]=v[g+28>>2]&-2;if(Ew(b)){break Fd}$=!(w[g+28|0]&4)|$}n=n+1|0;if((n|0)!=250){continue}break}l=j+12|0;g=j+12300|0;e=j+14348|0;rB(l,g,e,k,ca);a=j+1074476|0;r=w[a|0];t[a|0]=0;a=g;c=e;while(1){A=(j+B(h,160)|0)+906300|0;b=v[A>>2];Hd:{if(!b|!v[b+24>>2]){break Hd}if(!mi(b+44|0)){break Hd}M=v[A>>2];Id:{if(Ew(A)){break Id}b=v[A>>2];if(kb[v[v[b>>2]+144>>2]](b)|w[v[A>>2]+28|0]&2){break Id}n=0;if(!h){break Hd}while(1){if((Wk((j+B(n,160)|0)+906300|0)|0)==(h|0)){break Id}n=n+1|0;if((n|0)!=(h|0)){continue}break}break Hd}b=M+44|0;T=Nd(b,0);o=Nd(b,1);J=v[A>>2];q=(a|0)==(T|0);a=q?g:a;b=a;c=q?e:c;d=c;Jd:{if(!(w[A+28|0]|w[A+29|0]<<8|(w[A+30|0]<<16|w[A+31|0]<<24))){break Jd}b=a;i=Wk(A);d=c;if(i>>>0>249){break Jd}d=c;if(h>>>0>=i>>>0){break Jd}i=v[(j+B(i,160)|0)+906300>>2];d=c;if(!i){break Jd}if(!(w[J+28|0]&4)){kb[v[v[i>>2]+148>>2]](i)}i=i+44|0;d=c;if(!mi(i)){break Jd}b=Nd(i,0);d=Nd(i,1)}Kd:{if(!Ew(A)){break Kd}Ld:{if(q){break Ld}n=0;if(!k){break Ld}while(1){p=n<<2;i=p+T|0;m=a+p|0;z[i>>2]=z[m>>2]+z[i>>2];q=p+o|0;i=c+p|0;z[q>>2]=z[i>>2]+z[q>>2];v[m>>2]=0;v[i>>2]=0;n=n+1|0;if((k|0)!=(n|0)){continue}break}}c=d;a=b;if(!($&1)){break Kd}a=v[A>>2];if(a){kb[v[v[a>>2]+148>>2]](a)}a=b;n=Wk(A);if(n>>>0>249|h>>>0>=n>>>0){break Kd}while(1){c=n&255;a=(j+B(c,160)|0)+906300|0;n=Wk(a);a=v[a>>2];if(a){kb[v[v[a>>2]+148>>2]](a)}if(c>>>0<n>>>0&n>>>0<=249){continue}break}c=d;a=b}Md:{Nd:{if(!((w[A+24|0]&2)>>>1|0)){if(!oF(A)|!(w[J+28|0]&4)){break Nd}}n=0;if(!k){break Md}while(1){q=n<<2;i=q+b|0;z[i>>2]=z[q+T>>2]+z[i>>2];i=d+q|0;z[i>>2]=z[o+q>>2]+z[i>>2];n=n+1|0;if((k|0)!=(n|0)){continue}break}break Md}if(r){kb[v[v[M>>2]+128>>2]](M)}kb[v[v[M>>2]+60>>2]](M,b,d,k);v[J+32>>2]=k+v[J+32>>2];if(!oF(A)){break Md}if((kb[v[v[M>>2]+156>>2]](M)|0)<=0|y[J+32>>2]<v[j+24620>>2]<<2>>>0){break Md}n=0;Od:{if(!k){break Od}while(1){Pd:{i=n<<2;ca=z[i+b>>2];if(ca>=C(1.1920928955078125e-7)|ca<=C(-1.1920928955078125e-7)){break Pd}ca=z[d+i>>2];if(ca>=C(1.1920928955078125e-7)|ca<=C(-1.1920928955078125e-7)){break Pd}n=n+1|0;if((k|0)!=(n|0)){continue}break Od}break}v[J+32>>2]=0;break Md}v[J+28>>2]=v[J+28>>2]|4}v[J+28>>2]=v[J+28>>2]&-3}h=h+1|0;if((h|0)!=250){continue}break}b=0;if(k){while(1){d=l;ca=C(z[a>>2]*Ha);Qd:{if(C(D(ca))<C(2147483648)){e=~~ca;break Qd}e=-2147483648}v[d>>2]=e;d=l;ca=C(z[c>>2]*Ha);Rd:{if(C(D(ca))<C(2147483648)){e=~~ca;break Rd}e=-2147483648}v[d+4>>2]=e;l=l+8|0;c=c+4|0;a=a+4|0;b=b+1|0;if((k|0)!=(b|0)){continue}break}}}if(v[N+24624>>2]==1){b=la;e=0;a=f;if(a){while(1){c=b+(e<<3)|0;v[b+(e<<2)>>2]=(v[c+4>>2]+v[c>>2]|0)/2;e=e+1|0;if((a|0)!=(e|0)){continue}break}}}if(w[Ka+33|0]){c=f;q=gb-16|0;gb=q;Sd:{Td:{h=N;Ud:{if(!v[h+1074376>>2]){d=h+1074460|0;v[d>>2]=0;v[d+4>>2]=0;v[h+1074468>>2]=v[h+1074456>>2];break Ud}b=v[h+1074468>>2];e=v[h+1074456>>2];Vd:{if((b|0)==(e|0)){e=v[h+1074460>>2];break Vd}v[h+1074468>>2]=e;d=h+24604|0;a=h+1074460|0;Wd:{if((b|0)<(e|0)){e=KS(d);break Wd}e=JS(d)}v[a>>2]=e;v[h+1074464>>2]=e}d=h+1074460|0;if((e|0)>0){break Td}}n=0;break Sd}g=(v[h+1074468>>2]<<12)-v[h+1074472>>2]|0;n=(g|0)/(e|0)|0;if(w[h+1074368|0]!=2){break Sd}v[q+12>>2]=50;e=h+1074464|0;v[q+8>>2]=1e4/(v[e>>2]+1|0);b=v[Gf(q+12|0,q+8|0)>>2];a=n>>31;if((b|0)>=(a+n^a)){break Sd}a=v[e>>2];e=v[d>>2];while(1){e=a+e|0;n=(g|0)/(e|0)|0;j=n>>31;if((b|0)<(j^j+n)){continue}break}v[d>>2]=e}Xd:{Yd:{switch(v[h+24624>>2]-1|0){case 0:if((c|0)<=0){break Xd}a=v[h+1074456>>2];k=a<<12;b=a;j=a>>31;e=h+12|0;a=0;while(1){Zd:{if(v[d>>2]>0){i=v[h+1074472>>2]+n|0;v[h+1074472>>2]=i;g=v[e>>2];Qa=e,Ra=Ac(lqa(kqa(g,g>>31,i,i>>31),jb,1048576,0),jb),v[Qa>>2]=Ra;v[h+1074460>>2]=v[h+1074460>>2]-1;break Zd}g=v[e>>2];Qa=e,Ra=Ac(lqa(kqa(g,g>>31,b,j),jb,256,0),jb),v[Qa>>2]=Ra;v[h+1074472>>2]=k}e=e+4|0;a=a+1|0;if((c|0)!=(a|0)){continue}break};break Xd;case 1:if((c|0)<=0){break Xd}a=v[h+1074456>>2];j=a<<12;b=a;i=a>>31;e=h+12|0;a=0;while(1){_d:{if(v[d>>2]>0){k=v[h+1074472>>2]+n|0;v[h+1074472>>2]=k;g=v[e>>2];Qa=e,Ra=Ac(lqa(kqa(g,g>>31,k,k>>31),jb,1048576,0),jb),v[Qa>>2]=Ra;g=v[h+1074472>>2];k=g;l=g>>31;g=v[e+4>>2];Qa=e,Ra=Ac(lqa(kqa(k,l,g,g>>31),jb,1048576,0),jb),v[Qa+4>>2]=Ra;v[h+1074460>>2]=v[h+1074460>>2]-1;break _d}g=v[e>>2];Qa=e,Ra=Ac(lqa(kqa(g,g>>31,b,i),jb,256,0),jb),v[Qa>>2]=Ra;g=v[e+4>>2];Qa=e,Ra=Ac(lqa(kqa(g,g>>31,b,i),jb,256,0),jb),v[Qa+4>>2]=Ra;v[h+1074472>>2]=j}e=e+8|0;a=a+1|0;if((c|0)!=(a|0)){continue}break};break Xd;case 3:break Yd;default:break Xd}}if((c|0)<=0){break Xd}a=v[h+1074456>>2];j=a<<12;b=a;i=a>>31;e=h+12|0;a=h+8204|0;l=0;while(1){$d:{if(v[d>>2]>0){k=v[h+1074472>>2]+n|0;v[h+1074472>>2]=k;g=v[e>>2];Qa=e,Ra=Ac(lqa(kqa(g,g>>31,k,k>>31),jb,1048576,0),jb),v[Qa>>2]=Ra;g=v[h+1074472>>2];k=g;r=g>>31;g=v[e+4>>2];Qa=e,Ra=Ac(lqa(kqa(k,r,g,g>>31),jb,1048576,0),jb),v[Qa+4>>2]=Ra;g=v[h+1074472>>2];k=g;r=g>>31;g=v[a>>2];Qa=a,Ra=Ac(lqa(kqa(k,r,g,g>>31),jb,1048576,0),jb),v[Qa>>2]=Ra;g=v[h+1074472>>2];k=g;r=g>>31;g=v[a+4>>2];Qa=a,Ra=Ac(lqa(kqa(k,r,g,g>>31),jb,1048576,0),jb),v[Qa+4>>2]=Ra;v[h+1074460>>2]=v[h+1074460>>2]-1;break $d}g=v[e>>2];Qa=e,Ra=Ac(lqa(kqa(g,g>>31,b,i),jb,256,0),jb),v[Qa>>2]=Ra;g=v[e+4>>2];Qa=e,Ra=Ac(lqa(kqa(g,g>>31,b,i),jb,256,0),jb),v[Qa+4>>2]=Ra;g=v[a>>2];Qa=a,Ra=Ac(lqa(kqa(g,g>>31,b,i),jb,256,0),jb),v[Qa>>2]=Ra;g=v[a+4>>2];Qa=a,Ra=Ac(lqa(kqa(g,g>>31,b,i),jb,256,0),jb),v[Qa+4>>2]=Ra;v[h+1074472>>2]=j}a=a+8|0;e=e+8|0;l=l+1|0;if((c|0)!=(l|0)){continue}break}}gb=q+16|0}if(v[Ea>>2]!=128){d=N+12|0;c=N+8204|0;a=f;e=v[N+24604>>2];b=v[N+24624>>2];ae:{if((e|0)==128|b>>>0<2){break ae}iO(d,a,e);if(b>>>0<4){break ae}iO(c,a,e)}}if(v[N+24624>>2]==4){d=la;c=Ja;a=f-1|0;if((a|0)>=0){while(1){b=a;g=d+(a<<4)|0;h=a<<3;e=h|4;v[g+12>>2]=v[e+c>>2];v[g+8>>2]=v[c+h>>2];v[g+4>>2]=v[d+e>>2];v[g>>2]=v[d+h>>2];a=a-1|0;if(b){continue}break}}}if(w[ia+20|0]){c=v[ia+16>>2];d=mg(W+72|0,la,v[N+24624>>2],f);b=v[v[c>>2]+8>>2];v[W+24>>2]=v[d+8>>2];a=v[d+4>>2];v[W+16>>2]=v[d>>2];v[W+20>>2]=a;kb[b|0](c,W+16|0)}c=mg(W+56|0,la,v[N+24624>>2],f);b=v[v[Da>>2]+8>>2];v[W+8>>2]=v[c+8>>2];a=v[c+4>>2];v[W>>2]=v[c>>2];v[W+4>>2]=a;kb[b|0](Da,W);q=v[N+1074380>>2]-f|0;v[N+1074380>>2]=q;v[N+1074376>>2]=f+v[N+1074376>>2];Ia=f+Ia|0;a=v[N+480208>>2];if(a&512){break i}ua=ua-f|0;if(ua){continue}break}}gb=W+128|0;gb=ia+48|0;return Ia}function Ioa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,z=0,A=0,C=0,D=0,E=0,F=0;d=gb-496|0;gb=d;vc(b);g=gb-32|0;gb=g;f=g+24|0;h=d+304|0;Qr(f,h);j=yb(f);f=v[g+28>>2];i=v[g+24>>2];v[g+8>>2]=i;v[g+12>>2]=f;v[g>>2]=i;v[g+4>>2]=f;i=g+16|0;f=b;cc(i,f,g);i=yb(i);if((i|0)==(j|0)){Rb(f,yb(g+24|0))}gb=g+32|0;f=(i|0)==(j|0);if(!f){TW(h)}a:{b:{c:{if(!f){break c}if(!rX(d+304|0)){break c}if(!Pb(b,Qc(qX(d+304|0),jb))){break c}if(!c){e=1;break c}Gd(a,32);t[d+303|0]=0;j=Kb(d+288|0);d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{t:{u:{v:{w:{x:{y:{z:{A:{B:{C:{D:{E:{F:{G:{if(v[d+304>>2]==778924148){v[22656]=0;R(558,a|0,16777216);e=v[22656];v[22656]=0;if((e|0)==1){break b}v[22656]=0;e=T(195,b|0)|0;f=v[22656];v[22656]=0;if((f|0)==1){break b}v[22656]=0;Q(190,b|0,e-4|0)|0;e=v[22656];v[22656]=0;if((e|0)==1){break b}v[22656]=0;s=T(192,b|0)|0;e=v[22656];v[22656]=0;if((e|0)!=1){break G}break b}H:{I:{J:{K:{L:{e=w[d+344|0]|w[d+345|0]<<8;M:{if(e>>>0<2185|e>>>0>4095){break M}v[22656]=0;e=T(195,b|0)|0;f=v[22656];v[22656]=0;if((f|0)==1){break b}v[22656]=0;Q(190,b|0,e-4|0)|0;e=v[22656];v[22656]=0;if((e|0)==1){break b}v[22656]=0;s=T(192,b|0)|0;e=v[22656];v[22656]=0;if((e|0)==1){break b}if(s>>>0<256){break M}v[22656]=0;e=T(195,b|0)|0;f=v[22656];v[22656]=0;if((f|0)==1){break b}if(e>>>0<=s>>>0){break M}v[22656]=0;e=Q(190,b|0,s|0)|0;f=v[22656];v[22656]=0;if((f|0)==1){break b}if(!e){break M}v[22656]=0;e=T(559,b|0)|0;f=v[22656];v[22656]=0;if((f|0)==1){break b}if(!e){break M}v[22656]=0;R(558,a|0,16777216);e=v[22656];v[22656]=0;if((e|0)==1){break b}if((w[d+344|0]|w[d+345|0]<<8)>>>0>=4096){v[22656]=0;b=Q(2,d+104|0,13592)|0;c=v[22656];v[22656]=0;if((c|0)==1){break F}v[22656]=0;U(560,a|0,1,b|0);a=v[22656];v[22656]=0;if((a|0)!=1){vb(b);e=0;break d}a=P()|0;O()|0;vb(b);break a}if((w[d+344|0]|w[d+345|0]<<8)>>>0<2194){break M}v[22656]=0;e=Q(2,d+104|0,13121)|0;f=v[22656];v[22656]=0;if((f|0)==1){break L}v[22656]=0;U(560,a|0,4,e|0);f=v[22656];v[22656]=0;if((f|0)==1){break K}vb(e)}if(v[a+480180>>2]!=32){break G}if(((w[d+344|0]|w[d+345|0]<<8)&61440)!=20480){break H}f=(w[d+344|0]|w[d+345|0]<<8)&4095;e=f<<16;if(v[d+364>>2]!=1414548815){break J}t[d+303|0]=1;break I}a=P()|0;O()|0;break a}a=P()|0;O()|0;vb(e);break a}if(f>>>0<297){break I}e=w[d+364|0]|w[d+365|0]<<8|e}v[a+1074308>>2]=e;break G}if(!((w[d+346|0]|w[d+347|0]<<8)!=2184&(w[d+344|0]|w[d+345|0]<<8)!=2184)){t[d+303|0]=1;v[a+1074308>>2]=18284544;break G}if(!((w[d+344|0]|w[d+345|0]<<8)!=535|(w[d+346|0]|w[d+347|0]<<8)!=512|(w[d+364|0]|w[d+365|0]<<8|(w[d+366|0]<<16|w[d+367|0]<<24)))){v[22656]=0;e=Cv(d+368|0,255,64);f=v[22656];v[22656]=0;if((f|0)==1){break b}N:{if(e){v[a+1074308>>2]=18219008;v[22656]=0;h=Q(2,d+104|0,12025)|0;e=v[22656];v[22656]=0;if((e|0)!=1){break N}a=P()|0;O()|0;break a}v[a+1074308>>2]=18284544;v[22656]=0;h=Q(2,d+104|0,13943)|0;e=v[22656];v[22656]=0;if((e|0)==1){break E}}Eb(j,h);vb(h);t[d+303|0]=1;break G}if(!((w[d+344|0]|w[d+345|0]<<8)!=532|(w[d+346|0]|w[d+347|0]<<8)!=514|(w[d+364|0]|w[d+365|0]<<8|(w[d+366|0]<<16|w[d+367|0]<<24)))){v[a+1074308>>2]=17367040;v[22656]=0;e=Q(2,d+104|0,11917)|0;f=v[22656];v[22656]=0;if((f|0)!=1){Eb(j,e);vb(e);t[d+303|0]=1;break G}a=P()|0;O()|0;break a}if((w[d+344|0]|w[d+345|0]<<8)!=768|(w[d+346|0]|w[d+347|0]<<8)!=768|(w[d+364|0]|w[d+365|0]<<8|(w[d+366|0]<<16|w[d+367|0]<<24)|(w[d+336|0]|w[d+337|0]<<8)!=256)){break G}if(w[d+357|0]|w[d+356|0]!=128){break G}v[a+1074308>>2]=18285088;t[d+303|0]=1}v[a+480208>>2]=v[a+480208>>2]&-17|(w[d+348|0]|w[d+349|0]<<8)<<1&16;v[a+480208>>2]=v[a+480208>>2]&-5|(w[d+348|0]|w[d+349|0]<<8)>>>2&4;v[a+480208>>2]=v[a+480208>>2]&-9|(w[d+348|0]|w[d+349|0]<<8)>>>2&8;v[a+480208>>2]=v[a+480208>>2]&-32769|(w[d+348|0]|w[d+349|0]<<8)<<3&32768;v[22656]=0;Dp(d+216|0,3,d+304|4);e=v[22656];v[22656]=0;if((e|0)==1){break D}v[22656]=0;R(324,d+104|0,d+216|0);e=v[22656];v[22656]=0;if((e|0)==1){break D}e=d+104|0;Eb(a+1298268|0,e);vb(e);if(!(!(w[d+350|0]&4)|v[a+1074308>>2]-1>>>0<18285313)){v[a+480216>>2]=w[d+334|0];v[a+480220>>2]=w[d+335|0]}e=w[d+352|0];v[a+480200>>2]=e>>>0>128?256:e<<1;if(w[d+354|0]){v[a+480196>>2]=w[d+354|0]}t[d+104|0]=31;e=w[d+355|0];v[22656]=0;t[d+216|0]=e;e=df(d+104|0,d+216|0);f=v[22656];v[22656]=0;if((f|0)==1){break e}v[a+480204>>2]=B(w[e|0],1e4);t[d+104|0]=w[d+353|0];v[22656]=0;t[d+216|0]=128;e=ac(d+104|0,d+216|0);f=v[22656];v[22656]=0;if((f|0)==1){break f}v[a+480228>>2]=w[e|0];e=0;while(1){i=(d+304|0)+e|0;g=i- -64|0;O:{if(w[g|0]==255){break O}v[22656]=0;h=(e<<5)+a|0;f=h+480280|0;We(f);l=v[22656];v[22656]=0;if((l|0)==1){break C}E=h+480286|0,F=Md(w[i+128|0],0,64),u[E>>1]=F;if(t[g|0]<0){v[f>>2]=v[f>>2]|1024}g=w[g|0]&127;if(g>>>0<=64){u[h+480284>>1]=g<<2;break O}if((g|0)!=100){break O}v[f>>2]=v[f>>2]|256}e=e+1|0;if((e|0)!=64){continue}break}v[22656]=0;Q(190,b|0,192)|0;e=v[22656];v[22656]=0;if((e|0)==1){break b}P:{if(!(v[a+480180>>2]!=16777216|(w[d+344|0]|w[d+345|0]<<8)>>>0<2187|(w[d+344|0]|w[d+345|0]<<8)>>>0>2189)){e=0;v[22656]=0;f=T(287,b|0)|0;g=v[22656];v[22656]=0;if((g|0)==1){break B}if(f){break d}v[22656]=0;f=T(192,b|0)|0;g=v[22656];v[22656]=0;Q:{if((g|0)==1){break Q}if(f>>>0>4e3){break d}g=Sb(a+484360|0);v[22656]=0;f=W(563,g|0,b|0,f|0)|0;g=v[22656];v[22656]=0;if((g|0)==1){break Q}if(!f){break d}break P}a=P()|0;O()|0;break a}e=Sb(a+484360|0);f=w[d+336|0]|w[d+337|0]<<8;v[22656]=0;fa(522,e|0,b|0,f|0,255,254)|0;e=v[22656];v[22656]=0;if((e|0)==1){break b}}r=mc(d+272|0);q=mc(d+256|0);n=mc(d+240|0);f=w[d+338|0]|w[d+339|0]<<8;e=0;v[22656]=0;f=W(564,b|0,r|0,f|0)|0;g=v[22656];v[22656]=0;R:{if((g|0)==1){break R}if(!f){break z}f=w[d+340|0]|w[d+341|0]<<8;v[22656]=0;f=W(564,b|0,q|0,f|0)|0;g=v[22656];v[22656]=0;if((g|0)==1){break R}if(!f){break z}f=w[d+342|0]|w[d+343|0]<<8;v[22656]=0;f=W(564,b|0,n|0,f|0)|0;g=v[22656];v[22656]=0;if((g|0)==1){break R}if(!f){break z}v[d+236>>2]=-1;E=d,F=Vb(r),v[E+104>>2]=F;E=d,F=Zb(r),v[E+216>>2]=F;if(!Gb(d+104|0,d+216|0)){break A}while(1){e=v[d+104>>2];e=w[e|0]|w[e+1|0]<<8|(w[e+2|0]<<16|w[e+3|0]<<24);if(!(!e|e>>>0>=y[d+236>>2])){v[d+236>>2]=e}e=d+104|0;Qe(e);if(Gb(e,d+216|0)){continue}break}break A}a=P()|0;O()|0;break g}a=P()|0;O()|0;break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;break a}E=d,F=Vb(q),v[E+104>>2]=F;E=d,F=Zb(q),v[E+216>>2]=F;if(Gb(d+104|0,d+216|0)){while(1){e=v[d+104>>2];e=w[e|0]|w[e+1|0]<<8|(w[e+2|0]<<16|w[e+3|0]<<24);if(!(!e|e>>>0>=y[d+236>>2])){v[d+236>>2]=e}e=d+104|0;Qe(e);if(Gb(e,d+216|0)){continue}break}}E=d,F=Vb(n),v[E+104>>2]=F;E=d,F=Zb(n),v[E+216>>2]=F;if(Gb(d+104|0,d+216|0)){while(1){e=v[d+104>>2];e=w[e|0]|w[e+1|0]<<8|(w[e+2|0]<<16|w[e+3|0]<<24);if(!(!e|e>>>0>=y[d+236>>2])){v[d+236>>2]=e}e=d+104|0;Qe(e);if(Gb(e,d+216|0)){continue}break}}S:{T:{U:{V:{W:{X:{Y:{Z:{_:{$:{aa:{ba:{if(t[d+350|0]&1){e=w[d+360|0]|w[d+361|0]<<8|(w[d+362|0]<<16|w[d+363|0]<<24);v[22656]=0;v[d+104>>2]=e;e=Fb(d+236|0,d+104|0);f=v[22656];v[22656]=0;if((f|0)==1){break ba}v[d+236>>2]=v[e>>2]}e=0;g=w[d+344|0]|w[d+345|0]<<8;ca:{if((w[d+346|0]|w[d+347|0]<<8)!=532|(g?(g|0)!=532:0)|(w[d+335|0]|w[d+334|0])){break ca}if(w[d+348|0]&192|(w[d+357|0]|(w[d+364|0]|w[d+365|0]<<8|(w[d+366|0]<<16|w[d+367|0]<<24)))){break ca}da:{if(!(w[d+340|0]|w[d+341|0]<<8)|(w[d+338|0]|w[d+339|0]<<8)){break da}if((v[b+8>>2]+(Nb(q)<<2)|0)+2>>>0>y[d+236>>2]){break da}if(w[d+340|0]|w[d+341|0]<<8){g=0;while(1){v[22656]=0;e=T(192,b|0)|0;f=v[22656];v[22656]=0;ea:{if((f|0)!=1){if(!e){break ea}pg(b,((g&65535)<<2)+4|0);break da}a=P()|0;O()|0;break g}g=g+1|0;if((g&65535)>>>0<(w[d+340|0]|w[d+341|0]<<8)>>>0){continue}break}}v[22656]=0;e=Q(2,d+104|0,12183)|0;f=v[22656];v[22656]=0;if((f|0)==1){break $}Eb(j,e);vb(e)}e=1;if(w[d+344|0]|w[d+345|0]<<8){break ca}v[22656]=0;f=Q(2,d+104|0,12541)|0;g=v[22656];v[22656]=0;if((g|0)==1){break _}Eb(j,f);vb(f)}fa:{if(w[d+350|0]&2){v[22656]=0;f=T(287,b|0)|0;g=v[22656];v[22656]=0;if((g|0)==1){break Z}v[22656]=0;g=f<<3;h=Q(191,b|0,g|0)|0;i=v[22656];v[22656]=0;if((i|0)==1){break Z}if(!(!h|y[d+236>>2]<g+v[b+8>>2]>>>0)){v[22656]=0;g=a+1298368|0;R(565,g|0,f|0);h=v[22656];v[22656]=0;if((h|0)==1){break Z}E=d,F=Vb(g),v[E+216>>2]=F;E=d,F=Zb(g),v[E+192>>2]=F;if(Gb(d+216|0,d+192|0)){while(1){g=v[d+216>>2];v[22656]=0;R(566,b|0,d+104|0);h=v[22656];v[22656]=0;if((h|0)==1){break Y}v[22656]=0;YE(d+104|0,g);g=v[22656];v[22656]=0;if((g|0)==1){break Y}g=d+216|0;v[g>>2]=v[g>>2]+48;if(Gb(g,d+192|0)){continue}break}}if(!(!f&e)){break fa}if(w[d+350|0]&4){v[22656]=0;e=Q(2,d+104|0,12574)|0;f=v[22656];v[22656]=0;if((f|0)!=1){Eb(j,e);vb(e);break fa}a=P()|0;O()|0;break g}v[22656]=0;e=Q(2,d+104|0,12205)|0;f=v[22656];v[22656]=0;if((f|0)!=1){Eb(j,e);vb(e);break fa}a=P()|0;O()|0;break g}pg(b,2);break fa}if(!e|(w[d+350|0]|w[d+351|0]<<8)>>>0>1){break fa}v[22656]=0;e=T(287,b|0)|0;f=v[22656];v[22656]=0;if((f|0)==1){break aa}if(!e){v[22656]=0;e=Q(2,d+104|0,12183)|0;f=v[22656];v[22656]=0;if((f|0)!=1){Eb(j,e);vb(e);break fa}a=P()|0;O()|0;break g}pg(b,2)}ga:{if(!(w[d+350|0]&8?1:w[d+348|0]&128)){break ga}v[22656]=0;e=a+901404|0;f=Q(568,b|0,e|0)|0;g=v[22656];v[22656]=0;if((g|0)==1){break h}if(!f){break ga}v[22656]=0;Nu(e);e=v[22656];v[22656]=0;if((e|0)==1){break h}}if((w[d+344|0]|w[d+345|0]<<8)>>>0<=531){v[22656]=0;Xo(a+901404|0);e=v[22656];v[22656]=0;if((e|0)==1){break h}}v[22656]=0;z=T(215,d+216|0)|0;e=v[22656];v[22656]=0;ha:{ia:{ja:{ka:{la:{ma:{if((e|0)!=1){v[22656]=0;e=Q(555,b|0,11155)|0;f=v[22656];v[22656]=0;if((f|0)==1){break ma}if(e){v[22656]=0;e=T(192,b|0)|0;f=v[22656];v[22656]=0;if((f|0)==1){break la}v[22656]=0;U(288,d+192|0,b|0,e|0);e=v[22656];v[22656]=0;if((e|0)==1){break la}e=d+192|0;f=kc(d+104|0,e);Vc(z,f);xb(f);xb(e)}u[a+480188>>1]=1;v[22656]=0;e=Q(555,b|0,11160)|0;f=v[22656];v[22656]=0;if((f|0)==1){break ma}if(e){v[22656]=0;e=T(192,b|0)|0;f=v[22656];v[22656]=0;if((f|0)==1){break ka}v[22656]=0;U(288,d+192|0,b|0,e|0);e=v[22656];v[22656]=0;if((e|0)==1){break ka}e=d+192|0;f=kc(d+104|0,e);xb(e);v[22656]=0;e=T(195,f|0)|0;g=v[22656];v[22656]=0;if((g|0)==1){break ja}v[22656]=0;u[d+192>>1]=(e>>>0)/20;e=Pc(28868,d+192|0);g=v[22656];v[22656]=0;if((g|0)==1){break ja}g=x[e>>1];u[a+480188>>1]=g;if(g){e=0;while(1){v[22656]=0;W(571,f|0,((e<<5)+a|0)+480289|0,20)|0;h=v[22656];v[22656]=0;if((h|0)==1){break ja}e=e+1|0;if((g|0)!=(e|0)){continue}break}}xb(f)}if(y[b+8>>2]>y[d+236>>2]){break ia}e=v[d+236>>2]-v[b+8>>2]|0;break ha}a=P()|0;O()|0;break g}a=P()|0;O()|0;break i}a=P()|0;O()|0;break i}a=P()|0;O()|0;break i}a=P()|0;O()|0;xb(f);break i}v[22656]=0;e=T(467,b|0)|0;f=v[22656];v[22656]=0;if((f|0)==1){break X}}v[22656]=0;U(288,d+104|0,b|0,e|0);e=v[22656];v[22656]=0;if((e|0)==1){break X}e=d+104|0;A=kc(d+192|0,e);xb(e);v[22656]=0;D=Q(572,a|0,A|0)|0;e=v[22656];v[22656]=0;na:{oa:{if((e|0)==1){break oa}if(!(t[d+350|0]&1)|!(w[d+358|0]|w[d+359|0]<<8)){break na}e=w[d+360|0]|w[d+361|0]<<8|(w[d+362|0]<<16|w[d+363|0]<<24);v[22656]=0;e=Q(190,b|0,e|0)|0;f=v[22656];v[22656]=0;if((f|0)==1){break oa}if(!e){break na}e=w[d+358|0]|w[d+359|0]<<8;v[22656]=0;da(510,a+1298292|0,b|0,e|0,4)|0;e=v[22656];v[22656]=0;if((e|0)!=1){break na}}a=P()|0;O()|0;break j}e=0;u[a+480192>>1]=0;if(w[d+348|0]&4){u[d+104>>1]=w[d+338|0]|w[d+339|0]<<8;v[22656]=0;u[d+32>>1]=255;f=Pc(d+104|0,d+32|0);g=v[22656];v[22656]=0;if((g|0)==1){break W}u[a+480192>>1]=x[f>>1]}pa:{qa:{ra:{sa:{if(x[a+480192>>1]){while(1){f=Mb(r,e);ta:{if(!(w[f|0]|w[f+1|0]<<8|(w[f+2|0]<<16|w[f+3|0]<<24))){break ta}f=Mb(r,e);f=w[f|0]|w[f+1|0]<<8|(w[f+2|0]<<16|w[f+3|0]<<24);v[22656]=0;f=Q(190,b|0,f|0)|0;g=v[22656];v[22656]=0;if((g|0)==1){break sa}if(!f){break ta}v[22656]=0;f=Q(191,b|0,554)|0;g=v[22656];v[22656]=0;if((g|0)==1){break sa}if(!f){break ta}v[22656]=0;f=W(376,a|0,e+1&65535,0)|0;g=v[22656];v[22656]=0;if((g|0)==1){break ra}if(!f){break ta}g=w[d+346|0]|w[d+347|0]<<8;v[22656]=0;da(573,a|0,b|0,f|0,g|0)|0;g=v[22656];v[22656]=0;if((g|0)==1){break ra}t[f+33|0]=w[d+357|0]}e=e+1|0;if(e>>>0<x[a+480192>>1]){continue}break}}v[d+188>>2]=0;if(w[d+340|0]|w[d+341|0]<<8){e=Mb(q,(w[d+340|0]|w[d+341|0]<<8)-1|0);v[d+188>>2]=(w[e|0]|w[e+1|0]<<8|(w[e+2|0]<<16|w[e+3|0]<<24))+80}u[d+104>>1]=w[d+340|0]|w[d+341|0]<<8;v[22656]=0;u[d+32>>1]=3999;e=Pc(d+104|0,d+32|0);f=v[22656];v[22656]=0;if((f|0)==1){break qa}u[a+480190>>1]=x[e>>1];e=0;if(x[a+480190>>1]){break pa}f=0;h=0;break S}a=P()|0;O()|0;break j}a=P()|0;O()|0;break j}a=P()|0;O()|0;break j}l=c&2;k=d+124|0;h=0;f=0;while(1){g=Mb(q,e);ua:{if(!(w[g|0]|w[g+1|0]<<8|(w[g+2|0]<<16|w[g+3|0]<<24))){break ua}g=Mb(q,e);g=w[g|0]|w[g+1|0]<<8|(w[g+2|0]<<16|w[g+3|0]<<24);v[22656]=0;g=Q(190,b|0,g|0)|0;i=v[22656];v[22656]=0;va:{wa:{xa:{ya:{za:{Aa:{Ba:{if((i|0)==1){break Ba}if(!g){break ua}v[22656]=0;g=Q(574,b|0,d+104|0)|0;i=v[22656];v[22656]=0;if((i|0)==1){break Ba}if(!g){break ua}v[22656]=0;g=e+1|0;o=B(g,104)+a|0;i=o+484380|0;p=Q(575,d+104|0,i|0)|0;m=v[22656];v[22656]=0;if((m|0)==1){break Aa}v[22656]=0;Dp(d+88|0,3,k);m=v[22656];v[22656]=0;if((m|0)==1){break za}v[22656]=0;R(324,d+32|0,d+88|0);m=v[22656];v[22656]=0;if((m|0)==1){break za}v[22656]=0;Q(301,((g<<5)+a|0)+946304|0,d+32|0)|0;m=v[22656];v[22656]=0;if((m|0)==1){break ya}vb(d+32|0);v[22656]=0;p=Q(190,b|0,p|0)|0;m=v[22656];v[22656]=0;if((m|0)==1){break Aa}if(!p){break ua}f=x[o+484414>>1];if(!(f&512)){break xa}v[22656]=0;f=Q(576,b|0,d+32|0)|0;g=v[22656];v[22656]=0;if((g|0)!=1){if(!f){break wa}v[d+16>>2]=v[d+40>>2];v[22656]=0;f=v[d+36>>2];v[d+8>>2]=v[d+32>>2];v[d+12>>2]=f;U(577,i|0,1,d+8|0);f=v[22656];v[22656]=0;if((f|0)!=1){break wa}}a=P()|0;O()|0;break j}a=P()|0;O()|0;break j}a=P()|0;O()|0;break j}a=P()|0;O()|0;break j}a=P()|0;O()|0;vb(d+32|0);break j}if(!(f&16384)){f=w[d+344|0]|w[d+345|0]<<8;v[22656]=0;ZE(d+32|0,d+104|0,f);f=v[22656];v[22656]=0;if((f|0)==1){break T}Ca:{if(l){g=0;v[22656]=0;W(329,d+32|0,i|0,b|0)|0;f=v[22656];v[22656]=0;if((f|0)!=1){break Ca}break T}g=1;f=w[d+35|0];if(f>>>0>17){break Ca}f=1<<f;Da:{if(!(f&63503)){if(f&198144){break Da}break Ca}if(!w[d+32|0]){break Ca}}f=v[i>>2];v[22656]=0;f=Bv(d+32|0,f);g=v[22656];v[22656]=0;if((g|0)==1){break T}g=0;v[22656]=0;Q(318,b|0,f|0)|0;f=v[22656];v[22656]=0;if((f|0)==1){break T}}if(w[d+35|0]!=1){break va}h=v[i>>2]!=0|h;break va}v[22656]=0;Q(580,b|0,d+84|0)|0;f=v[22656];v[22656]=0;if((f|0)==1){break U}f=v[d+84>>2];if(!(!l|!f)){f=Kb(d+32|0);v[22656]=0;W(413,b|0,f|0,v[d+84>>2])|0;i=v[22656];v[22656]=0;Ea:{Fa:{Ga:{Ha:{Ia:{Ja:{Ka:{if((i|0)!=1){v[22656]=0;R(581,d+72|0,13514);i=v[22656];v[22656]=0;if((i|0)==1){break Ka}v[d+68>>2]=g;v[22656]=0;U(13,d+56|0,0,f|0);g=v[22656];v[22656]=0;if((g|0)==1){break Ja}v[22656]=0;Y(582,d+88|0,d+72|0,d+68|0,d+56|0);g=v[22656];v[22656]=0;if((g|0)==1){break Ia}v[22656]=0;U(560,a|0,2,d+88|0);g=v[22656];v[22656]=0;if((g|0)==1){break Ha}vb(d+88|0);vb(d+56|0);Hb(d+72|0);vb(f);break wa}a=P()|0;O()|0;break Ea}a=P()|0;O()|0;break Ea}a=P()|0;O()|0;break Fa}a=P()|0;O()|0;break Ga}a=P()|0;O()|0;vb(d+88|0)}vb(d+56|0)}Hb(d+72|0)}vb(f);break j}v[22656]=0;Q(318,b|0,f|0)|0;f=v[22656];v[22656]=0;if((f|0)==1){break U}}g=0}f=v[b+8>>2];v[22656]=0;v[d+32>>2]=f;f=Lc(d+188|0,d+32|0);i=v[22656];v[22656]=0;if((i|0)==1){break V}v[d+188>>2]=v[f>>2];f=(g|0)!=0}e=e+1|0;if(e>>>0<x[a+480190>>1]){continue}break}break S}a=P()|0;O()|0;break g}a=P()|0;O()|0;break g}a=P()|0;O()|0;break g}a=P()|0;O()|0;break g}a=P()|0;O()|0;break g}a=P()|0;O()|0;break g}a=P()|0;O()|0;break i}a=P()|0;O()|0;break j}a=P()|0;O()|0;break j}a=P()|0;O()|0;break j}a=P()|0;O()|0;break j}u[d+104>>1]=1;e=x[a+480190>>1];v[22656]=0;u[d+32>>1]=e;e=Le(d+104|0,d+32|0);g=v[22656];v[22656]=0;La:{Ma:{Na:{Oa:{Pa:{Qa:{Ra:{Sa:{Ta:{Ua:{if((g|0)!=1){u[a+480190>>1]=x[e>>1];Va:{if(!(h&1)|(w[d+344|0]|w[d+345|0]<<8)!=516|(w[d+350|0]|w[d+351|0]<<8|(w[d+346|0]|w[d+347|0]<<8)!=512)){break Va}if(w[d+364|0]|w[d+365|0]<<8|(w[d+366|0]<<16|w[d+367|0]<<24)|((w[d+348|0]|w[d+349|0]<<8)&65527)!=21|(w[d+352|0]!=128|w[d+353|0]!=48)){break Va}if(w[d+357|0]|w[d+356|0]!=128|(w[d+358|0]|w[d+359|0]<<8)){break Va}h=d+432|0;g=d+368|0;e=1;while(1){e=(w[g|0]&127)==32&e;g=g+1|0;if((h|0)!=(g|0)){continue}break}h=d+496|0;g=d+432|0;while(1){e=w[g|0]==64&e;g=g+1|0;if((h|0)!=(g|0)){continue}break}g=20;while(1){e=!w[(d+g|0)+308|0]&e;g=g+1|0;if((g|0)!=26){continue}break}if(!e){break Va}v[22656]=0;e=Q(2,d+104|0,7125)|0;g=v[22656];v[22656]=0;if((g|0)==1){break Ma}Eb(j,e);vb(e)}v[a+480260>>2]=0;v[a+480264>>2]=2147483647;E=d,F=Nb(n),u[E+104>>1]=F;e=v[a+8>>2];v[22656]=0;e=Pc(d+104|0,e+10|0);g=v[22656];v[22656]=0;if((g|0)==1){break Ua}e=x[e>>1];u[d+84>>1]=e;if((Nb(n)|0)!=(e|0)){v[22656]=0;_(584,d+32|0);e=v[22656];v[22656]=0;if((e|0)==1){break Ta}e=Nb(n);v[22656]=0;v[d+88>>2]=e;Y(585,d+104|0,d+32|0,d+88|0,d+84|0);e=v[22656];v[22656]=0;if((e|0)==1){break Sa}v[22656]=0;U(560,a|0,2,d+104|0);e=v[22656];v[22656]=0;if((e|0)==1){break Ra}vb(d+104|0);Hb(d+32|0)}if(c&1){break Pa}u[d+84>>1]=0;break Oa}a=P()|0;O()|0;break j}a=P()|0;O()|0;break j}a=P()|0;O()|0;break j}a=P()|0;O()|0;break Qa}a=P()|0;O()|0;vb(d+104|0)}Hb(d+32|0);break j}if(!x[d+84>>1]){break Oa}e=0;while(1){c=Mb(n,e);Wa:{if(!(w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24))){break Wa}c=Mb(n,e);c=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);v[22656]=0;c=Q(190,b|0,c|0)|0;g=v[22656];v[22656]=0;if((g|0)==1){break Na}if(!c){break Wa}v[22656]=0;c=T(287,b|0)|0;g=v[22656];v[22656]=0;if((g|0)==1){break k}v[22656]=0;i=T(287,b|0)|0;g=v[22656];v[22656]=0;if((g|0)==1){break l}if((i-1&65535)>>>0>1023){break Wa}v[22656]=0;g=Q(318,b|0,4)|0;h=v[22656];v[22656]=0;if((h|0)==1){break l}if(!g){break Wa}v[22656]=0;U(288,d+32|0,b|0,c|0);c=v[22656];v[22656]=0;if((c|0)==1){break m}c=d+32|0;l=kc(d+104|0,c);xb(c);g=0;h=x[a+480188>>1];v[22656]=0;c=Q(586,c|0,h|0)|0;h=v[22656];v[22656]=0;if((h|0)==1){break o}while(1){Xa:{v[22656]=0;h=Q(191,d+104|0,1)|0;k=v[22656];v[22656]=0;Ya:{Za:{if((k|0)!=1){if(!h){break Xa}v[22656]=0;h=T(374,l|0)|0;k=v[22656];v[22656]=0;if((k|0)==1){break p}k=h<<24>>24;if(k){break Za}g=g+1|0;break Ya}break p}_a:{h=k&127;o=h?h-1|0:0;h=o&65535;if(oc(c)>>>0>h>>>0){break _a}v[22656]=0;t[d+88|0]=0;U(587,c|0,h+1|0,d+88|0);p=v[22656];v[22656]=0;if((p|0)!=1){break _a}break p}if((k|0)<0){v[22656]=0;k=T(374,l|0)|0;p=v[22656];v[22656]=0;if((p|0)==1){break p}E=lc(c,h),F=k,t[E|0]=F}if(!(!(w[lc(c,h)|0]&15)|h>>>0<x[a+480188>>1])){u[a+480188>>1]=o+1}if(t[lc(c,h)|0]&1){v[22656]=0;Q(318,d+104|0,1)|0;k=v[22656];v[22656]=0;if((k|0)==1){break p}}if(w[lc(c,h)|0]&2){v[22656]=0;Q(318,d+104|0,1)|0;k=v[22656];v[22656]=0;if((k|0)==1){break p}}if(w[lc(c,h)|0]&4){v[22656]=0;Q(318,d+104|0,1)|0;k=v[22656];v[22656]=0;if((k|0)==1){break p}}if(!(w[lc(c,h)|0]&8)){break Ya}v[22656]=0;Q(318,d+104|0,2)|0;h=v[22656];v[22656]=0;if((h|0)==1){break p}}if(g>>>0<i>>>0){continue}}break}g=v[b+8>>2];v[22656]=0;v[d+88>>2]=g;g=Lc(d+188|0,d+88|0);h=v[22656];v[22656]=0;if((h|0)==1){break p}v[d+188>>2]=v[g>>2];gc(c);xb(d+104|0)}e=e+1|0;if(e>>>0<x[d+84>>1]){continue}break}}c=v[d+188>>2];if(!c){break La}v[22656]=0;Q(190,b|0,c|0)|0;c=v[22656];v[22656]=0;if((c|0)==1){break q}if(!(f&1)){break La}while(1){$a:{v[22656]=0;c=Q(191,b|0,4)|0;e=v[22656];v[22656]=0;if((e|0)==1){break $a}if(!c){break La}v[22656]=0;c=Q(555,b|0,11134)|0;e=v[22656];v[22656]=0;if((e|0)==1){break $a}ab:{if(!c){v[22656]=0;c=Q(555,b|0,11139)|0;e=v[22656];v[22656]=0;if((e|0)==1){break $a}if(!c){break ab}}v[22656]=0;c=T(192,b|0)|0;e=v[22656];v[22656]=0;if((e|0)!=1){pg(b,8);if(!(c&1616928864)|c&-2139062144){break ab}break La}a=P()|0;O()|0;break j}v[22656]=0;c=T(287,b|0)|0;e=v[22656];v[22656]=0;if((e|0)==1){break $a}v[22656]=0;Q(318,b|0,c|0)|0;c=v[22656];v[22656]=0;if((c|0)!=1){continue}}break}a=P()|0;O()|0;break j}a=P()|0;O()|0;break j}a=P()|0;O()|0;break j}v[22656]=0;c=Q(588,a|0,b|0)|0;e=v[22656];v[22656]=0;if((e|0)==1){break q}c=c|w[d+303|0];t[d+303|0]=c;if(!(!c|D)){Av(a+1074312|0);t[a+1074368|0]=0}v[22656]=0;Y(589,a|0,b|0,0,d+303|0);c=v[22656];v[22656]=0;if((c|0)==1){break q}v[22656]=0;o=a+484344|0;R(330,o|0,x[d+84>>1]);c=v[22656];v[22656]=0;if((c|0)==1){break q}e=0;u[d+68>>1]=0;bb:{if(!x[d+84>>1]){break bb}while(1){cb:{db:{c=Mb(n,e&65535);eb:{if(w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24)){c=Mb(n,x[d+68>>1]);c=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);v[22656]=0;c=Q(190,b|0,c|0)|0;e=v[22656];v[22656]=0;if((e|0)==1){break eb}if(c){break db}}v[22656]=0;c=W(331,o|0,x[d+68>>1],64)|0;e=v[22656];v[22656]=0;if((e|0)==1){break eb}if(!c){v[22656]=0;_(590,d+32|0);c=v[22656];v[22656]=0;fb:{gb:{hb:{if((c|0)!=1){v[22656]=0;U(591,d+104|0,d+32|0,d+68|0);c=v[22656];v[22656]=0;if((c|0)==1){break hb}v[22656]=0;U(560,a|0,2,d+104|0);c=v[22656];v[22656]=0;if((c|0)==1){break gb}vb(d+104|0);Hb(d+32|0);break bb}a=P()|0;O()|0;break j}a=P()|0;O()|0;break fb}a=P()|0;O()|0;vb(d+104|0)}Hb(d+32|0);break j}c=_b(o,x[d+68>>1]);v[22656]=0;R(592,c|0,z|0);c=v[22656];v[22656]=0;if((c|0)!=1){break cb}}a=P()|0;O()|0;break j}v[22656]=0;c=T(287,b|0)|0;e=v[22656];v[22656]=0;ib:{jb:{if((e|0)!=1){v[22656]=0;p=T(287,b|0)|0;e=v[22656];v[22656]=0;if((e|0)==1){break jb}v[22656]=0;e=Q(318,b|0,4)|0;f=v[22656];v[22656]=0;if((f|0)==1){break jb}if(!e){break cb}v[22656]=0;e=W(331,o|0,x[d+68>>1],p|0)|0;f=v[22656];v[22656]=0;if((f|0)==1){break jb}if(e){break ib}break cb}a=P()|0;O()|0;break j}a=P()|0;O()|0;break j}v[22656]=0;U(288,d+32|0,b|0,c|0);c=v[22656];v[22656]=0;if((c|0)!=1){c=d+32|0;k=kc(d+104|0,c);xb(c);c=_b(o,x[d+68>>1]);v[22656]=0;R(592,c|0,z|0);c=v[22656];v[22656]=0;kb:{if((c|0)!=1){c=x[a+480188>>1];v[22656]=0;l=Q(586,d+32|0,c|0)|0;c=v[22656];v[22656]=0;if((c|0)!=1){c=x[a+480188>>1];e=d+72|0;gi(e);v[22656]=0;i=W(593,d+88|0,c|0,e|0)|0;c=v[22656];v[22656]=0;lb:{if((c|0)!=1){E=d,F=Vb(_b(o,x[d+68>>1])),v[E+56>>2]=F;m=0;mb:{if(!p){break mb}while(1){v[22656]=0;c=Q(191,d+104|0,1)|0;e=v[22656];v[22656]=0;nb:{if((e|0)!=1){ob:{if(!c){break mb}v[22656]=0;c=T(374,k|0)|0;e=v[22656];v[22656]=0;pb:{if((e|0)!=1){c=c<<24>>24;if(c){break pb}BX(d+56|0,x[a+480188>>1]);m=m+1|0;break nb}break ob}qb:{e=c&127;h=e?e-1&65535:0;if(oc(l)>>>0>h>>>0){break qb}v[22656]=0;t[d+72|0]=0;e=h+1|0;U(587,l|0,e|0,d+72|0);f=v[22656];v[22656]=0;if((f|0)==1){break ob}f=d+72|0;gi(f);v[22656]=0;U(594,i|0,e|0,f|0);e=v[22656];v[22656]=0;if((e|0)!=1){break qb}break ob}if((c|0)<0){v[22656]=0;c=T(374,k|0)|0;e=v[22656];v[22656]=0;if((e|0)==1){break ob}E=lc(l,h),F=c,t[E|0]=F}e=d+72|0;gi(e);if(h>>>0<x[a+480188>>1]){e=ad(d+56|0,h)}if(w[lc(l,h)|0]&16){E=e,F=w[ad(i,h)|0],t[E|0]=F}if(w[lc(l,h)|0]&32){E=e,F=w[ad(i,h)+1|0],t[E+1|0]=F}if(w[lc(l,h)|0]&64){E=e,F=w[ad(i,h)+2|0],t[E+2|0]=F;E=e,F=w[ad(i,h)+4|0],t[E+4|0]=F}if(t[lc(l,h)|0]<0){E=e,F=w[ad(i,h)+3|0],t[E+3|0]=F;E=e,F=w[ad(i,h)+5|0],t[E+5|0]=F}if(t[lc(l,h)|0]&1){v[22656]=0;c=T(374,k|0)|0;f=v[22656];v[22656]=0;C=e;rb:{sb:{if((f|0)!=1){c=c+(((c^-1)&128)>>>7|0)|0;if(!(v[a+480180>>2]&16777216)){break sb}f=c;break rb}break ob}f=253;if((c-121&255)>>>0<132){break rb}f=(c&255)==253?0:c}t[C|0]=f;E=ad(i,h),F=f,t[E|0]=F}if(w[lc(l,h)|0]&2){v[22656]=0;c=T(374,k|0)|0;f=v[22656];v[22656]=0;if((f|0)==1){break ob}t[e+1|0]=c;E=ad(i,h),F=c,t[E+1|0]=F}if(w[lc(l,h)|0]&4){v[22656]=0;g=T(374,k|0)|0;f=v[22656];v[22656]=0;C=e;tb:{ub:{vb:{if((f|0)!=1){if(g>>>0>64){break vb}t[e+4|0]=g;f=1;break ub}break ob}if(!(g>>>0>192|g<<24>>24>=0)){f=2;t[e+2|0]=2;t[e+4|0]=g^128;break tb}if(g>>>0<=74){f=5;t[e+2|0]=5;t[e+4|0]=g-65;break tb}if(g>>>0<=84){f=6;t[e+2|0]=6;t[e+4|0]=g-75;break tb}if(g>>>0<=94){f=3;t[e+2|0]=3;t[e+4|0]=g-85;break tb}if(g>>>0<=104){f=4;t[e+2|0]=4;t[e+4|0]=g-95;break tb}if(g>>>0<=114){f=13;t[e+2|0]=13;t[e+4|0]=g-105;break tb}if(g>>>0<=124){f=12;t[e+2|0]=12;t[e+4|0]=g-115;break tb}f=g+63|0;if((f&255)>>>0<=9){t[e+4|0]=f;f=11;break ub}f=g+53|0;c=f&255;if(c>>>0<=9){t[e+4|0]=f;f=8;t[e+2|0]=8;if(!c|v[a+1074308>>2]-1>>>0>18285139){break tb}f=7;break ub}f=g+33|0;if((f&255)>>>0>=10){f=w[e+2|0];break tb}t[e+4|0]=f;f=15}t[C+2|0]=f}E=ad(i,h),F=f,t[E+2|0]=F;c=w[e+4|0];E=ad(i,h),F=c,t[E+4|0]=F}if(!(w[lc(l,h)|0]&8)){break nb}v[22656]=0;R(403,d+24|0,k|0);c=v[22656];v[22656]=0;if((c|0)!=1){wb:{c=d+24|0;f=qd(c);t[e+3|0]=w[c|0];t[e+5|0]=w[f|0];v[22656]=0;_u(e,1);c=v[22656];v[22656]=0;if((c|0)==1){break wb}c=w[e+3|0];E=ad(i,h),F=c,t[E+3|0]=F;c=w[e+5|0];E=ad(i,h),F=c,t[E+5|0]=F;break nb}}}}a=P()|0;O()|0;jn(i);break lb}if(m>>>0<p>>>0){continue}break}}jn(i);gc(l);xb(d+104|0);break cb}a=P()|0;O()|0}gc(l);break kb}a=P()|0;O()|0;break kb}a=P()|0;O()|0}xb(d+104|0);break j}a=P()|0;O()|0;break j}e=x[d+68>>1]+1|0;u[d+68>>1]=e;if(x[d+84>>1]>(e&65535)>>>0){continue}break}}c=a+1074308|0;xb:{yb:{zb:{if(v[a+1074308>>2]){break zb}if((w[d+344|0]|w[d+345|0]<<8)==2184){v[a+1074308>>2]=18284544;break zb}if(!v[c>>2]){break yb}}if(!gd(j)){break yb}v[22656]=0;e=Q(2,d+32|0,14719)|0;f=v[22656];v[22656]=0;Ab:{Bb:{Cb:{Db:{Eb:{Fb:{if((f|0)!=1){v[22656]=0;R(162,d+88|0,c|0);f=v[22656];v[22656]=0;if((f|0)==1){break Fb}v[22656]=0;U(3,d+104|0,e|0,d+88|0);f=v[22656];v[22656]=0;if((f|0)==1){break Eb}f=d+104|0;Eb(j,f);vb(f);vb(d+88|0);vb(e);if(v[d+364>>2]==1414548815|((w[d+344|0]|w[d+345|0]<<8)&61440)!=20480){break Ab}v[22656]=0;c=Q(2,d+104|0,13955)|0;e=v[22656];v[22656]=0;if((e|0)==1){break Cb}v[22656]=0;Q(113,j|0,c|0)|0;e=v[22656];v[22656]=0;if((e|0)==1){break Bb}vb(c);break xb}a=P()|0;O()|0;break j}a=P()|0;O()|0;break Db}a=P()|0;O()|0;vb(d+88|0)}vb(e);break j}a=P()|0;O()|0;break j}a=P()|0;O()|0;vb(c);break j}if(!rH(c)){break xb}v[22656]=0;c=Q(2,d+104|0,14191)|0;e=v[22656];v[22656]=0;Gb:{if((e|0)!=1){v[22656]=0;Q(113,j|0,c|0)|0;e=v[22656];v[22656]=0;if((e|0)==1){break Gb}vb(c);break xb}a=P()|0;O()|0;break j}a=P()|0;O()|0;vb(c);break j}if((w[d+344|0]|w[d+345|0]<<8)==8191){c=w[d+364|0]|w[d+365|0]<<8|(w[d+366|0]<<16|w[d+367|0]<<24)}else{c=(w[d+344|0]|w[d+345|0]<<8)-4176|0}Hb:{switch((w[d+344|0]|w[d+345|0]<<8)>>>12|0){case 0:if(D){v[22656]=0;c=Q(2,d+104|0,5473)|0;e=v[22656];v[22656]=0;if((e|0)!=1){Eb(j,c);vb(c);break xb}a=P()|0;O()|0;break j}Ib:{if((w[d+344|0]|w[d+345|0]<<8)!=532|(w[d+346|0]|w[d+347|0]<<8)!=512|(w[d+350|0]|w[d+351|0]<<8|(w[d+348|0]|w[d+349|0]<<8)!=9)){break Ib}if(w[d+335|0]|w[d+334|0]|(w[d+338|0]|w[d+339|0]<<8|((w[d+342|0]|w[d+343|0]<<8)+1|0)!=(w[d+336|0]|w[d+337|0]<<8))){break Ib}if(w[d+352|0]!=128|w[d+353|0]!=100|(w[d+354|0]!=1|w[d+356|0]!=128)){break Ib}if(w[d+357|0]|(w[d+358|0]|w[d+359|0]<<8)|(w[d+360|0]|w[d+361|0]<<8|(w[d+362|0]<<16|w[d+363|0]<<24)|(w[d+364|0]|w[d+365|0]<<8|(w[d+366|0]<<16|w[d+367|0]<<24)))){break Ib}v[22656]=0;c=Q(2,d+104|0,7106)|0;e=v[22656];v[22656]=0;if((e|0)!=1){Eb(j,c);vb(c);break xb}a=P()|0;O()|0;break j}Jb:{if((w[d+344|0]|w[d+345|0]<<8)!=532|(w[d+346|0]|w[d+347|0]<<8)!=512|(w[d+335|0]|w[d+334|0])){break Jb}if(w[d+364|0]|w[d+365|0]<<8|(w[d+366|0]<<16|w[d+367|0]<<24)){break Jb}v[a+1074308>>2]=16777381;v[22656]=0;c=Q(2,d+104|0,12106)|0;e=v[22656];v[22656]=0;if((e|0)!=1){Eb(j,c);vb(c);t[d+303|0]=1;break xb}a=P()|0;O()|0;break j}if(!((w[d+344|0]|w[d+345|0]<<8)!=532|(w[d+346|0]|w[d+347|0]<<8)!=532|v[d+364>>2]!=1229080643)){v[22656]=0;c=Q(2,d+104|0,5525)|0;e=v[22656];v[22656]=0;if((e|0)!=1){Eb(j,c);vb(c);v[22656]=0;Q(410,a+1074312|0,38)|0;c=v[22656];v[22656]=0;if((c|0)!=1){break xb}break r}a=P()|0;O()|0;break j}Kb:{if((w[d+344|0]|w[d+345|0]<<8)!=532|(w[d+346|0]|w[d+347|0]<<8)!=532|(w[d+357|0]|(w[d+350|0]|w[d+351|0]<<8)>>>0>1)){break Kb}if(!x[a+480190>>1]|(w[d+364|0]|w[d+365|0]<<8|(w[d+366|0]<<16|w[d+367|0]<<24)|((w[d+348|0]|w[d+349|0]<<8)&4294)!=4)){break Kb}v[22656]=0;c=Q(70,d+104|0,10812)|0;e=v[22656];v[22656]=0;Lb:{Mb:{if((e|0)!=1){v[22656]=0;e=Q(596,a+484527|0,c|0)|0;f=v[22656];v[22656]=0;if((f|0)==1){break Mb}vb(c);if(!e){break Kb}v[22656]=0;c=Q(2,d+104|0,5551)|0;e=v[22656];v[22656]=0;if((e|0)==1){break Lb}Eb(j,c);vb(c);break xb}a=P()|0;O()|0;break j}a=P()|0;O()|0;vb(c);break j}a=P()|0;O()|0;break j}Nb:{if(w[d+344|0]|w[d+345|0]<<8){break Nb}if(!gd(j)){break Nb}v[22656]=0;c=Q(2,d+104|0,6892)|0;e=v[22656];v[22656]=0;if((e|0)!=1){Eb(j,c);vb(c);break xb}a=P()|0;O()|0;break j}if((w[d+346|0]|w[d+347|0]<<8)>>>0>767){break xb}if(!gd(j)){break xb}Ob:{Pb:{Qb:{Rb:{Sb:{if((w[d+346|0]|w[d+347|0]<<8)>>>0>=533){v[22656]=0;c=Q(2,d+104|0,12153)|0;e=v[22656];v[22656]=0;if((e|0)!=1){Eb(j,c);vb(c);break Sb}a=P()|0;O()|0;break j}if((w[d+344|0]|w[d+345|0]<<8)>>>0>=533){v[22656]=0;R(597,d+32|0,1124);c=v[22656];v[22656]=0;Tb:{if((c|0)!=1){c=w[d+344|0]|w[d+345|0]<<8;v[22656]=0;v[d+88>>2]=c-532;U(598,d+104|0,d+32|0,d+88|0);c=v[22656];v[22656]=0;if((c|0)==1){break Tb}c=d+104|0;Eb(j,c);vb(c);Hb(d+32|0);break Sb}a=P()|0;O()|0;break j}a=P()|0;O()|0;Hb(d+32|0);break j}v[22656]=0;R(411,d+32|0,1423);c=v[22656];v[22656]=0;if((c|0)==1){break Rb}v[d+72>>2]=w[d+345|0]&15;c=w[d+344|0];v[22656]=0;v[d+56>>2]=c;R(599,d+88|0,d+56|0);c=v[22656];v[22656]=0;if((c|0)==1){break Qb}v[22656]=0;Y(582,d+104|0,d+32|0,d+72|0,d+88|0);c=v[22656];v[22656]=0;if((c|0)==1){break Pb}c=d+104|0;Eb(j,c);vb(c);vb(d+88|0);Hb(d+32|0)}c=a+1298368|0;if(!cd(c)|!(w[d+364|0]|w[d+365|0]<<8|(w[d+366|0]<<16|w[d+367|0]<<24))){break xb}e=w[d+344|0]|w[d+345|0]<<8;f=w[d+364|0]|w[d+365|0]<<8|(w[d+366|0]<<16|w[d+367|0]<<24);v[22656]=0;e=xw(e,f);f=v[22656];v[22656]=0;if((f|0)==1){break u}f=Dr(d+104|0);v[f+44>>2]=e;v[22656]=0;R(601,c|0,f|0);c=v[22656];v[22656]=0;if((c|0)!=1){break xb}a=P()|0;O()|0;break j}a=P()|0;O()|0;break j}a=P()|0;O()|0;break Ob}a=P()|0;O()|0;vb(d+88|0)}Hb(d+32|0);break j;case 1:e=w[d+344|0]|w[d+345|0]<<8;f=w[d+364|0]|w[d+365|0]<<8|(w[d+366|0]<<16|w[d+367|0]<<24);v[22656]=0;U(602,d+104|0,e|0,f|0);e=v[22656];v[22656]=0;Ub:{Vb:{Wb:{Xb:{Yb:{Zb:{if((e|0)!=1){e=d+104|0;Eb(j,e);vb(e);if((c|0)>1915){break Zb}g=v[a+480208>>2];if(!(g&16)){break Yb}v[22656]=0;Q(410,a+1074312|0,7)|0;c=v[22656];v[22656]=0;if((c|0)==1){break r}break Xb}a=P()|0;O()|0;break j}if(c>>>0>4200){break Vb}g=v[a+480208>>2]}if(!(g&16)){v[22656]=0;Q(410,a+1074312|0,7)|0;e=v[22656];v[22656]=0;if((e|0)==1){break r}}if((c|0)>2385){break Wb}}v[22656]=0;Q(410,a+1074312|0,38)|0;c=v[22656];v[22656]=0;if((c|0)==1){break r}}v[22656]=0;c=a+1074312|0;Q(410,c|0,102)|0;e=v[22656];v[22656]=0;if((e|0)==1){break r}v[22656]=0;Q(410,c|0,48)|0;c=v[22656];v[22656]=0;if((c|0)==1){break r}break Ub}if(c>>>0>4383){break xb}}v[22656]=0;c=a+1074312|0;W(409,c|0,116,1)|0;e=v[22656];v[22656]=0;if((e|0)==1){break r}v[22656]=0;Q(410,c|0,115)|0;c=v[22656];v[22656]=0;if((c|0)==1){break r}break xb;case 4:v[22656]=0;R(603,d+32|0,1487);c=v[22656];v[22656]=0;_b:{$b:{ac:{if((c|0)!=1){v[d+72>>2]=w[d+345|0]&15;c=w[d+344|0];v[22656]=0;v[d+56>>2]=c;R(599,d+88|0,d+56|0);c=v[22656];v[22656]=0;if((c|0)==1){break ac}v[22656]=0;Y(582,d+104|0,d+32|0,d+72|0,d+88|0);c=v[22656];v[22656]=0;if((c|0)==1){break $b}c=d+104|0;Eb(j,c);vb(c);vb(d+88|0);Hb(d+32|0);break xb}a=P()|0;O()|0;break j}a=P()|0;O()|0;break _b}a=P()|0;O()|0;vb(d+88|0)}Hb(d+32|0);break j;case 6:v[22656]=0;c=Q(2,d+104|0,5473)|0;e=v[22656];v[22656]=0;if((e|0)!=1){Eb(j,c);vb(c);break xb}a=P()|0;O()|0;break j;case 7:if(!((w[d+344|0]|w[d+345|0]<<8)!=32767|(w[d+346|0]|w[d+347|0]<<8)!=533)){v[22656]=0;c=Q(2,d+104|0,2138)|0;e=v[22656];v[22656]=0;if((e|0)!=1){Eb(j,c);vb(c);break xb}a=P()|0;O()|0;break j}v[22656]=0;R(158,d+32|0,1259);c=v[22656];v[22656]=0;bc:{if((c|0)!=1){v[d+88>>2]=w[d+345|0]&15;v[d+72>>2]=(w[d+344|0]|w[d+345|0]<<8)>>>4&15;c=w[d+344|0]|w[d+345|0]<<8;v[22656]=0;v[d+56>>2]=c&15;ha(159,d+104|0,d+32|0,d+88|0,d+72|0,d+56|0);c=v[22656];v[22656]=0;if((c|0)==1){break bc}c=d+104|0;Eb(j,c);vb(c);Hb(d+32|0);break xb}a=P()|0;O()|0;break j}a=P()|0;O()|0;Hb(d+32|0);break j;case 13:break Hb;default:break xb}}v[22656]=0;c=Q(2,d+104|0,3180)|0;e=v[22656];v[22656]=0;if((e|0)==1){break t}Eb(j,c);vb(c)}cc:{if(v[a+480180>>2]!=16777216|(w[d+344|0]|w[d+345|0]<<8)>>>0<2186){break cc}v[22656]=0;c=Q(190,b|0,s|0)|0;e=v[22656];v[22656]=0;if((e|0)==1){break q}if(!c){break cc}c=w[d+344|0]|w[d+345|0]<<8;v[22656]=0;U(604,a|0,b|0,c|0);b=v[22656];v[22656]=0;if((b|0)==1){break q}}b=v[a+480180>>2];dc:{if((b|0)==16777216){v[22656]=0;Q(2,d+104|0,11117)|0;c=v[22656];v[22656]=0;if((c|0)!=1){break dc}a=P()|0;O()|0;break j}v[22656]=0;R(411,d+32|0,1423);c=v[22656];v[22656]=0;if((c|0)==1){break y}v[d+72>>2]=w[d+347|0];c=w[d+346|0];v[22656]=0;v[d+56>>2]=c;R(599,d+88|0,d+56|0);c=v[22656];v[22656]=0;if((c|0)==1){break x}v[22656]=0;Y(582,d+104|0,d+32|0,d+72|0,d+88|0);c=v[22656];v[22656]=0;if((c|0)==1){break w}}c=d+104|0;Eb(a+1298304|0,c);vb(c);if((b|0)!=16777216){vb(d+88|0);Hb(d+32|0)}ec:{if(v[a+480180>>2]==16777216){v[22656]=0;Q(2,d+104|0,7394)|0;b=v[22656];v[22656]=0;if((b|0)!=1){break ec}break s}v[22656]=0;Q(2,d+104|0,3184)|0;b=v[22656];v[22656]=0;if((b|0)==1){break s}}b=d+104|0;Eb(a+1298316|0,b);vb(b);Eb(a+1298328|0,j);v[a+1298364>>2]=v[a+1074308>>2]?8:5;xb(A);xb(z);e=1}di(n);di(q);di(r);break d}a=P()|0;O()|0;break j}a=P()|0;O()|0;break v}a=P()|0;O()|0;vb(d+88|0)}Hb(d+32|0);break j}a=P()|0;O()|0;break j}a=P()|0;O()|0;break j}a=P()|0;O()|0;break j}a=P()|0;O()|0;break j}a=P()|0;O()|0;break j}a=P()|0;O()|0;gc(c);break n}a=P()|0;O()|0}xb(d+104|0);break j}a=P()|0;O()|0;break j}a=P()|0;O()|0;break j}a=P()|0;O()|0}xb(A)}xb(z);break g}a=P()|0;O()|0}di(n);di(q);di(r);break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;break a}vb(j)}gb=d+496|0;return e|0}a=P()|0;O()|0}vb(j);S(a|0);L()}function ana(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,z=0,A=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,M=0,N=0,V=0;d=gb-1712|0;gb=d;vc(b);a:{if(!Ih(b,d+1704|0)){break a}if(!OV(d+1704|0)){break a}if(!c){f=1;break a}e=w[d+1704|3];t[d+1703|0]=e;v[d+1696>>2]=-1;v[d+1692>>2]=1048576;if(e>>>0>=5){e=sg(b);v[d+1696>>2]=e;if(!Pb(b,e)){break a}v[d+304>>2]=134217727;N=d,V=v[Fb(d+304|0,d+1696|0)>>2]<<5,v[N+1692>>2]=V}C=mc(d+1680|0);e=d+1704|4;h=w[e|0]|w[e+1|0]<<8|(w[e+2|0]<<16|w[e+3|0]<<24);v[22656]=0;v[d+304>>2]=h;h=Fb(d+1692|0,d+304|0);g=v[22656];v[22656]=0;b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{t:{u:{v:{w:{x:{if((g|0)==1){break x}h=v[h>>2];v[22656]=0;R(729,C|0,h|0);h=v[22656];v[22656]=0;if((h|0)==1){break x}e=w[e|0]|w[e+1|0]<<8|(w[e+2|0]<<16|w[e+3|0]<<24);v[22656]=0;e=W(730,b|0,C|0,e|0)|0;h=v[22656];v[22656]=0;y:{if((h|0)==1){break y}if(!e){break t}if(w[d+1703|0]>=5){v[22656]=0;Q(190,b|0,v[d+1696>>2]+12|0)|0;e=v[22656];v[22656]=0;if((e|0)==1){break y}}v[22656]=0;R(367,a|0,0);e=v[22656];v[22656]=0;if((e|0)==1){break y}v[22656]=0;Bg(a);e=v[22656];v[22656]=0;if((e|0)==1){break y}v[22656]=0;Vd(d+1648|0,C);h=v[22656];v[22656]=0;e=a;z:{A:{B:{C:{if((h|0)==1){break C}h=Ud(d+1640|0);v[22656]=0;g=v[d+1652>>2];v[d+96>>2]=v[d+1648>>2];v[d+100>>2]=g;g=v[h+4>>2];v[d+88>>2]=v[h>>2];v[d+92>>2]=g;l=W(732,d+1656|0,d+96|0,d+88|0)|0;h=v[22656];v[22656]=0;if((h|0)==1){break C}v[22656]=0;W(534,l|0,a+1298268|0,-1)|0;h=v[22656];v[22656]=0;if((h|0)==1){break B}v[22656]=0;W(534,l|0,a+1298292|0,-1)|0;h=v[22656];v[22656]=0;if((h|0)==1){break B}v[22656]=0;h=Q(733,l|0,d+1216|0)|0;g=v[22656];v[22656]=0;if((g|0)==1){break d}if(!h|!w[d+1216|0]|t[d+1216|0]<0){break u}h=d+1225|0;if((w[h|0]|w[h+1|0]<<8)>>>0>255){break u}g=d+1227|0;if((w[g|0]|w[g+1|0]<<8)>>>0>3999){break u}n=d+1216|0;u[a+480188>>1]=w[n|0];j=a+484360|0;n=n|3;cf(Sb(j),w[n|0]|w[n+1|0]<<8);u[a+480192>>1]=w[h|0]|w[h+1|0]<<8;u[a+480190>>1]=w[g|0]|w[g+1|0]<<8;h=d+1229|0;if(w[h|0]){break A}h=6;break z}g=P()|0;O()|0;break b}g=P()|0;O()|0;break c}h=w[h|0]}v[e+480196>>2]=h;e=a;h=d+1230|0;if(w[h|0]){h=w[h|0]}else{h=125}v[e+480204>>2]=B(h,1e4);n=d+1231|0;D:{if(t[n+1|0]&1){v[22656]=0;R(558,a|0,32);e=v[22656];v[22656]=0;if((e|0)!=1){break D}break d}if(w[n|0]&2){v[22656]=0;R(558,a|0,2);e=v[22656];v[22656]=0;if((e|0)==1){break d}break D}if(w[n|0]&128){v[22656]=0;R(558,a|0,1);e=v[22656];v[22656]=0;if((e|0)==1){break d}break D}if(w[n|0]&8){v[22656]=0;R(558,a|0,16);e=v[22656];v[22656]=0;if((e|0)==1){break d}break D}v[22656]=0;R(558,a|0,4);e=v[22656];v[22656]=0;if((e|0)==1){break d}}v[a+480208>>2]=v[a+480208>>2]|16777216;if(t[n|0]&1){v[a+480208>>2]=v[a+480208>>2]|16}if(!(!(w[n|0]&16)|v[a+480180>>2]!=2)){v[a+480208>>2]=v[a+480208>>2]|65536}if(!(!(w[n|0]&4)|v[a+480180>>2]!=2)){v[a+480208>>2]=v[a+480208>>2]|2}if(!(w[n+1|0]&8|v[a+480180>>2]!=32)){v[a+480208>>2]=v[a+480208>>2]|4}if(!(w[n+1|0]&4|v[a+480180>>2]!=32)){v[a+480208>>2]=v[a+480208>>2]|8}if(w[n+2|0]&32){v[a+480208>>2]=v[a+480208>>2]|32768}if(w[n+2|0]&8){v[22656]=0;W(409,a+1074312|0,5,1)|0;e=v[22656];v[22656]=0;if((e|0)==1){break d}}E:{e=v[a+480180>>2];F:{if((e|0)!=2){if((e|0)!=32){break F}t[d+304|0]=w[d+1235|0];v[22656]=0;t[d+224|0]=128;e=ac(d+304|0,d+224|0);h=v[22656];v[22656]=0;if((h|0)==1){break w}v[a+480200>>2]=w[e|0]<<1;break F}t[d+304|0]=w[d+1235|0];v[22656]=0;t[d+224|0]=64;e=ac(d+304|0,d+224|0);h=v[22656];v[22656]=0;if((h|0)==1){break E}v[a+480200>>2]=w[e|0]<<2}J=a+480188|0;g=d+1237|0;h=t[g|0];e=a;if(t[g|0]<0){h=h+52|0}else{G=cx(+(h|0)*3.1/20);G:{if(G<4294967296&G>=0){h=~~G>>>0;break G}h=0}h=h+51|0}v[e+480228>>2]=h;v[22656]=0;u[d+304>>1]=64;e=Pc(J,d+304|0);h=v[22656];v[22656]=0;if((h|0)!=1){H:{h=x[e>>1];if(h){while(1){e=v[a+480180>>2];if((e|0)==32){t[d+304|0]=w[(d+f|0)+1238|0];v[22656]=0;t[d+224|0]=64;e=ac(d+304|0,d+224|0);g=v[22656];v[22656]=0;if((g|0)==1){break H}u[((f<<5)+a|0)+480286>>1]=w[e|0];e=v[a+480180>>2]}I:{if((e|0)==4){break I}e=(d+f|0)+1302|0;if(w[e|0]==127){v[((f<<5)+a|0)+480280>>2]=256;break I}if(w[e|0]==255){u[((f<<5)+a|0)+480284>>1]=256;break I}u[((f<<5)+a|0)+480284>>1]=w[e|0]}f=f+1|0;if((h|0)!=(f|0)){continue}break}}f=0;g=0;while(1){f=w[(d+g|0)+1366|0]!=0|f;g=g+1|0;if((g|0)!=16){continue}break}while(1){f=w[((k<<1)+d|0)+1383|0]!=0|f;k=k+1|0;if((k|0)!=128){continue}break}if(f&1){f=0;while(1){J:{e=(d+f|0)+1366|0;if(w[e|0]){v[22656]=0;_(734,d+224|0);h=v[22656];v[22656]=0;K:{L:{M:{N:{O:{if((h|0)!=1){e=w[e|0];v[22656]=0;v[d+248>>2]=e-1;R(735,d+1192|0,d+248|0);e=v[22656];v[22656]=0;if((e|0)==1){break O}v[22656]=0;U(443,d+304|0,d+224|0,d+1192|0);e=v[22656];v[22656]=0;if((e|0)==1){break N}v[22656]=0;R(444,d+1168|0,((f<<5)+a|0)+901692|0);e=v[22656];v[22656]=0;if((e|0)==1){break M}v[22656]=0;Q(401,d+1168|0,d+304|0)|0;e=v[22656];v[22656]=0;if((e|0)==1){break M}vb(d+304|0);vb(d+1192|0);Hb(d+224|0);break J}g=P()|0;O()|0;break c}g=P()|0;O()|0;break K}g=P()|0;O()|0;break L}g=P()|0;O()|0;vb(d+304|0)}vb(d+1192|0)}Hb(d+224|0);break c}v[22656]=0;e=Q(70,d+304|0,18726)|0;h=v[22656];v[22656]=0;P:{if((h|0)!=1){v[22656]=0;R(444,d+224|0,((f<<5)+a|0)+901692|0);h=v[22656];v[22656]=0;if((h|0)==1){break P}v[22656]=0;Q(401,d+224|0,e|0)|0;h=v[22656];v[22656]=0;if((h|0)==1){break P}vb(e);break J}g=P()|0;O()|0;break c}g=P()|0;O()|0;vb(e);break c}f=f+1|0;if((f|0)!=16){continue}break}f=0;while(1){e=(d+1216|0)+(f<<1)|0;h=e;Q:{if(w[e+167|0]){v[22656]=0;_(736,d+224|0);g=v[22656];v[22656]=0;R:{S:{T:{U:{V:{W:{X:{if((g|0)!=1){h=w[h+167|0];v[22656]=0;v[d+192>>2]=h-1;R(735,d+1192|0,d+192|0);h=v[22656];v[22656]=0;if((h|0)==1){break X}e=w[e+166|0];v[22656]=0;t[d+168|0]=e;R(737,d+1168|0,d+168|0);e=v[22656];v[22656]=0;if((e|0)==1){break W}v[22656]=0;Y(738,d+304|0,d+224|0,d+1192|0,d+1168|0);e=v[22656];v[22656]=0;if((e|0)==1){break V}v[22656]=0;R(444,d+248|0,((f<<5)+a|0)+902204|0);e=v[22656];v[22656]=0;if((e|0)==1){break U}v[22656]=0;Q(401,d+248|0,d+304|0)|0;e=v[22656];v[22656]=0;if((e|0)==1){break U}vb(d+304|0);vb(d+1168|0);vb(d+1192|0);Hb(d+224|0);break Q}g=P()|0;O()|0;break c}g=P()|0;O()|0;break R}g=P()|0;O()|0;break S}g=P()|0;O()|0;break T}g=P()|0;O()|0;vb(d+304|0)}vb(d+1168|0)}vb(d+1192|0)}Hb(d+224|0);break c}v[22656]=0;e=Q(70,d+304|0,18726)|0;h=v[22656];v[22656]=0;Y:{if((h|0)!=1){v[22656]=0;R(444,d+224|0,((f<<5)+a|0)+902204|0);h=v[22656];v[22656]=0;if((h|0)==1){break Y}v[22656]=0;Q(401,d+224|0,e|0)|0;h=v[22656];v[22656]=0;if((h|0)==1){break Y}vb(e);break Q}g=P()|0;O()|0;break c}g=P()|0;O()|0;vb(e);break c}f=f+1|0;if((f|0)!=128){continue}break}}e=Sb(j);f=d+1216|1;f=w[f|0]|w[f+1|0]<<8;v[22656]=0;fa(522,e|0,l|0,f|0,255,254)|0;e=v[22656];v[22656]=0;Z:{_:{$:{aa:{ba:{ca:{if((e|0)!=1){e=d+1216|0;j=e|5;f=w[j|0]|w[j+1|0]<<8;e=w[e|0];v[22656]=0;U(288,d+304|0,l|0,B(e,f)<<1);e=v[22656];v[22656]=0;if((e|0)==1){break ca}e=d+304|0;H=kc(d+1192|0,e);xb(e);f=w[j|0]|w[j+1|0]<<8;v[22656]=0;U(288,e|0,l|0,f<<1);e=v[22656];v[22656]=0;if((e|0)==1){break ba}e=d+304|0;I=kc(d+1168|0,e);xb(e);e=d+1216|7;e=w[e|0]|w[e+1|0]<<8;v[22656]=0;A=Q(328,d+1152|0,e|0)|0;e=v[22656];v[22656]=0;if((e|0)==1){break aa}N=d,V=Vb(A),v[N+248>>2]=V;N=d,V=Zb(A),v[N+192>>2]=V;if(Gb(d+248|0,d+192|0)){while(1){e=v[d+248>>2];v[22656]=0;f=T(192,l|0)|0;h=v[22656];v[22656]=0;if((h|0)==1){break $}v[22656]=0;U(288,d+224|0,l|0,f|0);f=v[22656];v[22656]=0;if((f|0)==1){break _}h=e;e=d+304|0;f=d+224|0;Vc(h,kc(e,f));xb(e);xb(f);e=d+248|0;Eh(e);if(Gb(e,d+192|0)){continue}break}}e=v[a+480180>>2];s=1;q=c&1;if(!q){break Z}f=w[j|0]|w[j+1|0]<<8;v[22656]=0;R(330,a+484344|0,f|0);f=v[22656];v[22656]=0;if((f|0)!=1){break Z}g=P()|0;O()|0;break g}g=P()|0;O()|0;break c}g=P()|0;O()|0;break c}g=P()|0;O()|0;break e}g=P()|0;O()|0;break f}g=P()|0;O()|0;break g}g=P()|0;O()|0;break g}E=a+484344|0;da:{ea:{fa:{ga:{ha:{ia:{if(w[j|0]|w[j+1|0]<<8){r=(e|0)==16?14:(e|0)==32?1:13;while(1){v[22656]=0;e=T(287,I|0)|0;f=v[22656];v[22656]=0;if((f|0)==1){break da}v[d+224>>2]=e;ja:{if(!q){break ja}v[22656]=0;e=W(331,E|0,o&65535,e|0)|0;f=v[22656];v[22656]=0;if((f|0)==1){break da}if(!e){break ja}i=0;if(!w[d+1216|0]){break ja}while(1){v[22656]=0;e=T(287,H|0)|0;f=v[22656];v[22656]=0;if((f|0)==1){break ea}ka:{if(Je(A)>>>0<=e>>>0){break ka}z=Lg(A,e);vc(z);e=_b(E,o);v[22656]=0;f=Yc(e,0,i&65535);e=v[22656];v[22656]=0;if((e|0)==1){break h}h=0;if(!v[d+224>>2]){break ka}while(1){v[22656]=0;m=T(374,z|0)|0;e=v[22656];v[22656]=0;la:{ma:{if((e|0)!=1){if(!m){break ka}gi(d+304|0);k=0;p=m&15;if(p){break ma}break la}g=P()|0;O()|0;break g}while(1){na:{v[22656]=0;R(739,z|0,d+248|0);e=v[22656];v[22656]=0;if((e|0)==1){break na}oa:{pa:{qa:{ra:{sa:{ta:{ua:{va:{wa:{xa:{ya:{za:{Aa:{Ba:{Ca:{Da:{Ea:{Fa:{Ga:{Ha:{Ia:{e=w[d+248|0];switch(e-1|0){case 2:case 3:case 4:case 7:case 8:case 9:case 11:case 12:case 13:case 16:case 18:case 21:case 22:case 23:case 24:case 25:case 27:case 32:break qa;case 33:break ua;case 30:case 31:break va;case 29:break wa;case 28:break xa;case 26:break ya;case 19:case 20:break za;case 17:break Aa;case 15:break Ba;case 14:break Ca;case 10:break Da;case 6:break Ea;case 5:break Fa;case 1:break Ga;case 0:break Ha;default:break Ia}}switch(e-48|0){case 4:break ra;case 1:case 2:break sa;case 0:break ta;default:break qa}}e=w[d+249|0];Ja:{if(e>>>0<=119){t[d+304|0]=e+r;break Ja}Ka:{switch(e-254|0){case 1:t[d+304|0]=255;break Ja;case 0:t[d+304|0]=254;break Ja;default:break Ka}}t[d+304|0]=253}v[22656]=0;e=Dv(d+304|0);g=v[22656];v[22656]=0;if((g|0)==1){break na}s=e&s;break oa}t[d+305|0]=w[d+249|0]+1;break oa}La:{if(w[d+306|0]){break La}e=v[a+480180>>2];if((e|0)!=32){if((e|0)!=4){break La}e=w[d+249|0];if(e&15){break La}t[d+306|0]=11;t[d+308|0]=e>>>4;break oa}g=0;e=w[d+249|0];while(1){if((e|0)==w[g+39104|0]){t[d+308|0]=g;t[d+306|0]=11;break oa}g=g+1|0;if((g|0)!=10){continue}break}}t[d+307|0]=4;t[d+309|0]=w[d+249|0];break oa}e=w[d+249|0];if(!(w[d+306|0]|e>>>0>9|v[a+480180>>2]!=32)){t[d+308|0]=e;t[d+306|0]=8;break oa}t[d+309|0]=e;t[d+307|0]=5;break oa}if(w[d+306|0]){g=w[d+249|0];break pa}e=v[a+480180>>2];D=(e|0)!=32;g=w[d+249|0];if(!(D|(g|0)!=255)){t[d+308|0]=64;t[d+306|0]=2;break oa}Ma:{if(!D){if(g&3){break pa}break Ma}if(g&15|(e|0)!=4){break pa}}t[d+306|0]=2;t[d+308|0]=(g&252)>>>2;break oa}e=w[d+249|0];if(!(w[d+306|0]|e>>>0>64|v[a+480180>>2]==1)){t[d+308|0]=e;t[d+306|0]=1;break oa}t[d+309|0]=e;t[d+307|0]=13;break oa}t[d+307|0]=14;e=w[d+249|0];t[d+309|0]=e;if(v[a+480180>>2]==32){break oa}t[d+309|0]=B((e&240)>>>4|0,10)+(e&15);break oa}e=w[d+249|0];t[d+309|0]=e;if(e>>>0<=31){t[d+307|0]=16;break oa}t[d+307|0]=17;break oa}g=w[d+249|0];if(g>>>0>=16){t[d+308|0]=g>>>4;t[d+306|0]=(e|0)==20?3:5;break oa}t[d+308|0]=g;t[d+306|0]=(e|0)==20?4:6;break oa}e=w[d+249|0];if(e>>>0>=16){t[d+306|0]=10;t[d+308|0]=e>>>4;break oa}t[d+308|0]=e;t[d+306|0]=9;break oa}t[d+307|0]=28;t[d+309|0]=w[d+249|0]|16;break oa}t[d+307|0]=28;t[d+309|0]=w[d+249|0]|32;break oa}t[d+308|0]=w[d+249|0];t[d+306|0]=w[e+33136|0];break oa}t[d+309|0]=w[d+249|0];e=w[d+307|0];t[d+307|0]=(e|0)==4?6:(e|0)==5?7:11;break oa}e=w[d+249|0];t[d+308|0]=(e>>>0)%10;if(e>>>0<=9){t[d+306|0]=5;break oa}if(e>>>0<=19){t[d+306|0]=6;break oa}if(e>>>0<=29){t[d+306|0]=3;break oa}if(e>>>0>39){break oa}t[d+306|0]=4;break oa}t[d+308|0]=w[d+249|0];t[d+306|0]=w[e+33136|0];break oa}e=w[d+249|0]+33|0;if((e&255)>>>0>9){break oa}t[d+308|0]=e;t[d+306|0]=15;break oa}if(e>>>0>=56){break oa}t[d+309|0]=w[d+249|0];t[d+307|0]=w[w[d+248|0]+33136|0];break oa}t[d+309|0]=g;t[d+307|0]=9}k=k+1|0;if(p>>>0>(k&255)>>>0){continue}break la}break}g=P()|0;O()|0;break g}v[22656]=0;v[d+248>>2]=(m>>>4|0)+h;e=Fb(d+248|0,d+224|0);g=v[22656];v[22656]=0;if((g|0)==1){break ia}e=v[e>>2];if(e>>>0>h>>>0){while(1){g=v[d+304>>2];t[f|0]=g;t[f+1|0]=g>>>8;t[f+2|0]=g>>>16;t[f+3|0]=g>>>24;g=x[d+308>>1];t[f+4|0]=g;t[f+5|0]=g>>>8;f=B(w[d+1216|0],6)+f|0;h=h+1|0;if((e|0)!=(h|0)){continue}break}h=e}if(y[d+224>>2]>h>>>0){continue}break}}i=i+1|0;if(w[d+1216|0]>(i&65535)>>>0){continue}break}}o=o+1|0;if(o>>>0<(w[j|0]|w[j+1|0]<<8)>>>0){continue}break}}if(!((s^1)&1|x[a+480188>>1]!=4|v[a+480180>>2]!=1)){v[a+480208>>2]=v[a+480208>>2]|8454144}if(v[a+480180>>2]!=4){break ha}j=0;break ga}g=P()|0;O()|0;break g}j=!((w[n|0]|w[n+1|0]<<8|(w[n+2|0]<<16|w[n+3|0]<<24))&512);e=0;if(v[a+480180>>2]!=4){break fa}}e=x[a+480192>>1]}v[22656]=0;s=Q(740,d+1136|0,e|0)|0;e=v[22656];v[22656]=0;h=1;if((e|0)!=1){Na:{Oa:{Pa:{if(x[a+480192>>1]){g=1;while(1){Qa:{Ra:{Sa:{if(!j){v[22656]=0;f=W(376,a|0,g&65535,0)|0;e=v[22656];v[22656]=0;if((e|0)==1){break Sa}if(f){break Ra}}while(1){v[22656]=0;e=T(374,l|0)|0;f=v[22656];v[22656]=0;if((f|0)==1){break j}if(e){continue}break}if(w[d+1703|0]>=5){while(1){v[22656]=0;e=T(374,l|0)|0;f=v[22656];v[22656]=0;if((f|0)==1){g=P()|0;O()|0;break i}if(e){continue}break}}v[22656]=0;Q(318,l|0,826)|0;e=v[22656];v[22656]=0;if((e|0)!=1){break Qa}}g=P()|0;O()|0;break i}e=Kb(d+224|0);v[22656]=0;W(534,l|0,e|0,-1)|0;k=v[22656];v[22656]=0;if((k|0)==1){break Pa}v[22656]=0;Q(301,f+492|0,e|0)|0;k=v[22656];v[22656]=0;if((k|0)==1){break Pa}Ta:{if(w[d+1703|0]<5){break Ta}v[22656]=0;W(534,l|0,e|0,-1)|0;k=v[22656];v[22656]=0;if((k|0)==1){break Pa}v[22656]=0;Q(301,f+524|0,e|0)|0;k=v[22656];v[22656]=0;if((k|0)!=1){break Ta}break Pa}v[22656]=0;k=Q(741,l|0,d+304|0)|0;i=v[22656];v[22656]=0;if((i|0)==1){break Pa}if(!k){break Oa}k=v[a+480180>>2];v[22656]=0;U(742,d+304|0,f|0,k|0);f=v[22656];v[22656]=0;if((f|0)==1){break Pa}if(v[a+480180>>2]==4){f=Mb(s,h-1|0);h=x[d+1106>>1]|x[d+1108>>1]<<16;t[f|0]=h;t[f+1|0]=h>>>8;t[f+2|0]=h>>>16;t[f+3|0]=h>>>24}vb(e)}g=g+1|0;h=g&65535;if(h>>>0<=x[a+480192>>1]){continue}break}}if(!j){break Na}u[a+480192>>1]=0;break Na}g=P()|0;O()|0;vb(e);break i}vb(e)}e=x[a+480190>>1];v[22656]=0;z=Q(743,d+288|0,e|0)|0;e=v[22656];v[22656]=0;o=1;if((e|0)!=1){o=w[d+1703|0]<=4?!(t[n|0]&1):o;D=c&2;e=0;Ua:{if(!x[a+480190>>1]){break Ua}k=1;h=1;while(1){c=e;m=Kb(d+272|0);v[22656]=0;W(534,l|0,m|0,-1)|0;e=v[22656];v[22656]=0;Va:{Wa:{Xa:{Ya:{Za:{if((e|0)==1){break Za}v[22656]=0;Q(301,((k<<5)+a|0)+946304|0,m|0)|0;e=v[22656];v[22656]=0;if((e|0)==1){break Za}g=B(k,104)+a|0;if(w[d+1703|0]<5){break Ya}v[22656]=0;W(534,l|0,m|0,-1)|0;e=v[22656];v[22656]=0;if((e|0)==1){break Za}v[22656]=0;Q(303,g+484423|0,m|0)|0;e=v[22656];v[22656]=0;if((e|0)!=1){break Ya}}g=P()|0;O()|0;break Xa}v[22656]=0;e=Q(744,l|0,d+304|0)|0;f=v[22656];v[22656]=0;_a:{$a:{ab:{bb:{cb:{db:{eb:{if((f|0)==1){break eb}if(!e){break db}e=v[a+480180>>2];v[22656]=0;f=g+484380|0;Y(745,d+304|0,f|0,e|0,o|0);e=v[22656];v[22656]=0;if((e|0)==1){break eb}j=0;fb:{if(((w[d+324|0]|w[d+325|0]<<8)&61440)!=28672|w[d+1703|0]<5){break fb}v[22656]=0;j=T(746,l|0)|0;e=v[22656];v[22656]=0;if((e|0)!=1){break fb}g=P()|0;O()|0;break Xa}if(!D){break Wa}K=w[d+324|0]|w[d+325|0]<<8;q=K&61440;if(!(q|(w[d+339|0]|w[d+340|0]<<8|(w[d+341|0]<<16|w[d+342|0]<<24)))){e=w[d+324|0]|w[d+325|0]<<8;e=Rc(d+224|0,e&1?16:8,e&1024?3:1,0,0);v[22656]=0;W(329,e|0,f|0,b|0)|0;e=v[22656];v[22656]=0;if((e|0)!=1){break Wa}g=P()|0;O()|0;break Xa}e=w[d+339|0]|w[d+340|0]<<8|(w[d+341|0]<<16|w[d+342|0]<<24);if(!((e|0)>=0|(e+k|0)<=0)){e=w[d+339|0]|w[d+340|0]<<8|(w[d+341|0]<<16|w[d+342|0]<<24);v[22656]=0;Q(747,f|0,(B(e+k|0,104)+a|0)+484380|0)|0;f=v[22656];v[22656]=0;e=c;if((f|0)!=1){break Va}g=P()|0;O()|0;break Xa}if((w[d+339|0]|w[d+340|0]<<8|(w[d+341|0]<<16|w[d+342|0]<<24))<=0){break Wa}if(t[d+324|0]&1){e=g+484414|0;u[e>>1]=x[e>>1]|1}if(w[d+325|0]&4){e=g+484414|0;u[e>>1]=x[e>>1]|64}e=w[d+339|0]|w[d+340|0]<<8|(w[d+341|0]<<16|w[d+342|0]<<24);v[22656]=0;U(288,d+224|0,b|0,e|0);i=v[22656];v[22656]=0;gb:{hb:{M=d;ib:{jb:{if((i|0)!=1){r=d+224|0;i=kc(d+248|0,r);xb(r);r=fd(f);e=(q|0)==16384;if(!e&(q|0)!=8192){break hb}v[22656]=0;p=T(195,d+248|0)|0;F=v[22656];v[22656]=0;if((F|0)==1){break gb}v[d+224>>2]=p;F=v[d+224>>2];p=4/(r>>>0)|0;if(F>>>0>4294967295/(p>>>0)>>>0){break jb}p=B(p,F);break ib}g=P()|0;O()|0;break Xa}p=-1}v[M+224>>2]=p;qc(f,p);if(!e){if((q|0)!=8192){break hb}v[22656]=0;e=T(386,f|0)|0;j=v[22656];v[22656]=0;if((j|0)==1){break $a}if(!e){break bb}if(t[d+324|0]&1){e=v[g+484400>>2];f=v[f>>2];v[22656]=0;Y(748,i|0,e|0,f|0,r|0);f=v[22656];v[22656]=0;e=c;if((f|0)!=1){break ab}break $a}e=v[g+484400>>2];f=v[f>>2];v[22656]=0;Y(749,i|0,e|0,f|0,r|0);f=v[22656];v[22656]=0;e=c;if((f|0)==1){break $a}break ab}v[22656]=0;e=T(386,f|0)|0;j=v[22656];v[22656]=0;if((j|0)==1){break $a}if(!e){break bb}if(t[d+324|0]&1){e=v[g+484400>>2];f=v[f>>2];v[22656]=0;Y(750,i|0,e|0,f|0,r|0);f=v[22656];v[22656]=0;e=c;if((f|0)==1){break $a}break ab}e=v[g+484400>>2];f=v[f>>2];v[22656]=0;Y(751,i|0,e|0,f|0,r|0);f=v[22656];v[22656]=0;e=c;if((f|0)==1){break $a}break ab}if((K&45056)==12288){e=NV(d+224|0,i,w[d+343|0]|w[d+344|0]<<8,j);f=Xl(z,k-1|0);Vc(f,e);v[f+20>>2]=v[e+20>>2];xb(e);break bb}if((q|0)!=32768){e=1;if((q|0)!=4096){break ab}e=le(d+224|0,i);v[22656]=0;Q(752,d+216|0,i|0)|0;j=v[22656];v[22656]=0;if((j|0)!=1){kb:{if(!w[d+221|0]){break kb}j=x[d+218>>1]<<1;if((j&65535)>>>0>(w[d+343|0]|w[d+344|0]<<8)>>>0){break kb}j=(w[d+343|0]|w[d+344|0]<<8)-j|0;t[d+343|0]=j;t[d+344|0]=j>>>8;v[22656]=0;Q(190,d+248|0,x[d+216>>1])|0;j=v[22656];v[22656]=0;if((j|0)==1){break cb}v[22656]=0;j=T(467,d+248|0)|0;k=v[22656];v[22656]=0;if((k|0)==1){break cb}v[22656]=0;U(288,d+168|0,d+248|0,j|0);j=v[22656];v[22656]=0;if((j|0)==1){break cb}j=d+192|0;k=d+168|0;Vc(e,kc(j,k));xb(j);xb(k)}v[22656]=0;e=fa(753,a|0,h&65535,e|0,1,1)|0;j=v[22656];v[22656]=0;if((j|0)==1){break cb}lb:{if(!e){v[22656]=0;c=v[22656];v[22656]=0;if((c|0)==1){break cb}c=1;break lb}mb:{if(!(w[d+343|0]|w[d+344|0]<<8)){break mb}e=w[d+343|0]|w[d+344|0]<<8;if(aj(f)>>>0<=e>>>0){break mb}e=w[d+343|0]|w[d+344|0]<<8;j=jj(f);g=g+484400|0;yh(zb(v[g>>2]),zb(v[g>>2])+(w[d+343|0]|w[d+344|0]<<8)|0,aj(f)-(w[d+343|0]|w[d+344|0]<<8)|0);v[f>>2]=v[f>>2]-((e>>>0)/(j>>>0)|0)}e=v[d+312>>2];v[d+164>>2]=e;v[d+68>>2]=e;if(y[f>>2]>(w[d+68|0]|w[d+69|0]<<8|(w[d+70|0]<<16|w[d+71|0]<<24))>>>0){v[f>>2]=w[d+68|0]|w[d+69|0]<<8|(w[d+70|0]<<16|w[d+71|0]<<24)}}e=c;xb(d+224|0);break ab}break cb}v[22656]=0;e=Q(576,i|0,d+224|0)|0;g=v[22656];v[22656]=0;if((g|0)!=1){if(!e){break bb}v[d+80>>2]=v[d+232>>2];v[22656]=0;e=v[d+228>>2];v[d+72>>2]=v[d+224>>2];v[d+76>>2]=e;U(577,f|0,1,d+72|0);e=v[22656];v[22656]=0;if((e|0)!=1){break bb}}g=P()|0;O()|0;break _a}g=P()|0;O()|0;break _a}g=P()|0;O()|0;break Xa}vb(m);e=c;break Ua}g=P()|0;O()|0;xb(d+224|0);break _a}e=c}xb(d+248|0);break Va}g=P()|0;O()|0}xb(d+248|0)}vb(m);break k}e=c}vb(m);h=h+1|0;k=h&65535;if(k>>>0<=x[a+480190>>1]){continue}break}}if(!(!D|!x[a+480190>>1])){f=1;i=1;while(1){c=Xl(z,f-1|0);v[22656]=0;b=T(275,c|0)|0;h=v[22656];v[22656]=0;nb:{ob:{pb:{if((h|0)!=1){if(!b){break nb}h=x[c+22>>1];b=h+i&65535;qb:{rb:{g=x[c+20>>1];k=(h|0)!=0&(b|0)!=0&b>>>0<=x[a+480190>>1]&(g|0)!=0;if(!k){v[22656]=0;T(195,c|0)|0;b=v[22656];v[22656]=0;if((b|0)!=1){break rb}break l}h=Xl(z,b-1|0);vc(h);b=x[c+20>>1];v[22656]=0;b=Q(191,h|0,b|0)|0;j=v[22656];v[22656]=0;if((j|0)==1){break l}if(!b){break nb}v[d+224>>2]=0;v[d+248>>2]=0;v[22656]=0;U(755,d+304|0,h|0,g|0);b=v[22656];v[22656]=0;sb:{if((b|0)!=1){v[22656]=0;b=Sd(d+304|0);g=v[22656];v[22656]=0;if((g|0)==1){break sb}b=zb(b);g=Ti(v[d+304>>2]);v[22656]=0;b=fa(756,b|0,g|0,d+224|0,d+248|0,0)|0;g=v[22656];v[22656]=0;if((g|0)==1){break sb}v[22656]=0;Q(318,h|0,v[d+224>>2])|0;h=v[22656];v[22656]=0;if((h|0)==1){break sb}zc(d+304|0);break qb}g=P()|0;O()|0;break k}g=P()|0;O()|0;zc(d+304|0);break k}vc(c);b=0;v[d+224>>2]=0;v[d+248>>2]=0}v[22656]=0;R(757,d+304|0,c|0);h=v[22656];v[22656]=0;tb:{ub:{if((h|0)!=1){v[22656]=0;j=Sd(d+304|0);h=v[22656];v[22656]=0;if((h|0)==1){break tb}g=v[d+304>>2];if(!k){b=zb(j);h=Ti(g);v[22656]=0;b=fa(756,b|0,h|0,d+224|0,d+248|0,0)|0;h=v[22656];v[22656]=0;if((h|0)==1){break pb}v[22656]=0;Q(318,c|0,v[d+224>>2])|0;h=v[22656];v[22656]=0;if((h|0)==1){break pb}h=v[d+224>>2];g=g-h|0;j=h+j|0}if(b){break ub}e=1;break ob}g=P()|0;O()|0;break k}v[22656]=0;f=B(f,104)+a|0;k=f+484380|0;T(386,k|0)|0;h=v[22656];v[22656]=0;if((h|0)==1){break pb}o=f+484400|0;r=f+484414|0;f=0;h=v[d+248>>2];while(1){vb:{if(y[k>>2]<=f>>>0|(!g|(h|0)!=1?h:0)){break vb}if(!Jd(k)){break vb}v[d+192>>2]=0;v[d+168>>2]=0;h=zb(j);m=Ti(g);v[22656]=0;h=la(758,b|0,h|0,m|0,d+192|0,d+272|0,d+168|0)|0;m=v[22656];v[22656]=0;if((m|0)==1){break pb}v[22656]=0;v[d+224>>2]=h;Q(318,c|0,h|0)|0;h=v[22656];v[22656]=0;if((h|0)==1){break pb}q=v[d+224>>2];dk(d+168|0,Ti(v[k>>2]-f|0));wb:{if(v[d+168>>2]<=0){break wb}if(v[d+192>>2]!=(fd(k)|0)){break wb}if(t[r|0]&1){h=mg(d+152|0,v[o>>2]+(B(fd(k),f)<<1)|0,fd(k),v[d+168>>2]);m=mg(d+136|0,v[d+272>>2],v[d+192>>2],v[d+168>>2]);v[22656]=0;v[d- -64>>2]=v[h+8>>2];p=v[h+4>>2];v[d+56>>2]=v[h>>2];v[d+60>>2]=p;v[d+48>>2]=v[m+8>>2];h=v[m+4>>2];v[d+40>>2]=v[m>>2];v[d+44>>2]=h;R(759,d+56|0,d+40|0);h=v[22656];v[22656]=0;if((h|0)!=1){break wb}break pb}h=mg(d+120|0,v[o>>2]+B(fd(k),f)|0,fd(k),v[d+168>>2]);m=mg(d+104|0,v[d+272>>2],v[d+192>>2],v[d+168>>2]);v[22656]=0;v[d+32>>2]=v[h+8>>2];p=v[h+4>>2];v[d+24>>2]=v[h>>2];v[d+28>>2]=p;v[d+16>>2]=v[m+8>>2];h=v[m+4>>2];v[d+8>>2]=v[m>>2];v[d+12>>2]=h;R(760,d+24|0,d+8|0);h=v[22656];v[22656]=0;if((h|0)==1){break pb}}v[22656]=0;m=v[d+168>>2];h=oy(b);p=v[22656];v[22656]=0;if((p|0)==1){break pb}g=g-q|0;j=j+q|0;v[d+248>>2]=h;f=f+m|0;continue}break}v[22656]=0;py(b);b=v[22656];v[22656]=0;if((b|0)!=1){break ob}break pb}break pb}g=P()|0;O()|0;break k}g=P()|0;O()|0;zc(d+304|0);break k}zc(d+304|0)}i=i+1|0;f=i&65535;if(f>>>0<=x[a+480190>>1]){continue}break}}xb:{if(v[a+480180>>2]!=4){break xb}f=0;while(1){if(x[a+480192>>1]<=f>>>0){break xb}b=w[Mb(s,f)|0];c=w[Mb(s,f)+1|0];h=w[Mb(s,f)+2|0];g=w[Mb(s,f)+3|0];v[22656]=0;f=f+1|0;ka(763,a|0,f&65535,b|0,c|0,h|0,g|0);b=v[22656];v[22656]=0;if((b|0)!=1){continue}break}g=P()|0;O()|0;break k}yb:{zb:{Ab:{Bb:{if(!(w[n+2|0]&16)){break Bb}v[22656]=0;b=Q(191,l|0,1)|0;c=v[22656];v[22656]=0;if((c|0)==1){break m}if(!b){break Bb}f=0;v[22656]=0;b=T(374,l|0)|0;c=v[22656];v[22656]=0;if((c|0)==1){break n}if(!(!(b&1)|!x[J>>1])){while(1){v[22656]=0;b=T(192,l|0)|0;c=v[22656];v[22656]=0;if((c|0)==1){break Ab}t[((f<<5)+a|0)+480288|0]=b;f=f+1|0;if(f>>>0<x[a+480188>>1]){continue}break}}while(1){v[22656]=0;b=Q(191,l|0,1)|0;c=v[22656];v[22656]=0;Cb:{if((c|0)!=1){if(!b){break Bb}v[22656]=0;b=T(374,l|0)|0;c=v[22656];v[22656]=0;if((c|0)==1){break zb}if(!b){break Bb}v[22656]=0;c=T(192,l|0)|0;f=v[22656];v[22656]=0;if((f|0)==1){break yb}v[22656]=0;U(288,d+224|0,l|0,c|0);c=v[22656];v[22656]=0;if((c|0)==1){break yb}c=d+224|0;f=kc(d+304|0,c);xb(c);if(b>>>0>250){break Cb}v[22656]=0;R(605,f|0,(B(b,160)+a|0)+906140|0);b=v[22656];v[22656]=0;if((b|0)!=1){break Cb}g=P()|0;O()|0;xb(d+304|0);break k}g=P()|0;O()|0;break k}xb(d+304|0);continue}}j=a+901404|0;k=a+1074308|0;h=Kb(d+192|0);g=0;c=0;Db:{Eb:{while(1){v[22656]=0;b=Q(191,l|0,8)|0;f=v[22656];v[22656]=0;if((f|0)==1){break Db}if(!b){break Eb}v[22656]=0;f=T(192,l|0)|0;b=v[22656];v[22656]=0;Fb:{Gb:{Hb:{Ib:{Jb:{Kb:{Lb:{Mb:{Nb:{Ob:{Pb:{Qb:{Rb:{Sb:{Tb:{Ub:{Vb:{if((b|0)!=1){v[22656]=0;b=T(192,l|0)|0;i=v[22656];v[22656]=0;if((i|0)==1){break Vb}v[22656]=0;U(288,d+304|0,l|0,b|0);b=v[22656];v[22656]=0;if((b|0)==1){break Ub}i=d+304|0;b=kc(d+224|0,i);xb(i);if((f|0)<=1397900629){if((f|0)==1229211981){break Sb}if((f|0)!=1229476432){break Gb}v[22656]=0;f=T(374,b|0)|0;i=v[22656];v[22656]=0;if((i|0)==1){break q}v[a+480216>>2]=f;v[22656]=0;b=T(374,b|0)|0;f=v[22656];v[22656]=0;if((f|0)==1){break q}v[a+480220>>2]=b;break Gb}if((f|0)==1397900630){break Tb}if((f|0)!=1414548815){break Gb}v[22656]=0;f=Q(555,b|0,11155)|0;i=v[22656];v[22656]=0;if((i|0)==1){break q}if(!f){break Qb}v[22656]=0;f=T(192,b|0)|0;i=v[22656];v[22656]=0;if((i|0)!=1){v[22656]=0;U(288,d+304|0,d+224|0,f|0);f=v[22656];v[22656]=0;if((f|0)!=1){break Rb}}g=P()|0;O()|0;break p}g=P()|0;O()|0;break o}g=P()|0;O()|0;break o}g=P()|0;O()|0;break o}Wb:{Xb:{Yb:{f=v[a+480180>>2];switch(f-2|0){case 1:break Gb;case 0:break Hb;case 2:break Xb;default:break Yb}}if((f|0)==16){break Wb}if((f|0)!=32){break Gb}v[22656]=0;g=T(287,b|0)|0;c=v[22656];v[22656]=0;if((c|0)==1){break q}v[22656]=0;c=T(287,b|0)|0;b=v[22656];v[22656]=0;if((b|0)!=1){break Gb}break q}v[d+304>>2]=32;v[22656]=0;f=T(195,d+224|0)|0;i=v[22656];v[22656]=0;Zb:{if((i|0)==1){break Zb}v[22656]=0;v[d+248>>2]=f;f=Fb(d+304|0,d+248|0);i=v[22656];v[22656]=0;if((i|0)==1){break Zb}f=v[f>>2];v[22656]=0;U(764,b|0,h|0,f|0);b=v[22656];v[22656]=0;if((b|0)!=1){break Gb}}g=P()|0;O()|0;break p}v[22656]=0;b=T(374,b|0)|0;f=v[22656];v[22656]=0;if((f|0)==1){break Fb}v[22656]=0;R(765,d+248|0,1320);f=v[22656];v[22656]=0;_b:{if((f|0)!=1){v[d+168>>2]=b>>>4;v[22656]=0;v[d+272>>2]=b&15;Y(460,d+304|0,d+248|0,d+168|0,d+272|0);b=v[22656];v[22656]=0;if((b|0)==1){break _b}b=d+304|0;Eb(h,b);vb(b);Hb(d+248|0);break Gb}g=P()|0;O()|0;break p}g=P()|0;O()|0;Hb(d+248|0);break p}v[22656]=0;Q(568,b|0,j|0)|0;b=v[22656];v[22656]=0;if((b|0)==1){break q}v[22656]=0;Nu(j);b=v[22656];v[22656]=0;if((b|0)==1){break q}break Gb}f=d+248|0;i=d+304|0;m=kc(f,i);xb(i);v[22656]=0;f=T(195,f|0)|0;i=v[22656];v[22656]=0;if((i|0)==1){break Pb}u[d+304>>1]=f>>>5;f=Te(E);v[22656]=0;u[d+168>>1]=f;f=Pc(d+304|0,d+168|0);i=v[22656];v[22656]=0;if((i|0)==1){break Pb}i=x[f>>1];if(i){f=0;while(1){v[22656]=0;W(766,m|0,d+304|0,32)|0;o=v[22656];v[22656]=0;if((o|0)==1){break Pb}o=_b(E,f);v[22656]=0;Q(767,o|0,d+304|0)|0;o=v[22656];v[22656]=0;if((o|0)==1){break Pb}f=f+1|0;if((i|0)!=(f|0)){continue}break}}xb(d+248|0)}v[22656]=0;f=Q(555,b|0,11160)|0;i=v[22656];v[22656]=0;if((i|0)==1){break q}if(!f){break Nb}v[22656]=0;f=T(192,b|0)|0;i=v[22656];v[22656]=0;if((i|0)!=1){v[22656]=0;U(288,d+248|0,d+224|0,f|0);f=v[22656];v[22656]=0;if((f|0)!=1){break Ob}}g=P()|0;O()|0;break p}g=P()|0;O()|0;xb(d+248|0);break p}f=d+304|0;i=d+248|0;m=kc(f,i);xb(i);v[22656]=0;f=T(195,f|0)|0;i=v[22656];v[22656]=0;if((i|0)==1){break Mb}u[d+248>>1]=(f>>>0)/20;f=x[a+480188>>1];v[22656]=0;u[d+168>>1]=f;f=Pc(d+248|0,d+168|0);i=v[22656];v[22656]=0;if((i|0)==1){break Mb}i=x[f>>1];if(i){f=0;while(1){v[22656]=0;W(571,m|0,((f<<5)+a|0)+480289|0,20)|0;o=v[22656];v[22656]=0;if((o|0)==1){break Mb}f=f+1|0;if((i|0)!=(f|0)){continue}break}}xb(d+304|0)}v[22656]=0;Q(588,a|0,b|0)|0;f=v[22656];v[22656]=0;if((f|0)==1){break q}v[22656]=0;Y(589,a|0,b|0,1,0);f=v[22656];v[22656]=0;if((f|0)==1){break q}if((g-2186&65535)>>>0<=117){v[a+480180>>2]=16777216;v[22656]=0;U(604,a|0,b|0,g&65535);b=v[22656];v[22656]=0;if((b|0)==1){break q}}if(!v[k>>2]){break Gb}v[22656]=0;b=Q(2,d+248|0,14719)|0;f=v[22656];v[22656]=0;if((f|0)==1){break Lb}v[22656]=0;R(162,d+168|0,k|0);f=v[22656];v[22656]=0;if((f|0)==1){break Kb}v[22656]=0;U(3,d+304|0,b|0,d+168|0);f=v[22656];v[22656]=0;if((f|0)==1){break Jb}f=d+304|0;Eb(h,f);vb(f);vb(d+168|0);vb(b);break Gb}g=P()|0;O()|0;xb(d+304|0);break p}g=P()|0;O()|0;break p}g=P()|0;O()|0;break Ib}g=P()|0;O()|0;vb(d+168|0)}vb(b);break p}v[22656]=0;g=T(287,b|0)|0;b=v[22656];v[22656]=0;if((b|0)==1){break q}}xb(d+224|0);continue}break}g=P()|0;O()|0;break p}$b:{ac:{bc:{cc:{dc:{ec:{fc:{if(v[a+480180>>2]!=32){break fc}b=g&65535;if(b>>>0<256){break fc}if(b>>>0<532){break ec}}gc:{if(v[a+480180>>2]!=2){break gc}b=g&65535;if(b>>>0<12544){break gc}if(b>>>0<12820){break ec}}if(v[a+480180>>2]!=2){break dc}b=g&65535;if(b>>>0<4864|b>>>0>4895){break dc}}v[22656]=0;Xo(j);b=v[22656];v[22656]=0;if((b|0)==1){break cc}}if(!(t[n+2|0]&1)){break $b}f=v[a+1074308>>2];if(!f){if(x[a+480192>>1]){f=1;while(1){b=v[(((f&65535)<<2)+a|0)+900380>>2];if(b){v[22656]=0;g=ji(b,2);n=v[22656];v[22656]=0;if((n|0)==1){break bc}n=v[a+480180>>2];v[22656]=0;U(768,g|0,4,n|0);g=v[22656];v[22656]=0;if((g|0)==1){break ac}t[b+19|0]=w[b+19|0]+3>>>2}f=f+1|0;if(x[a+480192>>1]>=(f&65535)>>>0){continue}break}}f=v[a+1074308>>2]}if(f>>>0<=18350079){v[22656]=0;b=a+1074312|0;Q(410,b|0,27)|0;f=v[22656];v[22656]=0;if((f|0)==1){break cc}v[22656]=0;Q(410,b|0,57)|0;b=v[22656];v[22656]=0;if((b|0)==1){break cc}f=v[a+1074308>>2]}if(f>>>0<=19070975){v[22656]=0;Q(410,a+1074312|0,73)|0;b=v[22656];v[22656]=0;if((b|0)==1){break cc}f=v[a+1074308>>2]}if(f>>>0>19267583){break $b}v[22656]=0;Q(410,a+1074312|0,50)|0;b=v[22656];v[22656]=0;if((b|0)!=1){break $b}}g=P()|0;O()|0;break o}g=P()|0;O()|0;break o}g=P()|0;O()|0;break o}hc:{ic:{jc:{kc:{lc:{mc:{nc:{oc:{pc:{qc:{rc:{sc:{tc:{uc:{if(gd(h)){v[22656]=0;_(769,d+224|0);b=v[22656];v[22656]=0;vc:{if((b|0)!=1){v[22656]=0;U(726,d+304|0,d+224|0,d+1703|0);b=v[22656];v[22656]=0;if((b|0)==1){break vc}break uc}g=P()|0;O()|0;break o}g=P()|0;O()|0;Hb(d+224|0);break o}v[22656]=0;_(770,d+224|0);b=v[22656];v[22656]=0;if((b|0)==1){break tc}v[22656]=0;Y(771,d+304|0,d+224|0,d+1703|0,h|0);b=v[22656];v[22656]=0;if((b|0)==1){break sc}}b=d+304|0;Eb(h,b);vb(b);b=d+224|0;Hb(b);v[22656]=0;R(725,b|0,1108);b=v[22656];v[22656]=0;if((b|0)==1){break qc}v[22656]=0;U(726,d+304|0,d+224|0,d+1703|0);b=v[22656];v[22656]=0;if((b|0)==1){break pc}b=d+304|0;Eb(a+1298304|0,b);vb(b);Hb(d+224|0);v[22656]=0;b=Q(2,b|0,12201)|0;f=v[22656];v[22656]=0;if((f|0)==1){break oc}Eb(a+1298316|0,b);vb(b);b=v[a+480180>>2];if((b|0)>15){break rc}switch(b-1|0){case 1:break kc;case 3:break lc;case 0:break mc;default:break v}}g=P()|0;O()|0;break o}g=P()|0;O()|0;Hb(d+224|0);break o}if((b|0)==16){break nc}if((b|0)==32){break jc}if((b|0)!=16777216){break v}v[22656]=0;b=Q(2,d+304|0,7394)|0;c=v[22656];v[22656]=0;if((c|0)==1){break ic}Eb(a+1298352|0,b);vb(b);v[22656]=0;b=Q(2,d+304|0,11117)|0;c=v[22656];v[22656]=0;if((c|0)==1){break hc}Eb(a+1298340|0,b);vb(b);break v}g=P()|0;O()|0;break o}g=P()|0;O()|0;Hb(d+224|0);break o}g=P()|0;O()|0;break o}v[22656]=0;b=Q(2,d+304|0,7399)|0;c=v[22656];v[22656]=0;wc:{if((c|0)!=1){Eb(a+1298352|0,b);vb(b);v[22656]=0;b=Q(2,d+304|0,5512)|0;c=v[22656];v[22656]=0;if((c|0)==1){break wc}Eb(a+1298340|0,b);vb(b);break v}g=P()|0;O()|0;break o}g=P()|0;O()|0;break o}v[22656]=0;b=Q(2,d+304|0,9562)|0;c=v[22656];v[22656]=0;xc:{if((c|0)!=1){Eb(a+1298352|0,b);vb(b);v[22656]=0;b=Q(2,d+304|0,11481)|0;c=v[22656];v[22656]=0;if((c|0)==1){break xc}Eb(a+1298340|0,b);vb(b);break v}g=P()|0;O()|0;break o}g=P()|0;O()|0;break o}v[22656]=0;b=Q(2,d+304|0,7372)|0;c=v[22656];v[22656]=0;yc:{if((c|0)!=1){Eb(a+1298352|0,b);vb(b);v[22656]=0;b=Q(2,d+304|0,12411)|0;c=v[22656];v[22656]=0;if((c|0)==1){break yc}Eb(a+1298340|0,b);vb(b);break v}g=P()|0;O()|0;break o}g=P()|0;O()|0;break o}v[22656]=0;b=Q(2,d+304|0,7744)|0;c=v[22656];v[22656]=0;zc:{if((c|0)!=1){Eb(a+1298352|0,b);vb(b);v[22656]=0;b=Q(2,d+304|0,12236)|0;c=v[22656];v[22656]=0;if((c|0)==1){break zc}Eb(a+1298340|0,b);vb(b);break v}g=P()|0;O()|0;break o}g=P()|0;O()|0;break o}v[22656]=0;b=Q(2,d+304|0,3184)|0;f=v[22656];v[22656]=0;Ac:{Bc:{Cc:{Dc:{Ec:{if((f|0)!=1){Eb(a+1298352|0,b);vb(b);if(!(c&65535)){break Ac}v[22656]=0;R(411,d+224|0,1423);b=v[22656];v[22656]=0;if((b|0)==1){break Ec}v[d+168>>2]=(c&65280)>>>8;v[22656]=0;v[d+272>>2]=c&255;R(599,d+248|0,d+272|0);b=v[22656];v[22656]=0;if((b|0)==1){break Dc}v[22656]=0;Y(582,d+304|0,d+224|0,d+168|0,d+248|0);b=v[22656];v[22656]=0;if((b|0)==1){break Cc}b=d+304|0;Eb(a+1298340|0,b);vb(b);vb(d+248|0);Hb(d+224|0);break v}g=P()|0;O()|0;break o}g=P()|0;O()|0;break o}g=P()|0;O()|0;break Bc}g=P()|0;O()|0;vb(d+248|0)}Hb(d+224|0);break o}v[22656]=0;b=Q(2,d+304|0,5688)|0;c=v[22656];v[22656]=0;if((c|0)!=1){Eb(a+1298340|0,b);vb(b);break v}g=P()|0;O()|0;break o}g=P()|0;O()|0;break o}g=P()|0;O()|0;break o}g=P()|0;O()|0;break o}g=P()|0;O()|0;break k}g=P()|0;O()|0;break k}g=P()|0;O()|0;break k}g=P()|0;O()|0;break i}g=P()|0;O()|0;break g}g=P()|0;O()|0;break g}g=P()|0;O()|0;break g}g=P()|0;O()|0;break c}g=P()|0;O()|0;break c}g=P()|0;O()|0;break c}g=P()|0;O()|0;break b}g=P()|0;O()|0;break b}g=P()|0;O()|0;break c}Eb(a+1298328|0,h);Fc:{if(v[a+1074308>>2]){v[a+1298364>>2]=8;break Fc}if(v[a+480180>>2]==1){v[a+1298364>>2]=2;break Fc}v[a+1298364>>2]=5}f=1;if(e&1){v[22656]=0;b=Q(2,d+304|0,13726)|0;c=v[22656];v[22656]=0;if((c|0)==1){break s}v[22656]=0;U(560,a|0,2,b|0);a=v[22656];v[22656]=0;if((a|0)==1){break r}vb(b)}vb(h);mC(z);ci(s);jd(A);xb(I);xb(H)}xb(l)}gc(C);break a}g=P()|0;O()|0;break o}g=P()|0;O()|0;vb(b);break o}g=P()|0;O()|0}xb(d+224|0)}vb(h);break k}g=P()|0;O()|0;break k}g=P()|0;O()|0;break k}g=P()|0;O()|0}mC(z);break i}g=P()|0;O()|0}ci(s);break g}g=P()|0;O()|0}jd(A)}xb(I)}xb(H);break c}g=P()|0;O()|0}xb(l)}gc(C);S(g|0);L()}gb=d+1712|0;return f|0}function Qka(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=C(0),o=0,p=0,q=0,r=0,s=0,A=0,D=C(0),E=0,F=0,G=0,H=0,I=0,J=0,K=0,M=0,N=0,V=0,X=0,Z=0,$=0,aa=0,ba=0,ca=0,ea=0,ga=0,ha=0,ia=0,ja=C(0),ka=0,la=0,ma=0,na=C(0);e=gb-480|0;gb=e;vc(b);a:{b:{c:{if(!Ih(b,e+472|0)){break c}if(!TT(e+472|0)){break c}if((OT(b)|0)>=0){break c}if(!c){f=1;break c}Gd(a,16777216);v[a+480208>>2]=v[a+480208>>2]|1681e4;oA(e+208|0,32);o=v[e+220>>2];d=a+1074320|0;v[d>>2]=v[e+216>>2];v[d+4>>2]=o;d=v[e+212>>2];v[a+1074312>>2]=v[e+208>>2];v[a+1074316>>2]=d;Rf(a+1074312|0,38);E=dd(e+456|0);H=dd(e+440|0);F=dd(e+424|0);o=dd(e+408|0);pg(b,4);i=a+480190|0;K=c&1;l=a+1298292|0;A=2500;G=!(c&2);d:{e:{f:{g:{h:{i:{while(1){v[22656]=0;c=Q(191,b|0,4)|0;d=v[22656];v[22656]=0;j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{if((d|0)!=1){t:{if(c){v[22656]=0;h=T(900,b|0)|0;c=v[22656];v[22656]=0;u:{if((c|0)==1){break u}v:{switch(h+21|0){case 20:v[22656]=0;c=T(426,b|0)|0;d=v[22656];v[22656]=0;if((d|0)!=1){if(x[a+480188>>1]){continue}d=c&65535;if(!d|d>>>0>127){continue}u[a+480188>>1]=c;la=a,ma=Lb(512/(d>>>0)|0,16,128),v[la+480228>>2]=ma;continue}a=P()|0;O()|0;break a;case 19:v[22656]=0;N=T(426,b|0)|0;c=v[22656];v[22656]=0;if((c|0)==1){break u}if(N>>>0<=1024){continue}break q;case 16:v[22656]=0;c=T(426,b|0)|0;d=v[22656];v[22656]=0;if((d|0)!=1){if((c&65535)==4){continue}break q}a=P()|0;O()|0;break a;case 15:v[22656]=0;c=T(426,b|0)|0;d=v[22656];v[22656]=0;w:{if((d|0)!=1){v[e+208>>2]=c;v[22656]=0;v[e+104>>2]=800;d=Fb(e+208|0,e+104|0);c=v[22656];v[22656]=0;if((c|0)==1){break w}c=a;J=+y[d>>2]*1.24*1e4;x:{if(J<4294967296&J>=0){d=~~J>>>0;break x}d=0}v[c+480204>>2]=d;continue}a=P()|0;O()|0;break a}a=P()|0;O()|0;break a;case 17:case 18:v[22656]=0;Q(318,b|0,4)|0;c=v[22656];v[22656]=0;if((c|0)!=1){continue}break u;case 31:v[22656]=0;c=T(426,b|0)|0;d=v[22656];v[22656]=0;if((d|0)==1){break u}aa=1;A=Md(c,0,1e4);continue;case 32:case 33:v[22656]=0;c=T(426,b|0)|0;d=v[22656];v[22656]=0;y:{z:{if((d|0)!=1){aa=1;if(!c){continue}v[22656]=0;c=Q(2,e+208|0,9822)|0;d=v[22656];v[22656]=0;if((d|0)==1){break z}v[22656]=0;U(560,a|0,2,c|0);d=v[22656];v[22656]=0;if((d|0)==1){break y}vb(c);continue}a=P()|0;O()|0;break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;vb(c);break a;case 14:v[22656]=0;Q(318,b|0,4)|0;c=v[22656];v[22656]=0;if((c|0)==1){break u}p=!x[i>>1]|p;continue;case 11:A:{if(!K){break A}if(!cd(E)){break A}v[22656]=0;R(901,e+208|0,b|0);c=v[22656];v[22656]=0;if((c|0)!=1){j=e+208|0;h=j;c=E;d=c;if(v[c>>2]){Od(d);MB(v[d>>2],bi(d));la=wb(d),ma=0,v[la>>2]=ma;v[d>>2]=0;v[d+4>>2]=0}v[c>>2]=v[h>>2];v[c+4>>2]=v[h+4>>2];d=wb(h);la=wb(c),ma=v[d>>2],v[la>>2]=ma;v[d>>2]=0;v[h>>2]=0;v[h+4>>2]=0;Xu(j);continue}a=P()|0;O()|0;break a}v[22656]=0;c=T(426,b|0)|0;d=v[22656];v[22656]=0;if((d|0)==1){break u}v[22656]=0;Q(318,b|0,c|0)|0;c=v[22656];v[22656]=0;if((c|0)!=1){continue}break u;case 3:case 4:case 10:if(dh(o)>>>0<=x[i>>1]){continue}B:{if((p|G)&1){break B}if(!ei(a)){break B}j=x[i>>1]+1|0;u[i>>1]=j;d=mc(e+392|0);v[22656]=0;c=T(215,e+208|0)|0;k=v[22656];v[22656]=0;C:{D:{E:{if((k|0)!=1){if((h|0)==-17){break E}if((h|0)!=-11){break D}v[22656]=0;h=T(426,b|0)|0;k=v[22656];v[22656]=0;if((k|0)==1){break C}v[22656]=0;U(288,e+368|0,b|0,h|0);h=v[22656];v[22656]=0;if((h|0)==1){break C}h=e+104|0;k=e+368|0;Vc(c,kc(h,k));xb(h);xb(k);break j}a=P()|0;O()|0;break d}v[22656]=0;R(902,e+104|0,b|0);h=v[22656];v[22656]=0;F:{if((h|0)!=1){h=e+104|0;op(d,h);gc(h);v[22656]=0;Vd(e+360|0,d);h=v[22656];v[22656]=0;if((h|0)==1){break F}h=Ud(e+352|0);v[22656]=0;k=v[e+364>>2];v[e+32>>2]=v[e+360>>2];v[e+36>>2]=k;k=v[h+4>>2];v[e+24>>2]=v[h>>2];v[e+28>>2]=k;h=W(508,e+104|0,e+32|0,e+24|0)|0;k=v[22656];v[22656]=0;if((k|0)==1){break F}Vc(c,h);xb(e+104|0);break j}a=P()|0;O()|0;break e}a=P()|0;O()|0;break e}v[22656]=0;R(903,e+104|0,b|0);h=v[22656];v[22656]=0;G:{if((h|0)!=1){h=e+104|0;op(d,h);gc(h);v[22656]=0;Vd(e+344|0,d);h=v[22656];v[22656]=0;if((h|0)==1){break G}h=Ud(e+336|0);v[22656]=0;k=v[e+348>>2];v[e+16>>2]=v[e+344>>2];v[e+20>>2]=k;k=v[h+4>>2];v[e+8>>2]=v[h>>2];v[e+12>>2]=k;h=W(508,e+104|0,e+16|0,e+8|0)|0;k=v[22656];v[22656]=0;if((k|0)==1){break G}Vc(c,h);xb(e+104|0);break j}a=P()|0;O()|0;break e}a=P()|0;O()|0;break e}a=P()|0;O()|0;break e}v[22656]=0;c=T(426,b|0)|0;d=v[22656];v[22656]=0;if((d|0)==1){break u}v[22656]=0;Q(318,b|0,c|0)|0;c=v[22656];v[22656]=0;if((c|0)!=1){continue}break u;case 9:if(!ei(a)){continue}u[i>>1]=x[i>>1]+1;continue;case 8:H:{if(!K){break H}if(!cd(F)){break H}v[22656]=0;R(904,e+208|0,b|0);c=v[22656];v[22656]=0;if((c|0)!=1){j=e+208|0;h=j;c=F;d=c;if(v[c>>2]){Od(d);xC(v[d>>2],pe(d));la=wb(d),ma=0,v[la>>2]=ma;v[d>>2]=0;v[d+4>>2]=0}v[c>>2]=v[h>>2];v[c+4>>2]=v[h+4>>2];d=wb(h);la=wb(c),ma=v[d>>2],v[la>>2]=ma;v[d>>2]=0;v[h>>2]=0;v[h+4>>2]=0;ci(j);continue}a=P()|0;O()|0;break a}v[22656]=0;c=T(426,b|0)|0;d=v[22656];v[22656]=0;if((d|0)==1){break u}v[22656]=0;Q(318,b|0,c|0)|0;c=v[22656];v[22656]=0;if((c|0)!=1){continue}break u;case 7:if(cd(o)){v[22656]=0;R(905,e+208|0,b|0);c=v[22656];v[22656]=0;if((c|0)!=1){j=e+208|0;h=j;c=o;d=c;if(v[c>>2]){Od(d);JB(v[d>>2],KB(d));la=wb(d),ma=0,v[la>>2]=ma;v[d>>2]=0;v[d+4>>2]=0}v[c>>2]=v[h>>2];v[c+4>>2]=v[h+4>>2];d=wb(h);la=wb(c),ma=v[d>>2],v[la>>2]=ma;v[d>>2]=0;v[h>>2]=0;v[h+4>>2]=0;Vu(j);continue}a=P()|0;O()|0;break a}v[22656]=0;c=T(426,b|0)|0;d=v[22656];v[22656]=0;if((d|0)==1){break u}v[22656]=0;Q(318,b|0,c|0)|0;c=v[22656];v[22656]=0;if((c|0)!=1){continue}break u;case 6:I:{if(!K){break I}if(!cd(H)){break I}v[22656]=0;R(906,e+208|0,b|0);c=v[22656];v[22656]=0;if((c|0)!=1){j=e+208|0;h=j;c=H;d=c;if(v[c>>2]){Od(d);LB(v[d>>2],xi(d));la=wb(d),ma=0,v[la>>2]=ma;v[d>>2]=0;v[d+4>>2]=0}v[c>>2]=v[h>>2];v[c+4>>2]=v[h+4>>2];d=wb(h);la=wb(c),ma=v[d>>2],v[la>>2]=ma;v[d>>2]=0;v[h>>2]=0;v[h+4>>2]=0;Uu(j);continue}a=P()|0;O()|0;break a}v[22656]=0;c=T(426,b|0)|0;d=v[22656];v[22656]=0;if((d|0)==1){break u}v[22656]=0;Q(318,b|0,c|0)|0;c=v[22656];v[22656]=0;if((c|0)!=1){continue}break u;case 5:v[22656]=0;R(907,e+208|0,b|0);c=v[22656];v[22656]=0;if((c|0)==1){break t}J:{if(cd(e+208|0)){break J}c=e+208|0;d=v[c>>2];c=oc(c);v[22656]=0;da(908,l|0,d|0,c|0,1)|0;c=v[22656];v[22656]=0;if((c|0)!=1){break J}a=P()|0;O()|0;gc(e+208|0);break a}gc(e+208|0);continue;case 0:case 1:case 2:break v;default:break q}}v[22656]=0;c=T(426,b|0)|0;d=v[22656];v[22656]=0;if((d|0)==1){break u}v[22656]=0;Q(318,b|0,c|0)|0;c=v[22656];v[22656]=0;if((c|0)!=1){continue}}a=P()|0;O()|0;break a}if(!x[a+480188>>1]|!N){break q}if(cd(o)){break q}if(K){if(cd(E)){break q}if(cd(F)){break q}if(cd(H)){break q}}if(dh(o)>>>0>=256){v[22656]=0;R(909,o|0,255);b=v[22656];v[22656]=0;if((b|0)==1){break b}}la=a,ma=dh(o),u[la+480192>>1]=ma;v[22656]=0;j=a+480192|0;b=Le(i,j);c=v[22656];v[22656]=0;if((c|0)==1){break b}u[i>>1]=x[b>>1];if(p&1){v[22656]=0;b=Q(2,e+208|0,13556)|0;c=v[22656];v[22656]=0;if((c|0)==1){break k}v[22656]=0;U(560,a|0,2,b|0);c=v[22656];v[22656]=0;if((c|0)==1){break l}vb(b)}f=x[j>>1];p=1;while(1){d=f&65535;f=0;c=1;b=1;K:{if(!d){break K}while(1){L:{h=Ul(o,c-1|0);d=h;M:{if(w[d|0]?t[d+128|0]<0:1){break M}if((Tu(h)|0)==(p&1)){break M}f=0;d=h;N:{if(!Tu(d)){break N}if(Ib(w[d+6|0]|w[d+7|0]<<8)){break N}if(Ib(w[d+14|0]|w[d+15|0]<<8)>>>0>20){break N}f=(Ib(w[d+18|0]|w[d+19|0]<<8)|0)==4}O:{P:{if(f){f=w[h+23|0];d=w[h+140|0];v[22656]=0;d=fa(910,h|0,a|0,(d&2)>>>1|0,(B(c,104)+a|0)+484380|0,A&65535)|0;l=v[22656];v[22656]=0;Q:{R:{S:{if((l|0)!=1){if(!d){break Q}v[22656]=0;d=Q(70,e+208|0,8013)|0;l=v[22656];v[22656]=0;if((l|0)==1){break S}v[22656]=0;Q(301,((c<<5)+a|0)+946304|0,d|0)|0;c=v[22656];v[22656]=0;if((c|0)==1){break R}vb(d);d=b;if(dh(o)>>>0<=f>>>0){break O}la=h,ma=w[Ul(o,f)+143|0]+w[h+143|0]|0,t[la+143|0]=ma;break P}a=P()|0;O()|0;break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;vb(d);break a}d=f+1|0;break O}f=0;T:{if(!Tu(h)){break T}if((Ib(w[d+6|0]|w[d+7|0]<<8)|0)!=1){break T}if((Ib(w[d+14|0]|w[d+15|0]<<8)|0)!=2){break T}f=(Ib(w[d+18|0]|w[d+19|0]<<8)|0)==10}d=b;if(!f){break O}hc(e+208|0,h,128);if(Ib(w[e+228|0]|w[e+229|0]<<8)>>>0>=x[i>>1]){break P}v[22656]=0;f=Q(895,e+104|0,0)|0;d=v[22656];v[22656]=0;U:{V:{W:{if((d|0)!=1){d=(B(Ib(w[e+228|0]|w[e+229|0]<<8),104)+a|0)+484484|0;if(Ib(w[e+244|0]|w[e+245|0]<<8)>>>0<x[a+480190>>1]){f=(B(Ib(w[e+244|0]|w[e+245|0]<<8),104)+a|0)+484484|0}v[22656]=0;d=da(911,e+208|0,d|0,f|0,(B(c,104)+a|0)+484380|0)|0;f=v[22656];v[22656]=0;if((f|0)==1){break W}if(!d){break P}v[22656]=0;d=Q(70,e+368|0,8543)|0;f=v[22656];v[22656]=0;if((f|0)==1){break V}v[22656]=0;Q(301,((c<<5)+a|0)+946304|0,d|0)|0;c=v[22656];v[22656]=0;if((c|0)==1){break U}vb(d);t[h+139|0]=w[h+139|0]+12;break P}a=P()|0;O()|0;break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;vb(d);break a}d=b}v[22656]=0;c=d&65535;d=W(376,a|0,b&65535,c|0)|0;f=v[22656];v[22656]=0;if((f|0)==1){break L}if(!d|c>>>0>x[i>>1]){break M}v[22656]=0;Y(912,h|0,d|0,(B(c,104)+a|0)+484380|0,a|0);c=v[22656];v[22656]=0;if((c|0)==1){break L}}b=b+1|0;c=b&65535;f=x[j>>1];if(c>>>0<=f>>>0){continue}break K}break}a=P()|0;O()|0;break a}b=p&1;p=0;if(b){continue}break}k=Jk(e+104|0);j=Jk(e+368|0);b=Nb(F);ba=B(x[a+480188>>1],N);ca=Qv((b>>>0)/(ba>>>0)|0);v[22656]=0;V=a+484344|0;R(330,V|0,ca|0);b=v[22656];v[22656]=0;if((b|0)==1){a=P()|0;O()|0;break m}ea=a+484360|0;cm(Sb(ea));b=x[a+480188>>1];v[22656]=0;r=Q(913,e+392|0,b|0)|0;b=v[22656];v[22656]=0;if((b|0)!=1){la=e,ma=Vb(H),v[la+96>>2]=ma;la=e,ma=Zb(H),v[la+88>>2]=ma;if(!Gb(e+96|0,e+88|0)){break s}X:{Y:{Z:{_:{$:{aa:{ba:{ca:{da:{while(1){ea:{q=v[e+96>>2];b=q;fa:{if((Ib(w[b+6|0]|w[b+7|0]<<8)|0)==1){break fa}if((Ib(w[b+6|0]|w[b+7|0]<<8)|0)==65535){break ea}b=Ib(w[q|0]|w[q+1|0]<<8);if(ze(E)>>>0<=b>>>0){break fa}b=Ib(w[q+2|0]|w[q+3|0]<<8);if(ze(E)>>>0<b>>>0){break fa}if(!Ib(w[q+2|0]|w[q+3|0]<<8)){break fa}if(ze(E)-Ib(w[q+2|0]|w[q+3|0]<<8)>>>0<Ib(w[q|0]|w[q+1|0]<<8)>>>0){break fa}b=v[E>>2];td(e+208|0,b,b+(ze(E)<<5)|0);c=Ib(w[q|0]|w[q+1|0]<<8);b=Ib(w[q+2|0]|w[q+3|0]<<8);d=v[e+208>>2]+(c<<5)|0;b=(b|0)==-1?(v[e+212>>2]-v[e+208>>2]>>5)-c|0:b;v[e+80>>2]=d;v[e+84>>2]=d+(b<<5);ga:{X=Sb(ea);if(cd(X)){break ga}v[22656]=0;R(710,X|0,65534);b=v[22656];v[22656]=0;if((b|0)!=1){break ga}a=P()|0;O()|0;break n}b=v[e+80>>2];ga=v[e+84>>2];if((b|0)==(ga|0)){break fa}while(1){G=b;c=Ib(Ib(w[q+8|0]|w[q+9|0]<<8)+Ib(w[b+16|0]|w[b+17|0]<<8)&65535);t[b+16|0]=c;t[b+17|0]=c>>>8;ha:{ia:{ja:{d=b;f=k;c=Yd(f);ka:{if(c){wb(f);while(1){h=c+14|0;if(!Ru(d,h)){f=1;if(!Ru(h,d)){break ka}c=c+4|0}c=v[c>>2];if(c){continue}break}}f=0}if(f){v[22656]=0;c=Q(914,k|0,b|0)|0;d=v[22656];v[22656]=0;if((d|0)==1){break ja}I=x[c>>1];break ia}I=0;if(!K){break ia}c=Ib(w[b+12|0]|w[b+13|0]<<8);v[22656]=0;I=W(545,V|0,c|0,0)|0;c=v[22656];v[22656]=0;if((c|0)==1){break ja}if((I|0)==65535){break fa}v[22656]=0;c=Q(914,k|0,b|0)|0;d=v[22656];v[22656]=0;if((d|0)==1){break ja}u[c>>1]=I;c=b;if(Ib(w[c+8|0]|w[c+9|0]<<8)>>>0>=ca>>>0){break ha}d=b;if(Ib(w[d+10|0]|w[d+11|0]<<8)>>>0>=N>>>0){break ha}ha=b;h=Ib(w[b+14|0]|w[b+15|0]<<8);la=e,ma=Vb(F),v[la+56>>2]=ma;f=e+56|0;la=e,ma=$o(f,B(Ib(w[c+8|0]|w[c+9|0]<<8),ba)),v[la+208>>2]=ma;la=e,ma=$o(e+208|0,B(Ib(w[d+10|0]|w[d+11|0]<<8),x[a+480188>>1])),v[la+72>>2]=ma;v[e+68>>2]=0;bj(f);ia=b;if(Ib(w[b+12|0]|w[b+13|0]<<8)){Z=0;while(1){c=_b(V,I);v[22656]=0;$=Yc(c,Z,0);c=v[22656];v[22656]=0;la:{ma:{if((c|0)!=1){s=0;p=0;if(x[a+480188>>1]){break ma}break la}a=P()|0;O()|0;break n}while(1){la=e,ma=Zb(F),v[la+208>>2]=ma;c=e+68|0;if(Gb(e+72|0,e+208|0)){c=v[e+72>>2]}la=e,ma=Zb(F),v[la+208>>2]=ma;if(Gb(e+72|0,e+208|0)){Qe(e+72|0)}d=B(s,6);i=c;if(t[c+1|0]<0|t[c+1|0]>84){f=255}else{f=w[i+1|0]+25|0}d=d+$|0;A=0;m=dh(o);l=c;M=w[c+3|0];na:{if(m>>>0<=M>>>0){break na}A=M+1|0;if(t[Ul(o,M)+142|0]&1|f<<24>>24<0){break na}f=on(Ib(w[G+16|0]|w[G+17|0]<<8)+f<<24>>24)}oa:{if(!w[d|0]){break oa}if(!(w[l+3|0]|(w[c|0]|w[i+1|0]!=255))){if(!w[c+2|0]){break oa}}m=w[d+1|0];if(!m){break oa}if(dh(o)>>>0<m>>>0){break oa}if(w[Ul(o,m-1|0)+132|0]!=2){break oa}ap(d)}g=Qj(r,s);pa:{if(p&1){m=v[e+56>>2];t[d|0]=m;t[d+1|0]=m>>>8;t[d+2|0]=m>>>16;t[d+3|0]=m>>>24;m=x[e+60>>1];t[d+4|0]=m;t[d+5|0]=m>>>8;qa:{if(w[d+3|0]){break qa}m=s-1|0;if(w[g+21|0]==w[Qj(r,m)+21|0]){break qa}t[d+3|0]=21;m=w[Qj(r,m)+21|0];t[g+21|0]=m;t[d+5|0]=m}p=0;m=1;ra:{if(w[c|0]==9){break ra}if(w[c|0]==24|w[c|0]==25|!w[c|0]&(w[c+2|0]==249|w[c+2|0]==250)){break ra}m=0}if(!m){break pa}}m=d;sa:{ta:{ua:{va:{wa:{xa:{ya:{za:{switch(w[c|0]){case 5:i=w[g+17|0];break ya;case 0:Aa:{if(w[c+2|0]>=201){p=0;Ba:{switch(w[c+2|0]-242|0){case 11:t[d+4|0]=1;t[d+2|0]=14;t[g+16|0]=0;break ta;case 9:t[d+4|0]=1;t[d+2|0]=15;break ta;case 8:if((h&255)>>>0<2){break ta}h=h-1|0;break ua;case 7:if((h&255)==255){h=255;break ta}h=h+1|0;break ua;case 6:t[g+17|0]=f;if(w[g+18|0]!=(A&255)){break ta}t[d|0]=f;t[d+5|0]=255;t[d+3|0]=4;u[g+32>>1]=0;v[g+8>>2]=0;break ta;case 5:t[d+5|0]=242;t[d+3|0]=2;break ta;case 4:t[d+5|0]=242;t[d+3|0]=3;break ta;case 3:t[d+5|0]=244;t[d+3|0]=2;break ta;case 2:t[d+5|0]=244;t[d+3|0]=3;break ta;case 1:t[d+5|0]=248;t[d+3|0]=2;break ta;case 12:break Aa;case 0:break Ba;default:break ta}}t[d+5|0]=248;t[d+3|0]=3;break ta}if(t[i+1|0]<0){p=0;if(w[c+2|0]>99){break ta}}if(t[i+1|0]>=0){t[g+17|0]=f;t[d|0]=f;t[g+18|0]=A;t[d+1|0]=A;u[g+32>>1]=0;v[g+8>>2]=0}if(!w[c+2|0]){p=0;break ta}c=w[c+2|0];v[22656]=0;c=gn(+(c>>>0)*.64);f=v[22656];v[22656]=0;if((f|0)==1){break va}t[g+19|0]=c;n=z[g>>2];v[g>>2]=0;p=n!=C(0);break ta}t[d+4|0]=0;t[d+2|0]=14;t[g+16|0]=1;break ta;case 1:v[g+4>>2]=0;z[g>>2]=C(w[c+2|0])*C(.0333000011742115);break sa;case 2:v[g+4>>2]=0;z[g>>2]=C(w[c+2|0])*C(-.0333000011742115);break sa;case 12:t[e+208|0]=15;f=w[l+3|0];v[22656]=0;t[e+52|0]=f>>>3;f=ac(e+208|0,e+52|0);i=v[22656];v[22656]=0;Ca:{if((i|0)!=1){f=w[f|0];t[e+208|0]=15;c=w[c+2|0];v[22656]=0;t[e+52|0]=c>>>3;c=ac(e+208|0,e+52|0);i=v[22656];v[22656]=0;if((i|0)==1){break Ca}t[g+24|0]=w[c|0]|f<<4;break sa}a=P()|0;O()|0;break n}a=P()|0;O()|0;break n;case 3:v[g+12>>2]=0;c=w[c+2|0];u[g+32>>1]=0;z[g+8>>2]=C(c>>>0)*C(.0333000011742115);break sa;case 4:v[g+12>>2]=0;c=w[c+2|0];u[g+32>>1]=0;z[g+8>>2]=C(c>>>0)*C(-.0333000011742115);break sa;case 15:i=f<<24>>24;if(!w[c+2|0]|(i|0)<0){break sa}l=i-w[g+17|0]|0;i=l>>31;i=i^i+(l<<5);v[e+208>>2]=i;t[g+17|0]=f;v[g+8>>2]=0;t[d|0]=f;t[d+3|0]=4;c=Xi((i>>>0)/(w[c+2|0]<<1>>>0)|0);t[d+5|0]=c;t[g+27|0]=c;v[22656]=0;f=v[e+208>>2];v[e+52>>2]=B(c,(h&255)-1|0);c=pd(e+208|0,e+52|0);i=v[22656];v[22656]=0;if((i|0)!=1){u[g+32>>1]=f-v[c>>2];break sa}a=P()|0;O()|0;break n;case 10:case 11:t[d+3|0]=0;t[d+5|0]=0;break sa;case 13:t[e+208|0]=15;f=w[l+3|0];v[22656]=0;t[e+52|0]=f>>>3;f=ac(e+208|0,e+52|0);i=v[22656];v[22656]=0;Da:{if((i|0)!=1){f=w[f|0];t[e+208|0]=15;c=w[c+2|0];v[22656]=0;t[e+52|0]=c;c=ac(e+208|0,e+52|0);i=v[22656];v[22656]=0;if((i|0)==1){break Da}t[g+23|0]=w[c|0]|f<<4;break sa}a=P()|0;O()|0;break n}a=P()|0;O()|0;break n;case 23:case 24:case 25:l=j;f=Yd(j);Ea:{if(f){wb(l);while(1){m=f+13|0;if(!Qu(i,m)){l=1;if(!Qu(m,i)){break Ea}f=f+4|0}f=v[f>>2];if(f){continue}break}}l=0}if(l){t[d+3|0]=31;v[22656]=0;c=Q(915,j|0,c|0)|0;f=v[22656];v[22656]=0;if((f|0)==1){break va}t[d+5|0]=w[c|0];break sa}if(QT(j)>>>0>127){break sa}f=QT(j);i=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);v[22656]=0;v[e+48>>2]=i;v[e+40>>2]=i;i=W(916,e+40|0,(((f&255)<<5)+a|0)+902204|0,a|0)|0;l=v[22656];v[22656]=0;Fa:{if((l|0)==1){break Fa}if(!i){break sa}t[d+3|0]=31;v[22656]=0;i=Q(915,j|0,c|0)|0;l=v[22656];v[22656]=0;if((l|0)==1){break Fa}f=f|-128;t[i|0]=f;t[d+5|0]=f;if(w[c|0]!=24&w[c|0]!=25){break sa}ka=1;break sa}a=P()|0;O()|0;break n;case 16:if(!w[c+2|0]){break sa}t[d+3|0]=15;v[e+208>>2]=15;f=w[l+3|0];v[22656]=0;v[e+52>>2]=f+1;f=pd(e+208|0,e+52|0);i=v[22656];v[22656]=0;if((i|0)!=1){t[d+5|0]=v[f>>2];u[g+30>>1]=B(w[c+2|0],w[l+3|0]+1|0);break sa}a=P()|0;O()|0;break n;case 9:t[d+3|0]=16;h=w[c+2|0]?w[c+2|0]:4;t[d+5|0]=h;break sa;case 19:if(w[i+1|0]!=4?w[i+1|0]:0){break sa}t[e+47|0]=w[i+1|0]==4?w[l+3|0]:128;t[e+208|0]=w[c+2|0];v[22656]=0;t[e+52|0]=100;c=ac(e+208|0,e+52|0);f=v[22656];v[22656]=0;Ga:{Ha:{if((f|0)!=1){c=w[c|0];v[e+208>>2]=128;v[22656]=0;v[e+52>>2]=256-w[e+47|0];f=pd(e+208|0,e+52|0);l=v[22656];v[22656]=0;if((l|0)==1){break Ha}f=v[f>>2];v[22656]=0;t[e+208|0]=128;l=ac(e+208|0,e+47|0);m=v[22656];v[22656]=0;if((m|0)==1){break Ga}l=w[l|0];f=(B(c,f)|0)/128|0;m=f&255;if((m|0)!=w[g+20|0]){t[g+20|0]=f;t[d+3|0]=21;f=Qc(((B(m,w[g+19|0])+50&65535)>>>0)/100|0,0);t[g+21|0]=f;t[d+5|0]=f}if(w[i+1|0]!=4|(x[a+480188>>1]-1|0)<=(s|0)){break sa}f=s+1|0;i=Qj(r,f);c=B(c,l)>>>7|0;if(w[i+20|0]==(c&255)){break sa}t[i+20|0]=c;c=B(f,6)+$|0;t[c+3|0]=21;f=Qc(((B(w[g+20|0],w[g+19|0])+50&65535)>>>0)/100|0,0);t[g+21|0]=f;t[c+5|0]=f;break sa}a=P()|0;O()|0;break n}a=P()|0;O()|0;break n}a=P()|0;O()|0;break n;case 17:case 20:t[d+3|0]=0;break sa;case 7:c=w[c+2|0];t[g+25|0]=0;t[g+26|0]=0;t[g+22|0]=c;break sa;case 8:t[g+22|0]=w[g+22|0]+w[c+2|0];break sa;case 14:t[g+25|0]=w[l+3|0];t[g+26|0]=w[c+2|0];break sa;case 18:break xa;case 6:break za;default:break sa}}t[g+18|0]=A;t[g+17|0]=f;t[d+1|0]=A;i=f}t[m|0]=i;if(f<<24>>24>=0){t[g+18|0]=A;t[d+1|0]=A}if(w[c|0]==5){t[d+4|0]=1;t[d+2|0]=11}f=w[g+26|0];if(!(f?1:w[c+2|0]|w[g+22|0])){break wa}if(f){J=(ri(+x[g+28>>1]*.006135923151542565+4.71238898038469)+-1)*+(f>>>0)*.25}else{J=0}t[d+3|0]=44;f=w[g+22|0];c=w[c+2|0];v[22656]=0;c=gn(J+ +(c+f|0));f=v[22656];v[22656]=0;if((f|0)!=1){t[d+5|0]=c;break wa}a=P()|0;O()|0;break n}c=w[g+17|0]+w[c+2|0]&255;c=c?c>>>0<120?c:120:1;t[g+17|0]=c;t[d|0]=c;t[d+5|0]=255;t[d+3|0]=4}u[g+32>>1]=0;break sa}a=P()|0;O()|0;break n}t[d+5|0]=h;t[d+3|0]=16}c=Qc(((B(w[g+20|0],w[g+19|0])+50&65535)>>>0)/100|0,0);if(!(!p&w[g+21|0]==(c&255))){t[g+21|0]=c;t[d+5|0]=c;t[d+3|0]=21}if(s&1|t[i+1|0]<=0|(x[a+480188>>1]-1|0)<=(s|0)){break sa}if(dh(o)>>>0<=M>>>0){break sa}if(w[Ul(o,M)+132|0]!=1){break sa}f=s+1|0;c=B(f,6)+$|0;i=w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24);t[c|0]=i;t[c+1|0]=i>>>8;t[c+2|0]=i>>>16;t[c+3|0]=i>>>24;i=w[d+4|0]|w[d+5|0]<<8;t[c+4|0]=i;t[c+5|0]=i>>>8;t[c+1|0]=w[c+1|0]+1;la=Qj(r,f),ma=w[g+19|0],t[la+19|0]=ma;la=Qj(r,f),na=z[g>>2],z[la>>2]=na;la=Qj(r,f),na=z[g+4>>2],z[la+4>>2]=na;la=Qj(r,f),na=z[g+8>>2],z[la+8>>2]=na;la=Qj(r,f),na=z[g+12>>2],z[la+12>>2]=na;la=Qj(r,f),ma=x[g+30>>1],u[la+30>>1]=ma}Ia:{if(w[d|0]){t[g+16|0]=0;break Ia}p=0;if(w[g+16|0]){break pa}}Ja:{Ka:{La:{Ma:{Na:{Oa:{if(!x[g+30>>1]){break Oa}v[22656]=0;c=h&255;u[e+208>>1]=c;f=Le(g+30|0,e+208|0);i=v[22656];v[22656]=0;if((i|0)==1){break Na}u[g+30>>1]=x[f>>1]-c;if(w[d+3|0]){break Oa}t[d+3|0]=15;t[d+5|0]=0}n=z[g>>2];if(n==C(0)){break Ja}c=h&255;n=C(C(n*C(c>>>0))+z[g+4>>2]);z[g+4>>2]=n;if(w[d+3|0]){break Ja}Pa:{Qa:{if(c>>>0>=2){f=c-1|0;D=C(f|0);if(!(D<=n)){break Qa}t[e+208|0]=15;v[22656]=0;c=ch(C(n/D));i=v[22656];v[22656]=0;Ra:{if((i|0)==1){break Ra}v[22656]=0;t[e+52|0]=c;c=ac(e+208|0,e+52|0);i=v[22656];v[22656]=0;if((i|0)==1){break Ra}c=w[c|0];z[g+4>>2]=z[g+4>>2]-C(B(c,f)|0);t[d+3|0]=22;c=c<<4;break Ka}a=P()|0;O()|0;break n}if(!(n>=C(1))){break Pa}break La}if(n>=C(1)){break La}if(!(n<=C(1-c|0))){break Pa}t[e+208|0]=15;v[22656]=0;c=ch(C(C(-n)/D));i=v[22656];v[22656]=0;Sa:{if((i|0)==1){break Sa}v[22656]=0;t[e+52|0]=c;c=ac(e+208|0,e+52|0);i=v[22656];v[22656]=0;if((i|0)==1){break Sa}c=w[c|0];z[g+4>>2]=z[g+4>>2]+C(B(f,c)|0);t[d+3|0]=22;break Ka}a=P()|0;O()|0;break n}if(!(n<=C(-1))){break Ja}t[e+208|0]=14;v[22656]=0;c=ch(C(-n));f=v[22656];v[22656]=0;if((f|0)==1){break Ma}v[22656]=0;t[e+52|0]=c;c=ac(e+208|0,e+52|0);f=v[22656];v[22656]=0;if((f|0)==1){break Ma}c=w[c|0];z[g+4>>2]=z[g+4>>2]+C(c>>>0);t[d+3|0]=22;c=c|-16;break Ka}a=P()|0;O()|0;break n}a=P()|0;O()|0;break n}t[e+208|0]=15;v[22656]=0;c=ch(n);f=v[22656];v[22656]=0;Ta:{if((f|0)==1){break Ta}v[22656]=0;t[e+52|0]=c;c=ac(e+208|0,e+52|0);f=v[22656];v[22656]=0;if((f|0)==1){break Ta}c=w[c|0];z[g+4>>2]=z[g+4>>2]-C(c>>>0);t[d+3|0]=22;c=c<<4|15;break Ka}a=P()|0;O()|0;break n}t[d+5|0]=c}Ua:{n=z[g+8>>2];if(n==C(0)){break Ua}c=h&255;n=C(C(n*C(c>>>0))+z[g+12>>2]);z[g+12>>2]=n;Va:{if(!w[d+3|0]){Wa:{Xa:{if(c>>>0>=2){f=c-1|0;D=C(f|0);if(!(D<=n)){break Xa}t[e+208|0]=223;v[22656]=0;c=ch(C(n/D));i=v[22656];v[22656]=0;Ya:{if((i|0)==1){break Ya}v[22656]=0;t[e+52|0]=c;c=ac(e+208|0,e+52|0);i=v[22656];v[22656]=0;if((i|0)==1){break Ya}c=w[c|0];z[g+12>>2]=z[g+12>>2]-C(B(c,f)|0);t[d+3|0]=2;t[d+5|0]=c;break Ua}a=P()|0;O()|0;break n}if(!(n>=C(1))){break Wa}break Va}if(n>=C(1)){break Va}if(!(n<=C(1-c|0))){break Wa}t[e+208|0]=223;v[22656]=0;c=ch(C(C(-n)/D));i=v[22656];v[22656]=0;Za:{if((i|0)==1){break Za}v[22656]=0;t[e+52|0]=c;c=ac(e+208|0,e+52|0);i=v[22656];v[22656]=0;if((i|0)==1){break Za}c=w[c|0];z[g+12>>2]=z[g+12>>2]+C(B(c,f)|0);t[d+3|0]=3;t[d+5|0]=c;break Ua}a=P()|0;O()|0;break n}if(!(n<=C(-1))){break Ua}t[e+208|0]=14;v[22656]=0;c=ch(C(-n));f=v[22656];v[22656]=0;_a:{if((f|0)==1){break _a}v[22656]=0;t[e+52|0]=c;c=ac(e+208|0,e+52|0);f=v[22656];v[22656]=0;if((f|0)==1){break _a}c=w[c|0];z[g+12>>2]=z[g+12>>2]+C(c>>>0);t[d+3|0]=3;t[d+5|0]=c|240;break Ua}a=P()|0;O()|0;break n}if(w[d+2|0]|c>>>0<2){break Ua}ja=C(n*C(.25));f=c-1|0;D=C(f|0);if(ja>=D){t[e+208|0]=9;v[22656]=0;c=ch(C(n/D));i=v[22656];v[22656]=0;$a:{if((i|0)==1){break $a}v[22656]=0;t[e+52|0]=c>>>2;c=ac(e+208|0,e+52|0);i=v[22656];v[22656]=0;if((i|0)==1){break $a}c=w[c|0];z[g+12>>2]=z[g+12>>2]-C(B(c,f)<<2);t[d+2|0]=12;t[d+4|0]=c;break Ua}a=P()|0;O()|0;break n}if(!(C(1-c|0)>=ja)){break Ua}t[e+208|0]=9;v[22656]=0;c=ch(C(C(-n)/D));i=v[22656];v[22656]=0;ab:{if((i|0)==1){break ab}v[22656]=0;t[e+52|0]=c>>>2;c=ac(e+208|0,e+52|0);i=v[22656];v[22656]=0;if((i|0)==1){break ab}c=w[c|0];z[g+12>>2]=z[g+12>>2]+C(B(c,f)<<2);t[d+2|0]=13;t[d+4|0]=c;break Ua}a=P()|0;O()|0;break n}t[e+208|0]=15;v[22656]=0;c=ch(n);f=v[22656];v[22656]=0;bb:{if((f|0)==1){break bb}v[22656]=0;t[e+52|0]=c;c=ac(e+208|0,e+52|0);f=v[22656];v[22656]=0;if((f|0)==1){break bb}c=w[c|0];z[g+12>>2]=z[g+12>>2]-C(c>>>0);t[d+3|0]=2;t[d+5|0]=c|240;break Ua}a=P()|0;O()|0;break n}cb:{db:{eb:{fb:{gb:{hb:{ib:{i=w[d+3|0];switch(i|0){case 4:break cb;case 0:break ib;default:break hb}}jb:{c=w[g+23|0];if(!c){c=w[g+24|0];if(c){break jb}if(!x[g+32>>1]){break cb}c=g+32|0;break gb}t[d+3|0]=5;t[d+5|0]=c;if(!x[g+32>>1]){break cb}break fb}t[d+3|0]=8;t[d+5|0]=c;if(x[g+32>>1]){break fb}break cb}if(!x[g+32>>1]){break cb}c=g+32|0;f=c;if(i){break eb}}t[d+3|0]=4;break db}f=g+32|0}c=f;t[d+2|0]=11}f=w[g+27|0];v[22656]=0;u[e+208>>1]=B(f,(h&255)-1|0);f=Pc(c,e+208|0);i=v[22656];v[22656]=0;if((i|0)!=1){u[c>>1]=x[c>>1]-x[f>>1];break cb}a=P()|0;O()|0;break n}u[g+28>>1]=x[g+28>>1]+B(w[g+25|0],h&255)&1023;p=0;if(s&1){break pa}c=w[g+18|0];if(!c){break pa}if(dh(o)>>>0<c>>>0){break pa}if(!(w[Ul(o,c-1|0)+142|0]&4)){break pa}v[e+56>>2]=w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24);u[e+60>>1]=w[d+4|0]|w[d+5|0]<<8;if(!w[e+57|0]){p=1;break pa}p=1;if(w[Ul(o,w[g+18|0]-1|0)+132|0]!=1){break pa}t[e+57|0]=w[e+57|0]+1}s=s+1|0;if(s>>>0<x[a+480188>>1]){continue}break}}Z=Z+1|0;if(Ib(w[ia+12|0]|w[ia+13|0]<<8)>>>0>Z>>>0){continue}break}}c=_b(V,I);d=Ib(w[ha+14|0]|w[ha+15|0]<<8);v[22656]=0;d=Be(e+208|0,16,d&255);f=v[22656];v[22656]=0;if((f|0)!=1){d=Fh(Ue(d,0));v[22656]=0;Q(431,c|0,d|0)|0;c=v[22656];v[22656]=0;if((c|0)!=1){break ia}}a=P()|0;O()|0;break n}a=P()|0;O()|0;break n}c=am(X);la=e,ma=Ib(w[b+4|0]|w[b+5|0]<<8),u[la+208>>1]=ma;v[22656]=0;u[e+56>>1]=1;d=Le(e+208|0,e+56|0);f=v[22656];v[22656]=0;if((f|0)==1){break da}d=x[d>>1];v[22656]=0;da(918,X|0,c|0,d|0,I&65535)|0;c=v[22656];v[22656]=0;if((c|0)==1){break da}c=Ib(w[q+8|0]|w[q+9|0]<<8);c=Ib(Ib(w[G+16|0]|w[G+17|0]<<8)-c&65535);t[G+16|0]=c;t[G+17|0]=c>>>8}b=b+32|0;if((ga|0)!=(b|0)){continue}break}}b=e+96|0;_o(b);if(Gb(b,e+88|0)){continue}}break}c=0;if(!ka){break r}v[22656]=0;_(436,a+906300|0);b=v[22656];v[22656]=0;if((b|0)==1){break ca}b=a+906316|0;v[b>>2]=1299020115;v[b+4>>2]=1869112133;t[a+906324|0]=16;t[a+906325|0]=0;t[a+906326|0]=10;t[a+906327|0]=0;b=a+906328|0;t[b|0]=0;t[b+1|0]=0;t[b+2|0]=0;t[b+3|0]=0;v[22656]=0;v[e+208>>2]=0;b=a+906332|0;GD(b,b+16|0,e+208|0);b=v[22656];v[22656]=0;if((b|0)==1){break ba}v[22656]=0;b=Q(70,e+208|0,6713)|0;c=v[22656];v[22656]=0;if((c|0)==1){break aa}v[22656]=0;Rv(a+906348|0,b);c=v[22656];v[22656]=0;if((c|0)==1){break $}vb(b);v[22656]=0;b=Q(70,e+208|0,6706)|0;c=v[22656];v[22656]=0;if((c|0)==1){break _}v[22656]=0;Jr(a+906380|0,b);c=v[22656];v[22656]=0;if((c|0)==1){break Z}vb(b);v[22656]=0;b=Q(70,e+208|0,6698)|0;c=v[22656];v[22656]=0;if((c|0)==1){break Y}v[22656]=0;Rv(a+906508|0,b);d=v[22656];v[22656]=0;c=1;if((d|0)==1){break X}vb(b);break r}a=P()|0;O()|0;break n}a=P()|0;O()|0;break n}a=P()|0;O()|0;break n}a=P()|0;O()|0;break n}a=P()|0;O()|0;vb(b);break n}a=P()|0;O()|0;break n}a=P()|0;O()|0;vb(b);break n}a=P()|0;O()|0;break n}a=P()|0;O()|0;vb(b);break n}a=P()|0;O()|0;break m}a=P()|0;O()|0;break a}a=P()|0;O()|0;break a}c=0}if(x[a+480188>>1]){b=0;while(1){v[22656]=0;gu(a,b&65535);d=v[22656];v[22656]=0;if((d|0)==1){break p}d=(b<<5)+a|0;u[d+480284>>1]=b<<8&256;if(c){t[d+480288|0]=1}b=b+1|0;if(b>>>0<x[a+480188>>1]){continue}break}}v[22656]=0;b=Q(2,e+208|0,9351)|0;c=v[22656];v[22656]=0;kb:{lb:{mb:{nb:{if((c|0)!=1){Eb(a+1298304|0,b);vb(b);v[22656]=0;b=Q(2,e+208|0,9559)|0;c=v[22656];v[22656]=0;if((c|0)==1){break nb}Eb(a+1298316|0,b);vb(b);if(aa){break lb}v[22656]=0;b=Q(2,e+208|0,9351)|0;c=v[22656];v[22656]=0;if((c|0)==1){break mb}break kb}a=P()|0;O()|0;break n}a=P()|0;O()|0;break n}a=P()|0;O()|0;break n}if(dh(o)>>>0<=128){v[22656]=0;b=Q(2,e+208|0,6455)|0;c=v[22656];v[22656]=0;if((c|0)!=1){break kb}a=P()|0;O()|0;break n}v[22656]=0;b=Q(2,e+208|0,11997)|0;c=v[22656];v[22656]=0;if((c|0)==1){break o}}Eb(a+1298328|0,b);vb(b);v[a+1298364>>2]=2;PB(r);HT(j);GT(k);f=1}Vu(o);ci(F);Uu(H);Xu(E);break c}a=P()|0;O()|0;break n}a=P()|0;O()|0}PB(r)}HT(j);GT(k);break a}a=P()|0;O()|0;vb(b);break a}a=P()|0;O()|0;break a}v[22656]=0;h=j&65535;j=W(920,a|0,h|0,c|0)|0;k=v[22656];v[22656]=0;ob:{pb:{qb:{rb:{if((k|0)==1){break rb}if(j){break ob}v[22656]=0;j=fa(921,a|0,h|0,c|0,0,0)|0;k=v[22656];v[22656]=0;if((k|0)==1){break rb}if(j){break ob}v[22656]=0;j=da(922,a|0,h|0,c|0,0)|0;k=v[22656];v[22656]=0;if((k|0)==1){break rb}if(j){break ob}v[22656]=0;c=Q(923,(B(h,104)+a|0)+484380|0,c|0)|0;j=v[22656];v[22656]=0;if((j|0)==1){break rb}if(c){break ob}v[22656]=0;c=Q(2,e+104|0,13267)|0;j=v[22656];v[22656]=0;if((j|0)==1){break qb}v[22656]=0;U(560,a|0,2,c|0);j=v[22656];v[22656]=0;if((j|0)==1){break pb}vb(c);break ob}a=P()|0;O()|0;break e}a=P()|0;O()|0;break e}a=P()|0;O()|0;vb(c);break e}sb:{tb:{ub:{j=B(h,104)+a|0;if(w[j+484414|0]&64){if(ei(a)){break ub}}if(dh(o)>>>0<=h>>>0){break tb}if(w[Ul(o,h)+132|0]!=2){break tb}if(!ei(a)){break tb}u[i>>1]=x[i>>1]+1;break tb}c=x[a+480190>>1]+1|0;u[a+480190>>1]=c;v[22656]=0;h=j+484380|0;k=B(c&65535,104)+a|0;da(924,h|0,k+484380|0,h|0,a|0)|0;c=v[22656];v[22656]=0;if((c|0)==1){break sb}v[22656]=0;c=Q(70,e+104|0,3377)|0;h=v[22656];v[22656]=0;if((h|0)==1){break i}v[22656]=0;Q(303,k+484423|0,c|0)|0;h=v[22656];v[22656]=0;if((h|0)==1){break h}vb(c);v[22656]=0;c=Q(70,e+104|0,3280)|0;h=v[22656];v[22656]=0;if((h|0)==1){break g}v[22656]=0;Q(303,j+484423|0,c|0)|0;h=v[22656];v[22656]=0;if((h|0)==1){break f}vb(c)}xb(e+208|0);gc(d);p=0;continue}break}a=P()|0;O()|0;break e}a=P()|0;O()|0;break e}a=P()|0;O()|0;vb(c);break e}a=P()|0;O()|0;break e}a=P()|0;O()|0;vb(c)}xb(e+208|0)}gc(d);break a}gb=e+480|0;return f|0}a=P()|0;O()|0}Vu(o);ci(F);Uu(H);Xu(E);S(a|0);L()}function qna(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,z=0,A=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,M=0,N=0,V=0,X=0,Z=0,_=0,$=0,aa=0,ba=0,ca=0,ea=0,fa=0,ga=0,ia=0,ja=0,ka=0,la=0,ma=0;d=gb-928|0;gb=d;vc(b);a:{if(!hW(b,d+872|0)){break a}if(!jW(d+872|0)){break a}if(!Pb(b,Qc(iW(d+872|0),jb))){break a}if(!c){e=1;break a}Gd(a,8);Bg(a);i=w[d+872|3]-48|0;t[d+871|0]=i;Wc(b,Xb(w[d+880|0]|w[d+881|0]<<8|(w[d+882|0]<<16|w[d+883|0]<<24)));g=d+560|0;Td(g,b,504);N=kc(d+848|0,g);xb(g);v[22656]=0;R(689,b|0,g|0);g=v[22656];v[22656]=0;b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{if((g|0)!=1){if(w[d+843|0]>63){break b}if(Ib(w[d+560|0]|w[d+561|0]<<8)<<16>>16<0){break b}Qb(d+480|0,0,80);o:{if(!Xb(w[d+904|0]|w[d+905|0]<<8|(w[d+906|0]<<16|w[d+907|0]<<24))){break o}g=Xb(w[d+904|0]|w[d+905|0]<<8|(w[d+906|0]<<16|w[d+907|0]<<24));v[22656]=0;g=Q(190,b|0,g|0)|0;h=v[22656];v[22656]=0;if((h|0)!=1){if(!g){break o}v[22656]=0;R(690,b|0,d+480|0);g=v[22656];v[22656]=0;if((g|0)!=1){break o}}f=P()|0;O()|0;break e}v[22656]=0;U(691,d+472|0,b|0,i&255);g=v[22656];v[22656]=0;if((g|0)!=1){g=d+472|0;V=Ve(g);g=x[g>>1];if((g-1&65535)>>>0>126){break b}u[a+480188>>1]=g;J=dd(d+456|0);p:{if(Xb(w[d+896|0]|w[d+897|0]<<8|(w[d+898|0]<<16|w[d+899|0]<<24))){g=Xb(w[d+896|0]|w[d+897|0]<<8|(w[d+898|0]<<16|w[d+899|0]<<24));v[22656]=0;Q(190,b|0,g|0)|0;g=v[22656];v[22656]=0;if((g|0)!=1){g=w[d+843|0];v[22656]=0;U(692,b|0,J|0,g|0);g=v[22656];v[22656]=0;if((g|0)!=1){break p}}f=P()|0;O()|0;break f}e=0;if(w[d+843|0]){break c}}g=w[d+843|0];u[a+480192>>1]=g;u[a+480190>>1]=g;e=1;X=1;if((i&255)>>>0>=2){X=t[d+824|0]>=0;g=x[a+480192>>1]}if(g&65535){F=c&2;G=!X;g=d- -64|0;n=g|2;H=g|7;K=g|6;q=g|5;r=g|4;h=d+24|4;p=1;o=1;while(1){v[22656]=0;s=o&65535;g=W(376,a|0,p&65535,s|0)|0;i=v[22656];v[22656]=0;q:{r:{if((i|0)!=1){if(!g){break d}j=v[((e<<2)+a|0)+900380>>2];u[d+28>>1]=0;v[d+24>>2]=0;v[22656]=0;C=T(215,d+144|0)|0;g=v[22656];v[22656]=0;s:{t:{u:{v:{if((g|0)!=1){i=e-1|0;g=Mb(J,i);w:{if(!Xb(w[g|0]|w[g+1|0]<<8|(w[g+2|0]<<16|w[g+3|0]<<24))){break w}g=Mb(J,i);g=Xb(w[g|0]|w[g+1|0]<<8|(w[g+2|0]<<16|w[g+3|0]<<24));v[22656]=0;g=Q(190,b|0,g|0)|0;i=v[22656];v[22656]=0;if((i|0)==1){break g}if(!g){break w}v[22656]=0;R(693,b|0,d+24|0);g=v[22656];v[22656]=0;if((g|0)==1){break g}g=Xb(w[d+24|0]|w[d+25|0]<<8|(w[d+26|0]<<16|w[d+27|0]<<24));v[22656]=0;U(288,d+432|0,b|0,g|0);g=v[22656];v[22656]=0;if((g|0)==1){break g}g=d- -64|0;i=d+432|0;Vc(C,kc(g,i));xb(g);xb(i)}i=Ib(w[h|0]|w[h+1|0]<<8);g=Ib(w[h|0]|w[h+1|0]<<8)&15;m=i<<16>>16;if((m|0)>=0){break v}v[22656]=0;pr(j,0);i=v[22656];v[22656]=0;ba=1;if((i|0)!=1){break u}break g}f=P()|0;O()|0;break f}if(g>>>0>6){break u}i=w[g+28918|0];if(!g){g=i;break r}u[a+480190>>1]=(x[a+480190>>1]+i|0)-1;g=j+108|0;l=j+236|0;D=i-2|0;f=4;while(1){k=B(f,12);e=(D<<3)+f|0;E=e+28972|0;z=w[e+28924|0]+o|0;e=0;while(1){A=e+k|0;la=vd(l,A),ma=z,u[la>>1]=ma;A=ic(g,A);t[A|0]=w[A|0]+w[E|0];e=e+1|0;if((e|0)!=12){continue}break}k=1;f=f+1|0;if((f|0)!=10){continue}break}g=i;break t}i=1;if((g|0)!=7){g=1;break r}k=0;v[22656]=0;BS(j,-24);i=v[22656];v[22656]=0;g=1;if((i|0)==1){break s}i=1}D=1;break q}break g}f=P()|0;O()|0;break f}k=0;if(G|(m|0)<0){break q}l=j+108|0;f=7;while(1){E=B(f,12);z=B(f,-12)+72|0;e=0;while(1){A=ic(l,e+E|0);t[A|0]=z+w[A|0];e=e+1|0;if((e|0)!=12){continue}break}f=f+1|0;if((f|0)!=10){continue}break}}v[22656]=0;R(696,N|0,d- -64|0);e=v[22656];v[22656]=0;x:{if((e|0)!=1){if(!(!w[r|0]|w[r|0]>16)){t[j+31|0]=w[r|0];D=1}if(!(!w[q|0]|w[q|0]>128)){t[j+30|0]=w[q|0]}e=0;f=0;if(!g){break x}y:{while(1){z:{v[22656]=0;e=B(e+s|0,104)+a|0;R(424,e+484380|0,8);j=v[22656];v[22656]=0;if((j|0)==1){break z}t[d+432|0]=w[K|0];v[22656]=0;t[d+400|0]=64;j=ac(d+432|0,d+400|0);l=v[22656];v[22656]=0;if((l|0)==1){break y}u[e+484410>>1]=w[j|0]<<2;t[e+484416|0]=w[H|0];f=f+1|0;e=f&65535;if(g>>>0>e>>>0){continue}break x}break}break g}break g}break g}A:{if(!F|(m|0)<0){break A}j=Rc(d+432|0,8,1,1,0);E=Ib(w[n|0]|w[n+1|0]<<8);e=d- -64|0;f=Ib(w[e|0]|w[e+1|0]<<8);m=Ib(w[n|0]|w[n+1|0]<<8);v[22656]=0;e=T(195,d+144|0)|0;l=v[22656];v[22656]=0;if((l|0)==1){break g}if(Ib(w[h|0]|w[h+1|0]<<8)&16){Yi(j,16);e=e>>>1|0}if(Ib(w[h|0]|w[h+1|0]<<8)&32){Bp(j,3);e=e>>>1|0}if(Ib(w[h|0]|w[h+1|0]<<8)&64){Bf(j,2)}e=k?(e>>>0)/((-1<<g^-1)>>>0)|0:e;if(!g){break A}m=f+m|0;k=0;l=0;while(1){k=B(k+s|0,104)+a|0;z=k+484380|0;v[z>>2]=e;v[22656]=0;W(329,j|0,z|0,C|0)|0;z=v[22656];v[22656]=0;if((z|0)==1){break g}f=f<<1;m=m<<1;if(E>>>0>=2){v[k+484388>>2]=m;v[k+484384>>2]=f;k=k+484414|0;u[k>>1]=x[k>>1]|2}e=e<<1;l=l+1|0;k=l&65535;if(k>>>0<g>>>0){continue}break}}o=i+o|0;xb(d+144|0);p=p+1|0;e=p&65535;if(e>>>0<=x[a+480192>>1]){continue}break}}g=d+480|4;B:{if(!Xb(w[g|0]|w[g+1|0]<<8|(w[g+2|0]<<16|w[g+3|0]<<24))){break B}if(!Ib(w[d+488|0]|w[d+489|0]<<8)){break B}g=Xb(w[g|0]|w[g+1|0]<<8|(w[g+2|0]<<16|w[g+3|0]<<24));v[22656]=0;g=Q(190,b|0,g|0)|0;i=v[22656];v[22656]=0;if((i|0)==1){break h}if(!g){break B}la=d,ma=Ib(w[d+488|0]|w[d+489|0]<<8),u[la+144>>1]=ma;g=w[d+843|0];v[22656]=0;u[d+64>>1]=g;g=Pc(d+144|0,d- -64|0);i=v[22656];v[22656]=0;if((i|0)==1){break i}n=x[g>>1];h=Ib(w[d+490|0]|w[d+491|0]<<8);if(!n){break B}g=d+144|0;j=g|5;l=g|3;k=g|1;i=d+72|0;p=d- -64|4;o=h>>>0<19;q=h>>>0<21;r=h>>>0<15;s=h>>>0<6;f=0;while(1){v[22656]=0;U(697,b|0,d+144|0,h|0);g=v[22656];v[22656]=0;C:{D:{E:{if((g|0)!=1){f=f+1|0;g=v[((f<<2)+a|0)+900380>>2];if(!w[d+144|0]){break C}D=qr(d- -64|0,0,64);qr(p,w[d+144|0]-1&65535,64);C=w[d+144|0];qr(i,C+(w[k|0]?64/w[k|0]|0:0)|0,0);v[d+428>>2]=3;v[d+424>>2]=D;v[22656]=0;e=v[d+428>>2];v[d>>2]=v[d+424>>2];v[d+4>>2]=e;e=g+48|0;R(698,e|0,d|0);m=v[22656];v[22656]=0;if((m|0)==1){break E}if(w[d+144|0]!=1){break D}la=d,ma=Vb(e),v[la+64>>2]=ma;Fd(d+416|0,d- -64|0);v[22656]=0;R(699,e|0,v[d+416>>2]);e=v[22656];v[22656]=0;if((e|0)!=1){break D}f=P()|0;O()|0;break f}f=P()|0;O()|0;break f}f=P()|0;O()|0;break f}v[g>>2]=w[k|0]?w[k|0]<<9:32767;D=1;t[g+60|0]=w[g+60|0]|1}F:{if(o){break F}v[g+4>>2]=w[d+162|0]+1>>>1;if(q){break F}u[g+28>>1]=w[d+164|0]|w[d+165|0]<<8}g=B(x[vd(g+236|0,61)>>1],104)+a|0;t[g+484417|0]=w[l|0]<<4;G:{H:{if(!r){la=g+484384|0,ma=Xb(w[d+154|0]|w[d+155|0]<<8|(w[d+156|0]<<16|w[d+157|0]<<24)),v[la>>2]=ma;la=g+484388|0,ma=Xb(w[d+154|0]|w[d+155|0]<<8|(w[d+156|0]<<16|w[d+157|0]<<24))+Xb(w[d+158|0]|w[d+159|0]<<8|(w[d+160|0]<<16|w[d+161|0]<<24))|0,v[la>>2]=ma;break H}if(s){break G}}e=g+484414|0;u[e>>1]=x[e>>1]&65533|w[j|0]<<1&2;u[e>>1]=x[e>>1]&65531|w[j|0]>>>1&4;if(!(w[j|0]&4)){break G}u[g+484412>>1]=0}if((f|0)!=(n|0)){continue}break}}if(!Xb(w[d+500|0]|w[d+501|0]<<8|(w[d+502|0]<<16|w[d+503|0]<<24))){break j}if(!Ib(w[d+504|0]|w[d+505|0]<<8)){break j}g=Xb(w[d+500|0]|w[d+501|0]<<8|(w[d+502|0]<<16|w[d+503|0]<<24));v[22656]=0;g=Q(190,b|0,g|0)|0;i=v[22656];v[22656]=0;if((i|0)==1){break h}if(!g){break j}la=d,ma=Ib(w[d+504|0]|w[d+505|0]<<8),u[la+144>>1]=ma;g=w[d+843|0];v[22656]=0;u[d+64>>1]=g;g=Pc(d+144|0,d- -64|0);i=v[22656];v[22656]=0;if((i|0)!=1){e=x[g>>1];f=Ib(w[d+506|0]|w[d+507|0]<<8);if(!e){break j}k=0;I:while(1){J:{v[22656]=0;U(700,b|0,d+144|0,f|0);g=v[22656];v[22656]=0;if((g|0)==1){break k}v[22656]=0;eD(d+432|0,2,d+144|0);g=v[22656];v[22656]=0;if((g|0)==1){break l}v[22656]=0;R(324,d- -64|0,d+432|0);g=v[22656];v[22656]=0;if((g|0)==1){break l}k=k+1|0;h=((k<<2)+a|0)+900380|0;g=v[h>>2];v[22656]=0;Q(301,g+492|0,d- -64|0)|0;g=v[22656];v[22656]=0;if((g|0)==1){break m}g=d- -64|0;vb(g);i=v[h>>2];v[22656]=0;R(702,g|0,i|0);g=v[22656];v[22656]=0;if((g|0)==1){break n}g=d- -64|0;la=d,ma=or(g),v[la+432>>2]=ma;la=d,ma=Dh(g),v[la+24>>2]=ma;while(1){v[22656]=0;g=Gb(d+432|0,d+24|0);i=v[22656];v[22656]=0;K:{if((i|0)!=1){if(g){break K}nr(d- -64|0);if((e|0)!=(k|0)){continue I}break j}break J}v[22656]=0;g=Yl(d+432|0);i=v[22656];v[22656]=0;if((i|0)!=1){i=(x[g>>1]<<5)+a|0;j=i+946328|0;g=v[h>>2];n=v[g+520>>2];v[j>>2]=v[g+516>>2];v[j+4>>2]=n;n=v[g+512>>2];j=i+946320|0;v[j>>2]=v[g+508>>2];v[j+4>>2]=n;n=v[g+504>>2];j=i+946312|0;v[j>>2]=v[g+500>>2];v[j+4>>2]=n;j=v[g+496>>2];i=i+946304|0;v[i>>2]=v[g+492>>2];v[i+4>>2]=j;Uj(d+432|0);continue}break}}break}f=P()|0;O()|0;nr(d- -64|0);break f}f=P()|0;O()|0;break f}f=P()|0;O()|0;break e}f=P()|0;O()|0;break e}f=P()|0;O()|0;break f}f=P()|0;O()|0;vb(d- -64|0);break f}f=P()|0;O()|0;break f}f=P()|0;O()|0;break f}g=0;v[22656]=0;Xo(a+901404|0);i=v[22656];v[22656]=0;if((i|0)==1){break h}t[a+901696|0]=w[2040];i=a+901692|0;e=w[2036]|w[2037]<<8|(w[2038]<<16|w[2039]<<24);t[i|0]=e;t[i+1|0]=e>>>8;t[i+2|0]=e>>>16;t[i+3|0]=e>>>24;vc(b);K=a+484360|0;L:{M:{N:{O:{P:{Q:{if(!w[V|0]){break Q}ca=c&1;s=a+484344|0;C=a+1298292|0;z=a+1298268|0;c=d+144|0;ea=c|1;j=c|4;c=d+48|0;i=c|4;F=c|2;fa=c|3;q=d+560|2;R:{while(1){S:{v[22656]=0;Y(705,b|0,d+872|0,d+480|0,d+560|0);c=v[22656];v[22656]=0;T:{U:{V:{W:{X:{Y:{Z:{_:{$:{aa:{ba:{ca:{da:{ea:{fa:{if((c|0)==1){break fa}c=Z&255;if(c){v[22656]=0;e=T(417,K|0)|0;h=v[22656];v[22656]=0;if((h|0)==1){break fa}if((e|0)==255){break d}}n=Tj(K,c);r=Jk(d+400|0);cm(n);m=w[d+871|0];if(m>>>0>1){break da}if(Ib(w[q|0]|w[q+1|0]<<8)>>>0>256|x[a+480188>>1]>16){break ca}c=d+144|0;fW(c,d+560|0);e=Ib(w[q|0]|w[q+1|0]<<8);v[22656]=0;U(706,n|0,c|0,e|0);c=v[22656];v[22656]=0;if((c|0)==1){break ba}la=d,ma=Vb(n),v[la+144>>2]=ma;la=d,ma=Zb(n),v[la+64>>2]=ma;if(Gb(d+144|0,d- -64|0)){break ea}break V}f=P()|0;O()|0;break f}while(1){c=d+144|0;e=v[c>>2];u[e>>1]=x[e>>1]+g;of(c);if(Gb(c,d- -64|0)){continue}break}break V}fW(d+144|0,d+560|0);if(!Ib(w[d+156|0]|w[d+157|0]<<8)){break ca}if(Ib(w[d+156|0]|w[d+157|0]<<8)>>>0>64|x[a+480188>>1]>64){break ca}k=Xb(w[d+164|0]|w[d+165|0]<<8|(w[d+166|0]<<16|w[d+167|0]<<24));ga:{if(Ib(w[d+168|0]|w[d+169|0]<<8)){la=d,ma=Ib(w[d+168|0]|w[d+169|0]<<8),u[la+64>>1]=ma;v[22656]=0;u[d+432>>1]=800;c=Pc(d- -64|0,d+432|0);e=v[22656];v[22656]=0;if((e|0)==1){break ga}c=Qc(((x[c>>1]<<5)+50>>>0)/100|0,0)}else{c=32}e=Xb(w[d+152|0]|w[d+153|0]<<8|(w[d+154|0]<<16|w[d+155|0]<<24));v[22656]=0;h=Q(190,b|0,e|0)|0;e=v[22656];v[22656]=0;ha:{if((e|0)==1){break ha}e=0;ia:{ja:{ka:{la:{ma:{if(h&x[a+480188>>1]!=0){while(1){v[22656]=0;h=T(374,b|0)|0;f=v[22656];v[22656]=0;if((f|0)==1){break ma}t[d+64|0]=h;v[22656]=0;t[d+432|0]=64;h=ac(d- -64|0,d+432|0);f=v[22656];v[22656]=0;if((f|0)==1){break la}u[((e<<5)+a|0)+480286>>1]=w[h|0];e=e+1|0;if(e>>>0<x[a+480188>>1]){continue}break}}if(!Xb(w[d+160|0]|w[d+161|0]<<8|(w[d+162|0]<<16|w[d+163|0]<<24))){break ja}e=Xb(w[d+160|0]|w[d+161|0]<<8|(w[d+162|0]<<16|w[d+163|0]<<24));v[22656]=0;e=Q(190,b|0,e|0)|0;h=v[22656];v[22656]=0;if((h|0)==1){break ha}if(!e){break ja}e=0;if(!x[a+480188>>1]){break ia}while(1){v[22656]=0;h=T(707,b|0)|0;f=v[22656];v[22656]=0;if((f|0)==1){break ka}la=((e<<5)+a|0)+480284|0,ma=(Lb(h,-16,16)<<3)+128|0,u[la>>1]=ma;e=e+1|0;if(e>>>0<x[a+480188>>1]){continue}break}break ia}f=P()|0;O()|0;break L}f=P()|0;O()|0;break L}f=P()|0;O()|0;break L}v[22656]=0;xh(a,1);e=v[22656];v[22656]=0;if((e|0)==1){break ha}}h=dd(d+128|0);e=Xb(w[j|0]|w[j+1|0]<<8|(w[j+2|0]<<16|w[j+3|0]<<24));v[22656]=0;e=Q(190,b|0,e|0)|0;f=v[22656];v[22656]=0;if((f|0)==1){break aa}na:{if(!e){break na}e=Ib(w[q|0]|w[q+1|0]<<8);v[22656]=0;e=Q(191,b|0,e<<1)|0;f=v[22656];v[22656]=0;if((f|0)==1){break aa}if(!e){break na}e=Ib(w[q|0]|w[q+1|0]<<8);v[22656]=0;e=W(708,b|0,h|0,e|0)|0;f=v[22656];v[22656]=0;if((f|0)==1){break aa}if(!e){break na}la=d,ma=Vb(h),v[la+120>>2]=ma;la=d,ma=Zb(h),v[la+112>>2]=ma;if(Gb(d+120|0,d+112|0)){while(1){e=v[d+120>>2];e=Ib(w[e|0]|w[e+1|0]<<8);oa:{if(Ib(w[d+158|0]|w[d+159|0]<<8)>>>0<e>>>0){break oa}f=Xb(w[d+144|0]|w[d+145|0]<<8|(w[d+146|0]<<16|w[d+147|0]<<24));v[22656]=0;Q(190,b|0,f+(e<<2)|0)|0;e=v[22656];v[22656]=0;pa:{qa:{ra:{if((e|0)==1){break ra}v[22656]=0;e=T(426,b|0)|0;f=v[22656];v[22656]=0;if((f|0)==1){break ra}v[22656]=0;e=Q(190,b|0,e|0)|0;f=v[22656];v[22656]=0;if((f|0)==1){break ra}if(!e){break oa}v[22656]=0;e=Q(191,b|0,42)|0;f=v[22656];v[22656]=0;if((f|0)==1){break ra}if(!e){break oa}v[22656]=0;R(709,b|0,d- -64|0);e=v[22656];v[22656]=0;sa:{if((e|0)!=1){if(cd(n)){break sa}v[22656]=0;R(710,n|0,65534);e=v[22656];v[22656]=0;if((e|0)!=1){break sa}}f=P()|0;O()|0;break W}e=Ib(w[d+104|0]|w[d+105|0]<<8);v[22656]=0;v[d+60>>2]=e;e=Q(191,b|0,e|0)|0;f=v[22656];v[22656]=0;if((f|0)==1){break qa}if(!e){v[22656]=0;e=T(467,b|0)|0;f=v[22656];v[22656]=0;if((f|0)==1){break qa}qc(d+60|0,e)}qc(d+60|0,65534);f=tc(n);v[22656]=0;R(711,n|0,f+v[d+60>>2]|0);e=v[22656];v[22656]=0;if((e|0)==1){break X}e=0;if(!v[d+60>>2]){break pa}while(1){ta:{v[22656]=0;l=T(416,b|0)|0;p=v[22656];v[22656]=0;if((p|0)==1){break ta}l=l<<16>>16;if((l|0)>=0){v[22656]=0;R(710,n|0,g+l&65535);l=v[22656];v[22656]=0;if((l|0)==1){break ta}}e=e+1|0;if(e>>>0<y[d+60>>2]){continue}break pa}break}f=P()|0;O()|0;break W}f=P()|0;O()|0;break W}f=P()|0;O()|0;break W}if(w[d+64|0]){v[22656]=0;R(712,d+48|0,d- -64|0);e=v[22656];v[22656]=0;ua:{if((e|0)!=1){v[22656]=0;R(713,d+24|0,d+48|0);e=v[22656];v[22656]=0;if((e|0)!=1){break ua}}f=P()|0;O()|0;break W}v[22656]=0;U(13,d+432|0,2,d+24|0);e=v[22656];v[22656]=0;if((e|0)==1){break Z}v[22656]=0;R(418,n|0,d+432|0);e=v[22656];v[22656]=0;if((e|0)==1){break _}vb(d+432|0);vb(d+24|0)}if(!Xb(w[d+96|0]|w[d+97|0]<<8|(w[d+98|0]<<16|w[d+99|0]<<24))){break oa}e=Xb(w[d+96|0]|w[d+97|0]<<8|(w[d+98|0]<<16|w[d+99|0]<<24));v[22656]=0;e=Q(190,b|0,e|0)|0;l=v[22656];v[22656]=0;if((l|0)==1){break X}if(!e){break oa}while(1){va:{v[22656]=0;e=Q(714,b|0,d+48|0)|0;l=v[22656];v[22656]=0;wa:{xa:{if((l|0)!=1){if(!e){break oa}e=w[fa|0];v[22656]=0;U(288,d+24|0,b|0,e|0);e=v[22656];v[22656]=0;if((e|0)==1){break xa}e=d+24|0;l=kc(d+432|0,e);xb(e);la=d,ma=Qv(Ib(w[d+48|0]|w[d+49|0]<<8)+f|0),u[la+24>>1]=ma;if((Ib(w[d+48|0]|w[d+49|0]<<8)|0)==65535){break va}e=x[d+24>>1];if(tc(n)>>>0>e>>>0){break wa}xb(d+432|0);break oa}f=P()|0;O()|0;break W}f=P()|0;O()|0;break W}ya:{if(w[F|0]==1){e=65535}else{if(w[F|0]!=2){break ya}v[22656]=0;e=T(416,l|0)|0;l=v[22656];v[22656]=0;if((l|0)==1){break $}v[22656]=0;l=Q(715,r|0,d+24|0)|0;p=v[22656];v[22656]=0;if((p|0)==1){break $}u[l>>1]=e;e=65534}la=sc(n,x[d+24>>1]),ma=e,u[la>>1]=ma}xb(d+432|0);continue}break}xb(d+432|0)}e=d+120|0;Tv(e);if(Gb(e,d+112|0)){continue}break}}k=c>>>(k>>>1&1)|0;Hr(h);break U}Hr(h);break T}f=P()|0;O()|0;break L}f=P()|0;O()|0;break L}qv(r);break d}f=P()|0;O()|0;break L}f=P()|0;O()|0;break W}f=P()|0;O()|0;xb(d+432|0);break W}f=P()|0;O()|0;vb(d+432|0);break Y}f=P()|0;O()|0}vb(d+24|0);break W}f=P()|0;O()|0}Hr(h);break L}v[22656]=0;xh(a,1);c=v[22656];v[22656]=0;za:{if((c|0)!=1){e=0;k=32;if(!x[a+480188>>1]){break U}while(1){t[d+144|0]=w[(d+e|0)+826|0];v[22656]=0;t[d+64|0]=64;c=ac(d+144|0,d- -64|0);h=v[22656];v[22656]=0;if((h|0)==1){break za}u[((e<<5)+a|0)+480286>>1]=w[c|0];e=e+1|0;if(e>>>0<x[a+480188>>1]){continue}break}break U}f=P()|0;O()|0;break L}f=P()|0;O()|0;break L}e=w[d+823|0];A=w[d+823|0]&64;E=w[d+824|0]&32;G=(w[d+824|0]&31)+1|0;la=a,ma=cW(Ib(w[d+820|0]|w[d+821|0]<<8),A>>>6|0,E>>>5|0,G),v[la+480204>>2]=ma;la=a,ma=Md(w[d+825|0],1,32),v[la+480196>>2]=ma;if(E){v[a+480216>>2]=G;v[a+480220>>2]=G<<2}Aa:{Ba:{if(w[d+842|0]){t[d+144|0]=w[d+842|0];v[22656]=0;t[d+64|0]=64;c=ac(d+144|0,d- -64|0);h=v[22656];v[22656]=0;if((h|0)==1){break Ba}v[a+480200>>2]=w[c|0]<<2}v[a+480228>>2]=k;v[a+480232>>2]=k;v[a+480208>>2]=v[a+480208>>2]&-3|(w[d+823|0]>>>4^-1)&2;Ca:{Da:{Ea:{Fa:{Ga:{Ha:{Ia:{Ja:{Ka:{La:{Ma:{Na:{if(!Xb(w[d+524|0]|w[d+525|0]<<8|(w[d+526|0]<<16|w[d+527|0]<<24))){break Na}c=Xb(w[d+524|0]|w[d+525|0]<<8|(w[d+526|0]<<16|w[d+527|0]<<24));v[22656]=0;c=Q(190,b|0,c|0)|0;h=v[22656];v[22656]=0;if((h|0)==1){break Ma}if(!c){break Na}c=Xb(w[d+528|0]|w[d+529|0]<<8|(w[d+530|0]<<16|w[d+531|0]<<24));v[22656]=0;W(413,b|0,z|0,c|0)|0;c=v[22656];v[22656]=0;if((c|0)==1){break Ma}if(w[V|0]<2){break Na}v[22656]=0;U(13,d+144|0,2,z|0);c=v[22656];v[22656]=0;if((c|0)==1){break La}v[22656]=0;R(418,n|0,d+144|0);c=v[22656];v[22656]=0;if((c|0)==1){break Ka}vb(d+144|0)}Oa:{if(Xb(w[d+496|0]|w[d+497|0]<<8|(w[d+498|0]<<16|w[d+499|0]<<24))>>>0<2){break Oa}c=Xb(w[d+492|0]|w[d+493|0]<<8|(w[d+494|0]<<16|w[d+495|0]<<24));v[22656]=0;c=Q(190,b|0,c|0)|0;h=v[22656];v[22656]=0;if((h|0)==1){break Ma}if(!c){break Oa}c=Xb(w[d+496|0]|w[d+497|0]<<8|(w[d+498|0]<<16|w[d+499|0]<<24));v[22656]=0;da(510,C|0,b|0,c-1|0,4)|0;c=v[22656];v[22656]=0;if((c|0)==1){break Ma}}if(!Xb(w[d+536|0]|w[d+537|0]<<8|(w[d+538|0]<<16|w[d+539|0]<<24))){break Aa}c=Xb(w[d+536|0]|w[d+537|0]<<8|(w[d+538|0]<<16|w[d+539|0]<<24));v[22656]=0;c=Q(190,b|0,c|0)|0;h=v[22656];v[22656]=0;if((h|0)==1){break Ma}if(!c){break Aa}v[22656]=0;c=Q(191,b|0,12)|0;h=v[22656];v[22656]=0;if((h|0)==1){break Ma}if(!c){break Aa}v[22656]=0;Q(318,b|0,6)|0;c=v[22656];v[22656]=0;if((c|0)==1){break Ma}v[22656]=0;c=T(416,b|0)|0;h=v[22656];v[22656]=0;if((h|0)==1){break Ma}if((c|0)!=1){break Aa}v[22656]=0;c=T(426,b|0)|0;h=v[22656];v[22656]=0;if((h|0)==1){break Ia}if(!c){break Aa}v[22656]=0;h=Q(191,b|0,c|0)|0;f=v[22656];v[22656]=0;if((f|0)==1){break Ia}if(h){break Ja}break Aa}f=P()|0;O()|0;break L}f=P()|0;O()|0;break L}f=P()|0;O()|0;vb(d+144|0);break L}Dc(d+144|0,C);v[22656]=0;da(510,C|0,b|0,c|0,4)|0;c=v[22656];v[22656]=0;if((c|0)==1){break Da}if(!gd(d+144|0)){v[22656]=0;c=W(716,d+432|0,2,13)|0;h=v[22656];v[22656]=0;if((h|0)==1){break Ha}v[22656]=0;U(717,d- -64|0,d+144|0,c|0);h=v[22656];v[22656]=0;if((h|0)==1){break Ga}v[22656]=0;U(718,d+8|0,d- -64|0,C|0);h=v[22656];v[22656]=0;if((h|0)==1){break Fa}h=d+8|0;Eb(C,h);vb(h);vb(d- -64|0);vb(c)}vb(d+144|0);break Aa}f=P()|0;O()|0;break L}f=P()|0;O()|0;break Ca}f=P()|0;O()|0;break Ea}f=P()|0;O()|0;vb(d- -64|0)}vb(c);break Ca}f=P()|0;O()|0}vb(d+144|0);break L}f=P()|0;O()|0;break L}Pa:{if(m>>>0<2){break Pa}if(!Xb(w[d+548|0]|w[d+549|0]<<8|(w[d+550|0]<<16|w[d+551|0]<<24))){break Pa}m=0;if(!x[a+480188>>1]){break Pa}while(1){c=Xb(w[d+548|0]|w[d+549|0]<<8|(w[d+550|0]<<16|w[d+551|0]<<24));v[22656]=0;c=Q(190,b|0,c+(m<<2)|0)|0;h=v[22656];v[22656]=0;if((h|0)==1){break M}Qa:{if(!c){break Qa}v[22656]=0;c=T(426,b|0)|0;h=v[22656];v[22656]=0;if((h|0)==1){break M}v[22656]=0;c=Q(190,b|0,c|0)|0;h=v[22656];v[22656]=0;if((h|0)==1){break M}k=0;l=0;if(!c){break Qa}while(1){Ra:{v[22656]=0;c=Q(191,b|0,8)|0;h=v[22656];v[22656]=0;Sa:{Ta:{Ua:{if((h|0)!=1){if(!c){break Ra}v[22656]=0;R(719,b|0,d+144|0);c=v[22656];v[22656]=0;if((c|0)==1){break Ua}if(!Xb(w[d+144|0]|w[d+145|0]<<8|(w[d+146|0]<<16|w[d+147|0]<<24))){break Ra}switch((Xb(w[d+144|0]|w[d+145|0]<<8|(w[d+146|0]<<16|w[d+147|0]<<24))&536870911)-1|0){case 1:break Sa;case 0:break Ta;default:continue}}f=P()|0;O()|0;break L}f=P()|0;O()|0;break L}k=Xb(w[j|0]|w[j+1|0]<<8|(w[j+2|0]<<16|w[j+3|0]<<24));continue}l=Xb(w[j|0]|w[j+1|0]<<8|(w[j+2|0]<<16|w[j+3|0]<<24));continue}break}if(!k|!l){break Qa}v[22656]=0;c=Q(190,b|0,k|0)|0;h=v[22656];v[22656]=0;if((h|0)==1){break N}if(!c){break Qa}v[22656]=0;W(571,b|0,((m<<5)+a|0)+480289|0,l|0)|0;c=v[22656];v[22656]=0;if((c|0)==1){break N}}m=m+1|0;if(m>>>0<x[a+480188>>1]){continue}break}}l=Ib(w[d+560|0]|w[d+561|0]<<8);v[22656]=0;c=g+l|0;R(330,s|0,c&65535);h=v[22656];v[22656]=0;if((h|0)==1){break S}if(l){ga=e&16;ia=g&65535;k=0;while(1){Va:{if(!ca){break Va}e=Xb(w[d+888|0]|w[d+889|0]<<8|(w[d+890|0]<<16|w[d+891|0]<<24));v[22656]=0;e=Q(190,b|0,e+(k<<2)|0)|0;h=v[22656];v[22656]=0;if((h|0)==1){break R}if(!e){break Va}v[22656]=0;e=T(426,b|0)|0;h=v[22656];v[22656]=0;if((h|0)==1){break R}v[22656]=0;e=Q(190,b|0,e|0)|0;h=v[22656];v[22656]=0;if((h|0)==1){break R}if(!e){break Va}H=Kb(d+128|0);v[22656]=0;$=T(215,d- -64|0)|0;e=v[22656];v[22656]=0;Wa:{Xa:{if((e|0)!=1){h=w[d+871|0];if(h){break Xa}v[22656]=0;R(720,b|0,d+144|0);e=v[22656];v[22656]=0;if((e|0)==1){break P}u[d+120>>1]=w[d+144|0];p=w[ea|0]+1|0;e=48;break Wa}f=P()|0;O()|0;break O}f=t[d+822|0];v[22656]=0;R(721,b|0,d+48|0);e=v[22656];v[22656]=0;Ya:{Za:{if((e|0)!=1){la=d,ma=Ib(w[d+48|0]|w[d+49|0]<<8),u[la+120>>1]=ma;p=Ib(w[F|0]|w[F+1|0]<<8)+1|0;e=i;if(!Xb(w[e|0]|w[e+1|0]<<8|(w[e+2|0]<<16|w[e+3|0]<<24))){break Ya}m=v[b+8>>2];e=Xb(w[i|0]|w[e+1|0]<<8|(w[e+2|0]<<16|w[e+3|0]<<24));v[22656]=0;Q(190,b|0,e|0)|0;e=v[22656];v[22656]=0;if((e|0)==1){break P}v[22656]=0;R(722,b|0,d+144|0);e=v[22656];v[22656]=0;if((e|0)==1){break P}e=Xb(w[j|0]|w[j+1|0]<<8|(w[j+2|0]<<16|w[j+3|0]<<24));v[22656]=0;e=Q(190,b|0,e|0)|0;o=v[22656];v[22656]=0;if((o|0)==1){break P}if(!e){break Za}e=Xb(w[d+152|0]|w[d+153|0]<<8|(w[d+154|0]<<16|w[d+155|0]<<24));v[22656]=0;W(413,b|0,H|0,e|0)|0;e=v[22656];v[22656]=0;if((e|0)!=1){break Za}break P}break P}_a:{if(!Xb(w[d+160|0]|w[d+161|0]<<8|(w[d+162|0]<<16|w[d+163|0]<<24))){break _a}e=Xb(w[d+160|0]|w[d+161|0]<<8|(w[d+162|0]<<16|w[d+163|0]<<24));v[22656]=0;e=Q(190,b|0,e|0)|0;o=v[22656];v[22656]=0;if((o|0)==1){break P}if(!e){break _a}v[22656]=0;e=T(426,b|0)|0;o=v[22656];v[22656]=0;if((o|0)==1){break P}v[22656]=0;e=Q(190,b|0,e|0)|0;o=v[22656];v[22656]=0;if((o|0)==1){break P}if(!e){break _a}v[22656]=0;U(288,d+24|0,b|0,B(x[d+120>>1],p)|0);e=v[22656];v[22656]=0;if((e|0)==1){break P}e=d+432|0;o=d+24|0;Vc($,kc(e,o));xb(e);xb(o)}v[22656]=0;Q(190,b|0,m|0)|0;e=v[22656];v[22656]=0;if((e|0)==1){break P}}e=f+(h>>>0<3?48:24)|0}v[22656]=0;f=k+ia|0;m=W(331,s|0,f&65535,p|0)|0;h=v[22656];v[22656]=0;if((h|0)==1){break P}h=e;if(m){aa=_b(s,f);v[22656]=0;Q(428,aa|0,H|0)|0;e=v[22656];v[22656]=0;if((e|0)==1){break P}zg(d+120|0,x[a+480188>>1]);o=0;while(1){v[22656]=0;e=Yc(aa,o,0);f=v[22656];v[22656]=0;$a:{ab:{if((f|0)!=1){m=0;if(x[d+120>>1]){break ab}break $a}break P}while(1){bb:{if(!w[d+871|0]){v[22656]=0;R(723,d+144|0,b|0);f=v[22656];v[22656]=0;if((f|0)!=1){f=d+144|0;I=qd(f);_=Ve(f);f=w[f|0];t[e+1|0]=f>>>3&16|w[I|0]>>>4|f>>>1&32;t[e+3|0]=w[I|0]&15;t[e+5|0]=w[_|0];f=f&63;f=f?f+h|0:0;break bb}break P}v[22656]=0;R(532,d+144|0,b|0);f=v[22656];v[22656]=0;cb:{db:{if((f|0)!=1){f=d+144|0;I=qd(f);_=Ve(f);ja=ej(f);v[22656]=0;M=T(374,$|0)|0;ka=v[22656];v[22656]=0;if((ka|0)==1){break P}t[e+4|0]=M;M=w[f|0];f=M&127;if(!f){break db}f=f+h|0;break cb}break P}f=0;if((M|0)!=128){break cb}t[e|0]=254}t[e+1|0]=w[I|0]&63;t[e+3|0]=w[_|0];t[e+5|0]=w[ja|0]}if(f-1>>>0<=119){t[e|0]=f}v[22656]=0;ha(724,e|0,(A|0)!=0|0,(E|0)!=0|0,G|0,(ga|0)!=0|0);I=v[22656];v[22656]=0;if((I|0)!=1){D=(f|0)>84&X|D;e=e+6|0;m=m+1|0;if(x[d+120>>1]<=(m&65535)>>>0){break $a}continue}break}break P}o=o+1|0;if((p|0)!=(o|0)){continue}break}}xb(d- -64|0);vb(H)}k=k+1|0;if((l|0)!=(k|0)){continue}break}}la=d,ma=or(r),v[la+64>>2]=ma;la=d,ma=Dh(r),v[la+432>>2]=ma;eb:{fb:{gb:{if(og(d- -64|0,d+432|0)){while(1){e=Yl(d- -64|0);c=e;h=Ve(e);hb:{ib:{jb:{e=x[e>>1];if(!e){e=0;break jb}v[22656]=0;f=Q(472,n|0,e-1&65535)|0;e=v[22656];v[22656]=0;if((e|0)==1){break gb}e=x[c>>1];if(!f){break jb}v[22656]=0;e=Q(546,n|0,e-1&65535)|0;c=v[22656];v[22656]=0;if((c|0)!=1){break ib}break gb}if(x[h>>1]==((e&65535)+1|0)){break hb}v[22656]=0;e=W(545,s|0,1,0)|0;f=v[22656];v[22656]=0;if((f|0)==1){break gb}if((e|0)==65535){break hb}la=sc(n,x[c>>1]),ma=e,u[la>>1]=ma}c=_b(s,e);h=Iv(x[h>>1]);v[22656]=0;h=Be(d+144|0,12,h);f=v[22656];v[22656]=0;if((f|0)==1){break fb}h=qp(Ue(h,v[_b(s,e)+12>>2]-1|0));v[22656]=0;Q(431,c|0,h|0)|0;c=v[22656];v[22656]=0;if((c|0)==1){break fb}l=(l&65535)>>>0>e>>>0?l:e+1|0}c=d- -64|0;Uj(c);if(og(c,d+432|0)){continue}break}c=g+l|0}if(!Xb(w[d+480|0]|w[d+481|0]<<8|(w[d+482|0]<<16|w[d+483|0]<<24))){break eb}g=Xb(w[d+480|0]|w[d+481|0]<<8|(w[d+482|0]<<16|w[d+483|0]<<24));v[22656]=0;g=Q(190,b|0,g|0)|0;e=v[22656];v[22656]=0;if((e|0)==1){break S}if(!g){break eb}g=c;break T}f=P()|0;O()|0;break L}f=P()|0;O()|0;break L}qv(r);break Q}qv(r);Z=Z+1|0;if(w[V|0]>(Z&255)>>>0){continue}break Q}break}f=P()|0;O()|0;break L}f=P()|0;O()|0;break L}v[22656]=0;Qi(K,0);b=v[22656];v[22656]=0;if((b|0)!=1){if(!(D&1)){m=x[a+480192>>1];if(m){e=1;while(1){b=(((e&65535)<<2)+a|0)+900380|0;c=v[b>>2];if(c){Yb(sv(c));m=x[a+480192>>1]}v[b>>2]=0;e=e+1|0;if((e&65535)>>>0<=(m&65535)>>>0){continue}break}}u[a+480192>>1]=0}kb:{lb:{mb:{nb:{ob:{pb:{qb:{if(ba){v[22656]=0;b=Q(2,d+144|0,13467)|0;c=v[22656];v[22656]=0;if((c|0)==1){break qb}v[22656]=0;U(560,a|0,2,b|0);c=v[22656];v[22656]=0;if((c|0)==1){break pb}vb(b)}f=18726;switch(w[d+871|0]){case 3:break lb;case 2:break mb;case 1:break nb;case 0:break ob;default:break kb}}f=P()|0;O()|0;break f}f=P()|0;O()|0;vb(b);break f}f=x[a+480188>>1]>4?14339:14325;break kb}f=14307;break kb}f=14289;break kb}f=14262}v[22656]=0;R(725,d- -64|0,13877);b=v[22656];v[22656]=0;rb:{sb:{tb:{if((b|0)!=1){v[22656]=0;U(726,d+144|0,d- -64|0,d+871|0);b=v[22656];v[22656]=0;if((b|0)==1){break tb}b=d+144|0;Eb(a+1298304|0,b);vb(b);Hb(d- -64|0);v[22656]=0;b=Q(2,b|0,9953)|0;c=v[22656];v[22656]=0;if((c|0)==1){break sb}Eb(a+1298316|0,b);vb(b);v[22656]=0;Q(157,a+1298328|0,f|0)|0;b=v[22656];v[22656]=0;if((b|0)==1){break rb}v[a+1298364>>2]=2;e=1;break c}f=P()|0;O()|0;break f}f=P()|0;O()|0;Hb(d- -64|0);break f}f=P()|0;O()|0;break f}f=P()|0;O()|0;break f}f=P()|0;O()|0;break f}f=P()|0;O()|0;xb(d- -64|0)}vb(H);break L}f=P()|0;O()|0;break L}f=P()|0;O()|0}qv(r);break f}f=P()|0;O()|0;break f}f=P()|0;O()|0;break f}f=P()|0;O()|0;xb(d+144|0)}ci(J)}xb(N);S(f|0);L()}e=0}ci(J)}xb(N)}gb=d+928|0;return e|0}function pma(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,z=0,A=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,M=0;f=gb-1728|0;gb=f;vc(b);h=gb-32|0;gb=h;e=h+24|0;i=f+1600|0;eV(e,i);g=yb(e);e=v[h+28>>2];l=v[h+24>>2];v[h+8>>2]=l;v[h+12>>2]=e;v[h>>2]=l;v[h+4>>2]=e;l=h+16|0;e=b;cc(l,e,h);l=yb(l);if((l|0)==(g|0)){Rb(e,yb(h+24|0))}gb=h+32|0;e=(g|0)==(l|0);if(!e){dV(i)}a:{if(!e){break a}if(!hV(f+1600|0)){break a}if(!Pb(b,Qc(256,0))){break a}b:{if(!c){break b}Gd(a,1048576);Bg(a);d=gb-16|0;gb=d;e=Tb(d,1339);Dc(f+1344|0,e);vb(e);gb=d+16|0;q=f+1608|0;v[f+160>>2]=w[q+1|0];d=w[q|0];v[22656]=0;v[f+16>>2]=d;R(599,f+88|0,f+16|0);d=v[22656];v[22656]=0;c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{if((d|0)!=1){v[22656]=0;Y(582,f+240|0,f+1344|0,f+160|0,f+88|0);d=v[22656];v[22656]=0;if((d|0)==1){break n}d=f+240|0;Eb(a+1298304|0,d);vb(d);e=f+88|0;vb(e);h=f+1344|0;Hb(h);g=Tb(d,12324);Eb(a+1298316|0,g);vb(g);Ke(e,2,f+1610|0);Bc(h,e);v[22656]=0;U(13,d|0,8,h|0);d=v[22656];v[22656]=0;if((d|0)==1){break j}d=f+240|0;Eb(a+1298328|0,d);vb(d);e=f+1344|0;vb(e);v[a+1298364>>2]=8;Gr(e,2,f+1642|0);Bc(d,e);Eb(a+1298268|0,d);vb(d);h=f+1712|0;u[a+480188>>1]=w[h|0]|w[h+1|0]<<8;h=Md(w[f+1716|0],1,31);v[a+480204>>2]=125e4;v[a+480208>>2]=32792;v[a+480196>>2]=h;C=f+1722|0;u[a+480192>>1]=w[C|0]|w[C+1|0]<<8;D=f+1724|0;u[a+480190>>1]=w[D|0]|w[D+1|0]<<8;h=Md(w[f+1717|0],1,32);v[a+480216>>2]=h;v[a+480228>>2]=96;v[a+480232>>2]=48;v[a+480220>>2]=h<<2;nw(b,e);E=a+484360|0;m=f+1706|0;Ur(Sb(E),e,w[m|0]|w[m+1|0]<<8,65535,65535);e=f+1708|0;cf(Sb(E),w[e|0]|w[e+1|0]<<8);A=Og(b);Td(d,b,A?274:0);I=kc(f+1320|0,d);xb(d);v[22656]=0;d=T(192,b|0)|0;e=v[22656];v[22656]=0;if((e|0)==1){break l}v[22656]=0;U(288,f+240|0,b|0,d|0);d=v[22656];v[22656]=0;if((d|0)==1){break l}d=f+240|0;G=kc(f+1296|0,d);xb(d);F=x[a+480188>>1];if(A){u[a+480188>>1]=F+8}H=c&1;if(!H){break k}d=f+1710|0;d=w[d|0]|w[d+1|0]<<8;v[22656]=0;R(330,a+484344|0,d|0);d=v[22656];v[22656]=0;if((d|0)!=1){break k}g=P()|0;O()|0;break e}g=P()|0;O()|0;break m}g=P()|0;O()|0;vb(f+88|0)}Hb(f+1344|0);break c}g=P()|0;O()|0;break d}n=a+484344|0;o=f+1718|0;l=f+1710|0;if(!(w[l|0]|w[l+1|0]<<8)){g=0;break f}g=0;while(1){v[22656]=0;d=T(287,b|0)|0;e=v[22656];v[22656]=0;if((e|0)==1){break g}v[f+160>>2]=d;v[22656]=0;d=T(192,b|0)|0;e=v[22656];v[22656]=0;if((e|0)==1){break h}v[22656]=0;U(288,f+88|0,b|0,d+1&-2);d=v[22656];v[22656]=0;if((d|0)==1){break h}d=f+88|0;p=kc(f+240|0,d);xb(d);qc(f+160|0,1024);d=v[f+160>>2];o:{if(!d|!H){break o}v[22656]=0;d=W(331,n|0,r&65535,d|0)|0;e=v[22656];v[22656]=0;p:{if((e|0)!=1){if(!d){break o}j=0;if(t[o|0]&1){i=0;while(1){v[22656]=0;d=Q(191,f+240|0,1)|0;e=v[22656];v[22656]=0;q:{if((e|0)!=1){if(!d){break o}v[22656]=0;d=T(374,p|0)|0;e=v[22656];v[22656]=0;if((e|0)==1){break i}s=0;if((d|0)!=255){break q}v[22656]=0;s=T(374,p|0)|0;d=v[22656];v[22656]=0;if((d|0)!=1){v[22656]=0;d=T(374,p|0)|0;e=v[22656];v[22656]=0;if((e|0)!=1){break q}}break i}break i}r:{if(!(d&127)){break r}e=_b(n,r);v[22656]=0;h=Yc(e,i,j&65535);e=v[22656];v[22656]=0;if((e|0)==1){break i}Xv(f+88|0);if(d&1){v[22656]=0;e=T(374,p|0)|0;k=v[22656];v[22656]=0;if((k|0)==1){break i}t[f+88|0]=e}if(d&2){v[22656]=0;e=T(374,p|0)|0;k=v[22656];v[22656]=0;if((k|0)==1){break i}t[f+89|0]=e}if(d&4){v[22656]=0;e=T(374,p|0)|0;k=v[22656];v[22656]=0;if((k|0)==1){break i}t[f+90|0]=e}if(d&8){v[22656]=0;e=T(374,p|0)|0;k=v[22656];v[22656]=0;if((k|0)==1){break i}t[f+91|0]=e}if(d&16){v[22656]=0;e=T(374,p|0)|0;k=v[22656];v[22656]=0;if((k|0)==1){break i}t[f+92|0]=e}if(d&32){v[22656]=0;e=T(374,p|0)|0;k=v[22656];v[22656]=0;if((k|0)==1){break i}t[f+93|0]=e}if(d&64){v[22656]=0;d=T(374,p|0)|0;e=v[22656];v[22656]=0;if((e|0)==1){break i}t[f+94|0]=d}v[22656]=0;d=Q(790,h|0,f+88|0)|0;e=v[22656];v[22656]=0;if((e|0)==1){break i}v[f+16>>2]=s;v[22656]=0;v[f+64>>2]=v[f+160>>2]+(i^-1);k=Fb(f+16|0,f- -64|0);e=v[22656];v[22656]=0;if((e|0)==1){break i}g=d|g;e=0;d=h;J=v[k>>2];if(!J){break r}while(1){d=B(x[a+480188>>1],6)+d|0;k=w[h|0]|w[h+1|0]<<8|(w[h+2|0]<<16|w[h+3|0]<<24);t[d|0]=k;t[d+1|0]=k>>>8;t[d+2|0]=k>>>16;t[d+3|0]=k>>>24;k=w[h+4|0]|w[h+5|0]<<8;t[d+4|0]=k;t[d+5|0]=k>>>8;e=e+1|0;if((J|0)!=(e|0)){continue}break}}i=(i+s|0)+1|0;d=v[f+160>>2];if(i>>>0>=d>>>0){while(1){j=j+1|0;i=i-d|0;if(d>>>0<=i>>>0){continue}break}}if(F>>>0>(j&65535)>>>0){continue}break}break o}e=0;if(v[f+160>>2]){break p}break o}break i}while(1){d=_b(n,r);v[22656]=0;h=Tf(d,e);d=v[22656];v[22656]=0;s:{t:{if((d|0)!=1){d=0;if(F){break t}break s}break i}while(1){u:{v[22656]=0;R(791,p|0,f+88|0);i=v[22656];v[22656]=0;if((i|0)==1){break u}v[22656]=0;i=Q(790,h+B(d,6)|0,f+88|0)|0;j=v[22656];v[22656]=0;if((j|0)==1){break u}g=g|i;d=d+1|0;if((F|0)!=(d|0)){continue}break s}break}break i}e=e+1|0;if(e>>>0<y[f+160>>2]){continue}break}}xb(f+240|0);r=r+1|0;if(r>>>0<(w[l|0]|w[l+1|0]<<8)>>>0){continue}break}break f}g=P()|0;O()|0;vb(f+1344|0);break c}g=P()|0;O()|0;xb(f+240|0);break e}g=P()|0;O()|0;break e}g=P()|0;O()|0;break e}d=f+1714|0;e=w[d+1|0]<<8;if(!((w[d|0]|e)>>>0<=1|(e|w[d|0])>>>0>4999)){v:{if(g&1){i=0;d=w[d|0]|w[d+1|0]<<8;d=Ac(((d>>>1|0)+11025e5>>>0)/(d>>>0)|0,0);break v}i=2;z=2646e3/+(B(B(v[a+480216>>2],v[a+480196>>2]),w[d|0]|w[d+1|0]<<8)>>>0)*1e4;w:{if(z<4294967296&z>=0){d=~~z>>>0;break w}d=0}}t[a+480224|0]=i;v[a+480204>>2]=d}d=x[a+480188>>1];v[22656]=0;t[f+240|0]=0;p=W(792,f+1280|0,d|0,f+240|0)|0;d=v[22656];v[22656]=0;if((d|0)!=1){i=a+1298280|0;r=a+1298292|0;k=f+240|3;s=0;x:{y:{z:{A:{B:{while(1){v[22656]=0;d=Q(191,G|0,8)|0;e=v[22656];v[22656]=0;C:{if((e|0)!=1){if(d){break C}if(x[a+480188>>1]){d=0;while(1){e=t[lc(p,d)|0];D:{if((e|0)<=(d|0)|(e|0)>=x[a+480188>>1]){break D}h=((e<<5)+a|0)+480288|0;e=w[h|0];if(!e){break D}g=((d<<5)+a|0)+480288|0;i=w[g|0];if(!i){t[g|0]=e;break D}g=(B(i-1&255,160)+a|0)+906300|0;if((Wk(g)|0)!=255){while(1){g=(B(Wk(g),160)+a|0)+906300|0;if((Wk(g)|0)!=255){continue}break}}e=g+28|0;h=w[h|0]-1&255;h=h>>>0<250?h+128|0:0;t[e|0]=h;t[e+1|0]=h>>>8;t[e+2|0]=h>>>16;t[e+3|0]=h>>>24}d=d+1|0;if(d>>>0<x[a+480188>>1]){continue}break}}v[f+232>>2]=0;v[f+236>>2]=0;v[f+224>>2]=0;v[f+228>>2]=0;v[f+216>>2]=0;v[f+220>>2]=0;v[f+208>>2]=0;v[f+212>>2]=0;E:{F:{G:{H:{I:{J:{if(A){v[22656]=0;R(793,I|0,f+240|0);d=v[22656];v[22656]=0;K:{if((d|0)!=1){g=0;while(1){d=x[a+480192>>1];v[22656]=0;d=GO(a,d+1&65535);e=v[22656];v[22656]=0;L:{M:{N:{O:{P:{Q:{R:{if((e|0)!=1){e=g<<1;h=e+(f+224|0)|0;u[h>>1]=d;j=e+(f+208|0)|0;e=f+e|0;i=e+242|0;u[j>>1]=w[i|0]|w[i+1|0]<<8;if((d|0)==65535){break M}e=w[e+242|0]|w[e+243|0]<<8;v[22656]=0;d=W(376,a|0,d|0,e+1&65535)|0;e=v[22656];v[22656]=0;if((e|0)==1){break R}if(!d){break L}v[22656]=0;R(441,f+160|0,1571);e=v[22656];v[22656]=0;if((e|0)==1){break Q}v[22656]=0;v[f+16>>2]=g+1;U(795,f+88|0,f+160|0,f+16|0);e=v[22656];v[22656]=0;if((e|0)==1){break P}v[22656]=0;Q(301,d+492|0,f+88|0)|0;d=v[22656];v[22656]=0;if((d|0)==1){break O}vb(f+88|0);Hb(f+160|0);break L}g=P()|0;O()|0;break x}g=P()|0;O()|0;break x}g=P()|0;O()|0;break x}g=P()|0;O()|0;break N}g=P()|0;O()|0;vb(f+88|0)}Hb(f+160|0);break x}u[h>>1]=0}g=g+1|0;if((g|0)!=8){continue}break}break K}g=P()|0;O()|0;break x}e=w[f+240|0]|w[f+241|0]<<8;d=0;v[22656]=0;r=Q(328,f+16|0,e|0)|0;e=v[22656];v[22656]=0;if((e|0)==1){break E}if(w[f+240|0]|w[f+241|0]<<8){while(1){v[22656]=0;e=T(287,b|0)|0;h=v[22656];v[22656]=0;if((h|0)==1){break G}v[22656]=0;U(288,f+160|0,b|0,e<<5);e=v[22656];v[22656]=0;if((e|0)==1){break H}e=f+88|0;h=f+160|0;g=kc(e,h);Vc(Lg(r,d),g);xb(e);xb(h);d=d+1|0;if(d>>>0<(w[f+240|0]|w[f+241|0]<<8)>>>0){continue}break}}d=w[l|0]|w[l+1|0]<<8;h=0;v[22656]=0;j=W(796,f+88|0,d|0,33236)|0;d=v[22656];v[22656]=0;if((d|0)==1){break I}if(w[m|0]|w[m+1|0]<<8){while(1){g=f+h|0;S:{if(w[g+258|0]>=(w[f+240|0]|w[f+241|0]<<8)>>>0){break S}if(x[sc(Sb(E),h)>>1]>=(w[l|0]|w[l+1|0]<<8)>>>0){break S}e=x[sc(Sb(E),h)>>1];T:{if(x[sc(j,e)>>1]==65535){d=w[g+258|0];K=sc(j,e),M=d,u[K>>1]=M;break T}if(x[sc(j,e)>>1]==w[g+258|0]){break T}v[22656]=0;d=W(797,n|0,e|0,0)|0;i=v[22656];v[22656]=0;if((i|0)==1){break J}if((d|0)==65535){break T}K=sc(Sb(E),h),M=d,u[K>>1]=M;e=d}v[22656]=0;d=me(n,e);i=v[22656];v[22656]=0;if((i|0)==1){break J}if(!d){break S}A=Lg(r,w[g+258|0]);vc(A);v[22656]=0;d=T(195,A|0)|0;g=v[22656];v[22656]=0;if((g|0)==1){break J}if(!v[_b(n,e)+12>>2]){break S}H=d>>>5|0;i=0;while(1){d=_b(n,e);g=x[a+480188>>1];v[22656]=0;d=Yc(d,i,g-8&65535);g=v[22656];v[22656]=0;if((g|0)==1){break J}g=0;while(1){gi(f+160|0);k=x[f+164>>1];t[d+4|0]=k;t[d+5|0]=k>>>8;k=v[f+160>>2];t[d|0]=k;t[d+1|0]=k>>>8;t[d+2|0]=k>>>16;t[d+3|0]=k>>>24;U:{if(i>>>0>=H>>>0){break U}v[22656]=0;Q(798,A|0,f+160|0)|0;k=v[22656];v[22656]=0;if((k|0)==1){break J}if(t[f+160|0]>=0){break U}t[d|0]=61;t[d+1|0]=w[(f+224|0)+(g<<1)|0];k=w[f+160|0]&31;t[f+64|0]=k;if(k){yf(f- -64|0,15);t[d+3|0]=20;t[d+5|0]=w[f+64|0]|208}t[d+2|0]=1;t[d+4|0]=w[f+161|0]+3>>>2}d=d+6|0;g=g+1|0;if((g|0)!=8){continue}break}i=i+1|0;if(i>>>0<y[_b(n,e)+12>>2]){continue}break}}h=h+1|0;if(h>>>0<(w[m|0]|w[m+1|0]<<8)>>>0){continue}break}}Ze(j);jd(r)}if(!(!(w[o|0]&2)|!(w[l|0]|w[l+1|0]<<8))){i=0;d=w[o|0]|w[o+1|0]<<8|(w[o+2|0]<<16|w[o+3|0]<<24);e=(((d&8?x[a+480188>>1]:F)&65535)+((w[q|0]|w[q+1|0]<<8)>>>0>591?s:0)|0)+(d>>>4&1)|0;while(1){d=0;V:{if(!e){break V}while(1){W:{v[22656]=0;h=Q(191,b|0,4)|0;g=v[22656];v[22656]=0;if((g|0)==1){break W}if(!h){break V}h=w[q|0]|w[q+1|0]<<8;v[22656]=0;R(799,h|0,b|0);h=v[22656];v[22656]=0;if((h|0)==1){break W}d=d+1|0;if((e|0)!=(d|0)){continue}break V}break}g=P()|0;O()|0;break x}i=i+1|0;if(i>>>0<(w[l|0]|w[l+1|0]<<8)>>>0){continue}break}}v[22656]=0;l=Q(328,f+192|0,255)|0;d=v[22656];v[22656]=0;X:{Y:{Z:{_:{$:{aa:{if((d|0)!=1){d=f+88|0;r=d|7;F=d|1;E=d|4;s=d|2;k=d|3;h=0;while(1){d=h;v[22656]=0;R(800,b|0,f+160|0);e=v[22656];v[22656]=0;ba:{ca:{da:{ea:{if((e|0)!=1){v[22656]=0;e=T(192,b|0)|0;h=v[22656];v[22656]=0;if((h|0)==1){break ea}h=w[q|0]|w[q+1|0]<<8;v[22656]=0;e=(e|0)==32?428:e;e=h>>>0>513?e?e+4|0:e:e;U(288,f+88|0,b|0,e|0);h=v[22656];v[22656]=0;if((h|0)==1){break da}h=d+1|0;g=f+240|0;i=f+88|0;j=kc(g,i);j=le(f+16|0,Vc(Lg(l,d),j));xb(g);xb(i);if(d>>>0>=(w[C|0]|w[C+1|0]<<8)>>>0){break ba}v[22656]=0;d=h&65535;g=W(376,a|0,d|0,d|0)|0;d=v[22656];v[22656]=0;if((d|0)!=1){break ca}g=P()|0;O()|0;break Y}g=P()|0;O()|0;break X}g=P()|0;O()|0;break X}g=P()|0;O()|0;break X}if(!g){break ba}v[22656]=0;Ke(f+88|0,2,f+160|0);d=v[22656];v[22656]=0;fa:{ga:{ha:{if((d|0)==1){break ha}v[22656]=0;R(324,f+240|0,f+88|0);d=v[22656];v[22656]=0;if((d|0)==1){break ha}v[22656]=0;Q(301,g+492|0,f+240|0)|0;d=v[22656];v[22656]=0;if((d|0)==1){break ga}vb(f+240|0);if(!e){break ba}v[22656]=0;R(801,j|0,f+240|0);d=v[22656];v[22656]=0;if((d|0)==1){break _}n=0;if((w[q|0]|w[q+1|0]<<8)>>>0<513){break fa}v[22656]=0;n=T(287,j|0)|0;d=v[22656];v[22656]=0;if((d|0)!=1){break fa}g=P()|0;O()|0;break Y}g=P()|0;O()|0;break Y}g=P()|0;O()|0;vb(f+240|0);break Y}i=3;ia:{if((w[q|0]|w[q+1|0]<<8)>>>0<514){break ia}v[22656]=0;i=T(192,j|0)|0;d=v[22656];v[22656]=0;if((d|0)!=1){break ia}g=P()|0;O()|0;break Y}v[g>>2]=w[f+342|0]|w[f+343|0]<<8;t[g+16|0]=w[((w[f+344|0]|w[f+345|0]<<8)&3)+33238|0];t[g+17|0]=w[(w[f+345|0]&3)+33238|0];t[g+18|0]=w[((w[f+344|0]|w[f+345|0]<<8)>>>12&3)+33242|0];o=0;ja:{ka:{la:{ma:{while(1){na:{if(!(i&1)){break na}v[22656]=0;R(802,j|0,f+88|0);d=v[22656];v[22656]=0;if((d|0)==1){break ma}v[22656]=0;e=ji(g,w[o+33246|0]);d=v[22656];v[22656]=0;if((d|0)==1){break la}d=e;if((o|0)!=3){m=w[e+12|0]&-17}else{m=w[e+12|0]&-17|w[f+88|0]<<4&16}t[d+12|0]=m;t[e+12|0]=w[e+12|0]&254|t[f+88|0]&1;t[e+12|0]=w[e+12|0]&251|w[f+88|0]<<1&4;t[e+12|0]=w[e+12|0]&253|w[f+88|0]>>>1&2;t[f+64|0]=w[F|0];v[22656]=0;t[f+48|0]=16;d=ac(f- -64|0,f+48|0);m=v[22656];v[22656]=0;if((m|0)==1){break ka}d=w[d|0];v[22656]=0;R(446,e|0,d|0);d=v[22656];v[22656]=0;if((d|0)==1){break ka}d=w[s|0];t[e+15|0]=d;t[e+16|0]=d;t[e+13|0]=w[k|0];t[e+14|0]=w[E|0];d=0;if(!Nb(e)){break na}while(1){m=(f+88|0)+(d<<2)|0;A=w[m+8|0]|w[m+9|0]<<8;K=Mb(e,d),M=A,u[K>>1]=M;m=Md(w[m+10|0]|w[m+11|0]<<8,0,64);K=Mb(e,d),M=m,t[K+2|0]=M;d=d+1|0;if(Nb(e)>>>0>d>>>0){continue}break}}i=i>>>1|0;o=o+1|0;if((o|0)!=4){continue}break}if(!(t[g+60|0]&1|w[g+16|0]==3)){v[g>>2]=32767}v[22656]=0;hm(g,127,1);d=v[22656];v[22656]=0;if((d|0)==1){break aa}v[22656]=0;gm(g,0,1);d=v[22656];v[22656]=0;if((d|0)==1){break aa}if(!n){break ba}v[22656]=0;R(805,j|0,f+88|0);d=v[22656];v[22656]=0;if((d|0)==1){break Z}if(!(n&2)){break ja}d=w[s|0]|w[s+1|0]<<8;v[22656]=0;d=FA(a,+(d>>>0));e=v[22656];v[22656]=0;if((e|0)==1){break Z}v[22656]=0;hm(g,d,1);d=v[22656];v[22656]=0;if((d|0)==1){break Z}d=w[E|0];v[22656]=0;gm(g,d,1);d=v[22656];v[22656]=0;if((d|0)!=1){break ja}break Z}g=P()|0;O()|0;break Y}g=P()|0;O()|0;break Y}g=P()|0;O()|0;break Y}t[g+25|0]=w[F|0]==1;if(!(n&4)){break ba}t[g+31|0]=w[r|0]+1;t[g+34|0]=w[f+96|0]+1;if(t[f+96|0]<0){t[g+30|0]=w[f+103|0]+1}if(w[f+100|0]){d=0;i=g+108|0;while(1){e=d+1|0;v[f+64>>2]=e+t[f+100|0];fV(f- -64|0);j=v[f+64>>2];K=ic(i,d),M=j,t[K|0]=M;d=e;if(d>>>0<128){continue}break}}v[22656]=0;pr(g,0);d=v[22656];v[22656]=0;if((d|0)==1){break Z}}xb(f+16|0);if((h|0)!=255){continue}break}q=bC(f+88|0);h=f+16|4;n=bC(f+160|0);g=0;oa:{pa:{while(1){v[22656]=0;R(800,b|0,f+240|0);d=v[22656];v[22656]=0;if((d|0)==1){break oa}v[22656]=0;d=T(192,b|0)|0;e=v[22656];v[22656]=0;qa:{ra:{sa:{ta:{ua:{va:{wa:{xa:{if((e|0)!=1){v[22656]=0;U(288,f+16|0,b|0,d|0);e=v[22656];v[22656]=0;if((e|0)==1){break xa}e=f+16|0;i=kc(f- -64|0,e);xb(e);if((w[D|0]|w[D+1|0]<<8)>>>0>g>>>0){v[22656]=0;Ke(f+48|0,2,f+240|0);e=v[22656];v[22656]=0;if((e|0)==1){break qa}v[22656]=0;R(324,f+16|0,f+48|0);e=v[22656];v[22656]=0;if((e|0)==1){break qa}v[22656]=0;Q(301,((g<<5)+a|0)+946336|0,f+16|0)|0;e=v[22656];v[22656]=0;if((e|0)==1){break wa}vb(f+16|0)}if(!d|(w[D|0]|w[D+1|0]<<8)>>>0<=g>>>0){break ra}v[22656]=0;d=B(g+1|0,104)+a|0;e=d+484380|0;R(424,e|0,32);j=v[22656];v[22656]=0;if((j|0)==1){break va}v[22656]=0;R(807,i|0,f+16|0);i=v[22656];v[22656]=0;if((i|0)==1){break ua}v[e>>2]=w[f+16|0]|w[f+17|0]<<8|(w[f+18|0]<<16|w[f+19|0]<<24);v[d+484404>>2]=w[h|0]|w[h+1|0]<<8|(w[h+2|0]<<16|w[h+3|0]<<24);if(w[f+24|0]>=2){i=d+484414|0;u[i>>1]=x[i>>1]|1;v[e>>2]=v[e>>2]>>>1}if(w[f+25|0]>=2){i=d+484414|0;u[i>>1]=x[i>>1]|64;v[e>>2]=v[e>>2]>>>1}i=2;ya:{if(w[f+27|0]!=1){i=6;if(w[f+27|0]!=2){break ya}}e=d+484414|0;u[e>>1]=x[e>>1]|i}v[d+484384>>2]=w[f+28|0]|w[f+29|0]<<8|(w[f+30|0]<<16|w[f+31|0]<<24);v[d+484388>>2]=w[f+32|0]|w[f+33|0]<<8|(w[f+34|0]<<16|w[f+35|0]<<24);u[d+484410>>1]=(w[f+36|0]|w[f+37|0]<<8)>>>7;if(w[f+38|0]!=128){break ta}e=d+484414|0;j=x[e>>1]|256;u[e>>1]=j;break sa}g=P()|0;O()|0;break X}g=P()|0;O()|0;break X}g=P()|0;O()|0;vb(f+16|0);break pa}g=P()|0;O()|0;break pa}g=P()|0;O()|0;break pa}u[d+484408>>1]=t[f+38|0]+128;j=x[d+484414>>1]}e=d+484414|0;u[e>>1]=j|32;t[d+484416|0]=w[f+39|0];if(w[f+26|0]&2){d=f+48|0;Db(d,n,g);er(d)}if(w[f+26|0]&5){u[e>>1]=x[e>>1]|16384}if(!(w[f+26|0]&8)){break ra}d=f+48|0;Db(d,q,g);er(d);d=0;while(1){e=d<<1;za:{if(x[e+(f+208|0)>>1]!=(g|0)){break za}e=v[((x[e+(f+224|0)>>1]<<2)+a|0)+900380>>2];if(!e){break za}t[e+14|0]=0}d=d+1|0;if((d|0)!=8){continue}break}}xb(f- -64|0);g=g+1|0;if((g|0)==256){break $}continue}break}g=P()|0;O()|0}xb(f- -64|0);break X}g=P()|0;O()|0;break X}g=P()|0;O()|0;break x}g=P()|0;O()|0;break Y}Aa:{if(!(w[C|0]|w[C+1|0]<<8)){break Aa}i=0;Ba:{Ca:{while(1){Da:{d=Lg(l,i);v[22656]=0;d=T(195,d|0)|0;e=v[22656];v[22656]=0;if((e|0)==1){break Da}Ea:{if(!d){i=i+1|0;break Ea}d=Lg(l,i);vc(d);v[22656]=0;R(801,d|0,f+240|0);d=v[22656];v[22656]=0;if((d|0)==1){break Ca}j=dd(f+16|0);d=w[f+240|0]|w[f+241|0]<<8;v[22656]=0;U(808,b|0,j|0,d|0);d=v[22656];v[22656]=0;if((d|0)==1){break Ba}i=i+1|0;e=v[((i<<2)+a|0)+900380>>2];if(!(!e|w[e+34|0])){v[e+4>>2]=32;v[22656]=0;pr(e,0);d=v[22656];v[22656]=0;if((d|0)==1){break Ba}s=e+108|0;D=e+236|0;d=0;while(1){h=d+f|0;Fa:{if(w[h+242|0]>=(w[f+240|0]|w[f+241|0]<<8)>>>0){break Fa}o=ye(j,w[h+242|0]);h=w[o|0];g=h+1|0;m=d+12|0;K=vd(D,m),M=g,u[K>>1]=M;if(h>>>0>=x[a+480190>>1]){break Fa}h=B(g,104)+a|0;t[h+484418|0]=w[f+338|0]&3;t[h+484419|0]=w[f+339|0];t[h+484420|0]=w[f+340|0];t[h+484421|0]=w[f+341|0];u[h+484412>>1]=w[o+1|0]<<1;t[h+484417|0]=w[o+2|0];h=f- -64|0;g=g-1|0;Db(h,q,g);if(Cb(h)){t[e+14|0]=0}h=f- -64|0;Db(h,n,g);if(!Cb(h)){break Fa}K=ic(s,m),M=61,t[K|0]=M}d=d+1|0;if((d|0)!=96){continue}break}}ns(j)}if((w[C|0]|w[C+1|0]<<8)>>>0>i>>>0){continue}break Aa}break}g=P()|0;O()|0;break X}g=P()|0;O()|0;break X}g=P()|0;O()|0;ns(j);break X}Ga:{Ha:{Ia:{Ja:{Ka:{La:{Ma:{Na:{Oa:{Pa:{if(!(!(c&2)|!x[a+480190>>1])){g=0;while(1){g=g+1|0;d=B(g,104)+a|0;c=d+484416|0;e=t[c|0];h=d+484417|0;i=t[h|0];v[22656]=0;j=d+484380|0;Qo(j,(+(e-49|0)+ +(i|0)*-.0078125)/-12);e=v[22656];v[22656]=0;if((e|0)==1){break Ga}t[h|0]=0;t[c|0]=0;c=x[d+484414>>1];Qa:{if(!(c&16384)){c=Rc(f+240|0,c&1?16:8,c&64?3:1,0,11);v[22656]=0;W(329,c|0,j|0,b|0)|0;c=v[22656];v[22656]=0;if((c|0)!=1){break Qa}g=P()|0;O()|0;break X}v[22656]=0;e=T(192,b|0)|0;c=v[22656];v[22656]=0;if((c|0)==1){break Pa}v[22656]=0;Q(318,b|0,12)|0;c=v[22656];v[22656]=0;if((c|0)==1){break Pa}c=Kb(f+240|0);v[22656]=0;W(413,b|0,c|0,e|0)|0;e=v[22656];v[22656]=0;if((e|0)==1){break Oa}v[22656]=0;Q(303,d+484423|0,c|0)|0;d=v[22656];v[22656]=0;if((d|0)==1){break Oa}v[22656]=0;R(581,f- -64|0,13514);d=v[22656];v[22656]=0;if((d|0)==1){break Na}v[f+12>>2]=g;d=Kk(a);v[22656]=0;U(13,f+48|0,d|0,c|0);d=v[22656];v[22656]=0;if((d|0)==1){break Ma}v[22656]=0;Y(582,f+16|0,f- -64|0,f+12|0,f+48|0);d=v[22656];v[22656]=0;if((d|0)==1){break La}v[22656]=0;U(560,a|0,2,f+16|0);d=v[22656];v[22656]=0;if((d|0)==1){break Ka}vb(f+16|0);vb(f+48|0);Hb(f- -64|0);vb(c)}if(x[a+480190>>1]>g>>>0){continue}break}}jd(l);gc(p);xb(G);xb(I);break b}g=P()|0;O()|0;break X}g=P()|0;O()|0;break Ha}g=P()|0;O()|0;break Ha}g=P()|0;O()|0;break Ia}g=P()|0;O()|0;break Ja}g=P()|0;O()|0;vb(f+16|0)}vb(f+48|0)}Hb(f- -64|0)}vb(c);break X}g=P()|0;O()|0;break X}g=P()|0;O()|0;break Y}g=P()|0;O()|0}xb(f+16|0)}jd(l);break x}g=P()|0;O()|0;Ze(j);break F}g=P()|0;O()|0;break F}g=P()|0;O()|0;break F}g=P()|0;O()|0}jd(r);break x}g=P()|0;O()|0;break x}g=P()|0;O()|0;break x}v[22656]=0;e=T(192,G|0)|0;h=v[22656];v[22656]=0;d=a;Ra:{Sa:{Ta:{Ua:{Va:{Wa:{Xa:{Ya:{Za:{_a:{$a:{ab:{bb:{cb:{db:{if((h|0)!=1){v[22656]=0;h=T(192,G|0)|0;j=v[22656];v[22656]=0;if((j|0)==1){break db}v[22656]=0;U(288,f+240|0,G|0,h|0);h=v[22656];v[22656]=0;if((h|0)==1){break db}j=f+240|0;h=kc(f+88|0,j);xb(j);if((e|0)<=844387157){if((e|0)==4674381){break Va}if((e|0)==5068115){break Ua}if(g&1|(e|0)!=726487106){break Sa}t[a+480224|0]=2;v[22656]=0;z=+pa(810,h|0);e=v[22656];v[22656]=0;if((e|0)==1){break Ra}if(!(z>1e-8)){break Sa}z=2646e3/(z*+(B(v[a+480216>>2],v[a+480196>>2])>>>0))*1e4;if(!(z<4294967296&z>=0)){break cb}e=~~z>>>0;break bb}if((e|0)<=1314144591){if((e|0)==844387158){break Ta}if((e|0)!=1280004692){break Sa}j=0;if(!x[a+480188>>1]){break Sa}while(1){v[22656]=0;d=Q(191,f+88|0,1)|0;e=v[22656];v[22656]=0;if((e|0)==1){break A}if(!d){break Sa}d=Kb(f+240|0);v[22656]=0;W(534,h|0,d|0,-1)|0;e=v[22656];v[22656]=0;if((e|0)==1){break $a}e=Jb(d);H=Ab(d);v[22656]=0;Xe(f+16|0,3,e,H);e=v[22656];v[22656]=0;if((e|0)==1){break _a}v[22656]=0;R(324,f+160|0,f+16|0);e=v[22656];v[22656]=0;if((e|0)==1){break _a}v[22656]=0;Q(399,((j<<5)+a|0)+480289|0,f+160|0)|0;e=v[22656];v[22656]=0;if((e|0)==1){break Za}vb(f+160|0);vb(d);j=j+1|0;if(j>>>0<x[a+480188>>1]){continue}break}break Sa}if((e|0)==1397445204){break ab}if((e|0)!=1314144592){break Sa}d=0;if(!(w[l|0]|w[l+1|0]<<8)){break Sa}while(1){v[22656]=0;e=Q(191,f+88|0,1)|0;j=v[22656];v[22656]=0;if((j|0)==1){break Xa}if(!e){break Sa}v[22656]=0;e=dm(n,d&65535);j=v[22656];v[22656]=0;if((j|0)==1){break Xa}if(!e){break Sa}e=Kb(f+240|0);v[22656]=0;W(534,h|0,e|0,-1)|0;j=v[22656];v[22656]=0;if((j|0)==1){break Wa}j=_b(n,d);v[22656]=0;Q(428,j|0,e|0)|0;j=v[22656];v[22656]=0;if((j|0)==1){break Wa}vb(e);d=d+1|0;if(d>>>0<(w[l|0]|w[l+1|0]<<8)>>>0){continue}break}break Sa}g=P()|0;O()|0;break x}g=P()|0;O()|0;break x}e=0}v[d+480204>>2]=e;break Sa}v[22656]=0;d=T(287,h|0)|0;e=v[22656];v[22656]=0;if((e|0)==1){break z}d=d>>>0<256?48:d>>>8|0;v[a+480228>>2]=d;v[a+480232>>2]=d>>>1;d=0;if(!x[a+480188>>1]){break Sa}while(1){v[22656]=0;e=Q(812,h|0,f+240|0)|0;j=v[22656];v[22656]=0;if((j|0)==1){break B}if(e){u[((d<<5)+a|0)+480286>>1]=(w[f+240|0]|w[f+241|0]<<8)>>>10;e=w[k|0];K=lc(p,d),M=e,t[K|0]=M}d=d+1|0;if(d>>>0<x[a+480188>>1]){continue}break}break Sa}g=P()|0;O()|0;break Ya}g=P()|0;O()|0;break Ya}g=P()|0;O()|0;vb(f+160|0)}vb(d);break y}g=P()|0;O()|0;break y}g=P()|0;O()|0;vb(e);break y}v[22656]=0;Q(318,f+88|0,1)|0;d=v[22656];v[22656]=0;if((d|0)==1){break z}v[22656]=0;d=T(467,f+88|0)|0;e=v[22656];v[22656]=0;if((e|0)==1){break z}v[22656]=0;da(510,r|0,h|0,d|0,2)|0;d=v[22656];v[22656]=0;if((d|0)!=1){break Sa}break z}v[22656]=0;Q(813,h|0,f+16|0)|0;d=v[22656];v[22656]=0;eb:{if((d|0)!=1){d=Kb(f+240|0);v[22656]=0;W(534,h|0,d|0,-1)|0;e=v[22656];v[22656]=0;if((e|0)==1){break eb}if(xr(d,9889)){v[22656]=0;U(13,f+160|0,8,d|0);e=v[22656];v[22656]=0;if((e|0)==1){break eb}e=f+160|0;Eb(i,e);vb(e)}vb(d);break Sa}g=P()|0;O()|0;break y}g=P()|0;O()|0;vb(d);break y}v[22656]=0;s=T(192,h|0)|0;d=v[22656];v[22656]=0;if((d|0)==1){break z}}xb(f+88|0);continue}break}g=P()|0;O()|0;break y}g=P()|0;O()|0;break y}g=P()|0;O()|0;break y}g=P()|0;O()|0}xb(f+88|0)}gc(p);break e}g=P()|0;O()|0}xb(G)}xb(I)}S(g|0);L()}d=1}gb=f+1728|0;return d|0}function Dg(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=C(0),r=0,s=0,D=0,E=0,F=0;e=gb-2736|0;gb=e;a:{b:{c:{d:{e:{f:{if(es(c)){qc(b,268435456);D=v[c+8>>2];p=e+2712|0;d=p;v[d>>2]=0;v[d+4>>2]=0;mc(d+8|0);v[e+2708>>2]=0;g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{f=e;q:{r:{s:{t:{if(w[a+3|0]-4>>>0<=4){v[22656]=0;d=T(467,c|0)|0;i=v[22656];v[22656]=0;if((i|0)==1){break n}v[e+2708>>2]=d;break t}d=w[a+3|0];if(d>>>0>17){break t}d=1<<d;u:{if(!(d&63503)){if(d&198144){break u}break t}if(!w[a|0]){break t}}d=v[b>>2];v[22656]=0;d=Bv(a,d);i=v[22656];v[22656]=0;if((i|0)==1){break s}v[22656]=0;U(755,e+544|0,c|0,d|0);d=v[22656];v[22656]=0;if((d|0)==1){break s}d=e+544|0;i=v[d+4>>2];v[p>>2]=v[d>>2];v[p+4>>2]=i;op(p+8|0,d+8|0);zc(d);d=0;v[22656]=0;g=Sd(p);i=v[22656];v[22656]=0;if((i|0)==1){break n}v[e+2708>>2]=v[p>>2];if(!g){break g}}d=w[a+3|0];if(d>>>0>17){break p}i=1<<d;v:{if(!(i&63503)){h=0;if(i&198144){break v}break p}h=!w[a|0]}if(h|y[b>>2]<262145){break p}d=v[e+2708>>2];i=w[a+3|0];v[22656]=0;v[e+520>>2]=((i|0)==10)<<4;i=Fb(e+520|0,e+2708|0);h=v[22656];v[22656]=0;if((h|0)!=1){v[e+544>>2]=d-v[i>>2];d=w[a+3|0];if(d>>>0>15){break r}w:{if(!(1<<d&63503)){if((d|0)==10){break w}break r}if(!(w[a|0]&7)){break r}}d=v[e+544>>2];if(d>>>0<=2147483647){d=d<<1;break q}d=-1;break q}a=P()|0;O()|0;break a}a=P()|0;O()|0;break a}d=0;v[22656]=0;i=hp(a);h=v[22656];v[22656]=0;x:{y:{if((h|0)!=1){z:{A:{switch(w[a+3|0]){case 0:case 1:case 2:case 3:case 11:case 12:case 13:case 14:case 15:d=w[a|0];break z;case 9:d=16;break z;case 10:d=4;break z;case 16:case 17:break A;default:break z}}d=8}i=B(d,i)>>>3|0;d=i-1|0;h=v[e+544>>2];if(d>>>0>-1-h>>>0){break y}h=d+h|0;break x}a=P()|0;O()|0;break a}h=-1}d=(h>>>0)/(i>>>0)|0}v[f+544>>2]=d;qc(b,d);break o}f=e;B:{C:{D:{E:{if(!(w[a+3|0]==4|w[a+3|0]==5|(w[a+3|0]==8|w[a+3|0]==7))){if(w[a+3|0]!=6){break o}d=0;if(y[e+2708>>2]<10){break g}v[22656]=0;Q(318,c|0,4)|0;d=v[22656];v[22656]=0;if((d|0)==1){break n}v[22656]=0;d=T(192,c|0)|0;i=v[22656];v[22656]=0;if((i|0)==1){break E}v[e+520>>2]=d;d=v[e+2708>>2];v[22656]=0;v[e+2704>>2]=d;d=Fb(e+520|0,e+2704|0);i=v[22656];v[22656]=0;if((i|0)==1){break D}v[e+544>>2]=v[d>>2];pg(c,8);d=v[e+544>>2];if(d>>>0>50529027){break C}d=B(d,85);break B}v[e+544>>2]=v[e+2708>>2];v[22656]=0;f=hp(a);i=v[22656];v[22656]=0;h=e;F:{G:{if((i|0)!=1){i=v[e+544>>2];f=8/(f>>>0)|0;if(i>>>0>4294967295/(f>>>0)>>>0){break G}f=B(f,i);break F}a=P()|0;O()|0;break a}f=-1}v[h+544>>2]=f;qc(b,f);break o}a=P()|0;O()|0;break a}a=P()|0;O()|0;break a}d=-1}v[f+544>>2]=d;qc(b,(d>>>0)/(w[a|0]>>>3>>>0)|0)}if(!v[b>>2]){d=0;break g}u[b+34>>1]=x[b+34>>1]&65534|w[a|0]>15;u[b+34>>1]=x[b+34>>1]&65471|(w[a+1|0]!=1)<<6;v[22656]=0;d=T(386,b|0)|0;f=v[22656];v[22656]=0;if((f|0)==1){break f}if(!d){d=0;v[b>>2]=0;break g}if(je(a,Rc(e+544|0,8,1,0,10))){v[22656]=0;a=Q(1185,c|0,e+544|0)|0;d=v[22656];v[22656]=0;if((d|0)!=1){d=0;if(!a){break h}a=v[b>>2];v[22656]=0;v[e+520>>2]=a+1>>>1;a=T(467,c|0)|0;d=v[22656];v[22656]=0;H:{if((d|0)!=1){qc(e+520|0,a);a=zb(g);d=v[e+520>>2];if(d){break H}d=16;break h}a=P()|0;O()|0;break a}a=a+16|0;b=v[b+20>>2];g=0;while(1){f=e+544|0;i=w[f|w[a|0]&15]+g|0;t[b|0]=i;g=w[f|w[a|0]>>>4]+(i&255)|0;t[b+1|0]=g;a=a+1|0;b=b+2|0;d=d-1|0;if(d){continue}break}d=v[e+520>>2]+16|0;break h}a=P()|0;O()|0;break a}if(!(w[a+3|0]!=4&w[a+3|0]!=5)){a=w[a+3|0];v[22656]=0;a=da(1186,e+1616|0,c|0,b|0,(a|0)==5|0)|0;b=v[22656];v[22656]=0;if((b|0)==1){break f}xb(a);d=v[c+8>>2]-D|0;break h}if(!(w[a+3|0]!=6|w[a+1|0]!=1)){v[22656]=0;Q(318,c|0,4)|0;a=v[22656];v[22656]=0;if((a|0)==1){break f}v[22656]=0;a=T(192,c|0)|0;d=v[22656];v[22656]=0;I:{J:{K:{if((d|0)!=1){v[22656]=0;v[e+520>>2]=a;d=T(374,c|0)|0;f=v[22656];v[22656]=0;if((f|0)==1){break K}v[22656]=0;U(1187,e+544|0,c|0,a|0);a=v[22656];v[22656]=0;if((a|0)==1){break I}a=e+544|0;qc(e+520|0,v[a>>2]);v[22656]=0;f=v[e+520>>2];a=Sd(a);i=v[22656];v[22656]=0;if((i|0)!=1){i=v[e+544>>2];h=v[b+20>>2];b=aj(b);v[22656]=0;ha(1188,a|0,i|0,h|0,b|0,d<<24>>24);a=v[22656];v[22656]=0;if((a|0)!=1){break J}}a=P()|0;O()|0;zc(e+544|0);break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;break a}d=f+9|0;zc(e+544|0);break h}a=P()|0;O()|0;break a}if(!(w[a+3|0]!=9|w[a+1|0]!=1|w[a|0]!=16)){a=v[e+2708>>2];d=x[Rm(e+1608|0)>>1];v[22656]=0;d=KQ(b,g,a,d);a=v[22656];v[22656]=0;if((a|0)==1){break f}break h}if(w[a+3|0]!=8|w[a+1|0]!=1|w[a|0]>16){break m}d=0;v[22656]=0;f=Q(191,c|0,8)|0;i=v[22656];v[22656]=0;if((i|0)==1){break f}if(!f){break h}v[22656]=0;f=T(192,c|0)|0;i=v[22656];v[22656]=0;if((i|0)==1){break f}v[e+2708>>2]=f;if(f>>>0<4){break h}v[22656]=0;U(288,e+520|0,c|0,f|0);f=v[22656];v[22656]=0;if((f|0)==1){break b}v[22656]=0;f=Lp(e+544|0,e+520|0);i=v[22656];v[22656]=0;if((i|0)==1){break c}xb(e+520|0);v[22656]=0;i=T(1190,f|0)|0;h=v[22656];v[22656]=0;if((h|0)==1){break e}if(!v[b>>2]){break j}h=w[a|0];n=(h|0)!=16;while(1){L:{if(n){break L}v[22656]=0;o=Q(200,f|0,8)|0;a=v[22656];v[22656]=0;if((a|0)!=1){break L}a=V(27364)|0;break k}v[22656]=0;l=Q(200,f|0,1)|0;a=v[22656];v[22656]=0;if((a|0)==1){break l}v[22656]=0;a=Q(200,f|0,1)|0;g=v[22656];v[22656]=0;if((g|0)==1){break l}M:{N:{O:{if(!a){g=8;while(1){v[22656]=0;a=Q(200,f|0,1)|0;k=v[22656];v[22656]=0;if((k|0)==1){break M}if(a){break O}g=g+16|0;continue}}v[22656]=0;a=Q(200,f|0,3)|0;g=v[22656];v[22656]=0;if((g|0)!=1){break N}break l}v[22656]=0;a=Q(200,f|0,4)|0;k=v[22656];v[22656]=0;if((k|0)==1){break l}a=a+g|0}j=(j&255)+(((l?-1:0)^a)&255)|0;P:{if((h|0)!=16){t[v[b+20>>2]+d|0]=j;break P}u[v[b+20>>2]+(d<<1)>>1]=o&255|j<<8}d=d+1|0;if(d>>>0<y[b>>2]){continue}break j}break}a=V(27364)|0;break k}a=P()|0;O()|0;break a}if(!(w[a+3|0]!=7|w[a+1|0]!=1|w[a|0]>16)){d=0;if(y[e+2708>>2]<5){break h}a=zb(zb(v[b+20>>2]));b=aj(b);v[22656]=0;d=W(1191,c|0,a|0,b|0)|0;a=v[22656];v[22656]=0;if((a|0)==1){break f}break h}if(!(w[a+1|0]!=1&w[a+1|0]!=2|(w[a+3|0]!=16&w[a+3|0]!=17|w[a|0]!=16))){d=v[b>>2];v[22656]=0;f=hp(a);i=v[22656];v[22656]=0;if((i|0)!=1){v[e+544>>2]=B(d,f);qc(e+544|0,v[e+2708>>2]);b=v[b+20>>2];d=v[e+544>>2];f=w[a+3|0];a=v[e+544>>2];v[e+544>>2]=a-1;if((f|0)!=16){if(!a){break h}while(1){E=b,F=x[vd(37268,zb(w[g|0]))>>1],u[E>>1]=F;a=v[e+544>>2];v[e+544>>2]=a-1;b=b+2|0;g=g+1|0;if(a){continue}break}break h}if(!a){break h}while(1){E=b,F=x[vd(36756,zb(w[g|0]))>>1],u[E>>1]=F;a=v[e+544>>2];v[e+544>>2]=a-1;b=b+2|0;g=g+1|0;if(a){continue}break}break h}a=P()|0;O()|0;break a}if(!(w[a|0]!=8|w[a+1|0]!=1)){Q:{R:{S:{T:{a=w[a+3|0];switch(a|0){case 2:break Q;case 1:break S;case 0:break T;default:break R}}v[22656]=0;d=JQ(b,g,v[e+2708>>2]);a=v[22656];v[22656]=0;if((a|0)==1){break f}break h}v[22656]=0;d=IQ(b,g,v[e+2708>>2]);a=v[22656];v[22656]=0;if((a|0)==1){break f}break h}d=0;if((a|0)!=11){break h}}a=v[e+2708>>2];d=w[KA(e+512|0)|0];v[22656]=0;d=HQ(b,g,a,d);a=v[22656];v[22656]=0;if((a|0)==1){break f}break h}if(!(w[a|0]!=8|w[a+1|0]!=3)){U:{V:{W:{X:{f=w[a+3|0];switch(f|0){case 2:break U;case 1:break W;case 0:break X;default:break V}}v[22656]=0;d=GQ(b,g,v[e+2708>>2]);a=v[22656];v[22656]=0;if((a|0)==1){break f}break h}v[22656]=0;d=FQ(b,g,v[e+2708>>2]);a=v[22656];v[22656]=0;if((a|0)==1){break f}break h}d=0;if((f|0)!=11){break h}}d=v[e+2708>>2];f=w[KA(e+504|0)|0];v[22656]=0;d=EQ(b,g,d,f);f=v[22656];v[22656]=0;if((f|0)==1){break f}if(w[a+3|0]!=11){break h}f=v[b>>2]<<1;if((f|0)<=0){break h}a=v[b+20>>2];b=f+a|0;while(1){t[a+1|0]=w[a+1|0]+w[a|0];a=a+2|0;if(b>>>0>a>>>0){continue}break}break h}if(!(w[a|0]!=8|w[a+1|0]!=2)){d=0;Y:{switch(w[a+3|0]){case 0:v[22656]=0;d=DQ(b,g,v[e+2708>>2]);a=v[22656];v[22656]=0;if((a|0)==1){break f}break h;case 1:v[22656]=0;d=CQ(b,g,v[e+2708>>2]);a=v[22656];v[22656]=0;if((a|0)==1){break f}break h;case 2:break Y;default:break h}}a=v[e+2708>>2];d=w[KA(e+496|0)|0];v[22656]=0;d=BQ(b,g,a,d);a=v[22656];v[22656]=0;if((a|0)==1){break f}break h}if(!(w[a+2|0]|(w[a|0]!=16|w[a+1|0]!=1))){Z:{_:{$:{aa:{a=w[a+3|0];switch(a|0){case 2:break Z;case 1:break $;case 0:break aa;default:break _}}v[22656]=0;d=AQ(b,g,v[e+2708>>2]);a=v[22656];v[22656]=0;if((a|0)==1){break f}break h}v[22656]=0;d=zQ(b,g,v[e+2708>>2]);a=v[22656];v[22656]=0;if((a|0)==1){break f}break h}d=0;if((a|0)!=11){break h}}a=v[e+2708>>2];d=x[Rm(e+488|0)>>1];v[22656]=0;d=yQ(b,g,a,d);a=v[22656];v[22656]=0;if((a|0)==1){break f}break h}if(!(w[a|0]!=16|w[a+1|0]!=1|w[a+2|0]!=1)){d=0;ba:{switch(w[a+3|0]){case 0:v[22656]=0;d=xQ(b,g,v[e+2708>>2]);a=v[22656];v[22656]=0;if((a|0)==1){break f}break h;case 1:v[22656]=0;d=wQ(b,g,v[e+2708>>2]);a=v[22656];v[22656]=0;if((a|0)==1){break f}break h;case 2:break ba;default:break h}}a=v[e+2708>>2];d=x[Rm(e+480|0)>>1];v[22656]=0;d=vQ(b,g,a,d);a=v[22656];v[22656]=0;if((a|0)==1){break f}break h}if(!(w[a+2|0]|(w[a|0]!=16|w[a+1|0]!=3))){ca:{da:{ea:{fa:{f=w[a+3|0];switch(f|0){case 2:break ca;case 1:break ea;case 0:break fa;default:break da}}v[22656]=0;d=uQ(b,g,v[e+2708>>2]);a=v[22656];v[22656]=0;if((a|0)==1){break f}break h}v[22656]=0;d=tQ(b,g,v[e+2708>>2]);a=v[22656];v[22656]=0;if((a|0)==1){break f}break h}d=0;if((f|0)!=11){break h}}d=v[e+2708>>2];f=x[Rm(e+472|0)>>1];v[22656]=0;d=sQ(b,g,d,f);f=v[22656];v[22656]=0;if((f|0)==1){break f}if(w[a+3|0]!=11){break h}f=v[b>>2];if(f<<1<=0){break h}a=v[b+20>>2];b=a+(f<<2)|0;while(1){u[a+2>>1]=x[a+2>>1]+x[a>>1];a=a+4|0;if(b>>>0>a>>>0){continue}break}break h}if(!(w[a|0]!=16|w[a+1|0]!=3|w[a+2|0]!=1)){d=0;ga:{switch(w[a+3|0]){case 0:v[22656]=0;d=qQ(b,g,v[e+2708>>2]);a=v[22656];v[22656]=0;if((a|0)==1){break f}break h;case 1:v[22656]=0;d=pQ(b,g,v[e+2708>>2]);a=v[22656];v[22656]=0;if((a|0)==1){break f}break h;case 2:break ga;default:break h}}a=v[e+2708>>2];d=x[Rm(e+464|0)>>1];v[22656]=0;d=oQ(b,g,a,d);a=v[22656];v[22656]=0;if((a|0)==1){break f}break h}if(!(w[a+2|0]|(w[a|0]!=16|w[a+1|0]!=2))){d=0;ha:{switch(w[a+3|0]){case 0:v[22656]=0;d=nQ(b,g,v[e+2708>>2]);a=v[22656];v[22656]=0;if((a|0)==1){break f}break h;case 1:v[22656]=0;d=mQ(b,g,v[e+2708>>2]);a=v[22656];v[22656]=0;if((a|0)==1){break f}break h;case 2:break ha;default:break h}}a=v[e+2708>>2];d=x[Rm(e+456|0)>>1];v[22656]=0;d=lQ(b,g,a,d);a=v[22656];v[22656]=0;if((a|0)==1){break f}break h}if(!(w[a|0]!=16|w[a+1|0]!=2|w[a+2|0]!=1)){d=0;ia:{switch(w[a+3|0]){case 0:v[22656]=0;d=kQ(b,g,v[e+2708>>2]);a=v[22656];v[22656]=0;if((a|0)==1){break f}break h;case 1:v[22656]=0;d=jQ(b,g,v[e+2708>>2]);a=v[22656];v[22656]=0;if((a|0)==1){break f}break h;case 2:break ia;default:break h}}a=v[e+2708>>2];d=x[Rm(e+448|0)>>1];v[22656]=0;d=iQ(b,g,a,d);a=v[22656];v[22656]=0;if((a|0)==1){break f}break h}if(!(w[a+3|0]|(w[a|0]!=24|w[a+1|0]!=1))){d=v[e+2708>>2];if(!w[a+2|0]){v[22656]=0;d=hQ(b,g,d);a=v[22656];v[22656]=0;if((a|0)==1){break f}break h}v[22656]=0;d=gQ(b,g,d);a=v[22656];v[22656]=0;if((a|0)==1){break f}break h}if(!(w[a+3|0]|(w[a|0]!=24|w[a+1|0]!=2))){d=v[e+2708>>2];if(!w[a+2|0]){v[22656]=0;d=fQ(b,g,d);a=v[22656];v[22656]=0;if((a|0)==1){break f}break h}v[22656]=0;d=eQ(b,g,d);a=v[22656];v[22656]=0;if((a|0)==1){break f}break h}if(!(w[a+3|0]|(w[a|0]!=32|w[a+1|0]!=1))){d=v[e+2708>>2];if(!w[a+2|0]){v[22656]=0;d=dQ(b,g,d);a=v[22656];v[22656]=0;if((a|0)==1){break f}break h}v[22656]=0;d=cQ(b,g,d);a=v[22656];v[22656]=0;if((a|0)==1){break f}break h}if(!(w[a+3|0]|(w[a|0]!=32|w[a+1|0]!=2))){d=v[e+2708>>2];if(!w[a+2|0]){v[22656]=0;d=bQ(b,g,d);a=v[22656];v[22656]=0;if((a|0)==1){break f}break h}v[22656]=0;d=aQ(b,g,d);a=v[22656];v[22656]=0;if((a|0)==1){break f}break h}if(!(w[a+3|0]|(w[a|0]!=64|w[a+1|0]!=1))){d=v[e+2708>>2];if(!w[a+2|0]){v[22656]=0;d=$P(b,g,d);a=v[22656];v[22656]=0;if((a|0)==1){break f}break h}v[22656]=0;d=_P(b,g,d);a=v[22656];v[22656]=0;if((a|0)==1){break f}break h}if(!(w[a+3|0]|(w[a|0]!=64|w[a+1|0]!=2))){d=v[e+2708>>2];if(!w[a+2|0]){v[22656]=0;d=ZP(b,g,d);a=v[22656];v[22656]=0;if((a|0)==1){break f}break h}v[22656]=0;d=YP(b,g,d);a=v[22656];v[22656]=0;if((a|0)==1){break f}break h}if(!(w[a|0]!=32|w[a+1|0]!=1|w[a+3|0]!=3)){d=v[e+2708>>2];if(!w[a+2|0]){v[22656]=0;d=W(1231,b|0,g|0,d|0)|0;a=v[22656];v[22656]=0;if((a|0)==1){break f}break h}v[22656]=0;d=W(1232,b|0,g|0,d|0)|0;a=v[22656];v[22656]=0;if((a|0)==1){break f}break h}if(!(w[a|0]!=32|w[a+1|0]!=2|w[a+3|0]!=3)){d=v[e+2708>>2];if(!w[a+2|0]){v[22656]=0;d=W(1233,b|0,g|0,d|0)|0;a=v[22656];v[22656]=0;if((a|0)==1){break f}break h}v[22656]=0;d=W(1234,b|0,g|0,d|0)|0;a=v[22656];v[22656]=0;if((a|0)==1){break f}break h}if(!(w[a|0]!=64|w[a+1|0]!=1|w[a+3|0]!=3)){d=v[e+2708>>2];if(!w[a+2|0]){v[22656]=0;d=W(1235,b|0,g|0,d|0)|0;a=v[22656];v[22656]=0;if((a|0)==1){break f}break h}v[22656]=0;d=W(1236,b|0,g|0,d|0)|0;a=v[22656];v[22656]=0;if((a|0)==1){break f}break h}if(!(w[a|0]!=64|w[a+1|0]!=2|w[a+3|0]!=3)){d=v[e+2708>>2];if(!w[a+2|0]){v[22656]=0;d=W(1237,b|0,g|0,d|0)|0;a=v[22656];v[22656]=0;if((a|0)==1){break f}break h}v[22656]=0;d=W(1238,b|0,g|0,d|0)|0;a=v[22656];v[22656]=0;if((a|0)==1){break f}break h}if(!(w[a+1|0]!=1&w[a+1|0]!=2|w[a|0]!=24|w[a+3|0]!=15)){v[e+544>>2]=-2147483648;d=v[e+2708>>2];ja:{if(!w[a+2|0]){v[e+8>>2]=v[e+440>>2];v[e+436>>2]=0;a=v[e+436>>2];v[e>>2]=v[e+432>>2];v[e+4>>2]=a;k=gb-16|0;gb=k;h=b;E=k,F=B(v[b>>2],fd(b)),v[E+12>>2]=F;qc(k+12|0,(d>>>0)/3|0);d=zb(g);a=v[e+4>>2];i=v[k+12>>2];if(i){while(1){f=zb(w[d|0]);j=zb(w[d+1|0])<<16|f<<8|zb(w[d+2|0])<<24;ka:{if((j|0)<0){f=-2147483648;if((j|0)==-2147483648){break ka}j=0-j|0}f=a>>>0<j>>>0?j:a}a=f;d=d+3|0;i=i-1|0;if(i){continue}break}}m=e+544|0;la:{if(!a){break la}j=v[k+12>>2];if(!j){break la}n=a-1|0;s=a>>>1|0;i=a;d=v[h+20>>2];while(1){f=zb(w[g|0]);o=d;f=zb(w[g+1|0])<<16|f<<8|zb(w[g+2|0])<<24;l=f>>31;h=f;f=l<<31|f>>>1;h=s|h<<31;ma:{if((f|0)>0|(f|0)>=0){f=nqa(h,f,i,0);h=jb;break ma}l=n;h=nqa(l-h|0,0-((h>>>0>l>>>0)+f|0)|0,i,0);f=0-h|0;h=0-(jb+((h|0)!=0)|0)|0}E=o,F=id(Ac(f,h),16),u[E>>1]=F;g=g+3|0;d=d+2|0;j=j-1|0;if(j){continue}break}}if(m){v[m>>2]=a}gb=k+16|0;d=B(v[k+12>>2],3);break ja}v[e+24>>2]=v[e+424>>2];v[e+420>>2]=0;a=v[e+420>>2];v[e+16>>2]=v[e+416>>2];v[e+20>>2]=a;k=gb-16|0;gb=k;h=b;E=k,F=B(v[b>>2],fd(b)),v[E+12>>2]=F;qc(k+12|0,(d>>>0)/3|0);d=zb(g);a=v[e+20>>2];i=v[k+12>>2];if(i){while(1){f=zb(w[d+2|0]);j=zb(w[d+1|0])<<16|f<<8|zb(w[d|0])<<24;na:{if((j|0)<0){f=-2147483648;if((j|0)==-2147483648){break na}j=0-j|0}f=a>>>0<j>>>0?j:a}a=f;d=d+3|0;i=i-1|0;if(i){continue}break}}m=e+544|0;oa:{if(!a){break oa}j=v[k+12>>2];if(!j){break oa}n=a-1|0;s=a>>>1|0;i=a;d=v[h+20>>2];while(1){f=zb(w[g+2|0]);o=d;f=zb(w[g+1|0])<<16|f<<8|zb(w[g|0])<<24;l=f>>31;h=f;f=l<<31|f>>>1;h=s|h<<31;pa:{if((f|0)>0|(f|0)>=0){f=nqa(h,f,i,0);h=jb;break pa}l=n;h=nqa(l-h|0,0-((h>>>0>l>>>0)+f|0)|0,i,0);f=0-h|0;h=0-(jb+((h|0)!=0)|0)|0}E=o,F=id(Ac(f,h),16),u[E>>1]=F;g=g+3|0;d=d+2|0;j=j-1|0;if(j){continue}break}}if(m){v[m>>2]=a}gb=k+16|0;d=B(v[k+12>>2],3)}if(!d){break h}a=v[e+544>>2];if((a|0)==-2147483648){break h}f=kqa(x[b+32>>1],0,a,0)+1073741824|0;a=jb;a=f>>>0<1073741824?a+1|0:a;E=b,F=Md(Qc((a&2147483647)<<1|f>>>31,a>>>31|0),1,64),u[E+32>>1]=F;u[b+34>>1]=x[b+34>>1]|8192;break h}if(!(w[a+1|0]!=1&w[a+1|0]!=2|w[a|0]!=32|w[a+3|0]!=15)){v[e+544>>2]=-2147483648;d=v[e+2708>>2];qa:{if(!w[a+2|0]){v[e+40>>2]=v[e+408>>2];v[e+404>>2]=0;a=v[e+404>>2];v[e+32>>2]=v[e+400>>2];v[e+36>>2]=a;k=gb-16|0;gb=k;h=b;E=k,F=B(v[b>>2],fd(b)),v[E+12>>2]=F;qc(k+12|0,d>>>2|0);d=zb(g);a=v[e+36>>2];i=v[k+12>>2];if(i){while(1){f=zb(w[d|0]);j=f|zb(w[d+1|0])<<8|zb(w[d+2|0])<<16|zb(w[d+3|0])<<24;ra:{if((j|0)<0){f=-2147483648;if((j|0)==-2147483648){break ra}j=0-j|0}f=a>>>0<j>>>0?j:a}a=f;d=d+4|0;i=i-1|0;if(i){continue}break}}m=e+544|0;sa:{if(!a){break sa}j=v[k+12>>2];if(!j){break sa}n=a-1|0;s=a>>>1|0;i=a;d=v[h+20>>2];while(1){f=zb(w[g|0]);o=d;f=f|zb(w[g+1|0])<<8|zb(w[g+2|0])<<16|zb(w[g+3|0])<<24;l=f>>31;h=f;f=l<<31|f>>>1;h=s|h<<31;ta:{if((f|0)>0|(f|0)>=0){f=nqa(h,f,i,0);h=jb;break ta}l=n;h=nqa(l-h|0,0-((h>>>0>l>>>0)+f|0)|0,i,0);f=0-h|0;h=0-(jb+((h|0)!=0)|0)|0}E=o,F=id(Ac(f,h),16),u[E>>1]=F;g=g+4|0;d=d+2|0;j=j-1|0;if(j){continue}break}}if(m){v[m>>2]=a}gb=k+16|0;d=v[k+12>>2]<<2;break qa}v[e+56>>2]=v[e+392>>2];v[e+388>>2]=0;a=v[e+388>>2];v[e+48>>2]=v[e+384>>2];v[e+52>>2]=a;k=gb-16|0;gb=k;h=b;E=k,F=B(v[b>>2],fd(b)),v[E+12>>2]=F;qc(k+12|0,d>>>2|0);d=zb(g);a=v[e+52>>2];i=v[k+12>>2];if(i){while(1){f=zb(w[d+3|0]);j=f|zb(w[d+2|0])<<8|zb(w[d+1|0])<<16|zb(w[d|0])<<24;ua:{if((j|0)<0){f=-2147483648;if((j|0)==-2147483648){break ua}j=0-j|0}f=a>>>0<j>>>0?j:a}a=f;d=d+4|0;i=i-1|0;if(i){continue}break}}m=e+544|0;va:{if(!a){break va}j=v[k+12>>2];if(!j){break va}n=a-1|0;s=a>>>1|0;i=a;d=v[h+20>>2];while(1){f=zb(w[g+3|0]);o=d;f=f|zb(w[g+2|0])<<8|zb(w[g+1|0])<<16|zb(w[g|0])<<24;l=f>>31;h=f;f=l<<31|f>>>1;h=s|h<<31;wa:{if((f|0)>0|(f|0)>=0){f=nqa(h,f,i,0);h=jb;break wa}l=n;h=nqa(l-h|0,0-((h>>>0>l>>>0)+f|0)|0,i,0);f=0-h|0;h=0-(jb+((h|0)!=0)|0)|0}E=o,F=id(Ac(f,h),16),u[E>>1]=F;g=g+4|0;d=d+2|0;j=j-1|0;if(j){continue}break}}if(m){v[m>>2]=a}gb=k+16|0;d=v[k+12>>2]<<2}if(!d){break h}a=v[e+544>>2];if((a|0)==-2147483648){break h}a=kqa(x[b+32>>1],0,a,0)+1073741824|0;f=jb;f=a>>>0<1073741824?f+1|0:f;E=b,F=Md(Qc((f&2147483647)<<1|a>>>31,f>>>31|0),1,64),u[E+32>>1]=F;u[b+34>>1]=x[b+34>>1]|8192;break h}xa:{if(!(w[a+1|0]!=1&w[a+1|0]!=2|w[a|0]!=32|w[a+3|0]!=14)){v[e+544>>2]=1065353216;d=v[e+2708>>2];ya:{if(!w[a+2|0]){v[e+372>>2]=0;v[e+376>>2]=1065353216;a=v[e+380>>2];v[e+72>>2]=v[e+376>>2];v[e+76>>2]=a;v[22656]=0;a=v[e+372>>2];v[e+64>>2]=v[e+368>>2];v[e+68>>2]=a;d=fa(1239,b|0,g|0,d|0,e+544|0,e- -64|0)|0;a=v[22656];v[22656]=0;if((a|0)!=1){break ya}break xa}v[e+356>>2]=0;v[e+360>>2]=1065353216;a=v[e+364>>2];v[e+88>>2]=v[e+360>>2];v[e+92>>2]=a;v[22656]=0;a=v[e+356>>2];v[e+80>>2]=v[e+352>>2];v[e+84>>2]=a;d=fa(1240,b|0,g|0,d|0,e+544|0,e+80|0)|0;a=v[22656];v[22656]=0;if((a|0)==1){break xa}}if(!d){break h}q=z[e+544>>2];if(q==C(1)){break h}a=b;h=a;q=fe(Ho(C(q*C(x[a+32>>1])),C(1),C(64)));a=65535;za:{if(q>=C(65535)){break za}a=0;if(q<=C(0)){break za}a=~~q>>>0;if(q<C(4294967296)&q>=C(0)){break za}a=0}u[h+32>>1]=a;u[b+34>>1]=x[b+34>>1]|8192;break h}Aa:{if(!(w[a+1|0]!=1&w[a+1|0]!=2|w[a|0]!=64|w[a+3|0]!=14)){v[e+544>>2]=0;v[e+548>>2]=1072693248;d=v[e+2708>>2];Ba:{if(!w[a+2|0]){v[e+336>>2]=0;v[e+340>>2]=1072693248;v[e+328>>2]=0;v[e+332>>2]=0;v[e+104>>2]=0;v[e+108>>2]=0;v[e+112>>2]=0;v[e+116>>2]=1072693248;a=v[e+348>>2];v[e+120>>2]=v[e+344>>2];v[e+124>>2]=a;v[22656]=0;a=v[e+324>>2];v[e+96>>2]=v[e+320>>2];v[e+100>>2]=a;d=fa(1241,b|0,g|0,d|0,e+544|0,e+96|0)|0;a=v[22656];v[22656]=0;if((a|0)!=1){break Ba}break Aa}v[e+304>>2]=0;v[e+308>>2]=1072693248;v[e+296>>2]=0;v[e+300>>2]=0;v[e+136>>2]=0;v[e+140>>2]=0;v[e+144>>2]=0;v[e+148>>2]=1072693248;a=v[e+316>>2];v[e+152>>2]=v[e+312>>2];v[e+156>>2]=a;v[22656]=0;a=v[e+292>>2];v[e+128>>2]=v[e+288>>2];v[e+132>>2]=a;d=fa(1242,b|0,g|0,d|0,e+544|0,e+128|0)|0;a=v[22656];v[22656]=0;if((a|0)==1){break Aa}}if(!d){break h}r=A[e+544>>3];if(r==1){break h}a=b;h=a;r=ee(GA(r*+x[a+32>>1],1,64));a=65535;Ca:{if(r>=65535){break Ca}a=0;if(r<=0){break Ca}a=~~r>>>0;if(r<4294967296&r>=0){break Ca}a=0}u[h+32>>1]=a;u[b+34>>1]=x[b+34>>1]|8192;break h}if(!(w[a|0]!=32|w[a+1|0]!=1|w[a+3|0]!=12)){d=v[e+2708>>2];if(!w[a+2|0]){v[e+280>>2]=939524096;v[22656]=0;a=v[e+284>>2];v[e+160>>2]=v[e+280>>2];v[e+164>>2]=a;d=da(1243,b|0,g|0,d|0,e+160|0)|0;a=v[22656];v[22656]=0;if((a|0)==1){break f}break h}v[e+272>>2]=939524096;v[22656]=0;a=v[e+276>>2];v[e+168>>2]=v[e+272>>2];v[e+172>>2]=a;d=da(1244,b|0,g|0,d|0,e+168|0)|0;a=v[22656];v[22656]=0;if((a|0)==1){break f}break h}if(!(w[a|0]!=32|w[a+1|0]!=2|w[a+3|0]!=12)){d=v[e+2708>>2];if(!w[a+2|0]){v[e+264>>2]=939524096;v[22656]=0;a=v[e+268>>2];v[e+176>>2]=v[e+264>>2];v[e+180>>2]=a;d=da(1245,b|0,g|0,d|0,e+176|0)|0;a=v[22656];v[22656]=0;if((a|0)==1){break f}break h}v[e+256>>2]=939524096;v[22656]=0;a=v[e+260>>2];v[e+184>>2]=v[e+256>>2];v[e+188>>2]=a;d=da(1246,b|0,g|0,d|0,e+184|0)|0;a=v[22656];v[22656]=0;if((a|0)==1){break f}break h}if(!(w[a|0]!=32|w[a+1|0]!=1|w[a+3|0]!=13)){d=v[e+2708>>2];if(!w[a+2|0]){v[e+248>>2]=872415232;v[22656]=0;a=v[e+252>>2];v[e+192>>2]=v[e+248>>2];v[e+196>>2]=a;d=da(1243,b|0,g|0,d|0,e+192|0)|0;a=v[22656];v[22656]=0;if((a|0)==1){break f}break h}v[e+240>>2]=872415232;v[22656]=0;a=v[e+244>>2];v[e+200>>2]=v[e+240>>2];v[e+204>>2]=a;d=da(1244,b|0,g|0,d|0,e+200|0)|0;a=v[22656];v[22656]=0;if((a|0)==1){break f}break h}d=0;if(w[a|0]!=32|w[a+1|0]!=2|w[a+3|0]!=13){break h}d=v[e+2708>>2];if(!w[a+2|0]){v[e+232>>2]=872415232;v[22656]=0;a=v[e+236>>2];v[e+208>>2]=v[e+232>>2];v[e+212>>2]=a;d=da(1245,b|0,g|0,d|0,e+208|0)|0;a=v[22656];v[22656]=0;if((a|0)!=1){break h}break f}v[e+224>>2]=872415232;v[22656]=0;a=v[e+228>>2];v[e+216>>2]=v[e+224>>2];v[e+220>>2]=a;d=da(1246,b|0,g|0,d|0,e+216|0)|0;a=v[22656];v[22656]=0;if((a|0)==1){break f}break h}a=P()|0;O()|0;break a}a=P()|0;O()|0;break a}a=V(27364)|0}if((O()|0)!=(ea(27364)|0)){break d}Z(a|0)|0;v[22656]=0;X(20);a=v[22656];v[22656]=0;if((a|0)==1){break i}}d=i+4|0;xb(f);break h}a=P()|0;O()|0;break d}v[22656]=0;Q(190,c|0,d+D|0)|0;a=v[22656];v[22656]=0;if((a|0)==1){break f}}zc(p)}gb=e+2736|0;return d|0}a=P()|0;O()|0;break a}a=P()|0;O()|0}xb(f);break a}a=P()|0;O()|0;xb(e+520|0);break a}a=P()|0;O()|0}zc(p);S(a|0);L()}function vu(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,z=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,M=0,N=0,T=0,V=0,X=0,Z=0,$=0,aa=0,ba=0,ca=0,ea=0,ga=0,ia=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0;n=gb-192|0;gb=n;Z=dd(a);p=n+160|0;t[p+26|0]=0;u[p+24>>1]=0;v[p+16>>2]=0;v[p+20>>2]=-1;v[p+8>>2]=-1;v[p+12>>2]=-1;v[p>>2]=0;v[p+4>>2]=0;F=v[d+16>>2];X=w[d+6|0];$=b+484360|0;if(X>>>0>=Pi($)>>>0){X=w[$+16|0]}z=Tj($,X);v[22656]=0;r=Q(1247,n+120|0,b|0)|0;a=v[22656];v[22656]=0;a:{if((a|0)!=1){g=v[r+4>>2];v[22656]=0;G=W(1248,n+80|0,b|0,X|0)|0;a=v[22656];v[22656]=0;b:{if((a|0)!=1){h=x[d+4>>1];c:{d:{if(h>>>0>=tc(z)>>>0){break d}while(1){v[22656]=0;a=Q(472,z|0,h&65535)|0;k=v[22656];v[22656]=0;if((k|0)==1){break c}if(a){break d}v[d>>2]=0;h=h+1|0;u[d+4>>1]=h;if(tc(z)>>>0>(h&65535)>>>0){continue}break}}a=v[d>>2];v[g+52>>2]=a;v[g+48>>2]=a;v[p+16>>2]=a;u[g+74>>1]=h;u[g+72>>1]=h;u[p+24>>1]=h;H=n+72|0;Ud(H);ga=wr(n- -64|0);ia=c&7;la=(ia|0)!=7;e:{if(la){break e}Jl(H,1);Jl(H,2);Jl(H,3);Jl(H,28);Jl(H,38);Jl(H,40);Jl(H,39);Jl(H,41);UP(ga,12);UP(ga,13);if((F|0)!=2){break e}a=x[d+12>>1];if(tc(z)>>>0<=a>>>0){break e}a=x[sc(z,a)>>1];v[22656]=0;k=b+484344|0;h=me(k,a);e=v[22656];v[22656]=0;if((e|0)==1){break c}if(!h){break e}e=_b(k,a);h=v[d+8>>2];v[22656]=0;e=SP(e,h);i=v[22656];v[22656]=0;if((i|0)==1){break c}if(!e){break e}e=0;a=_b(k,a);v[22656]=0;h=Yc(a,h,0);a=v[22656];v[22656]=0;if((a|0)==1){break c}if(!x[b+480188>>1]){break e}a=r+20|0;while(1){f:{g:{h:{switch(w[h|0]-253|0){case 0:if(x[b+480192>>1]){break g}break;case 1:case 2:break g;default:break h}}v[22656]=0;k=Rd(h);i=v[22656];v[22656]=0;if((i|0)==1){break c}if(!k){break f}if(wu(h)){break f}}sa=ye(a,e),ta=-1,v[sa>>2]=ta}h=h+6|0;e=e+1|0;if(e>>>0<x[b+480188>>1]){continue}break}}V=g+74|0;J=g+48|0;K=g+80|0;oa=g+44|0;E=r+20|0;ka=r+8|0;aa=c&1;ba=g+20|0;s=b+1074312|0;ma=g+616|0;I=b+484344|0;ca=32768;pa=(F|0)!=3;na=(F|0)!=2;e=0;h=0;i:{j:{while(1){M=h;k:{l:{while(1){i=x[d+12>>1];qa=A[d+8>>3];while(1){v[22656]=0;Wz(n+32|0,b,g,e&1);a=v[22656];v[22656]=0;if((a|0)==1){break c}k=w[n+32|0];if(!pa&A[r+32>>3]>=qa){break l}h=x[g+72>>1];a=g;m:{if(tc(z)>>>0>h>>>0){h=x[sc(z,x[g+72>>1])>>1];break m}h=65535}u[a+70>>1]=h;v[22656]=0;a=me(I,h&65535);h=v[22656];v[22656]=0;if((h|0)==1){break i}if(!(x[g+70>>1]==65535|na|a)&(i|0)==x[g+72>>1]){break l}n:{if(x[g+70>>1]<Te(I)>>>0){break n}while(1){a=g;f=a;o:{p:{if(x[a+70>>1]!=65535){h=x[g+72>>1];if(tc(z)>>>0>h>>>0){break p}}if(x[z+28>>1]==x[g+72>>1]){break n}h=x[z+28>>1];break o}h=x[g+72>>1]+1|0}u[f+72>>1]=h;a=g;q:{if(tc(z)>>>0>(h&65535)>>>0){h=x[sc(z,x[g+72>>1])>>1];break q}h=65535}u[a+70>>1]=h;u[g+74>>1]=x[g+72>>1];v[22656]=0;a=me(I,h&65535);h=v[22656];v[22656]=0;if((h|0)==1){break i}r:{if(a){break r}a=x[g+72>>1];h=Iq(n+32|0,ma);v[22656]=0;a=fa(1251,G|0,a|0,0,h|0,(k|0)!=0|0)|0;h=v[22656];v[22656]=0;if((h|0)==1){break c}if(!a){break r}if(F>>>0<2){a=x[g+72>>1];v[p+8>>2]=0;u[p+20>>1]=a;if(!F){break n}}v[22656]=0;a=da(1252,G|0,V|0,J|0,1)|0;h=v[22656];v[22656]=0;if((h|0)==1){break i}if(!a){break n}A[p>>3]=A[r+32>>3];v[22656]=0;R(1253,Z|0,p|0);a=v[22656];v[22656]=0;if((a|0)==1){break i}v[p+16>>2]=v[J>>2];u[p+24>>1]=x[V>>1];v[22656]=0;_(1254,r|0);a=v[22656];v[22656]=0;if((a|0)==1){break i}a=x[g+74>>1];u[g+72>>1]=a;sa=g,ta=x[sc(z,a)>>1],u[sa+70>>1]=ta;v[g+52>>2]=v[g+48>>2];break n}if(x[g+70>>1]>=Te(I)>>>0){continue}break}}if(x[V>>1]==65535){break j}a=x[g+70>>1];v[22656]=0;a=me(I,a);h=v[22656];v[22656]=0;if((h|0)==1){break i}if(!a){if(x[z+28>>1]==x[g+72>>1]){if(!F){break j}v[22656]=0;a=da(1252,G|0,V|0,J|0,1)|0;k=v[22656];v[22656]=0;if((k|0)==1){break i}if(!a){break j}A[p>>3]=A[r+32>>3];v[22656]=0;R(1253,Z|0,p|0);a=v[22656];v[22656]=0;if((a|0)==1){break i}v[p+16>>2]=v[J>>2];u[p+24>>1]=x[V>>1];v[22656]=0;_(1254,r|0);a=v[22656];v[22656]=0;if((a|0)==1){break i}v[g+52>>2]=v[g+48>>2];continue}u[g+74>>1]=x[g+72>>1]+1;continue}break}if(y[g+48>>2]>=y[_b(I,x[g+70>>1])+12>>2]){v[J>>2]=0}if(!(x[g+72>>1]!=x[d+12>>1]|na)&v[J>>2]==v[d+8>>2]){break l}h=0;if(!((F|0)==3|y[G+28>>2]<ca>>>0)){v[r+32>>2]=0;v[r+36>>2]=2146435072;v[G+28>>2]=0;ca=ca>>>(ca>>>0>256)|0;h=1}a=v[g+48>>2];i=x[g+72>>1];f=Iq(n+32|0,ma);v[22656]=0;a=fa(1251,G|0,i|0,a|0,f|0,(k|0)!=0|0)|0;i=v[22656];v[22656]=0;if((i|0)==1){break c}if((a|h)==1){if(F>>>0<2){u[p+20>>1]=x[g+72>>1];v[p+8>>2]=v[g+48>>2];if(!F){break j}}v[22656]=0;a=da(1252,G|0,V|0,J|0,1)|0;k=v[22656];v[22656]=0;if((k|0)==1){break c}if(!a){break j}A[p>>3]=A[r+32>>3];v[22656]=0;R(1253,Z|0,p|0);a=v[22656];v[22656]=0;if((a|0)==1){break c}v[p+16>>2]=v[J>>2];u[p+24>>1]=x[V>>1];v[22656]=0;_(1254,r|0);a=v[22656];v[22656]=0;if((a|0)==1){break c}v[g+52>>2]=v[g+48>>2];continue}u[p+22>>1]=x[g+72>>1];v[p+12>>2]=v[g+48>>2];v[22656]=0;Vz(b,g,0);a=v[22656];v[22656]=0;if((a|0)==1){break c}if(y[g+48>>2]>=y[_b(I,x[g+70>>1])+12>>2]){v[J>>2]=0}if(k){continue}break}a=_b(I,x[g+70>>1]);k=v[g+48>>2];v[22656]=0;h=Yc(a,k,0);a=v[22656];v[22656]=0;s:{if((a|0)!=1){a=n+32|0;Db(a,s,77);e=Cb(a);f=0;if(x[b+480188>>1]){break s}break k}break c}while(1){t:{if(!(!EA(h)&(!e|!(w[((f<<5)+b|0)+480281|0]&4)))){ap((B(f,872)+g|0)+1404|0);break t}v[22656]=0;a=Cg(h);k=v[22656];v[22656]=0;if((k|0)==1){break c}if(a){u:{if(!aa){break u}a=w[h+1|0];if(a-251>>>0<5|!a){break u}v[22656]=0;k=Go(h);a=v[22656];v[22656]=0;if((a|0)==1){break c}v[22656]=0;a=Hq(h);i=v[22656];v[22656]=0;if((i|0)==1){break c}u[n+8>>1]=a;a=n+32|0;t[a|0]=w[h+1|0];u[a+2>>1]=x[n+8>>1];v[22656]=0;a=Q(1259,ka|0,a|0)|0;i=v[22656];v[22656]=0;if((i|0)==1){break c}u[a>>1]=k}ap((B(f,872)+g|0)+1404|0);break t}a=B(f,872)+g|0;k=a+1408|0;i=w[h+4|0]|w[h+5|0]<<8;t[k|0]=i;t[k+1|0]=i>>>8;a=a+1404|0;k=w[h|0]|w[h+1|0]<<8|(w[h+2|0]<<16|w[h+3|0]<<24);t[a|0]=k;t[a+1|0]=k>>>8;t[a+2|0]=k>>>16;t[a+3|0]=k>>>24;v:{switch(w[h+3|0]-16|0){case 0:a=w[h+5|0];v[22656]=0;U(1260,b|0,g|0,a|0);a=v[22656];v[22656]=0;if((a|0)==1){break c}break t;case 1:a=n+32|0;Db(a,s,5);if(!Cb(a)){break t}a=w[h+5|0];if(!a){break t}v[22656]=0;U(1260,b|0,g|0,a|0);a=v[22656];v[22656]=0;if((a|0)!=1){break t}break c;case 4:a=w[h+5|0];k=a&240;if((k|0)!=224){if((k|0)!=96){break t}v[g+24>>2]=v[g+24>>2]+(a&15);break t}if(v[ba>>2]){break t}a=w[h+5|0]&15;if(a?0:v[b+480180>>2]&2){break t}v[ba>>2]=a+1;break t;case 3:break v;default:break t}}a=w[h+5|0];if((a&240)!=224){break t}v[ba>>2]=(a&15)+1}h=h+6|0;f=f+1|0;if(f>>>0<x[b+480188>>1]){continue}break}break k}t[p+26|0]=1;break j}k=uk(g);v[22656]=0;v[n+32>>2]=1;a=Lc(ba,n+32|0);h=v[22656];v[22656]=0;w:{if((h|0)!=1){a=v[a>>2];u[g+68>>1]=65535;v[g+60>>2]=-1;v[g+64>>2]=-1;if(!x[b+480188>>1]){break w}N=k-1|0;h=k-a|0;T=B(h,1e4);f=0;while(1){x:{i=B(f,872)+g|0;a=i+1404|0;y:{if(EA(a)){break y}m=i+616|0;e=w[i+1409|0];ea=i+1407|0;l=w[ea|0];z:{A:{if(!aa){break A}j=w[a|0];o=i+1405|0;q=w[o|0];if(q){t[i+1415|0]=0;t[i+1419|0]=q;sa=ye(E,f),ta=255,t[sa+5|0]=ta}v[22656]=0;q=Rd(a);D=v[22656];v[22656]=0;if((D|0)==1){break x}if(q){t[i+1415|0]=j}v[22656]=0;q=Rd(a);D=v[22656];v[22656]=0;if((D|0)==1){break x}B:{if(!(w[o|0]?1:q)){break B}C:{o=i+1419|0;q=w[o|0];if(!q|q>>>0>x[b+480192>>1]){break C}q=v[((w[o|0]<<2)+b|0)+900380>>2];if(!q|!(t[q+15|0]&1)){break C}q=v[q+8>>2];v[22656]=0;Uo(m,q,b);q=v[22656];v[22656]=0;if((q|0)!=1){break C}break c}j=fA(b,j,w[o|0]);if(!j){break B}j=B(j,104)+b|0;if(!(w[j+484414|0]&32)){break B}j=x[j+484408>>1];v[22656]=0;Uo(m,j,b);j=v[22656];v[22656]=0;if((j|0)!=1){break B}break c}D:{E:{F:{j=w[i+1406|0];switch(j-1|0){case 1:break A;case 2:case 3:break E;case 0:break F;default:break D}}sa=ye(E,f),ta=w[i+1408|0],t[sa+5|0]=ta;break A}a=w[i+1408|0];if(!a){break A}t[i+1450|0]=a;break A}if(!w[i+1408|0]|(j|0)!=11){break A}j=n+32|0;DA(j,b,a,0);a=Ve(j);u[i+1384>>1]=x[j>>1];if(w[a|0]){break z}}G:{H:{switch(l-12|0){case 0:v[22656]=0;CA(b,g,f&65535);a=v[22656];v[22656]=0;if((a|0)!=1){break G}break x;case 2:v[22656]=0;a=BA(b,g,f&65535,e);j=v[22656];v[22656]=0;if((j|0)!=1){if((a|0)==-1){break G}v[g+60>>2]=a;break G}break c;case 5:a=n+32|0;Db(a,s,5);if(Cb(a)){break G}a=v[g+48>>2];j=x[g+70>>1];v[22656]=0;a=Qm(b,j,a,f&65535,0);j=v[22656];v[22656]=0;I:{J:{if((j|0)!=1){a=B(a,1e4);if(!aa|!(v[b+480180>>2]&16777250)){break I}if(a>>>0<1e4){break J}t[i+1451|0]=(a>>>0)/1e4;break I}break c}a=B(w[i+1451|0],1e4)}j=(a>>>0)/1e4|0;K:{if(a>>>0>319999){break K}o=B(T,j&15);a=v[g+44>>2];if((j&240)==16){a=a+o|0;break K}j=a-o|0;a=a>>>0<j>>>0?0:j}v[g+44>>2]=a;a=v[v[b+8>>2]+20>>2];j=v[v[b+8>>2]+24>>2];o=n+32|0;Db(o,s,8);Gp(oa,B(a,1e4),Cb(o)?255e4:B(j,1e4));break G;case 8:L:{switch((e&240)-144>>>4|0){case 0:if(e>>>0>145){break G}v[i+704>>2]=v[i+704>>2]&-257|((e|0)==145)<<8;break G;case 1:t[i+1452|0]=e&15;break G;case 2:uu(b,g,m,e&15);break G;case 6:break L;default:break G}}t[i+1460|0]=e&15;break G;case 7:a=e&240;if((a|0)!=240){if((a|0)!=96){break G}uu(b,g,m,e&15);break G}t[i+1460|0]=e&15;break G;case 1:case 3:case 4:case 6:break G;default:break H}}if((l|0)!=28|(e&240)!=160){break G}a=n+32|0;Db(a,s,58);if(Cb(a)){break G}t[i+1452|0]=e&15}if(!aa){break y}M:{N:{O:{P:{Q:{R:{S:{switch(l-2|0){case 0:if(!e){break z}a=n+32|0;Db(a,s,90);if(!Cb(a)){t[i+1428|0]=e}t[i+1427|0]=e;break z;case 1:if(!e){break z}a=n+32|0;Db(a,s,90);if(!Cb(a)){t[i+1427|0]=e}t[i+1428|0]=e;break z;case 2:if(!e){break z}u[i+1384>>1]=e;break z;case 8:if(!e){break z}v[i+1280>>2]=e<<8;break z;case 4:case 9:if(!e){break z}t[i+1425|0]=e;break z;case 11:sa=ye(E,f),ta=e,t[sa+5|0]=ta;break z;case 21:a=e<<(!(v[b+480180>>2]&59593760)&e<<24>>24>=0)&255;if(a>>>0<=128){v[K>>2]=a<<1;break z}if(v[b+480180>>2]&16777250){break z}v[K>>2]=256;break z;case 22:a=n+32|0;Db(a,s,9);T:{if(Cb(a)){a=i+1433|0;if(e){t[a|0]=e;break T}e=w[a|0];break T}if(e){t[g+1433|0]=e;break T}e=w[g+1433|0]}a=K;l=e&240;j=e&15;U:{if(!(!l|(j|0)!=15)){o=v[K>>2]+(l>>>4<<!(v[b+480180>>2]&59593760)<<1)|0;break U}o=v[K>>2]-(j<<(v[b+480180>>2]&59593760?1:2))|0;if(!(!j|(l|0)!=240)){break U}o=v[K>>2]+B(h,(e>>>3&30)<<!(v[b+480180>>2]&59593760))|0;if(l){break U}o=v[K>>2]-B(h,j<<(v[b+480180>>2]&59593760?1:2))|0}v[a>>2]=o;Zd(K,0,256);break z;case 19:if(e>>>0>64){break z}v[i+1364>>2]=e;break z;case 20:a=i+1432|0;V:{if(e){t[a|0]=e;break V}e=w[a|0]}l=e&255;j=i+1364|0;a=v[j>>2];o=e&240;e=e&15;W:{if(!(!o|(e|0)!=15)){v[n+32>>2]=a+(l>>>4|0);break W}if(!(!e|(o|0)!=240)){v[n+32>>2]=a-e;break W}if(e){v[n+32>>2]=a-B(e,h);break W}v[n+32>>2]=a+B(h,l>>>4|0)}Zd(n+32|0,0,64);v[j>>2]=v[n+32>>2];break z;case 7:Pm(b,m,e,8);break z;case 25:break M;case 6:break N;case 24:break O;case 3:break P;case 5:break Q;case 18:break R;case 17:break S;default:break z}}if(!x[b+480188>>1]|e>>>0>15){break R}l=(e&1)<<14;a=0;while(1){j=B(a,872)+g|0;v[j+704>>2]=(l|v[j+704>>2]&-16385)^16384;a=a+1|0;if(a>>>0<x[b+480188>>1]){continue}break}}if((e&240)!=128){break z}Pm(b,m,e&15,4);break z}if(e){t[i+1425|0]=e}e=0}Il(m,e);break z}PP(b,m,e);break z}OP(m,e);break z}NP(m,e)}X:{Y:{switch(w[i+1406|0]-2|0){case 0:Pm(b,m,w[i+1408|0],6);break X;case 5:a=n+32|0;Db(a,s,53);e=Cb(a);a=w[i+1408|0];if(e){t[i+1439|0]=a&15;break X}Il(m,a<<4);break X;case 6:break Y;default:break X}}Il(m,w[i+1408|0])}Z:{_:{$:{aa:{a=w[ea|0];switch(a-5|0){case 3:break _;case 0:case 2:break $;case 1:break y;default:break aa}}switch(a-26|0){case 1:break Z;case 0:break $;default:break y}}ba:{if(v[b+480180>>2]&16777248){a=k;if(!(w[b+480208|0]&4)){break ba}}a=h}e=w[i+1439|0];m=n+32|0;Db(m,s,21);m=Cb(m);i=i+1435|0;a=B(a,e);t[i|0]=w[i|0]+(m?a<<2:a);break y}ca:{if(v[b+480180>>2]&16777248){a=k;if(!(w[b+480208|0]&4)){break ca}}a=h}e=w[i+1442|0];m=n+32|0;Db(m,s,21);m=Cb(m);i=i+1436|0;a=B(a,e);t[i|0]=w[i|0]+(m?a<<2:a);break y}a=i+1437|0;t[a|0]=w[a|0]+B(N,w[i+1445|0]);v[22656]=0;Yz(b,m);a=v[22656];v[22656]=0;if((a|0)==1){break x}}f=f+1|0;if(f>>>0<x[b+480188>>1]){continue}break w}break}break c}break c}if(v[b+480180>>2]==4&v[g+40>>2]==65535){break j}v[g+32>>2]=v[b+480216>>2];if(MP(_b(I,x[g+70>>1]))){sa=g,ta=v[_b(I,x[g+70>>1])+16>>2],v[sa+32>>2]=ta}v[22656]=0;h=Q(1266,b|0,g|0)|0;a=v[22656];v[22656]=0;if((a|0)!=1){a=B(h,k);A[r+32>>3]=A[r+32>>3]+ +(a>>>0)/+y[b+24620>>2];v[g>>2]=a+v[g>>2];if(!(!x[b+480188>>1]|la)){a=0;ea=(M|0)!=0&(h|0)!=(M|0);while(1){da:{if(v[ye(E,a)>>2]==-1){break da}l=B(a,872)+g|0;N=l+1404|0;j=l+1316|0;if(!v[j>>2]){if(EA(N)){break da}}T=1;ea:{fa:{q=l+1407|0;switch(w[q|0]-4|0){case 0:case 2:break ea;default:break fa}}T=w[l+1406|0]==11}if(w[l+1405|0]){v[l+1276>>2]=0}o=l+1409|0;f=w[o|0];v[22656]=0;D=Rd(N);e=v[22656];v[22656]=0;if((e|0)==1){break i}i=l+616|0;m=f&15;e=0;ga:{if(!D){break ga}ha:{if(!T){break ha}if(!w[ye(E,a)+4|0]){break ha}e=v[j>>2];v[22656]=0;ha(1267,n+32|0,b|0,i|0,e|0,0);e=v[22656];v[22656]=0;if((e|0)==1){break c}e=v[n+36>>2];v[l+624>>2]=v[n+32>>2];v[l+628>>2]=e}t[l+1418|0]=w[l+1415|0];D=l+1308|0;ra=v[D>>2];e=w[l+1419|0];if(e){v[22656]=0;Fo(b,i,e,T,1,1);e=v[22656];v[22656]=0;if((e|0)==1){break i}}e=w[N|0];v[22656]=0;ja(1269,b|0,i|0,e|0,T|0,1,0,65535);e=v[22656];v[22656]=0;if((e|0)==1){break i}f=f>>>4|0;sa=ye(E,a),ta=1,t[sa+4|0]=ta;j=w[q|0];ia:{if(!((w[o|0]&240)!=208|(j-19&255)>>>0>1)){e=m;if(k>>>0>e>>>0){break ia}}e=(j|0)==33?f>>>0<k>>>0?f:0:0}e=!(v[b+480180>>2]&16777250)|(!e|y[ba>>2]<2)?e:B(v[g+20>>2]-1|0,v[g+24>>2]+v[g+40>>2]|0)+e|0;if(!T){sa=ye(E,a),ta=0,v[sa>>2]=ta}j=w[q|0];ja:{if((j|0)==9){break ja}ka:{if((j|0)!=19){if((j|0)!=20|(f|0)!=8){break ka}break ja}if((f|0)==8){break ja}}if(w[l+1406|0]!=2){break ga}}v[D>>2]=ra}v[22656]=0;f=Rd(N);j=v[22656];v[22656]=0;if((j|0)==1){break i}la:{if(!f){f=n+32|0;Db(f,s,114);if(!Cb(f)){break la}}ma:{na:{oa:{pa:{f=w[q|0];switch(f-42|0){case 1:break ma;case 0:break na;case 2:break oa;default:break pa}}if((f|0)!=10){break ma}v[22656]=0;Y(1270,b|0,i|0,a&65535,g|0);f=v[22656];v[22656]=0;if((f|0)==1){break i}break la}j=kqa(w[o|0],0,v[l+692>>2],0);f=jb;D=f>>>8|0;f=Qc((f&255)<<24|j>>>8,D);v[22656]=0;Om(b,i,f);f=v[22656];v[22656]=0;if((f|0)!=1){break la}break i}if(!v[l+720>>2]){break ma}v[22656]=0;Y(1272,r|0,a&65535,M|0,-1);e=v[22656];v[22656]=0;if((e|0)==1){break i}e=w[o|0];v[22656]=0;zA(i,e);e=v[22656];v[22656]=0;if((e|0)==1){break i}e=v[g+40>>2]-1|0;break la}if(!v[l+720>>2]|w[l+1406|0]!=15){break la}f=l+1408|0;if(w[f|0]>9){break la}f=w[f|0];qa:{if(!f){j=v[l+1280>>2];break qa}j=v[Fe(v[l+720>>2]+68|0,f-1|0)>>2];v[l+1280>>2]=j}v[22656]=0;Om(b,i,j);f=v[22656];v[22656]=0;if((f|0)!=1){break la}break c}ra:{sa:{ta:{ua:{va:{wa:{xa:{ya:{za:{Aa:{Ba:{Ca:{switch(w[N|0]-253|0){case 0:if(x[b+480192>>1]){break Ba}break;case 1:case 2:break Ba;default:break Ca}}j=w[q|0];if((j-19&255)>>>0<=1){f=0;if((w[o|0]&240)!=192){break za}if(k>>>0>m>>>0){break Ba}break za}f=0;D=j&255;if((D|0)==33&(m|0)!=0&e+m>>>0<k>>>0){break Ba}if((D|0)!=25){break Aa}}j=w[q|0];f=1}if((j&255)==13){break ya}}if(w[l+1406|0]==1){v[l+1304>>2]=w[l+1408|0]<<2}if(!v[l+720>>2]|f){break xa}f=0;if((j&255)>>>0>44){break va}break wa}v[l+1304>>2]=w[o|0]<<2;j=13;if(!(!v[l+720>>2]|f)){break wa}}if(!f){break ra}break sa}f=n+32|0;Db(f,H,j&255);if(Cb(f)){break ua}f=0;if(w[q|0]!=19){break va}f=w[o|0]&240;f=(f|0)==16|(f|0)==32}j=w[l+1406|0];if(j>>>0<16){break ta}if(f){break sa}break ra}f=1;j=w[l+1406|0];if(j>>>0>=16){break sa}}m=n+32|0;Bl(m,ga,j);m=Cb(m);if(f){break sa}if(!m){break ra}}v[22656]=0;qB(i);e=v[22656];v[22656]=0;if((e|0)==1){break i}sa=ye(E,a),ta=0,v[sa>>2]=ta;break da}if(ea){v[22656]=0;Y(1272,r|0,a&65535,M|0,-1);f=v[22656];v[22656]=0;if((f|0)==1){break i}}f=w[q|0];Da:{if(f>>>0<=18){if(!k|((f|0)!=11&f-6>>>0>=2|!w[o|0]&v[b+480180>>2]==1)){break Da}m=l+1467|0;f=0;while(1){t[m|0]=!f|w[m|0]&254;Eo(b,i,w[o|0]);f=f+1|0;if((k|0)!=(f|0)){continue}break}break Da}Ea:{switch(f-19|0){case 0:f=w[o|0];if(!(f&15)){if(!(v[b+480180>>2]&1048580)){break Da}f=w[o|0]}m=l+1467|0;t[m|0]=w[m|0]|1;m=f&240;if((m|0)!=176){if((m|0)!=160){break Da}Gq(b,i,f&15,0);break Da}Fq(b,i,f&15,0);break Da;case 1:Fa:{Ga:{Ha:{f=w[o|0];switch(f-158|0){case 1:break Ga;case 0:break Ha;default:break Fa}}v[22656]=0;Y(1272,r|0,a&65535,M|0,-1);f=v[22656];v[22656]=0;if((f|0)==1){break i}v[l+704>>2]=v[l+704>>2]&-129;break Da}v[22656]=0;Y(1272,r|0,a&65535,M|0,-1);f=v[22656];v[22656]=0;if((f|0)==1){break i}v[l+704>>2]=v[l+704>>2]|128;if(!v[l+692>>2]|v[i+4>>2]){break Da}v[22656]=0;f=Rd(N);m=v[22656];v[22656]=0;if((m|0)==1){break i}if(!(w[l+704|0]&2?f:1)){break Da}m=v[l+692>>2]-1|0;v[i>>2]=-1;v[i+4>>2]=m;break Da}if((f&240)!=112|f>>>0<115){break Da}v[22656]=0;pB(i,f,b);f=v[22656];v[22656]=0;if((f|0)==1){break i}break Da;default:break Ea}}if(f-35>>>0>=2){break Da}v[22656]=0;f=a&65535;Y(1272,r|0,f|0,M|0,-1);m=v[22656];v[22656]=0;if((m|0)==1){break i}v[22656]=0;Y(1276,b|0,f|0,g|0,0);f=v[22656];v[22656]=0;if((f|0)==1){break i}}m=l+1467|0;f=w[m|0]|1;t[m|0]=f;Ia:{Ja:{Ka:{La:{Ma:{o=l+1406|0;switch(w[o|0]-3|0){case 11:break Ja;case 0:case 1:break Ka;case 3:break La;case 2:break Ma;default:break Ia}}f=w[l+1408|0];l=n+32|0;Db(l,s,41);Gq(b,i,f,Cb(l));break Ia}f=w[l+1408|0];l=n+32|0;Db(l,s,41);Fq(b,i,f,Cb(l));break Ia}j=w[l+1408|0];Na:{if(j){break Na}f=n+32|0;Db(f,s,41);j=0;if(!Cb(f)){break Na}j=w[l+1450|0];if(!j){break Ia}}if(!k){break Ia}l=w[o|0]==3?j<<4:j;f=0;while(1){t[m|0]=!f|w[m|0]&254;Eo(b,i,l&255);f=f+1|0;if((k|0)!=(f|0)){continue}break}break Ia}i=w[l+1408|0];if(i>>>0>1){break Ia}t[m|0]=f&251|!i<<2}if(w[m|0]&4){break da}if(T){f=ye(E,a);i=v[f>>2];v[f>>2]=i+k;v[22656]=0;Y(1272,r|0,a&65535,h|0,(e+i|0)+1|0);e=v[22656];v[22656]=0;if((e|0)!=1){break da}break c}i=ye(E,a);v[i>>2]=v[i>>2]+(k-e|0)}a=a+1|0;if(a>>>0<x[b+480188>>1]){continue}break}}e=IP(b,g,0);continue}break}break c}if(!(!x[b+480188>>1]|(ia|0)!=7)){a=0;while(1){Oa:{if(v[ye(E,a)>>2]==-1){break Oa}v[22656]=0;Y(1272,r|0,a&65535,M|0,-1);d=v[22656];v[22656]=0;if((d|0)!=1){break Oa}break c}a=a+1|0;if(a>>>0<x[b+480188>>1]){continue}break}}if(w[p+26|0]){u[p+20>>1]=x[g+72>>1];v[p+8>>2]=v[g+48>>2]}A[p>>3]=A[r+32>>3];v[22656]=0;R(1253,Z|0,p|0);a=v[22656];v[22656]=0;Pa:{if((a|0)==1){break Pa}Qa:{Ra:{if(!aa){break Ra}Sa:{Ta:{if(F?w[p+26|0]:1){h=b+1074376|0;e=hc(h,g,614);a=0;while(1){k=B(a,872);d=(k+g|0)+616|0;k=hc((e+k|0)+616|0,d,88);v[k+88>>2]=v[d+88>>2];hc(k+92|0,d+92|0,576);v[k+668>>2]=v[d+668>>2];hc(k+672|0,d+672|0,52);zo(k+724|0,d+724|0);zo(k+732|0,d+732|0);zo(k+740|0,d+740|0);hc(k+748|0,d+748|0,123);a=a+1|0;if((a|0)!=256){continue}break}yA(h);a=0;v[b+1074400>>2]=0;t[b+1074476|0]=1;d=b+1074392|0;v[d>>2]=-2;v[d+4>>2]=0;v[b+1074428>>2]=v[b+1074424>>2];d=b+1298260|0;if(Dd(d)){g=v[d>>2];v[22656]=0;cB(g);g=v[22656];v[22656]=0;if((g|0)==1){break Pa}}if(x[b+480188>>1]){k=(ia|0)==7;while(1){g=B(a,872)+b|0;h=w[g+1075791|0];if(h){t[g+1075794|0]=h}h=ye(E,a);if(!(k|w[h+5|0]==255)){v[22656]=0;t[n+32|0]=64;h=ac(h+5|0,n+32|0);e=v[22656];v[22656]=0;if((e|0)==1){break c}v[g+1075680>>2]=w[h|0]<<2}Ua:{h=g+1075096|0;e=v[h>>2];if(!e|!(w[e+35|0]&2)){break Ua}if(!Dd(d)){break Ua}e=v[d>>2];h=v[h>>2];v[22656]=0;f=e;e=a&65535;Gu(f,e,h+68|0);h=v[22656];v[22656]=0;if((h|0)!=1){h=v[d>>2];v[22656]=0;Oi(h,e,1);h=v[22656];v[22656]=0;if((h|0)!=1){break Ua}}break c}v[g+1075008>>2]=0;a=a+1|0;if(a>>>0<x[b+480188>>1]){continue}break}}d=bC(n+32|0);sa=n,ta=or(ka),v[sa+24>>2]=ta;sa=n,ta=Dh(ka),v[sa+16>>2]=ta;if(!og(n+24|0,n+16|0)){break Ta}while(1){g=Yl(n+24|0);k=w[g|0]-1&255;a=v[(B(k,160)+b|0)+906300>>2];if(a){h=n+8|0;Db(h,d,k);if(!Cb(h)){v[22656]=0;R(1280,d|0,k|0);k=v[22656];v[22656]=0;if((k|0)==1){break Qa}k=v[v[a>>2]+172>>2];v[22656]=0;R(k|0,a|0,-1);k=v[22656];v[22656]=0;if((k|0)==1){break Qa}}k=x[g+2>>1];h=v[v[a>>2]+44>>2];g=x[g+4>>1];v[22656]=0;Aa(h|0,a|0,k|0,C(C(C(g>>>0)/C(999))));a=v[22656];v[22656]=0;if((a|0)==1){break Qa}}a=n+24|0;Uj(a);if(og(a,n+16|0)){continue}break}break Ta}if((c|0)==3){break Sa}v[b+1074416>>2]=v[b+480196>>2];v[b+1074420>>2]=v[b+480204>>2];v[b+1074456>>2]=v[b+480200>>2];break Sa}h=250;a=d;e=a;Va:{while(1){g=1;if(v[e>>2]){break Va}e=e+4|0;h=h-32|0;if(h>>>0>31){continue}break}g=(v[a+28>>2]&67108863)!=0}if(!g){break Sa}a=0;while(1){g=n+8|0;Db(g,d,a);Wa:{if(!Cb(g)){break Wa}g=v[(B(a,160)+b|0)+906300>>2];k=v[v[g>>2]+176>>2];v[22656]=0;_(k|0,g|0);g=v[22656];v[22656]=0;if((g|0)!=1){break Wa}break c}a=a+1|0;if((a|0)!=250){continue}break}}if(w[$+16|0]==(X|0)){break Ra}v[22656]=0;Qi($,X);a=v[22656];v[22656]=0;if((a|0)==1){break Pa}}if(c&9){c=G;b=b+1298224|0;d=b;a=b;if(v[a>>2]){Ec(a);mR(a);iR(a);mm(wb(a),v[a>>2],ug(a));sa=wb(a),ta=0,v[sa>>2]=ta;v[a>>2]=0;v[a+4>>2]=0}lp(d,c);v[d>>2]=v[c>>2];v[d+4>>2]=v[c+4>>2];a=wb(c);sa=wb(d),ta=v[a>>2],v[sa>>2]=ta;v[a>>2]=0;v[c>>2]=0;v[c+4>>2]=0;a=b+12|0;Kq(a,v[fc(a)>>2]);b=c+12|0;v[a>>2]=v[b>>2];v[a+4>>2]=v[b+4>>2];fc(b);fc(a);v[a+8>>2]=v[b+8>>2];d=v[wb(a)>>2];c=fc(a);Xa:{if(!d){v[a>>2]=c;break Xa}sa=v[fc(a)>>2],ta=c,v[sa+8>>2]=ta;sa=b,ta=fc(b),v[sa>>2]=ta;sa=fc(b),ta=0,v[sa>>2]=ta;sa=wb(b),ta=0,v[sa>>2]=ta}}Eq(G);HP(r);gb=n+192|0;return}}}}a=P()|0;O()|0;Eq(G);break b}a=P()|0;O()|0}HP(r);break a}a=P()|0;O()|0}en(Z);S(a|0);L()}function p6(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=C(0),p=0,q=0,r=0,s=C(0),A=C(0),D=0,E=0,F=0,G=0,H=0,I=0,J=C(0),K=0,M=C(0),N=0,O=0,P=0,Q=C(0),R=0,S=0,T=C(0),U=0,V=0,W=0,X=C(0),Y=C(0),Z=C(0),_=0,$=0,ba=0,ca=C(0),da=0,ea=C(0),fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0;fa=gb-16|0;gb=fa;a:{if(v[a+1420>>2]>=0){v[f>>2]=0;e=b;f=0;b=0;d=a;b:{c:{d:{g=v[a+1420>>2];if((g|0)<=0){break d}while(1){v[(d+B(f,20)|0)+1436>>2]=0;f=f+1|0;if((g|0)!=(f|0)){continue}break}if((g|0)<=3){break d}b=c;break c}if((c|0)<4){break b}a=c-3|0;e:{while(1){f:{l=b+e|0;if(w[l|0]!=79|(w[l|0]|w[l+1|0]<<8|(w[l+2|0]<<16|w[l+3|0]<<24))!=(w[90144]|w[90145]<<8|(w[90146]<<16|w[90147]<<24))){break f}h=b+26|0;if((h|0)>=(a|0)){break e}j=b+27|0;p=e+h|0;c=w[p|0];if((a|0)<=(j+c|0)){break e}i=c+27|0;f=0;if(c){while(1){i=w[e+(f+j|0)|0]+i|0;f=f+1|0;if((c|0)!=(f|0)){continue}break}}f=0;c=0;while(1){$=22;f=ny(f,w[e+(b+c|0)|0]);c=c+1|0;if((c|0)!=22){continue}break}while(1){f=ny(f,0);$=$+1|0;if(($|0)!=26){continue}break}v[d+1420>>2]=g+1;c=d+B(g,20)|0;v[c+1432>>2]=f;v[c+1428>>2]=i-26;v[c+1424>>2]=w[l+22|0]|w[l+23|0]<<8|(w[l+24|0]<<16|w[l+25|0]<<24);f=w[e+(h+w[p|0]|0)|0]==255?-1:w[l+6|0]|w[l+7|0]<<8|(w[l+8|0]<<16|w[l+9|0]<<24);v[c+1436>>2]=h;v[c+1440>>2]=f;g=v[d+1420>>2];if((g|0)!=4){break f}b=a;g=4;break c}b=b+1|0;if((a|0)!=(b|0)){continue}break}b=a}if((g|0)<=0){break b}}a=0;while(1){l=d+B(a,20)|0;p=l+1432|0;c=v[p>>2];f=0;j=v[l+1436>>2];h=b-j|0;k=l+1428|0;i=v[k>>2];h=(h|0)<(i|0)?h:i;if((h|0)>0){while(1){c=ny(c,w[e+(f+j|0)|0]);n=f+1|0;f=n;if((h|0)!=(n|0)){continue}break}}f=i-h|0;v[k>>2]=f;v[p>>2]=c;g:{if(!f){f=c;c=l+1424|0;if((f|0)==v[c>>2]){v[d+1380>>2]=-1;v[d+992>>2]=0;v[d+1420>>2]=-1;a=v[(d+B(a,20)|0)+1440>>2];v[d+1060>>2]=a;v[d+1064>>2]=(a|0)!=-1;b=h+j|0;break b}f=g-1|0;v[d+1420>>2]=f;f=d+B(f,20)|0;v[c+16>>2]=v[f+1440>>2];g=f+1432|0;l=v[g+4>>2];v[c+8>>2]=v[g>>2];v[c+12>>2]=l;f=f+1424|0;g=v[f+4>>2];v[c>>2]=v[f>>2];v[c+4>>2]=g;g=v[d+1420>>2];break g}a=a+1|0}if((a|0)<(g|0)){continue}break}}break a}v[a+100>>2]=0;v[a+32>>2]=b;v[a+40>>2]=b+c;if(!mJ(a)){v[f>>2]=0;b=0;break a}ja=gb-16|0;gb=ja;h=fa+4|0;j=h;l=a;c=l;v[c+1504>>2]=0;v[c+1508>>2]=0;h:{if(v[c+96>>2]){break h}g=c;i:{j:{k:{if(v[c+1380>>2]!=-1){break k}p=Ne(g);if(v[g+96>>2]){break i}if((p|0)!=79){break j}if((Ne(g)|0)!=103){break j}if((Ne(g)|0)!=103){break j}if((Ne(g)|0)!=83){break j}if(!hJ(g)){break i}if(!(t[g+1375|0]&1)){break k}t[g+1376|0]=0;v[g+1384>>2]=0;ec(g,32);break i}k=ky(g);break i}ec(g,30)}if(!k){break h}if(nc(c,1)){ec(c,35);break h}p=ja;l:{m:{if(!(v[c+84>>2]!=v[c+92>>2]?v[c+80>>2]:0)){g=nc(c,Dm(v[c+408>>2]-1|0));if((g|0)==-1|(g|0)>=v[c+408>>2]){break h}v[ja+12>>2]=g;k=c+B(g,6)|0;if(!w[k+412|0]){i=v[c+112>>2];g=i>>1;break m}i=v[c+116>>2];g=i>>1;n=nc(c,1);H=nc(c,1);if(n|!w[k+412|0]){break m}v[j>>2]=i-v[c+112>>2]>>2;j=v[c+112>>2]+i>>2;break l}aa(3382,10534,3152,8021);L()}v[j>>2]=0;j=g}v[p+8>>2]=j;n:{if(!(!w[k+412|0]|H)){g=B(i,3);v[fa+8>>2]=g-v[c+112>>2]>>2;i=g+v[c+112>>2]>>2;break n}v[fa+8>>2]=g}v[ja+4>>2]=i;i=1}if(i){o:{ga=v[h>>2];qa=v[fa+8>>2];pa=v[ja+4>>2];sa=h;i=0;S=gb-2368|0;gb=S;q=v[l+404>>2];ra=l+B(v[ja+12>>2],6)|0;D=w[ra+413|0];W=q+B(D,40)|0;ha=W;ba=v[(l+(w[ra+412|0]<<2)|0)+104>>2];p:{p=v[l+4>>2];q:{if((p|0)>0){while(1){c=w[(v[ha+4>>2]+B(i,3)|0)+2|0];P=(S+1344|0)+(i<<2)|0;v[P>>2]=0;g=w[(c+W|0)+9|0];if(!x[(l+(g<<1)|0)+132>>1]){ec(l,21);c=0;break q}h=v[l+260>>2];r:{s:{if(nc(l,1)){c=2;k=v[(l+(i<<2)|0)+996>>2];p=h+B(g,1596)|0;F=v[(w[p+1588|0]<<2)+69724>>2];g=Dm(F)-1|0;Aa=k,Ba=nc(l,g),u[Aa>>1]=Ba;Aa=k,Ba=nc(l,g),u[Aa+2>>1]=Ba;j=0;if(w[p|0]){while(1){N=w[(j+p|0)+1|0];h=N+p|0;n=w[h+33|0];g=0;r=w[h+49|0];t:{if(!r){break t}h=v[l+124>>2]+B(w[h+65|0],2096)|0;if(v[l+1396>>2]<=9){sl(l)}m=v[l+1392>>2];g=u[(h+((m&1023)<<1)|0)+36>>1];u:{if((g|0)>=0){E=m;m=w[g+v[h+8>>2]|0];v[l+1392>>2]=E>>>m;O=v[l+1396>>2]-m|0;m=(O|0)<0;v[l+1396>>2]=m?0:O;g=m?-1:g;break u}g=Cm(l,h)}if(!w[h+23|0]){break t}g=v[v[h+2088>>2]+(g<<2)>>2]}if(n){K=-1<<r^-1;h=c+n|0;while(1){m=0;n=u[((p+(N<<4)|0)+((g&K)<<1)|0)+82>>1];v:{if((n|0)<0){break v}n=v[l+124>>2]+B(n&65535,2096)|0;if(v[l+1396>>2]<=9){sl(l)}O=v[l+1392>>2];m=u[(n+((O&1023)<<1)|0)+36>>1];w:{if((m|0)>=0){E=O;O=w[m+v[n+8>>2]|0];v[l+1392>>2]=E>>>O;H=v[l+1396>>2]-O|0;O=(H|0)<0;v[l+1396>>2]=O?0:H;m=O?-1:m;break w}m=Cm(l,n)}if(!w[n+23|0]){break v}m=v[v[n+2088>>2]+(m<<2)>>2]}g=g>>r;u[k+(c<<1)>>1]=m;c=c+1|0;if((h|0)!=(c|0)){continue}break}c=h}j=j+1|0;if(j>>>0<w[p|0]){continue}break}}if(v[l+1396>>2]!=-1){break s}}v[P>>2]=1;break r}u[S+320>>1]=257;j=p+1592|0;c=v[p+1592>>2];if((c|0)>=3){g=2;while(1){h=p+338|0;n=g<<1;r=n+p|0;P=w[r+1088|0];O=P<<1;m=x[h+O>>1];N=w[r+1089|0];K=N<<1;H=u[k+O>>1];r=u[K+k>>1]-H|0;O=r>>31;h=(B(x[h+n>>1]-m|0,O^r+O)|0)/(x[h+K>>1]-m|0)|0;m=H+((r|0)<0?0-h|0:h)|0;O=k+n|0;n=x[O>>1];x:{y:{if(n){h=S+320|0;t[h+N|0]=1;t[h+P|0]=1;t[g+h|0]=1;h=n<<16>>16;r=F-m|0;if((h|0)>=((m|0)>(r|0)?r:m)<<1){if((m|0)<(r|0)){break x}m=F+(n^-1)|0;break y}if(h&1){m=m-(h+1>>>1|0)|0;break y}m=(h>>1)+m|0;break y}t[(S+320|0)+g|0]=0}u[O>>1]=m;c=v[j>>2]}g=g+1|0;if((g|0)<(c|0)){continue}break}}m=0;if((c|0)<=0){break r}while(1){if(!w[(S+320|0)+m|0]){u[k+(m<<1)>>1]=65535;c=v[j>>2]}m=m+1|0;if((m|0)<(c|0)){continue}break}}i=i+1|0;p=v[l+4>>2];if((i|0)<(p|0)){continue}break}}z:{A:{c=v[l+80>>2];if(!(v[l+84>>2]!=v[l+92>>2]?c:0)){hc(S+320|0,S+1344|0,p<<2);h=x[W>>1];if(h){j=v[ha+4>>2];m=0;while(1){i=j+B(m,3)|0;g=w[i+1|0];n=S+1344|0;i=n+(w[i|0]<<2)|0;if(!(v[(g<<2)+n>>2]?v[i>>2]:0)){v[(S+1344|0)+(g<<2)>>2]=0;v[i>>2]=0}m=m+1|0;if((h|0)!=(m|0)){continue}break}}O=ba>>1;na=q+B(D,40)|0;if(w[na+8|0]){c=0;while(1){B:{if((p|0)<=0){g=0;break B}i=v[ha+4>>2];m=0;g=0;while(1){if(w[(i+B(m,3)|0)+2|0]==(c|0)){k=g+S|0;h=m<<2;C:{if(v[h+(S+1344|0)>>2]){j=1;h=0;break C}j=0;h=v[(h+l|0)+800>>2]}t[k|0]=j;v[(S+256|0)+(g<<2)>>2]=h;g=g+1|0}m=m+1|0;if((m|0)!=(p|0)){continue}break}}ia=S+256|0;D=S;I=gb-16|0;gb=I;h=l;H=v[h+4>>2];m=v[h+396>>2];i=w[(c+na|0)+24|0];U=m+B(i,24)|0;k=v[U+4>>2];p=O;oa=x[(h+(i<<1)|0)+268>>1];j=p<<((oa|0)==2);n=j>>>0>k>>>0?k:j;k=v[U>>2];E=(n-(j>>>0>k>>>0?k:j)>>>0)/y[U+8>>2]|0;F=E<<2;j=B(H,F+4|0);V=v[v[h+124>>2]+B(w[U+13|0],2096)>>2];xa=v[h+92>>2];D:{if(v[h+80>>2]){j=co(h,j);H=v[h+4>>2];break D}j=Cd(j)}k=0;if((H|0)>0){n=(H<<2)+j|0;while(1){v[(k<<2)+j>>2]=n;n=n+F|0;k=k+1|0;if((H|0)!=(k|0)){continue}break}}F=j;E:{F:{G:{if((g|0)>0){j=p<<2;k=0;while(1){if(!w[k+D|0]){Qb(v[ia+(k<<2)>>2],0,j)}k=k+1|0;if((k|0)!=(g|0)){continue}break}if((g|0)==1|(oa|0)!=2){break G}k=0;while(1){if(!w[k+D|0]){break F}k=k+1|0;if((k|0)!=(g|0)){continue}break}break E}k=0;if((oa|0)==2){break F}}ta=m+B(i,24)|0;ka=ta;ya=(E|0)<=0;H=0;while(1){if(!ya){j=0;ua=(g|0)<=0;za=ua|(H|0)!=0;p=0;while(1){k=0;if(!za){while(1){if(!w[k+D|0]){i=v[h+124>>2]+B(w[U+13|0],2096)|0;if(v[h+1396>>2]<=9){sl(h)}m=v[h+1392>>2];n=u[(i+((m&1023)<<1)|0)+36>>1];H:{if((n|0)>=0){q=m;m=w[n+v[i+8>>2]|0];v[h+1392>>2]=q>>>m;r=v[h+1396>>2]-m|0;m=(r|0)<0;v[h+1396>>2]=m?0:r;n=m?-1:n;break H}n=Cm(h,i)}n=w[i+23|0]?v[v[i+2088>>2]+(n<<2)>>2]:n;if((n|0)==-1){break E}v[v[F+(k<<2)>>2]+(j<<2)>>2]=v[v[ta+16>>2]+(n<<2)>>2]}k=k+1|0;if((k|0)!=(g|0)){continue}break}}I:{if((V|0)<=0){break I}n=0;if((p|0)>=(E|0)){break I}while(1){k=0;if(!ua){while(1){J:{if(w[k+D|0]){break J}m=k<<2;i=u[(v[ka+20>>2]+(w[v[v[m+F>>2]+(j<<2)>>2]+n|0]<<4)|0)+(H<<1)>>1];if((i|0)<0){break J}P=h;i=v[h+124>>2]+B(i&65535,2096)|0;da=v[m+ia>>2];_=v[U+8>>2];m=v[U>>2]+B(_,p)|0;K:{L:{M:{if(oa){R=0;N=1;if((_|0)<=0){break K}while(1){la=da+(m<<2)|0;K=_-R|0;r=0;o=C(0);G=eJ(P,i);N:{if((G|0)<0){break N}q=i;r=v[i>>2];K=(r|0)<(K|0)?r:K;ma=B(r,G);O:{P:{if(w[i+22|0]){G=0;if((K|0)>0){break P}break O}G=0;if((K|0)<=0){break O}while(1){r=la+(G<<2)|0;z[r>>2]=z[r>>2]+C(z[v[q+28>>2]+(G+ma<<2)>>2]+C(0));r=1;G=G+1|0;if((K|0)!=(G|0)){continue}break}break N}while(1){r=la+(G<<2)|0;o=C(o+z[v[q+28>>2]+(G+ma<<2)>>2]);z[r>>2]=z[r>>2]+o;o=C(o+z[q+12>>2]);r=1;G=G+1|0;if((K|0)!=(G|0)){continue}break}break N}r=1}if(!r){break M}r=v[i>>2];m=r+m|0;R=r+R|0;if((_|0)>(R|0)){continue}break}break K}R=0;q=(_|0)/v[i>>2]|0;if((q|0)<=0){break L}la=da+(m<<2)|0;while(1){ma=la+(R<<2)|0;G=_-(m+R|0)|0;K=q;r=0;o=C(0);va=eJ(P,i);Q:{if((va|0)<0){break Q}r=1;N=i;da=v[i>>2];wa=(G|0)>(da|0)?da:G;if((wa|0)<=0){break Q}da=B(da,va);G=0;while(1){r=ma+(B(G,K)<<2)|0;s=C(o+z[v[N+28>>2]+(G+da<<2)>>2]);z[r>>2]=z[r>>2]+s;o=w[N+22|0]?s:o;r=1;G=G+1|0;if((wa|0)!=(G|0)){continue}break}}if(!r){break M}R=R+1|0;if((q|0)!=(R|0)){continue}break}break L}N=0;break K}N=1}if(!N){break E}}k=k+1|0;if((k|0)!=(g|0)){continue}break}}p=p+1|0;n=n+1|0;if((V|0)<=(n|0)){break I}if((p|0)<(E|0)){continue}break}}j=j+1|0;if((p|0)<(E|0)){continue}break}}H=H+1|0;if((H|0)!=8){continue}break}break E}if((g|0)==(k|0)){break E}m=m+B(i,24)|0;r=m;P=(g|0)!=2;D=(E|0)<=0;N=(g|0)<3;n=0;while(1){R:{if(!P){k=0;H=0;if(D){break R}while(1){j=v[U>>2]+B(v[U+8>>2],k)|0;v[I+12>>2]=j&1;v[I+8>>2]=j>>1;if(!n){i=v[h+124>>2]+B(w[U+13|0],2096)|0;if(v[h+1396>>2]<=9){sl(h)}q=v[h+1392>>2];j=u[(i+((q&1023)<<1)|0)+36>>1];S:{if((j|0)>=0){K=q;q=w[j+v[i+8>>2]|0];v[h+1392>>2]=K>>>q;K=v[h+1396>>2]-q|0;q=(K|0)<0;v[h+1396>>2]=q?0:K;j=q?-1:j;break S}j=Cm(h,i)}j=w[i+23|0]?v[v[i+2088>>2]+(j<<2)>>2]:j;if((j|0)==-1){break E}v[v[F>>2]+(H<<2)>>2]=v[v[m+16>>2]+(j<<2)>>2]}T:{if((V|0)<=0){break T}i=0;if((k|0)>=(E|0)){break T}while(1){j=v[U+8>>2];q=u[(v[r+20>>2]+(w[v[v[F>>2]+(H<<2)>>2]+i|0]<<4)|0)+(n<<1)>>1];U:{if((q|0)>=0){if(gJ(h,v[h+124>>2]+B(q&65535,2096)|0,ia,2,I+12|0,I+8|0,p,j)){break U}break E}j=v[U>>2]+(j+B(j,k)|0)|0;v[I+8>>2]=j>>1;v[I+12>>2]=j&1}k=k+1|0;i=i+1|0;if((V|0)<=(i|0)){break T}if((k|0)<(E|0)){continue}break}}H=H+1|0;if((k|0)<(E|0)){continue}break}break R}if(N){break R}k=0;H=0;if(D){break R}while(1){i=v[U>>2]+B(v[U+8>>2],k)|0;j=(i|0)/(g|0)|0;v[I+12>>2]=i-B(g,j);v[I+8>>2]=j;if(!n){i=v[h+124>>2]+B(w[U+13|0],2096)|0;if(v[h+1396>>2]<=9){sl(h)}q=v[h+1392>>2];j=u[(i+((q&1023)<<1)|0)+36>>1];V:{if((j|0)>=0){K=q;q=w[j+v[i+8>>2]|0];v[h+1392>>2]=K>>>q;K=v[h+1396>>2]-q|0;q=(K|0)<0;v[h+1396>>2]=q?0:K;j=q?-1:j;break V}j=Cm(h,i)}j=w[i+23|0]?v[v[i+2088>>2]+(j<<2)>>2]:j;if((j|0)==-1){break E}v[v[F>>2]+(H<<2)>>2]=v[v[m+16>>2]+(j<<2)>>2]}W:{if((V|0)<=0){break W}i=0;if((k|0)>=(E|0)){break W}while(1){j=v[U+8>>2];q=u[(v[r+20>>2]+(w[v[v[F>>2]+(H<<2)>>2]+i|0]<<4)|0)+(n<<1)>>1];X:{if((q|0)>=0){if(gJ(h,v[h+124>>2]+B(q&65535,2096)|0,ia,g,I+12|0,I+8|0,p,j)){break X}break E}j=v[U>>2]+(j+B(j,k)|0)|0;q=(j|0)/(g|0)|0;v[I+8>>2]=q;v[I+12>>2]=j-B(g,q)}k=k+1|0;i=i+1|0;if((V|0)<=(i|0)){break W}if((k|0)<(E|0)){continue}break}}H=H+1|0;if((k|0)<(E|0)){continue}break}}n=n+1|0;if((n|0)!=8){continue}break}}if(!v[h+80>>2]){Yb(F)}v[h+92>>2]=xa;gb=I+16|0;c=c+1|0;if(c>>>0<w[na+8|0]){p=v[l+4>>2];continue}break}c=v[l+80>>2]}if(!(v[l+84>>2]!=v[l+92>>2]?c:0)){i=x[W>>1];if(i){h=(O|0)>1?O:1;g=l+800|0;while(1){c=i;i=c-1|0;if((ba|0)>=2){j=v[ha+4>>2]+B(i,3)|0;p=v[g+(w[j+1|0]<<2)>>2];j=v[g+(w[j|0]<<2)>>2];m=0;while(1){k=m<<2;n=k+p|0;A=z[n>>2];k=j+k|0;o=z[k>>2];Y:{if(o>C(0)){if(A>C(0)){s=C(o-A);break Y}s=o;o=C(o+A);break Y}if(A>C(0)){s=C(o+A);break Y}s=o;o=C(o-A)}z[k>>2]=o;z[n>>2]=s;m=m+1|0;if((h|0)!=(m|0)){continue}break}}if((c|0)>1){continue}break}}m=0;if(v[l+4>>2]<=0){break z}U=O<<2;while(1){g=m<<2;h=g+l|0;c=h;Z:{if(v[g+(S+320|0)>>2]){Qb(v[c+800>>2],0,U);break Z}g=ba;j=v[c+800>>2];P=v[h+996>>2];k=1;c=l;h=w[(W+w[(v[W+4>>2]+B(m,3)|0)+2|0]|0)+9|0];_:{if(!x[(c+(h<<1)|0)+132>>1]){ec(c,21);break _}r=g>>1;F=v[c+260>>2]+B(h,1596)|0;g=B(w[F+1588|0],u[P>>1]);c=0;n=v[F+1592>>2];if((n|0)>=2){G=F+1592|0;I=F+1588|0;while(1){h=w[(k+F|0)+838|0]<<1;i=u[h+P>>1];if((i|0)>=0){i=B(w[I|0],i&65535);h=x[(h+F|0)+338>>1];if((h|0)!=(c|0)){p=j;n=c;N=i-g|0;D=h-c|0;q=(N|0)/(D|0)|0;K=(h|0)>(r|0)?r:h;$:{if((K|0)<=(c|0)){break $}c=p+(n<<2)|0;z[c>>2]=z[((g&255)<<2)+69744>>2]*z[c>>2];c=n+1|0;if((K|0)<=(c|0)){break $}n=N>>31;E=n+N^n;N=q>>31;N=E-B(D,N+q^N)|0;n=n|1;H=0;while(1){E=p+(c<<2)|0;H=H+N|0;R=(H|0)<(D|0);g=(g+q|0)+(R?0:n)|0;z[E>>2]=z[((g&255)<<2)+69744>>2]*z[E>>2];H=H-(R?0:D)|0;c=c+1|0;if((K|0)!=(c|0)){continue}break}}n=v[G>>2];c=h}g=i}k=k+1|0;if((n|0)>(k|0)){continue}break}}if((c|0)<(r|0)){o=z[(g<<2)+69744>>2];while(1){g=j+(c<<2)|0;z[g>>2]=o*z[g>>2];c=c+1|0;if((r|0)!=(c|0)){continue}break}}}}m=m+1|0;c=v[l+4>>2];if((m|0)<(c|0)){continue}break}break A}aa(3382,10534,3335,2726);L()}aa(3382,10534,3302,2726);L()}m=0;if((c|0)<=0){break z}while(1){ha=w[ra+412|0];F=ba;V=F>>1;g=V<<2;r=l;oa=v[l+92>>2];p=v[(l+(m<<2)|0)+800>>2];c=V<<2;W=p+c|0;aa:{if(v[l+80>>2]){n=co(r,g);break aa}n=Cd(g)}h=(n+c|0)-8|0;i=v[(r+(ha<<2)|0)+1068>>2];ba:{if(F>>>0<2){c=i;break ba}g=p;c=i;while(1){z[h+4>>2]=C(z[g>>2]*z[c>>2])-C(z[g+8>>2]*z[c+4>>2]);z[h>>2]=C(z[g>>2]*z[c+4>>2])+C(z[g+8>>2]*z[c>>2]);c=c+8|0;h=h-8|0;g=g+16|0;if((W|0)!=(g|0)){continue}break}}if(h>>>0>=n>>>0){g=((V<<2)+p|0)-12|0;while(1){z[h+4>>2]=C(z[g>>2]*z[c+4>>2])-C(z[g+8>>2]*z[c>>2]);z[h>>2]=C(z[c>>2]*C(-z[g>>2]))-C(z[g+8>>2]*z[c+4>>2]);g=g-16|0;c=c+8|0;h=h-8|0;if(n>>>0<=h>>>0){continue}break}}ia=F>>2;if((F|0)>=16){c=ia<<2;h=c+n|0;k=c+p|0;c=(i+(V<<2)|0)-32|0;j=p;g=n;while(1){o=z[g>>2];s=z[h>>2];A=z[h+4>>2];J=z[g+4>>2];z[k+4>>2]=A+J;z[k>>2]=z[h>>2]+z[g>>2];A=C(A-J);o=C(s-o);z[j+4>>2]=C(A*z[c+16>>2])-C(o*z[c+20>>2]);z[j>>2]=C(o*z[c+16>>2])+C(A*z[c+20>>2]);o=z[g+8>>2];s=z[h+8>>2];A=z[h+12>>2];J=z[g+12>>2];z[k+12>>2]=A+J;z[k+8>>2]=z[h+8>>2]+z[g+8>>2];A=C(A-J);o=C(s-o);z[j+12>>2]=C(A*z[c>>2])-C(o*z[c+4>>2]);z[j+8>>2]=C(o*z[c>>2])+C(A*z[c+4>>2]);g=g+16|0;h=h+16|0;j=j+16|0;k=k+16|0;c=c-32|0;if(i>>>0<=c>>>0){continue}break}}D=Dm(F);g=F>>4;k=V-1|0;c=F>>3;h=0-c|0;fJ(g,p,k,h,i);fJ(g,p,k-ia|0,h,i);_=F>>5;g=0-g|0;dq(_,p,k,g,i,16);dq(_,p,k-c|0,g,i,16);dq(_,p,k-(c<<1)|0,g,i,16);dq(_,p,k+B(c,-3)|0,g,i,16);j=2;if((D|0)>=10){j=D-4>>>1|0;h=2;while(1){g=h;h=g+1|0;q=2<<g;if((q|0)>0){P=8<<g;N=F>>g+4;c=0;g=F>>g+2;K=0-(g>>1)|0;while(1){dq(N,p,k-B(c,g)|0,K,i,P);c=c+1|0;if((q|0)!=(c|0)){continue}break}}if((h|0)!=(j|0)){continue}break}}na=D-7|0;if((na|0)>(j|0)){while(1){g=j;j=g+1|0;c=F>>g+6;if((c|0)>0){N=2<<g;K=8<<g;da=K<<2;H=F>>g+2;U=0-(H>>1)|0;h=i;g=k;while(1){G=p;I=g;E=U;D=h;q=K;R=H;P=N;if((P|0)>0){la=D+B(q,12)|0;o=z[la>>2];ma=D+(q<<3)|0;s=z[ma>>2];q=D+(q<<2)|0;A=z[q>>2];J=z[la+4>>2];Q=z[ma+4>>2];X=z[q+4>>2];Y=z[D+4>>2];ea=z[D>>2];D=G+(I<<2)|0;G=D+(E<<2)|0;q=0-R<<2;while(1){I=G-4|0;T=z[I>>2];Z=z[D>>2];ca=z[G>>2];z[D>>2]=Z+ca;E=D-4|0;M=z[E>>2];z[E>>2]=M+z[I>>2];Z=C(Z-ca);M=C(M-T);z[I>>2]=C(Y*Z)+C(ea*M);z[G>>2]=C(ea*Z)-C(Y*M);I=G-12|0;Z=z[I>>2];E=D-8|0;M=z[E>>2];ka=E;E=G-8|0;ca=z[E>>2];z[ka>>2]=M+ca;R=D-12|0;T=z[R>>2];z[R>>2]=T+z[I>>2];M=C(M-ca);T=C(T-Z);z[I>>2]=C(X*M)+C(A*T);z[E>>2]=C(A*M)-C(X*T);I=G-20|0;Z=z[I>>2];E=D-16|0;M=z[E>>2];ka=E;E=G-16|0;ca=z[E>>2];z[ka>>2]=M+ca;R=D-20|0;T=z[R>>2];z[R>>2]=T+z[I>>2];M=C(M-ca);T=C(T-Z);z[I>>2]=C(Q*M)+C(s*T);z[E>>2]=C(s*M)-C(Q*T);I=G-28|0;Z=z[I>>2];E=D-24|0;M=z[E>>2];ka=E;E=G-24|0;ca=z[E>>2];z[ka>>2]=M+ca;R=D-28|0;T=z[R>>2];z[R>>2]=T+z[I>>2];M=C(M-ca);T=C(T-Z);z[I>>2]=C(J*M)+C(o*T);z[E>>2]=C(o*M)-C(J*T);G=q+G|0;D=q+D|0;I=P>>>0>1;P=P-1|0;if(I){continue}break}}g=g-8|0;h=(da<<2)+h|0;D=c>>>0>1;c=c-1|0;if(D){continue}break}}if((j|0)!=(na|0)){continue}break}}c=p;g=F;if((0-(_<<4)|0)<0){c=c+(k<<2)|0;h=c-(_<<6)|0;o=z[i+(g>>3<<2)>>2];ea=C(-o);while(1){Q=z[c>>2];g=c-32|0;X=z[g>>2];z[c>>2]=Q+X;j=c-4|0;s=z[j>>2];i=j;j=c-36|0;Y=z[j>>2];z[i>>2]=s+Y;i=c-8|0;A=z[i>>2];q=i;i=c-40|0;M=z[i>>2];z[q>>2]=A+M;k=c-12|0;J=z[k>>2];q=k;k=c-44|0;T=z[k>>2];z[q>>2]=J+T;z[g>>2]=Q-X;z[j>>2]=s-Y;j=c-16|0;s=z[j>>2];q=j;j=c-48|0;Z=z[j>>2];z[q>>2]=s+Z;A=C(A-M);J=C(J-T);z[i>>2]=o*C(A+J);z[k>>2]=o*C(J-A);i=c-28|0;A=z[i>>2];k=c-60|0;J=z[k>>2];D=c-24|0;Q=z[D>>2];q=c-56|0;X=z[q>>2];P=c-20|0;Y=z[P>>2];E=P;P=c-52|0;M=z[P>>2];z[E>>2]=Y+M;z[D>>2]=Q+X;z[i>>2]=A+J;z[j>>2]=Y-M;z[P>>2]=-C(s-Z);s=C(A-J);A=C(Q-X);z[q>>2]=o*C(s-A);z[k>>2]=C(A+s)*ea;dJ(c);dJ(g);c=c+-64|0;if(h>>>0<c>>>0){continue}break}}D=V-4|0;c=(n+(ia<<2)|0)-16|0;if(n>>>0<=c>>>0){h=n+(D<<2)|0;g=v[(r+(ha<<2)|0)+1100>>2];while(1){j=(x[g>>1]<<2)+p|0;z[h+12>>2]=z[j>>2];z[h+8>>2]=z[j+4>>2];z[c+12>>2]=z[j+8>>2];z[c+8>>2]=z[j+12>>2];j=(x[g+2>>1]<<2)+p|0;z[h+4>>2]=z[j>>2];z[h>>2]=z[j+4>>2];z[c+4>>2]=z[j+8>>2];z[c>>2]=z[j+12>>2];g=g+4|0;h=h-16|0;c=c-16|0;if(n>>>0<=c>>>0){continue}break}}h=n+(V<<2)|0;i=h-16|0;if(n>>>0<i>>>0){g=v[(r+(ha<<2)|0)+1084>>2];k=h;c=n;while(1){o=z[c+4>>2];j=k-4|0;s=z[j>>2];A=C(o-s);J=z[g+4>>2];o=C(o+s);s=z[c>>2];q=k-8|0;Q=z[q>>2];X=C(s-Q);Y=z[g>>2];ea=C(C(J*o)-C(X*Y));z[c+4>>2]=A+ea;s=C(s+Q);o=C(C(X*J)+C(o*Y));z[c>>2]=s+o;z[j>>2]=ea-A;z[q>>2]=s-o;o=z[c+12>>2];j=k-12|0;s=z[j>>2];A=C(o-s);J=z[g+12>>2];o=C(o+s);s=z[c+8>>2];Q=z[i>>2];X=C(s-Q);Y=z[g+8>>2];ea=C(C(J*o)-C(X*Y));z[c+12>>2]=A+ea;s=C(s+Q);o=C(C(X*J)+C(o*Y));z[c+8>>2]=s+o;z[i>>2]=s-o;z[j>>2]=ea-A;g=g+16|0;c=c+16|0;k=i;i=i-16|0;if(c>>>0<i>>>0){continue}break}}i=h-32|0;if(n>>>0<=i>>>0){c=v[(r+(ha<<2)|0)+1076>>2]+(V<<2)|0;g=(D<<2)+p|0;k=((F<<2)+p|0)-16|0;while(1){o=z[h-8>>2];s=z[c-4>>2];A=z[h-4>>2];J=z[c-8>>2];Q=C(C(o*s)-C(A*J));z[p>>2]=Q;z[g+12>>2]=-Q;o=C(C(J*C(-o))-C(s*A));z[W>>2]=o;z[k+12>>2]=o;o=z[h-16>>2];s=z[c-12>>2];A=z[h-12>>2];J=z[c-16>>2];Q=C(C(o*s)-C(A*J));z[p+4>>2]=Q;z[g+8>>2]=-Q;o=C(C(J*C(-o))-C(s*A));z[W+4>>2]=o;z[k+8>>2]=o;o=z[h-24>>2];s=z[c-20>>2];A=z[h-20>>2];J=z[c-24>>2];Q=C(C(o*s)-C(A*J));z[p+8>>2]=Q;z[g+4>>2]=-Q;o=C(C(J*C(-o))-C(s*A));z[W+8>>2]=o;z[k+4>>2]=o;o=z[i>>2];s=z[c-28>>2];A=z[h-28>>2];c=c-32|0;J=z[c>>2];Q=C(C(o*s)-C(A*J));z[p+12>>2]=Q;z[g>>2]=-Q;o=C(C(J*C(-o))-C(s*A));z[W+12>>2]=o;z[k>>2]=o;k=k-16|0;g=g-16|0;W=W+16|0;p=p+16|0;h=i;i=h-32|0;if(n>>>0<=i>>>0){continue}break}}if(!v[r+80>>2]){Yb(n)}v[r+92>>2]=oa;m=m+1|0;if((m|0)<v[l+4>>2]){continue}break}}jJ(l);ca:{if(w[l+1377|0]){v[l+1060>>2]=0-O;t[l+1377|0]=0;v[l+1064>>2]=1;v[l+1412>>2]=ba-pa;break ca}c=v[l+1412>>2];if(!c){break ca}g=qa-ga|0;if((g|0)<=(c|0)){v[l+1412>>2]=c-g;v[sa>>2]=qa;ga=qa;break ca}ga=c+ga|0;v[sa>>2]=ga;v[l+1412>>2]=0}g=v[l+1064>>2];c=l;da:{ea:{fa:{if(v[c+1388>>2]==v[c+1404>>2]){ga:{if(!g|!(w[l+1375|0]&4)){break ga}g=v[l+1408>>2];h=v[l+1060>>2];if(g>>>0>=h+(pa-ga|0)>>>0){break ga}c=g-h|0;c=(c>>>0>g>>>0?0:c)+ga|0;c=(c|0)>(pa|0)?pa:c;v[fa+12>>2]=c;v[l+1060>>2]=c+v[l+1060>>2];break da}v[l+1064>>2]=1;g=v[l+1408>>2]+(ga-O|0)|0;break fa}if(!g){break ea}g=v[l+1060>>2]}v[c+1060>>2]=(qa-ga|0)+g}if(v[l+84>>2]!=v[l+92>>2]?v[l+80>>2]:0){break p}v[fa+12>>2]=pa}c=1}gb=S+2368|0;break o}aa(3382,10534,3451,2726);L()}}else{c=0}gb=ja+16|0;if(!c){ha:{ia:{ja:{c=v[a+100>>2];switch(c-32|0){case 0:break ia;case 3:break ja;default:break ha}}v[a+100>>2]=0;while(1){if(Aa=0,Ba=(ph(a)|0)!=-1,Ca=v[a+96>>2],Ca?Aa:Ba){continue}break}v[f>>2]=0;b=v[a+32>>2]-b|0;break a}if(v[a+992>>2]){break ha}v[a+100>>2]=0;while(1){if(Aa=0,Ba=(ph(a)|0)!=-1,Ca=v[a+96>>2],Ca?Aa:Ba){continue}break}v[f>>2]=0;b=v[a+32>>2]-b|0;break a}v[a+1420>>2]=0;v[a+992>>2]=0;v[a+1504>>2]=0;v[a+1508>>2]=0;v[a+1412>>2]=0;v[a+1416>>2]=0;t[a+1377|0]=0;v[a+1064>>2]=0;v[a+100>>2]=c;v[f>>2]=0;b=1;break a}j=fa;p=v[j+12>>2];n=v[j+4>>2];k=n;g=v[j+8>>2];ka:{la:{ma:{na:{c=a;i=v[c+992>>2];oa:{if(!i){h=v[c+4>>2];i=0;break oa}F=i<<1;pa:{if((F|0)==v[c+112>>2]){h=l+1092|0}else{h=0;if((F|0)!=v[l+116>>2]){break pa}h=l+1096|0}h=v[h>>2]}l=h;if(!l){break la}h=v[c+4>>2];if((h|0)<=0){break na}F=(i|0)<=0;while(1){if(!F){ba=c+($<<2)|0;m=ba;h=0;while(1){S=v[ba+800>>2]+(h+k<<2)|0;q=S;s=z[S>>2];S=h<<2;z[q>>2]=C(s*z[S+l>>2])+C(z[S+v[m+928>>2]>>2]*z[l+(i+(h^-1)<<2)>>2]);h=h+1|0;if((i|0)!=(h|0)){continue}break}h=v[c+4>>2]}$=$+1|0;if(($|0)<(h|0)){continue}break}i=v[c+992>>2]}F=p-g|0;v[c+992>>2]=F;if((h|0)>0){$=0;while(1){if((g|0)<(p|0)){ba=c+($<<2)|0;m=ba;h=0;l=g;while(1){z[v[m+928>>2]+(h<<2)>>2]=z[v[ba+800>>2]+(l<<2)>>2];h=h+1|0;l=g+h|0;if((h|0)!=(F|0)){continue}break}h=v[c+4>>2]}$=$+1|0;if(($|0)<(h|0)){continue}break}}if(!i){break la}break ma}v[c+992>>2]=p-g}h=c;i=v[c+1416>>2];c=((g|0)>(p|0)?p:g)-k|0;v[h+1416>>2]=i+c;break ka}c=0}g=c;v[j+12>>2]=c;l=v[a+4>>2];if((l|0)>0){c=0;while(1){h=(c<<2)+a|0;v[h+864>>2]=v[h+800>>2]+(n<<2);c=c+1|0;if((l|0)!=(c|0)){continue}break}}if(d){v[d>>2]=l}v[f>>2]=g;v[e>>2]=a+864;b=v[a+32>>2]-b|0}gb=fa+16|0;return b|0}function o6(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,A=0,E=C(0),F=0,G=0,I=0,J=C(0),K=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=C(0);s=gb-1520|0;gb=s;f=s+8|0;g=Qb(f,0,1512);if(e){h=v[e+4>>2];v[g+80>>2]=v[e>>2];v[g+84>>2]=h;e=h&-8;v[g+92>>2]=e;v[g+84>>2]=e}v[g+96>>2]=0;v[g+100>>2]=0;v[g+1420>>2]=-1;v[g+124>>2]=0;v[g+32>>2]=0;t[s+56|0]=1;v[s+48>>2]=a+b;v[s+40>>2]=a;b=0;p=gb-1024|0;gb=p;t[f+1377|0]=1;a:{if(!qt(f)){break a}e=w[f+1375|0];if(!(e&2)){ec(f,34);break a}if(e&4){ec(f,34);break a}if(e&1){ec(f,34);break a}if(v[f+1116>>2]!=1){ec(f,34);break a}e=w[f+1120|0];if((e|0)!=30){b:{if((e|0)!=64){break b}if(!my(f,p+1018|0,6)|w[p+1018|0]!=102|(w[p+1019|0]!=105|w[p+1020|0]!=115)){break b}if(w[p+1021|0]!=104|w[p+1022|0]!=101|w[p+1023|0]!=97){break b}if((Ne(f)|0)!=100){break b}if(Ne(f)){break b}ec(f,38);break a}ec(f,34);break a}if((Ne(f)|0)!=1){ec(f,34);break a}if(!my(f,p+1018|0,6)){ec(f,10);break a}if(!ly(p+1018|0)){ec(f,34);break a}if(yj(f)){ec(f,34);break a}e=Ne(f);v[f+4>>2]=e;if(!e){ec(f,34);break a}if(e>>>0>=17){ec(f,5);break a}e=yj(f);v[f>>2]=e;if(!e){ec(f,34);break a}yj(f);yj(f);yj(f);e=Ne(f);h=e>>>4|0;v[f+116>>2]=1<<h;g=e&15;v[f+112>>2]=1<<g;if(g-6>>>0>=8){ec(f,20);break a}if((e<<24)-1610612736>>24<0){ec(f,20);break a}if(g>>>0>h>>>0){ec(f,20);break a}if(!(Ne(f)&1)){ec(f,34);break a}if(!qt(f)){break a}if(!ky(f)){break a}if(!jy(f)){break a}c:{d:{if((ph(f)|0)==3){while(1){Q=(p+1018|0)+b|0,R=ph(f),t[Q|0]=R;b=b+1|0;if((b|0)!=6){continue}break}if(!ly(p+1018|0)){ec(f,20);break c}g=iy(f);e=$d(f,g+1|0);v[f+20>>2]=e;if(e){b=0;if((g|0)>0){while(1){e=ph(f);t[v[f+20>>2]+b|0]=e;b=b+1|0;if((g|0)!=(b|0)){continue}break}e=v[f+20>>2]}t[e+g|0]=0;b=iy(f);v[f+28>>2]=0;v[f+24>>2]=b;e:{f:{if((b|0)<=0){break f}b=$d(f,b<<2);v[f+28>>2]=b;if(!b){ec(f,3);break c}if(v[f+24>>2]<=0){break f}while(1){g=iy(f);b=$d(f,g+1|0);h=i<<2;v[h+v[f+28>>2]>>2]=b;e=v[h+v[f+28>>2]>>2];if(!e){break e}b=0;if((g|0)>0){while(1){e=ph(f);t[v[h+v[f+28>>2]>>2]+b|0]=e;b=b+1|0;if((g|0)!=(b|0)){continue}break}e=v[h+v[f+28>>2]>>2]}t[e+g|0]=0;i=i+1|0;if((i|0)<v[f+24>>2]){continue}break}}if(!(ph(f)&1)){ec(f,20);break c}lJ(f,w[f+1376|0]);t[f+1376|0]=0;while(1){b=jy(f);lJ(f,b);t[f+1376|0]=0;if(b){continue}break}b=0;if(!ky(f)){break a}if(!mJ(f)){if(v[f+100>>2]!=21){break a}v[f+100>>2]=20;break a}e=0;while(1){h=e<<24;g=0;while(1){h=h>>31&79764919^h<<1;g=g+1|0;if((g|0)!=8){continue}break}v[(e<<2)+459504>>2]=h;e=e+1|0;if((e|0)!=256){continue}break}if((ph(f)|0)==5){while(1){Q=(p+1018|0)+b|0,R=ph(f),t[Q|0]=R;b=b+1|0;if((b|0)!=6){continue}break}if(!ly(p+1018|0)){ec(f,20);break c}b=nc(f,8)+1|0;v[f+120>>2]=b;b=$d(f,B(b,2096));v[f+124>>2]=b;if(!b){ec(f,3);break c}Qb(b,0,B(v[f+120>>2],2096));g:{h:{i:{j:{if(v[f+120>>2]>0){while(1){b=v[f+124>>2];if((nc(f,8)&255)!=66){ec(f,20);break c}if((nc(f,8)&255)!=67){ec(f,20);break c}if((nc(f,8)&255)!=86){ec(f,20);break c}e=b+B(G,2096)|0;Q=e,R=nc(f,8)&255|nc(f,8)<<8,v[Q>>2]=R;Q=e,R=nc(f,8)&255|(nc(f,8)<<8&65280|nc(f,8)<<16),v[Q+4>>2]=R;b=0;k=nc(f,1);if(!k){b=nc(f,1)}t[e+23|0]=b;q=e+4|0;g=v[q>>2];k:{if(v[e>>2]){h=g;break k}h=0;if(!g){break k}ec(f,20);break c}l:{if(b&255){h=co(f,h);break l}h=$d(f,h);v[e+8>>2]=h}if(!h){ec(f,3);break c}m:{if(!k){b=0;j=0;g=v[q>>2];if((g|0)<=0){break m}while(1){n:{o:{if(w[e+23|0]){if(!nc(f,1)){break o}}g=nc(f,5)+1|0;t[b+h|0]=g;if((g&255)!=32){j=j+1|0;break n}ec(f,20);break c}t[b+h|0]=255}b=b+1|0;g=v[q>>2];if((b|0)<(g|0)){continue}break}break m}i=nc(f,5);j=0;b=0;g=v[q>>2];if((g|0)<=0){break m}while(1){k=nc(f,Dm(g-b|0));i=i+1|0;if((i|0)>=32){ec(f,20);break c}g=b+k|0;if((g|0)>v[q>>2]){ec(f,20);break c}Qb(b+h|0,i,k);b=g;g=v[q>>2];if((b|0)<(g|0)){continue}break}}p:{q:{if(w[e+23|0]){if(g>>2>(j|0)){break q}b=e;k=f;if(v[f+16>>2]<(g|0)){v[f+16>>2]=g;g=v[q>>2]}j=b;b=$d(k,g);v[j+8>>2]=b;if(!b){ec(f,3);break c}hc(b,h,v[q>>2]);xj(f,h,v[q>>2]);h=v[e+8>>2];t[e+23|0]=0;g=v[q>>2]}k=0;b=0;i=0;if((g|0)>0){while(1){i=((w[b+h|0]-11&255)>>>0<244)+i|0;b=b+1|0;if((g|0)!=(b|0)){continue}break}}v[e+2092>>2]=i;b=$d(f,g<<2);v[e+32>>2]=b;if(b){l=e+2092|0;break p}ec(f,3);break c}v[e+2092>>2]=j;l=e+2092|0;r:{if(!j){k=0;b=0;break r}b=$d(f,j);v[e+8>>2]=b;if(!b){ec(f,3);break c}b=co(f,v[l>>2]<<2);v[e+32>>2]=b;if(!b){ec(f,3);break c}k=co(f,v[l>>2]<<2);if(!k){break j}g=v[q>>2];b=v[l>>2]}b=(b<<3)+g|0;if(b>>>0<=y[f+16>>2]){break p}v[f+16>>2]=b}j=e;o=h;n=v[q>>2];i=k;m=0;b=gb-128|0;gb=b;A=Qb(b,0,128);s:{t:{u:{v:{w:{x:{y:{z:{if((n|0)<=0){break z}while(1){if(w[m+o|0]!=255){break z}m=m+1|0;if((n|0)!=(m|0)){continue}break}break y}if((m|0)!=(n|0)){break x}}g=1;if(!v[j+2092>>2]){break w}aa(12835,10534,1103,4632);L()}b=m+o|0;g=w[b|0];if(g>>>0>=32){break v}cJ(j,0,m,0,g,i);g=w[b|0];if(g){b=1;while(1){v[A+(b<<2)>>2]=1<<32-b;r=(b|0)==(g|0);b=b+1|0;if(!r){continue}break}}K=1;r=m+1|0;if((n|0)<=(r|0)){g=1;break w}while(1){M=o+r|0;m=w[M|0];A:{if((m|0)==255){break A}if(m>>>0>31){break u}g=0;b=m;if(!b){break w}while(1){N=A+(b<<2)|0;I=v[N>>2];if(!I){I=(b|0)>1;b=b-1|0;if(I){continue}break w}break}v[N>>2]=0;cJ(j,Bm(I),r,K,m,i);K=K+1|0;m=w[M|0];if(m>>>0<=b>>>0){break A}while(1){g=A+(m<<2)|0;if(v[g>>2]){break t}v[g>>2]=I+(1<<32-m);m=m-1|0;if((m|0)>(b|0)){continue}break}}g=1;r=r+1|0;if((n|0)!=(r|0)){continue}break}}gb=A+128|0;break s}aa(12363,10534,1104,4632);L()}aa(12356,10534,1118,4632);L()}aa(12879,10534,1133,4632);L()}if(!g){if(w[e+23|0]){xj(f,k,0)}ec(f,20);break c}b=v[l>>2];if(b){b=$d(f,(b<<2)+4|0);v[e+2084>>2]=b;if(!b){ec(f,3);break c}b=$d(f,(v[l>>2]<<2)+4|0);v[e+2088>>2]=b;if(!b){ec(f,3);break c}v[e+2088>>2]=b+4;v[b>>2]=-1;m=h;o=k;i=0;n=0;B:{b=e;if(w[b+23|0]){n=v[b+2092>>2];if((n|0)<=0){break B}while(1){g=i<<2;Q=g+v[b+2084>>2]|0,R=Bm(v[g+v[b+32>>2]>>2]),v[Q>>2]=R;i=i+1|0;n=v[b+2092>>2];if((i|0)<(n|0)){continue}break}break B}if(v[b+4>>2]>0){while(1){if(bJ(b,w[i+m|0])){Q=v[b+2084>>2]+(n<<2)|0,R=Bm(v[v[b+32>>2]+(i<<2)>>2]),v[Q>>2]=R;n=n+1|0}i=i+1|0;if((i|0)<v[b+4>>2]){continue}break}}if(v[b+2092>>2]==(n|0)){break B}aa(4573,10534,1200,7252);L()}RI(v[b+2084>>2],n,2284);v[v[b+2084>>2]+(v[b+2092>>2]<<2)>>2]=-1;C:{n=w[b+23|0];I=v[b+(n?2092:4)>>2];if((I|0)<=0){break C}g=0;while(1){D:{j=g;i=b;if(n&255){j=v[o+(g<<2)>>2]}M=w[j+m|0];E:{if(!bJ(i,M)){break E}N=g<<2;j=Bm(v[N+v[b+32>>2]>>2]);A=v[b+2084>>2];i=0;n=v[b+2092>>2];if((n|0)>=2){while(1){r=n>>>1|0;O=r+i|0;K=j>>>0<y[A+(O<<2)>>2];i=K?i:O;n=K?r:n-r|0;if((n|0)>1){continue}break}}n=i<<2;if((j|0)!=v[n+A>>2]){break D}if(w[b+23|0]){v[n+v[b+2088>>2]>>2]=v[o+N>>2];t[v[b+8>>2]+i|0]=M;break E}v[n+v[b+2088>>2]>>2]=g}g=g+1|0;if((I|0)==(g|0)){break C}n=w[b+23|0];continue}break}aa(9485,10534,1230,7252);L()}}if(w[e+23|0]){xj(f,k,v[l>>2]<<2);xj(f,v[e+32>>2],v[l>>2]<<2);xj(f,h,v[q>>2]);v[e+32>>2]=0}b=e;Qb(b+36|0,255,2048);g=v[b+(w[b+23|0]?2092:4)>>2];if((g|0)>0){j=g>>>0<32767?g:32767;k=v[b+8>>2];h=0;while(1){F:{if(w[h+k|0]>10){break F}G:{if(w[b+23|0]){g=Bm(v[v[b+2084>>2]+(h<<2)>>2]);break G}g=v[v[b+32>>2]+(h<<2)>>2]}if(g>>>0>1023){break F}while(1){u[(b+(g<<1)|0)+36>>1]=h;k=v[b+8>>2];g=(1<<w[k+h|0])+g|0;if(g>>>0<1024){continue}break}}h=h+1|0;if((j|0)!=(h|0)){continue}break}}b=nc(f,4);t[e+21|0]=b;b=b&255;if(b>>>0>=3){ec(f,20);break c}if(b){Q=e,S=kJ(nc(f,32)),z[Q+12>>2]=S;Q=e,S=kJ(nc(f,32)),z[Q+16>>2]=S;Q=e,R=nc(f,4)+1|0,t[Q+20|0]=R;Q=e,R=nc(f,1),t[Q+22|0]=R;h=v[e>>2];g=v[q>>2];H:{if(w[e+21|0]==1){F=H(cx(+C(C(Tp(+C(g|0)))/C(h|0))));I:{if(D(F)<2147483648){b=~~F;break I}b=-2147483648}F=+(h|0);P=H(hk(+C(C(b|0)+C(1)),F));J:{if(D(P)<2147483648){h=~~P;break J}h=-2147483648}b=((h|0)<=(g|0))+b|0;E=C(b|0);if(hk(+C(E+C(1)),F)<=+(g|0)){b=-1}else{F=H(hk(+E,F));K:{if(D(F)<2147483648){h=~~F;break K}h=-2147483648}b=(h|0)>(g|0)?-1:b}if((b|0)>=0){break H}ec(f,20);break c}b=B(g,h)}v[e+24>>2]=b;if(!b){ec(f,20);break c}g=co(f,b<<1);if(!g){break i}b=0;i=v[e+24>>2];if((i|0)>0){while(1){h=nc(f,w[e+20|0]);if((h|0)==-1){xj(f,g,v[e+24>>2]<<1);ec(f,20);break c}u[g+(b<<1)>>1]=h;b=b+1|0;i=v[e+24>>2];if((b|0)<(i|0)){continue}break}}L:{if(w[e+21|0]==1){h=w[e+23|0];M:{if(h){b=v[l>>2];if(b){break M}break L}b=v[q>>2]}b=$d(f,B(v[e>>2],b)<<2);v[e+28>>2]=b;if(!b){xj(f,g,v[e+24>>2]<<1);ec(f,3);break c}o=v[(h?l:q)>>2];if((o|0)>0){n=e+2088|0;E=C(0);m=0;while(1){l=m;l=h?v[v[n>>2]+(l<<2)>>2]:l;N:{k=v[e>>2];if((k|0)<=0){break N}j=v[e+24>>2];b=1;i=0;while(1){J=C(E+C(C(z[e+16>>2]*C(x[g+(((l>>>0)/(b>>>0)>>>0)%(j>>>0)<<1)>>1]))+z[e+12>>2]));z[v[e+28>>2]+(B(k,m)+i<<2)>>2]=J;E=w[e+22|0]?J:E;i=i+1|0;k=v[e>>2];if((i|0)>=(k|0)){break N}j=v[e+24>>2];kqa(j,0,b,0);if(jb){xj(f,g,j<<1);ec(f,20);break c}else{b=B(b,j);continue}}}m=m+1|0;if((o|0)!=(m|0)){continue}break}}t[e+21|0]=2;i=v[e+24>>2];break L}b=$d(f,i<<2);v[e+28>>2]=b;i=v[e+24>>2];if(!b){break h}if((i|0)<=0){break L}E=C(0);J=C(C(C(z[e+16>>2]*C(x[g>>1]))+z[e+12>>2])+C(0));z[b>>2]=J;b=1;i=v[e+24>>2];if((i|0)<=1){break L}while(1){E=w[e+22|0]?J:E;J=C(E+C(C(z[e+16>>2]*C(x[g+(b<<1)>>1]))+z[e+12>>2]));z[v[e+28>>2]+(b<<2)>>2]=J;b=b+1|0;i=v[e+24>>2];if((b|0)<(i|0)){continue}break}}xj(f,g,i<<1)}G=G+1|0;if((G|0)<v[f+120>>2]){continue}break}}O:{e=nc(f,6)+1&255;if(!e){break O}b=0;while(1){if(!nc(f,16)){b=b+1|0;if((e|0)!=(b|0)){continue}break O}break}ec(f,20);break c}b=nc(f,6)+1|0;v[f+128>>2]=b;b=$d(f,B(b,1596));v[f+260>>2]=b;if(!b){break g}m=0;if(v[f+128>>2]<=0){break d}G=0;P:while(1){b=nc(f,16);u[((m<<1)+f|0)+132>>1]=b;b=b&65535;if(b>>>0>=2){ec(f,20);break c}if(!b){e=v[f+260>>2]+B(m,1596)|0;Q=e,R=nc(f,8),t[Q|0]=R;Q=e,R=nc(f,16),u[Q+2>>1]=R;Q=e,R=nc(f,16),u[Q+4>>1]=R;Q=e,R=nc(f,6),t[Q+6|0]=R;Q=e,R=nc(f,8),t[Q+7|0]=R;b=(nc(f,4)&255)+1|0;t[e+8|0]=b;if((b|0)==(b&255)){g=e+9|0;b=0;while(1){Q=b+g|0,R=nc(f,8),t[Q|0]=R;b=b+1|0;if(b>>>0<w[e+8|0]){continue}break}}ec(f,4);break c}l=v[f+260>>2]+B(m,1596)|0;e=nc(f,5);t[l|0]=e;b=-1;i=0;g=0;if(e&255){while(1){e=nc(f,4);t[(g+l|0)+1|0]=e;e=e&255;b=(b|0)<(e|0)?e:b;g=g+1|0;if(g>>>0<w[l|0]){continue}break}while(1){e=i+l|0;Q=e,R=nc(f,3)+1|0,t[Q+33|0]=R;g=nc(f,2);t[e+49|0]=g;Q:{if(g&255){g=nc(f,8);t[e+65|0]=g;if(v[f+120>>2]<=(g&255)){ec(f,20);break c}if(w[e+49|0]==31){break Q}}g=0;while(1){R:{h=nc(f,8)-1|0;u[((l+(i<<4)|0)+(g<<1)|0)+82>>1]=h;if(v[f+120>>2]<=h<<16>>16){break R}g=g+1|0;if((g|0)<1<<w[e+49|0]){continue}break Q}break}ec(f,20);break c}e=(b|0)!=(i|0);i=i+1|0;if(e){continue}break}}h=2;Q=l,R=nc(f,2)+1|0,t[Q+1588|0]=R;b=nc(f,4);v[l+1592>>2]=2;k=0;u[l+338>>1]=0;t[l+1589|0]=b;u[l+340>>1]=1<<b;o=l+1592|0;j=w[l|0];S:{if(j){b=l+1589|0;while(1){g=0;e=l+w[(k+l|0)+1|0]|0;if(w[e+33|0]){while(1){h=nc(f,w[b|0]);u[(l+(v[o>>2]<<1)|0)+338>>1]=h;h=v[o>>2]+1|0;v[o>>2]=h;g=g+1|0;if(g>>>0<w[e+33|0]){continue}break}j=w[l|0]}k=k+1|0;if(k>>>0<(j&255)>>>0){continue}break}if((h|0)<=0){break S}}g=0;while(1){b=x[(l+(g<<1)|0)+338>>1];e=(p+16|0)+(g<<2)|0;u[e+2>>1]=g;u[e>>1]=b;h=v[o>>2];g=g+1|0;if((h|0)>(g|0)){continue}break}}k=l+338|0;RI(p+16|0,h,2283);g=0;h=v[o>>2];b=h-1|0;b=(b|0)>0?b:0;while(1){if((b|0)==(g|0)){g=0;T:{if((h|0)<=0){break T}while(1){t[(g+l|0)+838|0]=w[((p+16|0)+(g<<2)|0)+2|0];h=v[o>>2];g=g+1|0;if((h|0)>(g|0)){continue}break}g=2;if((h|0)<=2){break T}while(1){v[p+12>>2]=0;v[p+8>>2]=0;b=k;h=0;e=g;if((e|0)>0){i=b+(e<<1)|0;n=-1;q=65536;while(1){A=b+(h<<1)|0;j=x[A>>1];if(!((n|0)>=(j|0)|x[i>>1]<=j>>>0)){v[p+12>>2]=h;j=x[A>>1];n=j}if(!((j|0)>=(q|0)|x[i>>1]>=j>>>0)){v[p+8>>2]=h;q=x[A>>1]}h=h+1|0;if((e|0)!=(h|0)){continue}break}}b=l+(g<<1)|0;t[b+1088|0]=v[p+12>>2];t[b+1089|0]=v[p+8>>2];h=v[o>>2];g=g+1|0;if((h|0)>(g|0)){continue}break}}G=(h|0)>(G|0)?h:G;m=m+1|0;if((m|0)<v[f+128>>2]){continue P}m=G<<1;break d}e=p+16|0;j=x[e+(g<<2)>>1];g=g+1|0;if((j|0)!=x[e+(g<<2)>>1]){continue}break}break}ec(f,20);break c}ec(f,3);break c}ec(f,3);break c}xj(f,g,i<<1);ec(f,3);break c}ec(f,3);break c}ec(f,20);break c}ec(f,3);break c}ec(f,3);break c}ec(f,20);break c}b=nc(f,6)+1|0;v[f+264>>2]=b;b=$d(f,B(b,24));v[f+396>>2]=b;if(!b){ec(f,3);break c}l=0;Qb(b,0,B(v[f+264>>2],24));U:{if(v[f+264>>2]>0){while(1){b=v[f+396>>2];e=nc(f,16);u[((l<<1)+f|0)+268>>1]=e;if((e&65535)>>>0>=3){ec(f,20);break c}h=b+B(l,24)|0;Q=h,R=nc(f,24),v[Q>>2]=R;b=nc(f,24);v[h+4>>2]=b;if(b>>>0<y[h>>2]){ec(f,20);break c}Q=h,R=nc(f,24)+1|0,v[Q+8>>2]=R;Q=h,R=nc(f,6)+1|0,t[Q+12|0]=R;b=nc(f,8);t[h+13|0]=b;V:{W:{if(v[f+120>>2]>(b&255)){b=0;if(w[h+12|0]){break W}g=0;break V}ec(f,20);break c}while(1){g=(p+16|0)+b|0;j=nc(f,3);if(nc(f,1)){e=nc(f,5)}else{e=0}t[g|0]=j+(e<<3);b=b+1|0;g=w[h+12|0];if(b>>>0<g>>>0){continue}break}}b=$d(f,g<<4);v[h+20>>2]=b;if(!b){break U}if(w[h+12|0]){k=0;while(1){e=w[(p+16|0)+k|0];b=0;while(1){X:{if(e>>>b&1){g=nc(f,8);o=b<<1;j=k<<4;u[o+(j+v[h+20>>2]|0)>>1]=g;if(v[f+120>>2]>u[o+(j+v[h+20>>2]|0)>>1]){break X}ec(f,20);break c}u[(v[h+20>>2]+(k<<4)|0)+(b<<1)>>1]=65535}b=b+1|0;if((b|0)!=8){continue}break}k=k+1|0;if(k>>>0<w[h+12|0]){continue}break}}b=$d(f,v[(v[f+124>>2]+B(w[h+13|0],2096)|0)+4>>2]<<2);v[h+16>>2]=b;if(!b){ec(f,3);break c}j=0;Qb(b,0,v[(v[f+124>>2]+B(w[h+13|0],2096)|0)+4>>2]<<2);b=v[f+124>>2];g=w[h+13|0];if(v[(b+B(g,2096)|0)+4>>2]>0){while(1){e=v[B(g,2096)+b>>2];b=$d(f,e);k=j<<2;v[k+v[h+16>>2]>>2]=b;Y:{g=v[k+v[h+16>>2]>>2];if(g){if((e|0)<=0){break Y}b=e-1|0;t[g+b|0]=(j>>>0)%w[h+12|0];g=j;if((e|0)==1){break Y}while(1){e=b-1|0;o=w[h+12|0];g=(g|0)/(o|0)|0;t[e+v[k+v[h+16>>2]>>2]|0]=(g|0)%(o|0);o=b>>>0>1;b=e;if(o){continue}break}break Y}ec(f,3);break c}j=j+1|0;b=v[f+124>>2];g=w[h+13|0];if((j|0)<v[(b+B(g,2096)|0)+4>>2]){continue}break}}l=l+1|0;if((l|0)<v[f+264>>2]){continue}break}}b=nc(f,6)+1|0;v[f+400>>2]=b;b=$d(f,B(b,40));v[f+404>>2]=b;if(!b){ec(f,3);break c}k=0;Qb(b,0,B(v[f+400>>2],40));if(v[f+400>>2]>0){while(1){b=v[f+404>>2];if(nc(f,16)){ec(f,20);break c}e=b+B(k,40)|0;b=$d(f,B(v[f+4>>2],3));v[e+4>>2]=b;if(!b){ec(f,3);break c}b=e;if(nc(f,1)){g=nc(f,4)+1|0}else{g=1}t[b+8|0]=g;Z:{if(nc(f,1)){b=nc(f,8)+1|0;u[e>>1]=b;_:{g=v[f+4>>2];b=b&65535;if((g|0)>=(b|0)){j=0;if(b){break _}break Z}ec(f,20);break c}while(1){g=nc(f,Dm(g-1|0));b=B(j,3);t[b+v[e+4>>2]|0]=g;g=nc(f,Dm(v[f+4>>2]-1|0));t[(b+v[e+4>>2]|0)+1|0]=g;g=v[f+4>>2];b=b+v[e+4>>2]|0;h=w[b|0];if((g|0)<=(h|0)){ec(f,20);break c}b=w[b+1|0];if((b|0)>=(g|0)){ec(f,20);break c}if((b|0)!=(h|0)){j=j+1|0;if(j>>>0>=x[e>>1]){break Z}continue}break}ec(f,20);break c}u[e>>1]=0}if(nc(f,2)){ec(f,20);break c}h=v[f+4>>2];$:{aa:{b=w[e+8|0];if(b>>>0<=1){g=0;if((h|0)>0){while(1){t[(v[e+4>>2]+B(g,3)|0)+2|0]=0;g=g+1|0;if((g|0)<v[f+4>>2]){continue}break}b=w[e+8|0]}if(!(b&255)){break $}break aa}g=0;if((h|0)<=0){break aa}while(1){ba:{b=nc(f,4);h=B(g,3);t[(h+v[e+4>>2]|0)+2|0]=b;if(w[(h+v[e+4>>2]|0)+2|0]>=w[e+8|0]){break ba}g=g+1|0;if((g|0)<v[f+4>>2]){continue}break aa}break}ec(f,20);break c}b=0;while(1){nc(f,8);h=b+e|0;g=h;Q=g,R=nc(f,8),t[Q+9|0]=R;h=nc(f,8);t[g+24|0]=h;if(v[f+128>>2]<=w[g+9|0]){ec(f,20);break c}if(v[f+264>>2]>(h&255)){b=b+1|0;if(b>>>0>=w[e+8|0]){break $}continue}break}ec(f,20);break c}k=k+1|0;if((k|0)<v[f+400>>2]){continue}break}}b=nc(f,6);v[f+408>>2]=b+1;ca:{if(b>>>0>=2147483647){break ca}g=0;while(1){b=B(g,6)+f|0;Q=b,R=nc(f,1),t[Q+412|0]=R;Q=b,R=nc(f,16),u[Q+414>>1]=R;Q=b,R=nc(f,16),u[Q+416>>1]=R;e=nc(f,8);t[b+413|0]=e;if(x[b+414>>1]){ec(f,20);break c}if(x[b+416>>1]){ec(f,20);break c}if(v[f+400>>2]>(e&255)){g=g+1|0;if((g|0)>=v[f+408>>2]){break ca}continue}break}ec(f,20);break c}jJ(f);b=0;v[f+992>>2]=0;if(v[f+4>>2]>0){while(1){e=(b<<2)+f|0;Q=e,R=$d(f,v[f+116>>2]<<2),v[Q+800>>2]=R;Q=e,R=$d(f,v[f+116>>2]<<1&2147483646),v[Q+928>>2]=R;g=$d(f,m);v[e+996>>2]=g;h=v[e+800>>2];if(g?!h|!v[e+928>>2]:1){ec(f,3);break c}Qb(h,0,v[f+116>>2]<<2);b=b+1|0;if((b|0)<v[f+4>>2]){continue}break}}b=0;if(!iJ(f,0,v[f+112>>2])){break a}if(!iJ(f,1,v[f+116>>2])){break a}v[f+104>>2]=v[f+112>>2];h=v[f+116>>2];v[f+108>>2]=h;g=(h|0)/2|0;l=f;m=h<<1&2147483646;q=m;o=v[f+264>>2];if((o|0)<=0){e=4}else{i=v[f+396>>2];h=0;j=0;while(1){k=i+B(j,24)|0;n=v[k+4>>2];e=g>>>0>n>>>0?n:g;n=v[k>>2];k=(e-(g>>>0>n>>>0?n:g)>>>0)/y[k+8>>2]|0;h=(h|0)<(k|0)?k:h;j=j+1|0;if((o|0)!=(j|0)){continue}break}e=(h<<2)+4|0}e=B(e,v[f+4>>2]);e=e>>>0<m>>>0?q:e;v[l+12>>2]=e;da:{ea:{if(!v[f+80>>2]){break ea}g=v[f+92>>2];if((g|0)!=v[f+84>>2]){break da}if(g>>>0>=(e+v[f+88>>2]|0)+1512>>>0){break ea}ec(f,3);break a}if(v[f+1380>>2]==-1){v[f+52>>2]=w[f+48|0]?0:v[f+32>>2]-v[f+36>>2]|0;b=1;break a}v[f+52>>2]=0;b=1;break a}aa(4388,10534,4196,5960);L()}ec(f,3)}b=0}gb=p+1024|0;fa:{ga:{if(!b){v[d>>2]=v[s+104>>2]?1:v[s+108>>2];break ga}b=$d(s+8|0,1512);if(b){Q=c,R=v[hc(b,s+8|0,1512)+32>>2]-a|0,v[Q>>2]=R;v[d>>2]=0;break fa}}nJ(s+8|0);b=0}gb=s+1520|0;return b|0}function bZ(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,y=0,z=0,A=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0;d=gb-400|0;gb=d;vc(b);a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{t:{u:{v:{w:{x:{y:{z:{A:{B:{C:{D:{if(!Ih(b,d+392|0)){break D}if(!ID(d+392|0)){break D}if(!c){q=1;break D}r=le(d+368|0,b);v[22656]=0;R(404,d+352|0,r|0);b=v[22656];v[22656]=0;E:{F:{G:{H:{I:{J:{K:{L:{if((b|0)!=1){v[22656]=0;U(405,d+208|0,d+352|0,1229866575);b=v[22656];v[22656]=0;if((b|0)==1){break J}v[22656]=0;q=Q(406,d+208|0,d+336|0)|0;b=v[22656];v[22656]=0;if((b|0)==1){break L}xb(d+208|0);if(!q){break E}v[22656]=0;R(367,a|0,524288);b=v[22656];v[22656]=0;if((b|0)==1){break c}v[22656]=0;Bg(a);b=v[22656];v[22656]=0;if((b|0)!=1){break K}break c}b=P()|0;O()|0;break a}b=P()|0;O()|0;xb(d+208|0);break b}v[a+480208>>2]=12;H=a,I=Md(Ib(w[d+344|0]|w[d+345|0]<<8),1,127),u[H+480188>>1]=I;H=d,I=Ib(w[d+336|0]|w[d+337|0]<<8),u[H+208>>1]=I;v[22656]=0;u[d+312>>1]=255;b=Pc(d+208|0,d+312|0);e=v[22656];v[22656]=0;if((e|0)==1){break d}u[a+480192>>1]=x[b>>1];b=d+336|2;H=d,I=Ib(w[b|0]|w[b+1|0]<<8),u[H+208>>1]=I;v[22656]=0;u[d+312>>1]=3999;b=Pc(d+208|0,d+312|0);e=v[22656];v[22656]=0;if((e|0)==1){break e}u[a+480190>>1]=x[b>>1];v[22656]=0;b=a+1074312|0;W(409,b|0,6,1)|0;e=v[22656];v[22656]=0;if((e|0)==1){break c}v[22656]=0;Q(410,b|0,21)|0;e=v[22656];v[22656]=0;if((e|0)==1){break c}v[22656]=0;Q(410,b|0,13)|0;b=v[22656];v[22656]=0;if((b|0)==1){break c}v[22656]=0;b=Q(2,d+208|0,6439)|0;e=v[22656];v[22656]=0;if((e|0)==1){break f}Eb(a+1298304|0,b);vb(b);v[22656]=0;b=Q(2,d+208|0,7587)|0;e=v[22656];v[22656]=0;if((e|0)==1){break g}Eb(a+1298316|0,b);vb(b);v[22656]=0;R(411,d+312|0,1445);b=v[22656];v[22656]=0;if((b|0)==1){break h}v[22656]=0;R(412,d+288|0,d+392|4);b=v[22656];v[22656]=0;if((b|0)==1){break j}v[22656]=0;R(412,d+264|0,d+392|5);b=v[22656];v[22656]=0;if((b|0)==1){break l}v[22656]=0;Y(136,d+208|0,d+312|0,d+288|0,d+264|0);b=v[22656];v[22656]=0;if((b|0)==1){break m}b=d+208|0;Eb(a+1298328|0,b);vb(b);vb(d+264|0);vb(d+288|0);b=d+312|0;Hb(b);v[a+1298364>>2]=2;v[22656]=0;U(405,b|0,d+352|0,1312902469);b=v[22656];v[22656]=0;if((b|0)==1){break n}v[22656]=0;b=T(195,d+312|0)|0;e=v[22656];v[22656]=0;if((e|0)==1){break p}v[22656]=0;f=a+1298268|0;W(413,d+312|0,f|0,b|0)|0;b=v[22656];v[22656]=0;if((b|0)==1){break p}b=0;v[22656]=0;U(405,d+288|0,d+352|0,1397706311);e=v[22656];v[22656]=0;if((e|0)==1){break q}e=a+484360|0;cm(Sb(e));M:{h=d+336|4;h=Ib(w[h|0]|w[h+1|0]<<8);N:{if(!h){break N}while(1){v[22656]=0;i=Q(191,d+288|0,46)|0;g=v[22656];v[22656]=0;O:{if((g|0)!=1){if(!i){break N}v[22656]=0;R(414,d+288|0,d+208|0);i=v[22656];v[22656]=0;if((i|0)!=1){if(!gd(f)){break O}v[22656]=0;Q(415,f|0,d+208|0)|0;i=v[22656];v[22656]=0;if((i|0)!=1){break O}}b=P()|0;O()|0;break r}b=P()|0;O()|0;break r}v[22656]=0;i=T(416,d+288|0)|0;g=v[22656];v[22656]=0;if((g|0)==1){break M}if(!cd(Sb(e))){v[22656]=0;g=T(417,e|0)|0;l=v[22656];v[22656]=0;if((l|0)==1){break M}if((g|0)==255){break N}}g=Sb(e);v[22656]=0;U(6,d+264|0,2,d+208|0);l=v[22656];v[22656]=0;if((l|0)==1){break s}v[22656]=0;R(418,g|0,d+264|0);g=v[22656];v[22656]=0;if((g|0)==1){break t}vb(d+264|0);g=Sb(e);v[22656]=0;U(419,g|0,d+288|0,i|0);i=v[22656];v[22656]=0;if((i|0)==1){break M}b=b+1|0;if(h>>>0>(b&65535)>>>0){continue}break}}v[22656]=0;Qi(e,0);b=v[22656];v[22656]=0;if((b|0)==1){break u}v[22656]=0;U(405,d+264|0,d+352|0,1229869908);b=v[22656];v[22656]=0;if((b|0)==1){break v}v[22656]=0;b=T(421,d+264|0)|0;e=v[22656];v[22656]=0;P:{Q:{R:{S:{T:{U:{V:{W:{if((e|0)==1){break W}X:{Y:{Z:{_:{$:{aa:{if(!b){break aa}if(x[a+480192>>1]){b=1;while(1){v[22656]=0;R(422,d+264|0,d+208|0);e=v[22656];v[22656]=0;ba:{ca:{da:{if((e|0)!=1){e=Ib(w[d+238|0]|w[d+239|0]<<8);v[22656]=0;e=W(376,a|0,b&65535,e|0)|0;f=v[22656];v[22656]=0;if((f|0)==1){break da}if(!e){break ba}if(Ib(w[d+238|0]|w[d+239|0]<<8)>>>0>3999){break ba}v[22656]=0;Lr(d+96|0,2,d+208|0);f=v[22656];v[22656]=0;if((f|0)!=1){v[22656]=0;R(324,d+120|0,d+96|0);f=v[22656];v[22656]=0;if((f|0)!=1){break ca}}b=P()|0;O()|0;break V}b=P()|0;O()|0;break V}b=P()|0;O()|0;break V}v[22656]=0;Q(301,e+492|0,d+120|0)|0;f=v[22656];v[22656]=0;if((f|0)==1){break $}vb(d+120|0);v[22656]=0;Lr(d+96|0,2,d+208|0);f=v[22656];v[22656]=0;if((f|0)==1){break _}v[22656]=0;R(324,d+120|0,d+96|0);f=v[22656];v[22656]=0;if((f|0)==1){break _}f=Ib(w[d+238|0]|w[d+239|0]<<8);v[22656]=0;Q(301,((f<<5)+a|0)+946304|0,d+120|0)|0;f=v[22656];v[22656]=0;if((f|0)==1){break Z}vb(d+120|0);v[e>>2]=0;H=e,I=Ib(w[d+254|0]|w[d+255|0]<<8)+128&65535,v[H+8>>2]=I;qc(e+8|0,256);t[e+15|0]=w[e+15|0]|1;e=Ib(w[d+238|0]|w[d+239|0]<<8);v[22656]=0;e=B(e,104)+a|0;R(424,e+484380|0,0);f=v[22656];v[22656]=0;if((f|0)==1){break Y}H=d,I=Ib(w[d+240|0]|w[d+241|0]<<8),u[H+120>>1]=I;v[22656]=0;u[d+96>>1]=64;f=Pc(d+120|0,d+96|0);h=v[22656];v[22656]=0;if((h|0)==1){break X}u[e+484410>>1]=x[f>>1]<<2;H=e+484404|0,I=Xb(w[d+242|0]|w[d+243|0]<<8|(w[d+244|0]<<16|w[d+245|0]<<24)),v[H>>2]=I;if(!Xb(w[d+250|0]|w[d+251|0]<<8|(w[d+252|0]<<16|w[d+253|0]<<24))){break ba}if(!(Ib(w[d+256|0]|w[d+257|0]<<8)&3)){break ba}f=Xb(w[d+246|0]|w[d+247|0]<<8|(w[d+248|0]<<16|w[d+249|0]<<24));v[e+484384>>2]=f;H=e+484388|0,I=Xb(w[d+250|0]|w[d+251|0]<<8|(w[d+252|0]<<16|w[d+253|0]<<24))+f|0,v[H>>2]=I;e=e+484414|0;u[e>>1]=x[e>>1]|2;if(!(Ib(w[d+256|0]|w[d+257|0]<<8)&2)){break ba}u[e>>1]=x[e>>1]|4}b=b+1|0;if(x[a+480192>>1]>=(b&65535)>>>0){continue}break}}v[22656]=0;U(405,d+184|0,d+352|0,1447382614);b=v[22656];v[22656]=0;if((b|0)==1){break W}b=v[d+196>>2];v[d+40>>2]=v[d+192>>2];v[d+44>>2]=b;v[d+48>>2]=v[d+200>>2];v[22656]=0;b=v[d+188>>2];v[d+32>>2]=v[d+184>>2];v[d+36>>2]=b;Y(425,d+32|0,0,a|0,0);b=v[22656];v[22656]=0;if((b|0)==1){break W}v[22656]=0;U(405,d+160|0,d+352|0,1346719318);b=v[22656];v[22656]=0;if((b|0)==1){break W}b=v[d+172>>2];v[d+16>>2]=v[d+168>>2];v[d+20>>2]=b;v[d+24>>2]=v[d+176>>2];v[22656]=0;b=v[d+164>>2];v[d+8>>2]=v[d+160>>2];v[d+12>>2]=b;Y(425,d+8|0,1,a|0,w[d+396|0]>2|0);b=v[22656];v[22656]=0;if((b|0)==1){break W}if(!x[a+480192>>1]){break aa}b=1;while(1){e=v[(((b&65535)<<2)+a|0)+900380>>2];if(!(!e|t[e+60|0]&1)){v[e>>2]=32767}b=b+1|0;if(x[a+480192>>1]>=(b&65535)>>>0){continue}break}}xb(d+264|0);v[22656]=0;U(405,d+208|0,d+352|0,1346458708);b=v[22656];v[22656]=0;if((b|0)==1){break U}v[22656]=0;b=T(275,d+208|0)|0;e=v[22656];v[22656]=0;if((e|0)==1){break T}if(!b|!(c&1)){break I}v[22656]=0;U(405,d+264|0,d+352|0,1347305805);b=v[22656];v[22656]=0;if((b|0)==1){break S}v[22656]=0;Q(318,d+264|0,1)|0;b=v[22656];v[22656]=0;if((b|0)==1){break R}i=0;l=d+336|6;b=Ib(w[l|0]|w[l+1|0]<<8);v[22656]=0;n=a+484344|0;R(330,n|0,b|0);b=v[22656];v[22656]=0;if((b|0)==1){break R}e=dd(d+144|0);if(Ib(w[l|0]|w[l+1|0]<<8)){break Q}b=0;break P}b=P()|0;O()|0;vb(d+120|0);break V}b=P()|0;O()|0;break V}b=P()|0;O()|0;vb(d+120|0);break V}b=P()|0;O()|0;break V}b=P()|0;O()|0;break V}b=P()|0;O()|0}xb(d+264|0);break r}b=P()|0;O()|0;break r}b=P()|0;O()|0;break w}b=P()|0;O()|0;break w}b=P()|0;O()|0;break x}b=d+96|0;A=b|5;C=b|3;D=b|4;E=b|2;F=b|1;b=0;while(1){v[22656]=0;z=T(416,d+208|0)|0;f=v[22656];v[22656]=0;ea:{fa:{ga:{ha:{ia:{if((f|0)!=1){v[22656]=0;f=T(426,d+208|0)|0;h=v[22656];v[22656]=0;if((h|0)==1){break ia}v[22656]=0;U(288,d+96|0,d+208|0,f|0);f=v[22656];v[22656]=0;if((f|0)==1){break ha}h=d+96|0;f=kc(d+120|0,h);xb(h);v[22656]=0;h=W(331,n|0,i&65535,z|0)|0;g=v[22656];v[22656]=0;if((g|0)==1){break ga}if(!h){break ea}p=Kb(d+80|0);v[22656]=0;U(427,d+264|0,p|0,-1);h=v[22656];v[22656]=0;if((h|0)!=1){h=_b(n,i);v[22656]=0;Q(428,h|0,p|0)|0;h=v[22656];v[22656]=0;if((h|0)!=1){break fa}}break A}b=P()|0;O()|0;break y}b=P()|0;O()|0;break y}b=P()|0;O()|0;break y}b=P()|0;O()|0;break z}h=_b(n,i);v[22656]=0;h=Tf(h,0);g=v[22656];v[22656]=0;if((g|0)==1){break A}Od(e);o=0;ja:{while(1){v[22656]=0;g=Q(191,d+120|0,1)|0;k=v[22656];v[22656]=0;ka:{la:{ma:{if((k|0)!=1){if(!g){break ja}v[22656]=0;k=T(374,f|0)|0;g=v[22656];v[22656]=0;if((g|0)==1){break A}if(k){break la}H=d,I=Vb(e),v[H+72>>2]=I;H=d,I=Zb(e),v[H+64>>2]=I;if(Gb(d+72|0,d- -64|0)){break ma}break ka}break A}while(1){na:{h=v[d+72>>2];g=_b(n,i);k=w[h+1|0];h=w[h|0];v[22656]=0;h=Be(d+96|0,h,k);k=v[22656];v[22656]=0;if((k|0)==1){break na}h=Ue(h,o);v[22656]=0;Q(431,g|0,h|0)|0;h=v[22656];v[22656]=0;if((h|0)==1){break na}h=d+72|0;Tv(h);if(Gb(h,d- -64|0)){continue}break ka}break}break A}gi(d+96|0);s=x[a+480188>>1];v[22656]=0;g=T(374,f|0)|0;j=v[22656];v[22656]=0;oa:{pa:{if((j|0)!=1){y=k-1|0;qa:{if(!(g&1)){break qa}v[22656]=0;j=T(374,f|0)|0;m=v[22656];v[22656]=0;if((m|0)==1){break A}m=k>>>0>s>>>0?d+96|0:B(y,6)+h|0;if((j|0)!=31){if((j-1&255)>>>0>252){break qa}j=(B(j>>>4|0,12)+(j&15)|0)+13|0}else{j=255}t[m|0]=j}if(!(g&2)){break oa}v[22656]=0;j=T(374,f|0)|0;m=v[22656];v[22656]=0;if((m|0)!=1){break pa}}break A}t[(k>>>0>s>>>0?F:(B(y,6)+h|0)+1|0)|0]=j}if(!(g&60)){continue}t[d+63|0]=0;t[d+62|0]=0;t[d+61|0]=0;t[d+60|0]=0;if(g&4){v[22656]=0;j=T(374,f|0)|0;m=v[22656];v[22656]=0;if((m|0)==1){break A}t[d+62|0]=j}if(g&8){v[22656]=0;j=T(374,f|0)|0;m=v[22656];v[22656]=0;if((m|0)==1){break A}t[d+60|0]=j}if(g&16){v[22656]=0;j=T(374,f|0)|0;m=v[22656];v[22656]=0;if((m|0)==1){break A}t[d+63|0]=j}if(g&32){v[22656]=0;g=T(374,f|0)|0;j=v[22656];v[22656]=0;if((j|0)==1){break A}t[d+61|0]=g}QY(d+63|0,d+61|0);QY(d+62|0,d+60|0);g=w[d+62|0];if(!(w[d+63|0]==13|g?(g|0)!=13:0)){fi(d+63|0,d+62|0);fi(d+61|0,d+60|0)}v[22656]=0;vo(d- -64|0,d+63|0,d+61|0,d+62|0,d+60|0);g=v[22656];v[22656]=0;ra:{if((g|0)==1){break ra}v[22656]=0;g=uz(w[d+64|0],w[d+65|0]);j=v[22656];v[22656]=0;if((j|0)==1){break ra}sa:{if(!g){break sa}H=d,I=Vb(e),v[H+72>>2]=I;Fd(d+56|0,d+72|0);v[22656]=0;U(434,e|0,v[d+56>>2],d- -64|0);g=v[22656];v[22656]=0;if((g|0)!=1){break sa}break A}g=B(y,6)+h|0;k=k>>>0>s>>>0;t[(k?E:g+2|0)|0]=w[d+63|0];t[(k?D:g+4|0)|0]=w[d+61|0];j=w[d+62|0];t[(k?C:g+3|0)|0]=j;t[(k?A:g+5|0)|0]=w[d+60|0];if((j|0)==43){G=1;continue}if((j|0)!=31){continue}b=1;continue}break A}Od(e);o=o+1|0;if(z>>>0<=o>>>0){break ja}h=_b(n,i);v[22656]=0;h=Tf(h,o);g=v[22656];v[22656]=0;if((g|0)!=1){continue}break}break A}vb(p)}xb(d+120|0);i=i+1|0;if(Ib(w[l|0]|w[l+1|0]<<8)>>>0>i>>>0){continue}break}}Hr(e);h=b;xb(d+264|0);if(!(c&4)){break G}e=0;if(!G){break H}f=x[a+480188>>1];if(!f){e=1;break H}b=0;while(1){e=1;i=(b<<5)+a|0;t[i+480288|0]=1;i=i+480280|0;v[i>>2]=v[i>>2]|67108864;b=b+1|0;if((f|0)!=(b|0)){continue}break}break H}b=P()|0;O()|0;break r}b=P()|0;O()|0;break b}h=0;e=0;if(!(c&4)){break F}}v[d+120>>2]=-1778364416;v[d+124>>2]=-16756736;v[22656]=0;U(405,d+264|0,d+352|0,1146310725);b=v[22656];v[22656]=0;ta:{ua:{va:{wa:{xa:{ya:{if((b|0)!=1){v[22656]=0;b=T(421,d+264|0)|0;f=v[22656];v[22656]=0;if((f|0)==1){break va}if(!b){break xa}v[22656]=0;i=T(416,d+264|0)|0;b=v[22656];v[22656]=0;if((b|0)==1){break va}if(i){break ya}f=e;break wa}b=P()|0;O()|0;break w}b=0;f=e;while(1){v[22656]=0;g=T(374,d+264|0)|0;l=v[22656];v[22656]=0;za:{Aa:{if((l|0)!=1){if(x[a+480188>>1]<=b>>>0){break za}if(!e){break Aa}l=((b<<5)+a|0)+480280|0;v[l>>2]=v[l>>2]&-67108865|((g|0)!=0)<<26;break za}break va}if(g){break za}f=1;t[((b<<5)+a|0)+480288|0]=1}b=b+1|0;if((i|0)!=(b|0)){continue}break}break wa}xb(d+264|0);if(!e){break G}break ta}v[22656]=0;Q(435,d+264|0,d+120|0)|0;b=v[22656];v[22656]=0;if((b|0)!=1){break ua}}b=P()|0;O()|0;xb(d+264|0);break w}xb(d+264|0);if(!(f&1)){break G}}v[22656]=0;_(436,a+906300|0);b=v[22656];v[22656]=0;Ba:{Ca:{Da:{Ea:{Fa:{Ga:{if((b|0)==1){break Ga}b=a+906316|0;v[b>>2]=810369604;v[b+4>>2]=1869112133;t[a+906324|0]=16;t[a+906325|0]=0;t[a+906326|0]=10;t[a+906327|0]=0;b=a+906328|0;t[b|0]=0;t[b+1|0]=0;t[b+2|0]=0;t[b+3|0]=0;v[22656]=0;v[d+264>>2]=0;b=a+906332|0;GD(b,b+16|0,d+264|0);b=v[22656];v[22656]=0;if((b|0)==1){break Fa}v[22656]=0;e=Q(70,d+264|0,6713)|0;b=v[22656];v[22656]=0;if((b|0)==1){break Ea}v[22656]=0;Rv(a+906348|0,e);b=v[22656];v[22656]=0;if((b|0)==1){break Da}vb(e);v[22656]=0;e=Q(70,d+264|0,6677)|0;b=v[22656];v[22656]=0;if((b|0)==1){break Ca}v[22656]=0;Jr(a+906380|0,e);b=v[22656];v[22656]=0;if((b|0)==1){break Ba}vb(e);v[22656]=0;b=a+906304|0;R(440,b|0,8);e=v[22656];v[22656]=0;if((e|0)==1){break Ga}OY(d+264|0,w[d+121|0],w[d+123|0],w[d+125|0],w[d+127|0]);e=v[d+268>>2];b=v[b>>2];f=v[d+264>>2];t[b|0]=f;t[b+1|0]=f>>>8;t[b+2|0]=f>>>16;t[b+3|0]=f>>>24;t[b+4|0]=e;t[b+5|0]=e>>>8;t[b+6|0]=e>>>16;t[b+7|0]=e>>>24;break G}b=P()|0;O()|0;break w}b=P()|0;O()|0;break w}b=P()|0;O()|0;break w}b=P()|0;O()|0;vb(e);break w}b=P()|0;O()|0;break w}b=P()|0;O()|0;vb(e);break w}if(!h){break F}b=0;Ha:{Ia:{Ja:{Ka:{La:{Ma:{Na:{Oa:{Pa:{Qa:{Ra:{Sa:{Ta:{Ua:{Va:{Wa:{Xa:{Ya:{Za:{_a:{$a:{ab:{bb:{while(1){cb:{v[d+80>>2]=B(b,127)>>>5;v[22656]=0;R(441,d+120|0,1202);e=v[22656];v[22656]=0;if((e|0)==1){break cb}v[22656]=0;R(442,d+96|0,d+80|0);e=v[22656];v[22656]=0;if((e|0)==1){break bb}v[22656]=0;U(443,d+264|0,d+120|0,d+96|0);e=v[22656];v[22656]=0;if((e|0)==1){break ab}v[22656]=0;e=(b<<5)+a|0;R(444,d+144|0,e+902204|0);f=v[22656];v[22656]=0;if((f|0)==1){break $a}v[22656]=0;Q(401,d+144|0,d+264|0)|0;f=v[22656];v[22656]=0;if((f|0)==1){break $a}vb(d+264|0);vb(d+96|0);f=d+120|0;Hb(f);v[22656]=0;R(441,f|0,1184);f=v[22656];v[22656]=0;if((f|0)==1){break Ya}v[22656]=0;R(442,d+96|0,d+80|0);f=v[22656];v[22656]=0;if((f|0)==1){break Xa}v[22656]=0;U(443,d+264|0,d+120|0,d+96|0);f=v[22656];v[22656]=0;if((f|0)==1){break Wa}v[22656]=0;R(444,d+144|0,e+903228|0);f=v[22656];v[22656]=0;if((f|0)==1){break Va}v[22656]=0;Q(401,d+144|0,d+264|0)|0;f=v[22656];v[22656]=0;if((f|0)==1){break Va}vb(d+264|0);vb(d+96|0);f=d+120|0;Hb(f);v[22656]=0;R(441,f|0,1175);f=v[22656];v[22656]=0;if((f|0)==1){break Sa}v[22656]=0;R(442,d+96|0,d+80|0);f=v[22656];v[22656]=0;if((f|0)==1){break Ra}v[22656]=0;U(443,d+264|0,d+120|0,d+96|0);f=v[22656];v[22656]=0;if((f|0)==1){break Qa}v[22656]=0;R(444,d+144|0,e+904252|0);f=v[22656];v[22656]=0;if((f|0)==1){break Pa}v[22656]=0;Q(401,d+144|0,d+264|0)|0;f=v[22656];v[22656]=0;if((f|0)==1){break Pa}vb(d+264|0);vb(d+96|0);f=d+120|0;Hb(f);v[22656]=0;R(441,f|0,1148);f=v[22656];v[22656]=0;if((f|0)==1){break Ma}v[22656]=0;R(442,d+96|0,d+80|0);f=v[22656];v[22656]=0;if((f|0)==1){break La}v[22656]=0;U(443,d+264|0,d+120|0,d+96|0);f=v[22656];v[22656]=0;if((f|0)==1){break Ka}v[22656]=0;R(444,d+144|0,e+905276|0);e=v[22656];v[22656]=0;if((e|0)==1){break Ja}v[22656]=0;Q(401,d+144|0,d+264|0)|0;e=v[22656];v[22656]=0;if((e|0)==1){break Ja}vb(d+264|0);vb(d+96|0);Hb(d+120|0);b=b+1|0;if((b|0)!=32){continue}break F}break}b=P()|0;O()|0;break w}b=P()|0;O()|0;break Za}b=P()|0;O()|0;break _a}b=P()|0;O()|0;vb(d+264|0)}vb(d+96|0)}Hb(d+120|0);break w}b=P()|0;O()|0;break w}b=P()|0;O()|0;break Ta}b=P()|0;O()|0;break Ua}b=P()|0;O()|0;vb(d+264|0)}vb(d+96|0)}Hb(d+120|0);break w}b=P()|0;O()|0;break w}b=P()|0;O()|0;break Na}b=P()|0;O()|0;break Oa}b=P()|0;O()|0;vb(d+264|0)}vb(d+96|0)}Hb(d+120|0);break w}b=P()|0;O()|0;break w}b=P()|0;O()|0;break Ha}b=P()|0;O()|0;break Ia}b=P()|0;O()|0;vb(d+264|0)}vb(d+96|0)}Hb(d+120|0);break w}v[22656]=0;U(405,d+264|0,d+352|0,1397575756);b=v[22656];v[22656]=0;if((b|0)==1){break B}v[22656]=0;b=T(275,d+264|0)|0;e=v[22656];v[22656]=0;if((e|0)==1){break C}if(!(!x[a+480190>>1]|(!b|!(c&2)))){e=1;b=1;while(1){v[22656]=0;c=T(426,d+264|0)|0;f=v[22656];v[22656]=0;db:{if((f|0)!=1){v[22656]=0;f=T(426,d+264|0)|0;h=v[22656];v[22656]=0;if((h|0)==1){break C}if(!(c&7)){break db}e=(B(e,104)+a|0)+484380|0;v[e>>2]=f;c=Rc(d+120|0,c&4?32:c&2?16:8,1,1,0);v[22656]=0;W(329,c|0,e|0,d+264|0)|0;c=v[22656];v[22656]=0;if((c|0)!=1){break db}break C}break C}b=b+1|0;e=b&65535;if(e>>>0<=x[a+480190>>1]){continue}break}}xb(d+264|0);xb(d+208|0);xb(d+288|0);xb(d+312|0)}ke(d+352|0);xb(r)}gb=d+400|0;return q|0}b=P()|0;O()|0;xb(d+264|0);break w}b=P()|0;O()|0;break w}b=P()|0;O()|0;vb(p)}xb(d+120|0)}Hr(e)}xb(d+264|0)}xb(d+208|0);break r}b=P()|0;O()|0;break r}b=P()|0;O()|0;break r}b=P()|0;O()|0;vb(d+264|0);break r}b=P()|0;O()|0}xb(d+288|0);break o}b=P()|0;O()|0;break o}b=P()|0;O()|0}xb(d+312|0);break b}b=P()|0;O()|0;break b}b=P()|0;O()|0;vb(d+264|0);break k}b=P()|0;O()|0}vb(d+288|0);break i}b=P()|0;O()|0}Hb(d+312|0);break b}b=P()|0;O()|0;break b}b=P()|0;O()|0;break b}b=P()|0;O()|0;break b}b=P()|0;O()|0;break b}b=P()|0;O()|0;break b}b=P()|0;O()|0}ke(d+352|0)}xb(r);S(b|0);L()}function Ila(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,y=0,z=0;d=gb-352|0;gb=d;vc(b);a:{if(!Ar(b,d+336|0)){break a}if(!PU(d+336|0)){break a}r=le(d+312|0,b);q=hh(d+296|0);b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{t:{if(!c){v[22656]=0;R(844,d|0,r|0);b=v[22656];v[22656]=0;if((b|0)==1){break r}break t}v[22656]=0;R(845,d|0,r|0);b=v[22656];v[22656]=0;if((b|0)==1){break s}}OU(q,d);ke(d);v[22656]=0;U(846,d|0,q|0,1413891155);b=v[22656];v[22656]=0;u:{v:{if((b|0)!=1){v[22656]=0;e=Q(847,d|0,11394)|0;b=v[22656];v[22656]=0;if((b|0)==1){break v}xb(d);if(!e){break b}if(c){break u}break b}b=P()|0;O()|0;break c}b=P()|0;O()|0;xb(d);break c}v[22656]=0;R(367,a|0,4194304);b=v[22656];v[22656]=0;if((b|0)==1){break d}v[a+480208>>2]=12;v[22656]=0;U(846,d+272|0,q|0,1280592212);b=v[22656];v[22656]=0;if((b|0)==1){break e}v[22656]=0;b=T(195,d+272|0)|0;e=v[22656];v[22656]=0;if((e|0)==1){break g}v[22656]=0;W(616,d+272|0,a+1298268|0,b|0)|0;b=v[22656];v[22656]=0;if((b|0)==1){break g}m=a+484360|0;cm(Sb(m));l=dd(d+256|0);t[d+255|0]=0;v[22656]=0;U(848,d+240|0,q|0,1196314451);b=v[22656];v[22656]=0;if((b|0)==1){break i}b=d+240|0;y=d,z=Vb(b),v[y+232>>2]=z;y=d,z=Zb(b),v[y+224>>2]=z;w:{x:{y:{z:{A:{B:{if(!Gb(d+232|0,d+224|0)){break B}i=d+12|0;f=d+24|0;j=d+44|0;C:{while(1){b=le(d+200|0,v[d+232>>2]);v[22656]=0;e=Q(849,b|0,d+184|0)|0;g=v[22656];v[22656]=0;D:{if((g|0)!=1){if(w[d+193|0]==1?e:0){break D}xb(d+200|0);e=0;break A}b=P()|0;O()|0;break k}y=a,z=Md(w[d+194|0],x[a+480188>>1],127),u[y+480188>>1]=z;v[22656]=0;k=T(850,d|0)|0;e=v[22656];v[22656]=0;E:{F:{G:{H:{I:{J:{if((e|0)!=1){e=d+168|0;pf(e,d+184|0,9,1);v[22656]=0;R(324,d+120|0,e|0);e=v[22656];v[22656]=0;if((e|0)==1){break J}v[22656]=0;R(851,d+160|0,j|0);e=v[22656];v[22656]=0;if((e|0)==1){break I}v[22656]=0;Q(401,d+160|0,d+120|0)|0;e=v[22656];v[22656]=0;if((e|0)==1){break I}vb(d+120|0);if(cd(Sb(m))){break G}v[22656]=0;e=T(417,m|0)|0;g=v[22656];v[22656]=0;if((g|0)==1){break H}if((e|0)!=255){break G}b=2;break F}b=P()|0;O()|0;break k}b=P()|0;O()|0;break l}b=P()|0;O()|0;vb(d+120|0);break l}b=P()|0;O()|0;break l}e=Sb(m);v[22656]=0;U(6,d+120|0,5,j|0);g=v[22656];v[22656]=0;K:{L:{M:{N:{O:{if((g|0)!=1){v[22656]=0;R(418,e|0,d+120|0);e=v[22656];v[22656]=0;if((e|0)==1){break O}vb(d+120|0);v[22656]=0;R(845,d+168|0,b|0);b=v[22656];v[22656]=0;if((b|0)==1){break N}b=d+168|0;y=d,z=Vb(b),v[y+152>>2]=z;y=d,z=Zb(b),v[y+144>>2]=z;if(Gb(d+152|0,d+144|0)){break M}break L}b=P()|0;O()|0;break l}b=P()|0;O()|0;vb(d+120|0);break l}b=P()|0;O()|0;break l}while(1){P:{e=v[d+152>>2];rn(d+120|0,e);b=d+160|0;Zi(b,e);Q:{b=w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24);if((b|0)!=1212960847){if((b|0)!=1312903248){break Q}b=0;if(!x[a+480188>>1]){break Q}while(1){R:{v[22656]=0;e=Q(191,d+120|0,2)|0;g=v[22656];v[22656]=0;if((g|0)==1){break R}if(!e){break Q}v[22656]=0;R(403,d+96|0,d+120|0);e=v[22656];v[22656]=0;S:{T:{U:{V:{if((e|0)!=1){e=d+96|0;g=qd(e);switch(w[e|0]){case 4:break T;case 2:break U;case 0:break V;default:break S}}break P}e=w[g|0];y=lc(d,b),z=e^128,t[y|0]=z;e=d+104|0;Ce(e,f,b);Uf(e,0);break S}y=lc(d,b),z=128,t[y|0]=z;e=d+104|0;Ce(e,f,b);Uf(e,1);break S}y=lc(d,b),z=128,t[y|0]=z;e=d+104|0;Ce(e,f,b);Uf(e,0)}b=b+1|0;if(b>>>0<x[a+480188>>1]){continue}break Q}break}break P}if(cn(d+160|0)>>>0<9){break Q}b=0;v[22656]=0;Q(318,d+120|0,2)|0;e=v[22656];v[22656]=0;g=65535;if((e|0)==1){break P}while(1){v[22656]=0;e=Q(191,d+120|0,1)|0;h=v[22656];v[22656]=0;W:{X:{Y:{Z:{_:{$:{aa:{ba:{ca:{if((h|0)!=1){if(!e){break Q}v[22656]=0;e=T(374,d+120|0)|0;h=v[22656];v[22656]=0;if((h|0)==1){break P}switch(e|0){case 0:break Q;case 14:break X;case 13:break Y;case 12:break _;case 8:break $;case 7:break aa;case 4:break ba;case 1:break ca;default:break Z}}break P}if(x[d+36>>1]==65535){y=d,z=am(Sb(m)),u[y+36>>1]=z}e=am(Sb(m));v[22656]=0;u[d+38>>1]=e;e=Q(852,d+120|0,d+255|0)|0;h=v[22656];v[22656]=0;if((h|0)==1){break P}da:{ea:{switch(e-254|0){case 1:v[22656]=0;e=65535;h=v[22656];v[22656]=0;if((h|0)!=1){break da}break P;case 0:break ea;default:break da}}v[22656]=0;e=65534;h=v[22656];v[22656]=0;if((h|0)==1){break P}}h=Sb(m);v[22656]=0;R(710,h|0,e|0);e=v[22656];v[22656]=0;if((e|0)==1){break P}g=(g&65535)==65535?b:g;break W}v[22656]=0;e=T(287,d+120|0)|0;h=v[22656];v[22656]=0;if((h|0)==1){break P}if(e>>>0>=(g&65535)>>>0){u[d+40>>1]=e-g}cf(Sb(m),x[d+40>>1]);break W}v[22656]=0;e=T(374,d+120|0)|0;h=v[22656];v[22656]=0;if((h|0)==1){break P}t[d+43|0]=e;break W}v[22656]=0;e=T(374,d+120|0)|0;h=v[22656];v[22656]=0;if((h|0)==1){break P}t[d+42|0]=e;break W}v[22656]=0;e=Q(813,d+120|0,d+104|0)|0;h=v[22656];v[22656]=0;if((h|0)==1){break P}if(w[d+104|0]|!e|(w[d+106|0]|w[d+105|0]!=255)){break Z}if(w[d+107|0]|w[d+108|0]!=1){break Z}if(!w[d+109|0]){break W}}xb(d+120|0);b=1;break K}v[22656]=0;R(723,d+112|0,d+120|0);e=v[22656];v[22656]=0;fa:{ga:{ha:{ia:{if((e|0)!=1){e=d+112|0;h=qd(e);o=Ve(e);n=w[e|0];if(oc(d)>>>0<=n>>>0){break W}switch(w[o|0]){case 4:break ga;case 2:break ha;case 0:break ia;default:break fa}}break P}h=w[h|0];y=lc(d,w[e|0]),z=h^128,t[y|0]=z;h=d+104|0;Ce(h,f,w[e|0]);Uf(h,0);break fa}y=lc(d,w[e|0]),z=128,t[y|0]=z;h=d+104|0;Ce(h,f,w[e|0]);Uf(h,1);break fa}y=lc(d,w[e|0]),z=128,t[y|0]=z;h=d+104|0;Ce(h,f,w[e|0]);Uf(h,0)}ja:{if(p&1){break ja}p=0;if(!dr(l)){break W}if(w[lc(NU(l),w[e|0])|0]!=w[lc(d,w[e|0])|0]){break ja}h=d+104|0;Ce(h,NU(l)+24|0,w[e|0]);h=Cb(h);o=d+96|0;Ce(o,f,w[e|0]);if((Cb(o)|0)==(h|0)){break W}}p=1;break W}v[22656]=0;R(403,d+104|0,d+120|0);e=v[22656];v[22656]=0;if((e|0)==1){break P}e=d+104|0;h=qd(e);o=w[e|0];if(oc(i)>>>0<=o>>>0){break W}h=w[h|0];y=lc(i,w[e|0]),z=(h>>>2|0)+1|0,t[y|0]=z}b=b+1|0;continue}}xb(d+120|0);b=d+152|0;pn(b);if(Gb(b,d+144|0)){continue}break L}break}b=P()|0;O()|0;xb(d+120|0);break E}b=0;if(x[d+36>>1]==65535|x[d+38>>1]==65535){break K}b=Sb(m);v[22656]=0;_(855,b|0);b=v[22656];v[22656]=0;if((b|0)!=1){b=0;v[22656]=0;R(856,l|0,k|0);e=v[22656];v[22656]=0;if((e|0)!=1){break K}}b=P()|0;O()|0;break E}ke(d+168|0)}dv(k);xb(d+200|0);if(b){break C}b=d+232|0;Eh(b);if(Gb(b,d+224|0)){continue}break B}break}ke(d+168|0);break l}e=0;if((b|0)!=2){break A}}e=0;v[22656]=0;Qi(m,0);b=v[22656];v[22656]=0;if((b|0)==1){break q}if(cd(l)){break A}if(c&2){v[22656]=0;U(848,d+200|0,q|0,1347244868);b=v[22656];v[22656]=0;if((b|0)==1){break w}b=d+200|0;y=d,z=Vb(b),v[y+184>>2]=z;y=d,z=Zb(b),v[y+160>>2]=z;f=w[d+255|0];if(Gb(d+184|0,d+160|0)){e=a+480190|0;g=d+13|0;k=d+17|0;while(1){b=v[d+184>>2];ka:{la:{ma:{na:{oa:{if(!f){v[22656]=0;i=Q(857,b|0,d|0)|0;j=v[22656];v[22656]=0;if((j|0)==1){break oa}if(!i){break ka}i=w[d+52|0]|w[d+53|0]<<8;u[d+104>>1]=i+1;if(i>>>0>3998){break ma}v[22656]=0;i=Le(e,d+104|0);j=v[22656];v[22656]=0;if((j|0)==1){break oa}u[a+480190>>1]=x[i>>1];v[22656]=0;R(858,d|0,(B(x[d+104>>1],104)+a|0)+484380|0);i=v[22656];v[22656]=0;if((i|0)==1){break oa}i=d+168|0;MU(i,g);v[22656]=0;R(324,d+120|0,i|0);i=v[22656];v[22656]=0;pa:{if((i|0)!=1){v[22656]=0;Q(301,((x[d+104>>1]<<5)+a|0)+946304|0,d+120|0)|0;i=v[22656];v[22656]=0;if((i|0)==1){break pa}vb(d+120|0);break ma}b=P()|0;O()|0;break la}b=P()|0;O()|0;vb(d+120|0);break la}v[22656]=0;i=Q(859,b|0,d|0)|0;j=v[22656];v[22656]=0;if((j|0)==1){break na}if(!i){break ka}i=w[d+56|0]|w[d+57|0]<<8;u[d+104>>1]=i+1;if(i>>>0>3998){break ma}v[22656]=0;i=Le(e,d+104|0);j=v[22656];v[22656]=0;if((j|0)==1){break na}u[a+480190>>1]=x[i>>1];v[22656]=0;R(860,d|0,(B(x[d+104>>1],104)+a|0)+484380|0);i=v[22656];v[22656]=0;if((i|0)==1){break na}i=d+168|0;MU(i,k);v[22656]=0;R(324,d+120|0,i|0);i=v[22656];v[22656]=0;qa:{if((i|0)!=1){v[22656]=0;Q(301,((x[d+104>>1]<<5)+a|0)+946304|0,d+120|0)|0;i=v[22656];v[22656]=0;if((i|0)==1){break qa}vb(d+120|0);break ma}b=P()|0;O()|0;break la}b=P()|0;O()|0;vb(d+120|0);break la}b=P()|0;O()|0;break la}b=P()|0;O()|0;break la}if((x[d+104>>1]-1&65535)>>>0>3998){break ka}i=Rc(d,8,1,0,2);v[22656]=0;W(329,i|0,(B(x[d+104>>1],104)+a|0)+484380|0,b|0)|0;b=v[22656];v[22656]=0;if((b|0)!=1){break ka}b=P()|0;O()|0}jd(d+200|0);break j}b=d+184|0;Eh(b);if(Gb(b,d+160|0)){continue}break}}jd(d+200|0)}b=0;y=a,z=w[bn(l,0)+43|0],v[y+480196>>2]=z;y=a,z=B(w[bn(l,0)+42|0],1e4),v[y+480204>>2]=z;cf(Sb(m),x[bn(l,0)+40>>1]);if(x[a+480188>>1]){while(1){v[22656]=0;e=(b<<5)+a|0;f=e+480280|0;We(f);g=v[22656];v[22656]=0;if((g|0)==1){break x}y=e+480286|0,z=w[lc(bn(l,0)+12|0,b)|0],u[y>>1]=z;y=e+480284|0,z=w[lc(bn(l,0),b)|0],u[y>>1]=z;Ce(d,bn(l,0)+24|0,b);e=Cb(d);v[f>>2]=v[f>>2]&-257|(e?256:0);b=b+1|0;if(b>>>0<x[a+480188>>1]){continue}break}}ra:{if(w[d+255|0]){v[22656]=0;Q(2,d|0,14205)|0;b=v[22656];v[22656]=0;if((b|0)!=1){break ra}break m}v[22656]=0;Q(2,d|0,14078)|0;b=v[22656];v[22656]=0;if((b|0)==1){break m}}Eb(a+1298304|0,d);vb(d);v[22656]=0;b=Q(2,d|0,7407)|0;f=v[22656];v[22656]=0;e=1;if((f|0)==1){break y}Eb(a+1298316|0,b);vb(b);v[a+1298364>>2]=5;if(!(c&1)|!x[a+480188>>1]){break A}v[22656]=0;U(848,d+120|0,q|0,1146045008);b=v[22656];v[22656]=0;if((b|0)==1){break n}b=Je(d+120|0);v[22656]=0;i=a+484344|0;R(330,i|0,b&65535);b=v[22656];v[22656]=0;if((b|0)==1){break p}b=d+120|0;y=d,z=Vb(b),v[y+168>>2]=z;y=d,z=Zb(b),v[y+184>>2]=z;if(Gb(d+168|0,d+184|0)){while(1){k=v[d+168>>2];v[22656]=0;b=T(195,k|0)|0;c=v[22656];v[22656]=0;sa:{ta:{ua:{if((c|0)==1){break ua}v[22656]=0;c=T(192,k|0)|0;e=v[22656];v[22656]=0;if((e|0)==1){break ua}if((b|0)!=(c|0)){break sa}v[22656]=0;b=Q(861,k|0,8)|0;c=v[22656];v[22656]=0;if((c|0)==1){break ua}if(b){break ta}break sa}b=P()|0;O()|0;break o}v[22656]=0;o=Q(852,k|0,d+255|0)|0;b=v[22656];v[22656]=0;if((b|0)!=1){v[22656]=0;h=T(287,k|0)|0;b=v[22656];v[22656]=0;va:{if((b|0)==1){break va}v[22656]=0;b=W(331,i|0,o|0,h|0)|0;c=v[22656];v[22656]=0;if((c|0)==1){break va}if(!b|!h){break sa}c=0;wa:{xa:{ya:{while(1){za:{b=_b(i,o);v[22656]=0;e=Tf(b,c);b=v[22656];v[22656]=0;if((b|0)==1){break wa}v[22656]=0;b=T(287,k|0)|0;f=v[22656];v[22656]=0;if((f|0)==1){break xa}Aa:{if(b>>>0>=3){v[22656]=0;U(288,d+200|0,k|0,b-2|0);b=v[22656];v[22656]=0;if((b|0)==1){break ya}b=d+200|0;j=kc(d,b);xb(b);while(1){v[22656]=0;b=Q(191,d|0,3)|0;f=v[22656];v[22656]=0;if((f|0)==1){break Aa}if(b){v[22656]=0;R(403,d+200|0,j|0);b=v[22656];v[22656]=0;Ba:{Ca:{Da:{Ea:{if((b|0)!=1){b=d+200|0;g=b;b=qd(b);u[d+160>>1]=x[a+480188>>1]-1;b=w[b|0];v[22656]=0;u[d+104>>1]=b;b=Pc(d+160|0,d+104|0);f=v[22656];v[22656]=0;if((f|0)==1){break za}f=x[b>>1];b=t[g|0];if((b|0)>=0){break Ba}v[22656]=0;b=T(374,j|0)|0;n=v[22656];v[22656]=0;if((n|0)==1){break za}if(w[d+255|0]){break Da}if((b|0)!=255){break Ea}b=254;break Ca}break za}if(b>>>0>128){break Ca}b=(B(b>>>4|0,12)+(b&15)|0)+13|0;break Ca}b=b>>>0<85?b+36|0:b}t[e+B(f,6)|0]=b;b=w[g|0]}if(b&64){v[22656]=0;b=T(374,j|0)|0;n=v[22656];v[22656]=0;if((n|0)==1){break za}t[(e+B(f,6)|0)+1|0]=b+1;b=w[g|0]}if(b&32){v[22656]=0;b=T(374,j|0)|0;n=v[22656];v[22656]=0;if((n|0)==1){break za}t[d+160|0]=b;b=e+B(f,6)|0;t[b+2|0]=1;v[22656]=0;t[d+104|0]=127;n=ac(d+160|0,d+104|0);s=v[22656];v[22656]=0;if((s|0)==1){break za}t[b+4|0]=w[n|0]+1>>>1;b=w[g|0]}if(!(b&16)){continue}v[22656]=0;R(403,d+160|0,j|0);b=v[22656];v[22656]=0;if((b|0)==1){break za}b=e+B(f,6)|0;n=d+160|0;g=w[qd(n)|0];t[b+5|0]=g;Fa:{switch(w[n|0]-1|0){case 0:t[(e+B(f,6)|0)+3|0]=11;if(w[d+255|0]){t[b+5|0]=g<<4|15;continue}t[b+5|0]=g<<3|15;continue;case 1:t[(e+B(f,6)|0)+3|0]=11;if(w[d+255|0]){t[b+5|0]=g<<4;continue}t[b+5|0]=g<<3&240;continue;case 2:t[(e+B(f,6)|0)+3|0]=11;if(w[d+255|0]){t[b+5|0]=g|240;continue}t[b+5|0]=g>>>1|240;continue;case 3:t[(e+B(f,6)|0)+3|0]=11;if(w[d+255|0]){t[b+5|0]=g&15;continue}if(g>>>0<=1){t[b+5|0]=g|240;continue}t[b+5|0]=g>>>1&15;continue;case 10:t[(e+B(f,6)|0)+3|0]=2;y=b,z=bv(g,w[d+255|0])|240,t[y+5|0]=z;continue;case 11:t[(e+B(f,6)|0)+3|0]=2;y=b,z=bv(g,w[d+255|0]),t[y+5|0]=z;continue;case 12:t[(e+B(f,6)|0)+3|0]=3;y=b,z=bv(g,w[d+255|0])|240,t[y+5|0]=z;continue;case 13:t[(e+B(f,6)|0)+3|0]=3;y=b,z=bv(g,w[d+255|0]),t[y+5|0]=z;continue;case 14:t[(e+B(f,6)|0)+3|0]=4;if(w[d+255|0]){continue}t[b+5|0]=(g&252)>>>2;continue;case 16:t[(e+B(f,6)|0)+3|0]=20;t[b+5|0]=g&1|16;continue;case 15:t[(e+B(f,6)|0)+3|0]=6;t[b+5|0]=g&240;continue;case 17:t[(e+B(f,6)|0)+3|0]=6;t[b+5|0]=(g&240)>>>4;continue;case 18:t[(e+B(f,6)|0)+3|0]=20;continue;case 20:t[(e+B(f,6)|0)+3|0]=5;continue;case 21:t[(e+B(f,6)|0)+3|0]=20;t[b+5|0]=g&15|48;continue;case 22:t[(e+B(f,6)|0)+3|0]=7;t[b+5|0]=g|240;continue;case 23:t[(e+B(f,6)|0)+3|0]=7;continue;case 30:t[(e+B(f,6)|0)+3|0]=8;continue;case 31:t[(e+B(f,6)|0)+3|0]=20;t[b+5|0]=g&15|64;continue;case 40:t[(e+B(f,6)|0)+3|0]=10;v[22656]=0;f=T(374,j|0)|0;g=v[22656];v[22656]=0;if((g|0)==1){break za}t[b+5|0]=f;v[22656]=0;Q(318,d|0,1)|0;b=v[22656];v[22656]=0;if((b|0)!=1){continue}break za;case 41:t[(e+B(f,6)|0)+3|0]=15;continue;case 42:t[(e+B(f,6)|0)+3|0]=20;t[b+5|0]=g&15|192;continue;case 43:t[(e+B(f,6)|0)+3|0]=20;t[b+5|0]=g&15|208;continue;case 50:t[(e+B(f,6)|0)+3|0]=12;t[b+5|0]=(g&254)>>>1;v[22656]=0;Q(318,d|0,1)|0;b=v[22656];v[22656]=0;if((b|0)!=1){continue}break za;case 51:t[(e+B(f,6)|0)+3|0]=14;t[b+5|0]=0;continue;case 52:t[(e+B(f,6)|0)+3|0]=20;t[b+5|0]=g&15|176;continue;case 53:t[(e+B(f,6)|0)+3|0]=20;t[b+5|0]=g&15|224;continue;case 60:t[(e+B(f,6)|0)+3|0]=16;continue;case 61:t[(e+B(f,6)|0)+3|0]=17;continue;case 70:t[(e+B(f,6)|0)+3|0]=1;continue;case 71:t[(e+B(f,6)|0)+3|0]=20;t[b+5|0]=g&15|32;continue;case 72:t[(e+B(f,6)|0)+3|0]=20;t[b+5|0]=g&15|128;continue;default:break Fa}}t[(e+B(f,6)|0)+3|0]=0;continue}break}xb(d)}c=c+1|0;if((h|0)==(c|0)){break sa}continue}}break}b=P()|0;O()|0;xb(d);break o}b=P()|0;O()|0;break o}b=P()|0;O()|0;break o}b=P()|0;O()|0;break o}b=P()|0;O()|0;break o}b=P()|0;O()|0;break o}b=d+168|0;Eh(b);if(Gb(b,d+184|0)){continue}break}}if(dr(l)>>>0>=2){g=p&1;p=0;while(1){b=Tj(m,p&255);c=bn(l,p);e=x[sc(b,x[c+36>>1])>>1];v[22656]=0;e=me(i,e);f=v[22656];v[22656]=0;Ga:{Ha:{if((f|0)!=1){if(!e){break Ga}e=x[c+36>>1];v[22656]=0;e=Q(546,b|0,e|0)|0;b=v[22656];v[22656]=0;if((b|0)!=1){break Ha}}b=P()|0;O()|0;break o}if(!(!g|!x[a+480188>>1])){k=c+24|0;b=0;while(1){Ce(d,k,b);j=Cb(d);f=_b(i,e);Ia:{if(j){v[22656]=0;j=Be(d,20,145);h=v[22656];v[22656]=0;if((h|0)!=1){j=Fh(pp(Ue(j,0),b&65535));v[22656]=0;Q(431,f|0,j|0)|0;f=v[22656];v[22656]=0;if((f|0)!=1){break Ia}}b=P()|0;O()|0;break o}j=w[lc(c,b)|0];v[22656]=0;j=Be(d,9,j);h=v[22656];v[22656]=0;if((h|0)!=1){j=Fh(pp(Ue(j,0),b&65535));v[22656]=0;Q(431,f|0,j|0)|0;f=v[22656];v[22656]=0;if((f|0)!=1){break Ia}}b=P()|0;O()|0;break o}b=b+1|0;if(b>>>0<x[a+480188>>1]){continue}break}}b=_b(i,e);f=w[c+43|0];v[22656]=0;f=Be(d,16,f);k=v[22656];v[22656]=0;if((k|0)==1){break z}f=Fh(Ue(f,0));v[22656]=0;Q(431,b|0,f|0)|0;b=v[22656];v[22656]=0;if((b|0)==1){break z}b=_b(i,e);c=w[c+42|0];v[22656]=0;c=Be(d,17,c);e=v[22656];v[22656]=0;if((e|0)!=1){c=Fh(Ue(c,0));v[22656]=0;Q(431,b|0,c|0)|0;b=v[22656];v[22656]=0;if((b|0)!=1){break Ga}}b=P()|0;O()|0;break o}p=p+1|0;if(dr(l)>>>0>p>>>0){continue}break}}jd(d+120|0);e=1}jd(d+240|0);KU(l);xb(d+272|0);break b}b=P()|0;O()|0;break o}b=P()|0;O()|0;break j}b=P()|0;O()|0;break j}b=P()|0;O()|0;break j}b=P()|0;O()|0;break c}b=P()|0;O()|0;break c}b=P()|0;O()|0;break j}b=P()|0;O()|0}jd(d+120|0);break j}b=P()|0;O()|0;break j}b=P()|0;O()|0;break j}dv(k)}xb(d+200|0)}jd(d+240|0);break h}b=P()|0;O()|0}KU(l);break f}b=P()|0;O()|0}xb(d+272|0);break c}b=P()|0;O()|0;break c}b=P()|0;O()|0}ke(q);xb(r);S(b|0);L()}ke(q);xb(r)}gb=d+352|0;return e|0}function ipa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,z=0,A=0,C=0,D=0,E=0,F=0,G=0;d=gb-272|0;gb=d;vc(b);f=gb-32|0;gb=f;e=f+24|0;k=d+248|0;Gv(e,k);g=yb(e);e=v[f+28>>2];h=v[f+24>>2];v[f+8>>2]=h;v[f+12>>2]=e;v[f>>2]=h;v[f+4>>2]=e;e=b;h=f+16|0;cc(h,b,f);h=yb(h);if((h|0)==(g|0)){Rb(e,yb(f+24|0))}gb=f+32|0;e=(g|0)==(h|0);if(!e){OX(k)}a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{t:{u:{if(!e){break u}if(!RX(d+248|0)){break u}if(!c){i=1;break u}Gd(a,1024);Bg(a);v[a+480208>>2]=v[a+480208>>2]|12;Rf(a+1074312|0,21);if(Ib(w[d+264|0]|w[d+265|0]<<8)){F=a,G=B(Ib(w[d+264|0]|w[d+265|0]<<8),1e4),v[F+480204>>2]=G}if(Ib(w[d+262|0]|w[d+263|0]<<8)){F=a,G=Ib(w[d+262|0]|w[d+263|0]<<8),v[F+480196>>2]=G}if(!w[d+258|0]){xh(a,1)}e=d+248|4;Uv(b,a+1298268|0,Xb(w[e|0]|w[e+1|0]<<8|(w[e+2|0]<<16|w[e+3|0]<<24))-14|0);b=le(d+144|0,b);v[22656]=0;R(520,d+232|0,b|0);e=v[22656];v[22656]=0;v:{w:{x:{y:{z:{A:{B:{C:{D:{E:{F:{G:{H:{I:{J:{K:{L:{M:{if((e|0)!=1){xb(b);v[22656]=0;U(521,d+144|0,d+232|0,1395544366);b=v[22656];v[22656]=0;if((b|0)==1){break E}v[22656]=0;b=T(421,d+144|0)|0;e=v[22656];v[22656]=0;if((e|0)==1){break L}if(!b){break F}v[22656]=0;b=T(416,d+144|0)|0;e=v[22656];v[22656]=0;if((e|0)==1){break L}v[22656]=0;e=T(416,d+144|0)|0;f=v[22656];v[22656]=0;N:{if((f|0)==1){break N}v[22656]=0;Q(318,d+144|0,4)|0;f=v[22656];v[22656]=0;if((f|0)==1){break N}f=a+484360|0;g=Sb(f);v[22656]=0;fa(522,g|0,d+144|0,b|0,65535,65535)|0;b=v[22656];v[22656]=0;if((b|0)!=1){break M}}break L}a=P()|0;O()|0;xb(b);break a}cf(Sb(f),e);b=d+144|0;xb(b);v[22656]=0;U(521,b|0,d+232|0,1346458708);b=v[22656];v[22656]=0;if((b|0)==1){break K}v[22656]=0;b=T(421,d+144|0)|0;e=v[22656];v[22656]=0;if((e|0)==1){break J}if(!b){break H}v[22656]=0;b=T(416,d+144|0)|0;e=v[22656];v[22656]=0;if((e|0)==1){break J}u[a+480188>>1]=b;if((b-1&65535)>>>0>31){break H}v[22656]=0;b=T(416,d+144|0)|0;e=v[22656];v[22656]=0;if((e|0)==1){break J}v[22656]=0;p=a+484344|0;R(330,p|0,b|0);b=v[22656];v[22656]=0;if((b|0)==1){break J}v[22656]=0;k=T(426,d+144|0)|0;b=v[22656];v[22656]=0;if((b|0)==1){break J}switch(k-841887796|0){case 0:case 2:break G;case 1:break H;default:break I}}a=P()|0;O()|0;xb(d+144|0);break b}a=P()|0;O()|0;break b}a=P()|0;O()|0;xb(d+144|0);break b}if(!k){break G}}xb(d+144|0);break A}xb(d+144|0);v[22656]=0;U(521,d+208|0,d+232|0,1398157625);b=v[22656];v[22656]=0;if((b|0)==1){break D}v[22656]=0;b=T(421,d+208|0)|0;e=v[22656];v[22656]=0;O:{if((e|0)==1){break O}if(!b){break B}v[22656]=0;Q(318,d+208|0,2)|0;b=v[22656];v[22656]=0;if((b|0)==1){break O}v[22656]=0;e=T(426,d+208|0)|0;b=v[22656];v[22656]=0;if((b|0)==1){break c}b=a;f=b;r=(+(e>>>0)*2.3283064365386963e-10+ +(y[b+480204>>2]/1e4>>>0))*1e4;P:{if(r<4294967296&r>=0){b=~~r>>>0;break P}b=0}v[f+480204>>2]=b;v[22656]=0;Q(523,d+208|0,d+144|0)|0;b=v[22656];v[22656]=0;if((b|0)==1){break c}b=0;while(1){if(x[a+480188>>1]<=b>>>0){break C}e=(d+144|0)+(b<<1)|0;F=d,G=Ib(w[e|0]|w[e+1|0]<<8),v[F+80>>2]=G;v[22656]=0;v[d+64>>2]=180;e=pd(d+80|0,d- -64|0);f=v[22656];v[22656]=0;if((f|0)!=1){e=v[e>>2]-90|0;f=e>>31;F=((b<<5)+a|0)+480284|0,G=Ac(lqa(e<<7|45,f<<7|e>>>25,90,0),jb)+128|0,u[F>>1]=G;b=b+1|0;if((b|0)!=32){continue}break C}break}break c}break c}xb(d+144|0);break A}a=P()|0;O()|0;break b}a=P()|0;O()|0;break b}v[22656]=0;Q(318,d+208|0,16)|0;b=v[22656];v[22656]=0;if((b|0)==1){break c}v[22656]=0;b=Q(191,d+208|0,2)|0;e=v[22656];v[22656]=0;if((e|0)==1){break c}if(b){v[22656]=0;b=T(416,d+208|0)|0;e=v[22656];v[22656]=0;if((e|0)==1){break c}u[d+80>>1]=b;v[22656]=0;u[d+64>>1]=256;b=Pc(d+80|0,d- -64|0);e=v[22656];v[22656]=0;if((e|0)==1){break c}v[a+480200>>2]=x[b>>1]}v[22656]=0;Q(318,d+208|0,128)|0;b=v[22656];v[22656]=0;if((b|0)==1){break c}v[22656]=0;b=Q(523,d+208|0,d+80|0)|0;e=v[22656];v[22656]=0;Q:{if((e|0)!=1){if(!b){break B}b=0;while(1){if(x[a+480188>>1]<=b>>>0){break Q}e=(d+80|0)+(b<<1)|0;F=d,G=Ib(w[e|0]|w[e+1|0]<<8),v[F+64>>2]=G;v[22656]=0;v[d+40>>2]=128;e=pd(d- -64|0,d+40|0);f=v[22656];v[22656]=0;if((f|0)!=1){u[((b<<5)+a|0)+480286>>1]=v[e>>2]/2&255;b=b+1|0;if((b|0)!=32){continue}break Q}break}break c}break c}v[a+480228>>2]=v[a+480228>>2]<<1}xb(d+208|0);v[22656]=0;U(521,d+144|0,d+232|0,1413830740);b=v[22656];v[22656]=0;R:{S:{if((b|0)!=1){v[22656]=0;b=T(421,d+144|0)|0;e=v[22656];v[22656]=0;if((e|0)==1){break d}if(!b){break R}v[22656]=0;R(524,d+144|0,d+80|0);b=v[22656];v[22656]=0;if((b|0)==1){break d}if((Ib(w[d+90|0]|w[d+91|0]<<8)|0)!=65535){break S}v[22656]=0;Q(318,d+144|0,1)|0;b=v[22656];v[22656]=0;if((b|0)!=1){break S}break d}a=P()|0;O()|0;break b}v[22656]=0;b=T(467,d+144|0)|0;e=v[22656];v[22656]=0;if((e|0)==1){break d}v[22656]=0;da(510,a+1298292|0,d+144|0,b|0,2)|0;b=v[22656];v[22656]=0;if((b|0)==1){break d}}xb(d+144|0);v[22656]=0;U(521,d+80|0,d+232|0,1229869908);b=v[22656];v[22656]=0;if((b|0)==1){break e}v[22656]=0;b=T(421,d+80|0)|0;e=v[22656];v[22656]=0;if((e|0)!=1){if(b){v[22656]=0;b=T(416,d+80|0)|0;e=v[22656];v[22656]=0;if((e|0)==1){break g}T:{e=b<<16>>16;g=e&32767;if(g>>>0>3999){break T}v[22656]=0;b=Q(191,d+80|0,B(g,(e>>>14&2)+50|0)|0)|0;f=v[22656];v[22656]=0;if((f|0)==1){break y}if(!b){break T}u[a+480190>>1]=g;i=a+480190|0;if(!g){break z}h=d+162|0;b=1;j=(e|0)>=0;U:{V:{while(1){W:{e=b;f=d;X:{Y:{Z:{if(!j){v[22656]=0;e=T(416,d+80|0)|0;l=v[22656];v[22656]=0;if((l|0)==1){break Z}e=e+1|0}u[f+40>>1]=e;v[22656]=0;R(525,d+80|0,d+144|0);e=v[22656];v[22656]=0;if((e|0)!=1){if((x[d+40>>1]-1&65535)>>>0>3998){break X}v[22656]=0;e=Le(i,d+40|0);f=v[22656];v[22656]=0;if((f|0)!=1){break Y}}a=P()|0;O()|0;break f}a=P()|0;O()|0;break f}u[a+480190>>1]=x[e>>1];e=x[d+40>>1];f=Xb(w[d+266|0]|w[d+267|0]<<8|(w[d+268|0]<<16|w[d+269|0]<<24));v[22656]=0;Y(526,d+144|0,(B(e,104)+a|0)+484380|0,f|0,k|0);e=v[22656];v[22656]=0;if((e|0)==1){break W}v[22656]=0;Rk(d- -64|0,2,h);e=v[22656];v[22656]=0;if((e|0)==1){break V}v[22656]=0;R(324,d+208|0,d- -64|0);e=v[22656];v[22656]=0;if((e|0)==1){break V}v[22656]=0;Q(301,((x[d+40>>1]<<5)+a|0)+946304|0,d+208|0)|0;e=v[22656];v[22656]=0;if((e|0)==1){break U}vb(d+208|0)}e=b&65535;b=b+1|0;if(e>>>0<g>>>0){continue}break z}break}a=P()|0;O()|0;break f}a=P()|0;O()|0;break f}a=P()|0;O()|0;vb(d+208|0);break f}xb(d+80|0);break A}break w}a=P()|0;O()|0;break f}break v}v[22656]=0;b=T(416,d+80|0)|0;e=v[22656];v[22656]=0;if((e|0)!=1){break x}}a=P()|0;O()|0;break f}if((b|0)==4){u[d+144>>1]=x[i>>1];v[22656]=0;u[d+208>>1]=255;b=Pc(d+144|0,d+208|0);e=v[22656];v[22656]=0;if((e|0)==1){break h}u[a+480192>>1]=x[b>>1];v[22656]=0;U(521,d+208|0,d+232|0,1229278806);b=v[22656];v[22656]=0;if((b|0)==1){break i}b=d- -64|0;g=b|4;i=b|3;h=b|5;j=b|7;while(1){v[22656]=0;b=Q(191,d+80|0,15)|0;e=v[22656];v[22656]=0;_:{if((e|0)!=1){$:{if(b){v[22656]=0;R(528,d+80|0,d- -64|0);b=v[22656];v[22656]=0;aa:{if((b|0)!=1){b=d- -64|0;if(Ib(w[b|0]|w[b+1|0]<<8)>>>0>=x[a+480192>>1]){continue}f=d- -64|0;b=f;b=B(Ib(w[b|0]|w[b+1|0]<<8),104)+a|0;t[b+484524|0]=w[d+72|0];e=w[j|0];t[b+484523|0]=255;t[b+484525|0]=e;b=f;b=Ib(w[b|0]|w[b+1|0]<<8);e=f;e=Ib(w[e|0]|w[e+1|0]<<8);v[22656]=0;e=W(376,a|0,b+1&65535,e+1&65535)|0;b=v[22656];v[22656]=0;if((b|0)==1){break $}if(!e){continue}F=d,G=Ib(w[h|0]|w[h+1|0]<<8),u[F+144>>1]=G;v[22656]=0;u[d+40>>1]=4095;b=Pc(d+144|0,d+40|0);f=v[22656];v[22656]=0;if((f|0)==1){break $}v[e>>2]=x[b>>1];if(w[i|0]==255){continue}b=w[i|0];v[22656]=0;b=Q(190,d+208|0,B(b,34)+2|0)|0;f=v[22656];v[22656]=0;if((f|0)==1){break $}if(!b){continue}v[22656]=0;R(529,d+208|0,d+144|0);b=v[22656];v[22656]=0;if((b|0)==1){break $}t[e+60|0]=w[e+60|0]|1;b=Ib(w[d+144|0]|w[d+145|0]<<8);v[d+60>>2]=3;v[d+44>>2]=16;v[d+48>>2]=240;v[d+40>>2]=b;v[d+56>>2]=d+40;b=v[d+60>>2];v[d+8>>2]=v[d+56>>2];v[d+12>>2]=b;b=PX(d+8|0);v[22656]=0;f=e+48|0;R(446,f|0,b|0);b=v[22656];v[22656]=0;if((b|0)==1){break $}b=0;if(Nb(f)){break aa}break _}break $}while(1){ba:{t[d+40|0]=64;l=(d+144|0)+(b<<1)|0;n=w[l+2|0];v[22656]=0;t[d+32|0]=n;n=ac(d+40|0,d+32|0);o=v[22656];v[22656]=0;if((o|0)==1){break ba}n=w[n|0];F=Mb(f,b),G=n,t[F+2|0]=G;l=w[l+3|0];F=Mb(f,b),G=l,u[F>>1]=G;b=b+1|0;if(Nb(f)>>>0>b>>>0){continue}break _}break}break $}xb(d+208|0);break w}}a=P()|0;O()|0;xb(d+208|0);break f}if(w[g|0]!=255){t[e+60|0]=w[e+60|0]|4;b=w[g|0];t[e+63|0]=b;t[e- -64|0]=b}if(cd(f)){continue}t[e+60|0]=w[e+60|0]|2;b=Nb(f)-1|0;t[e+61|0]=b;t[e+62|0]=b;continue}}}xb(d+80|0);v[22656]=0;U(530,d+208|0,d+232|0,1145131092);b=v[22656];v[22656]=0;if((b|0)==1){break j}b=d+208|0;F=d,G=Vb(b),v[F+32>>2]=G;F=d,G=Zb(b),v[F+24>>2]=G;if(Gb(d+32|0,d+24|0)){z=c&1;l=d+80|4;n=(k|0)!=841887798;A=(k|0)!=841887796;while(1){g=v[d+32>>2];v[22656]=0;Q(318,g|0,4)|0;b=v[22656];v[22656]=0;ca:{da:{ea:{if((b|0)!=1){v[22656]=0;f=T(416,g|0)|0;b=v[22656];v[22656]=0;if((b|0)==1){break l}v[22656]=0;h=T(416,g|0)|0;b=v[22656];v[22656]=0;if((b|0)==1){break m}h=n?h:(h>>>0)/y[a+480196>>2]|0;if(!z|f>>>0>255){break ca}v[22656]=0;b=W(331,p|0,f|0,h|0)|0;e=v[22656];v[22656]=0;if((e|0)==1){break m}if(!b){break ca}if(n){break da}v[22656]=0;Q(318,g|0,4)|0;b=v[22656];v[22656]=0;if((b|0)==1){break m}j=0;if(!x[a+480188>>1]){break ca}while(1){v[22656]=0;b=T(416,g|0)|0;e=v[22656];v[22656]=0;if((e|0)==1){break ea}v[22656]=0;U(288,d+80|0,g|0,b+(b&1)&65535);b=v[22656];v[22656]=0;if((b|0)==1){break n}b=d+80|0;i=kc(d+144|0,b);xb(b);v[d+80>>2]=0;v[d+84>>2]=0;o=0;fa:{while(1){v[22656]=0;b=Q(191,d+144|0,6)|0;e=v[22656];v[22656]=0;if((e|0)==1){break o}if(!(b&y[d+80>>2]<h>>>0)){break fa}b=_b(p,f);v[22656]=0;b=Yc(b,v[d+80>>2],j&65535);e=v[22656];v[22656]=0;ga:{ha:{if((e|0)!=1){v[22656]=0;R(531,d+40|0,i|0);e=v[22656];v[22656]=0;if((e|0)==1){break o}e=d+40|0;m=qd(e);C=Ve(e);D=ej(e);q=fc(e);E=e+5|0;e=t[e|0];if((e-1&255)>>>0>95){break ha}t[b|0]=e+13;if(!v[d+84>>2]){break ga}t[b+3|0]=19;v[22656]=0;v[d+64>>2]=15;e=pd(l,d- -64|0);s=v[22656];v[22656]=0;if((s|0)==1){break o}t[b+5|0]=w[e|0]|208;break ga}break o}if((e|0)>=0){break ga}if(v[d+84>>2]){t[b+3|0]=19;v[22656]=0;v[d+64>>2]=15;e=pd(l,d- -64|0);s=v[22656];v[22656]=0;if((s|0)!=1){t[b+5|0]=w[e|0]|192;break ga}break o}t[b|0]=254}if(w[m|0]){t[b+2|0]=1;v[22656]=0;t[d+64|0]=64;e=ac(m,d- -64|0);m=v[22656];v[22656]=0;if((m|0)==1){break o}t[b+4|0]=w[e|0]}e=w[C|0];if(e){t[b+1|0]=e}e=w[D|0];if(e|w[q|0]){t[b+3|0]=e;t[b+5|0]=w[q|0];v[22656]=0;Of(b);b=v[22656];v[22656]=0;if((b|0)==1){break o}}b=w[E|0];if(b&128){v[22656]=0;e=T(374,i|0)|0;m=v[22656];v[22656]=0;if((m|0)==1){break o}b=e|b<<8&32512}e=v[a+480196>>2];v[22656]=0;o=b+o|0;mt(d- -64|0,o,e);b=v[22656];v[22656]=0;if((b|0)!=1){b=v[d+68>>2];v[d+80>>2]=v[d+64>>2];v[d+84>>2]=b;continue}break}break o}xb(d+144|0);j=j+1|0;if(x[a+480188>>1]>(j&65535)>>>0){continue}break}break ca}a=P()|0;O()|0;break k}a=P()|0;O()|0;break k}b=_b(p,f);v[22656]=0;b=Yc(b,0,0);e=v[22656];v[22656]=0;if((e|0)==1){break s}j=0;if(!h){break ca}while(1){i=0;ia:{if(!x[a+480188>>1]){break ia}while(1){ja:{v[22656]=0;R(532,d+144|0,g|0);e=v[22656];v[22656]=0;if((e|0)==1){break ja}ka:{if(!A){v[d+80>>2]=v[d+144>>2];e=d+80|0;o=qd(e);m=Ve(e);q=ej(e);e=t[e|0];if((e|0)>0){t[b|0]=(B((e&240)>>>4|0,12)+(e&15)|0)+12}f=b;e=w[o|0];if(e>>>0>=4){t[b+2|0]=1;t[b+4|0]=(e>>>2|0)-1;e=w[o|0]}t[f+1|0]=e<<4&48|w[m|0]>>>4;t[b+3|0]=w[m|0]&15;t[b+5|0]=w[q|0];break ka}e=v[d+144>>2];v[d+20>>2]=e;v[22656]=0;v[d+16>>2]=e;gr(d+16|0,b);e=v[22656];v[22656]=0;if((e|0)==1){break ja}e=ic(d+144|0,0);t[b+1|0]=w[b+1|0]|w[e|0]&48}v[22656]=0;Of(b);e=v[22656];v[22656]=0;if((e|0)==1){break ja}e=w[b+3|0];la:{if(e>>>0>11){break la}e=1<<e;ma:{if(!(e&2240)){if(!(e&12)){break la}if(!w[b+5|0]){break ma}break la}e=w[b+5|0];f=e&240;if(f){t[b+5|0]=f;break la}if(e){break la}}t[b+3|0]=0}b=b+6|0;i=i+1|0;if(x[a+480188>>1]>(i&65535)>>>0){continue}break ia}break}a=P()|0;O()|0;break k}j=j+1|0;if((j|0)!=(h|0)){continue}break}}b=d+32|0;Eh(b);if(Gb(b,d+24|0)){continue}break}}jd(d+208|0);v[22656]=0;U(521,d+144|0,d+232|0,1346458702);b=v[22656];v[22656]=0;if((b|0)==1){a=P()|0;O()|0;break b}v[22656]=0;b=T(421,d+144|0)|0;e=v[22656];v[22656]=0;na:{oa:{pa:{qa:{ra:{sa:{ta:{ua:{va:{wa:{xa:{ya:{za:{Aa:{if((e|0)!=1){if(b){e=Kb(d+80|0);b=0;Ba:{while(1){Ca:{v[22656]=0;f=Q(191,d+144|0,1)|0;g=v[22656];v[22656]=0;if((g|0)==1){break Ca}if(!f){break Ba}if(Te(p)>>>0<=b>>>0){break Ba}v[22656]=0;W(534,d+144|0,e|0,32)|0;f=v[22656];v[22656]=0;if((f|0)==1){break Ca}f=_b(p,b);v[22656]=0;Q(428,f|0,e|0)|0;f=v[22656];v[22656]=0;if((f|0)==1){break Ca}b=b+1|0;continue}break}a=P()|0;O()|0;vb(e);break Aa}vb(e)}b=d+144|0;xb(b);v[22656]=0;U(521,b|0,d+232|0,1414679374);b=v[22656];v[22656]=0;if((b|0)==1){break za}v[22656]=0;b=T(421,d+144|0)|0;e=v[22656];v[22656]=0;if((e|0)==1){break va}if(!b){break wa}e=Kb(d+80|0);b=0;while(1){v[22656]=0;f=Q(191,d+144|0,1)|0;g=v[22656];v[22656]=0;if((g|0)==1){break ya}if(!f|x[a+480188>>1]<=b>>>0){break xa}v[22656]=0;W(534,d+144|0,e|0,32)|0;f=v[22656];v[22656]=0;if((f|0)==1){break ya}v[22656]=0;Q(399,((b<<5)+a|0)+480289|0,e|0)|0;f=v[22656];v[22656]=0;if((f|0)==1){break ya}b=b+1|0;continue}}a=P()|0;O()|0}xb(d+144|0);break b}a=P()|0;O()|0;break b}a=P()|0;O()|0;vb(e);break ua}vb(e)}b=d+144|0;xb(b);v[22656]=0;U(530,b|0,d+232|0,1145129300);b=v[22656];v[22656]=0;if((b|0)==1){break ta}b=d+144|0;F=d,G=Vb(b),v[F+80>>2]=G;F=d,G=Zb(b),v[F+208>>2]=G;if(Gb(d+80|0,d+208|0)){e=c&2;while(1){b=v[d+80>>2];v[22656]=0;c=T(416,b|0)|0;f=v[22656];v[22656]=0;if((f|0)==1){break p}if(!(!e|c>>>0>=x[a+480190>>1])){c=B(c,104)+a|0;f=x[c+484518>>1];f=Rc(d- -64|0,f&1?16:8,f&64?2:1,1,0);v[22656]=0;W(329,f|0,c+484484|0,b|0)|0;b=v[22656];v[22656]=0;if((b|0)==1){break p}}b=d+80|0;Eh(b);if(Gb(b,d+208|0)){continue}break}}jd(d+144|0);b=Kb(d+80|0);if((k|0)!=841887798){break ra}v[22656]=0;c=Q(2,d+144|0,6647)|0;e=v[22656];v[22656]=0;if((e|0)==1){break sa}Eb(b,c);vb(c);break qa}a=P()|0;O()|0}xb(d+144|0);break b}a=P()|0;O()|0;break b}a=P()|0;O()|0;break q}v[22656]=0;U(521,d+144|0,d+232|0,1447383635);c=v[22656];v[22656]=0;Da:{Ea:{Fa:{Ga:{Ha:{if((c|0)!=1){v[22656]=0;c=T(421,d+144|0)|0;e=v[22656];v[22656]=0;if((e|0)==1){break pa}if(!c){break Ea}v[22656]=0;c=T(426,d+144|0)|0;e=v[22656];v[22656]=0;if((e|0)==1){break Ha}v[22656]=0;R(411,d- -64|0,1401);e=v[22656];v[22656]=0;if((e|0)==1){break Ga}v[d+40>>2]=c>>>4;v[22656]=0;v[d+32>>2]=c&15;Y(535,d+208|0,d- -64|0,d+40|0,d+32|0);c=v[22656];v[22656]=0;if((c|0)==1){break Fa}c=d+208|0;Eb(b,c);vb(c);Hb(d- -64|0);break Da}a=P()|0;O()|0;break q}a=P()|0;O()|0;break r}a=P()|0;O()|0;break r}a=P()|0;O()|0;Hb(d- -64|0);break r}v[22656]=0;c=Q(2,d+208|0,5656)|0;e=v[22656];v[22656]=0;if((e|0)==1){break t}Eb(b,c);vb(c)}xb(d+144|0)}v[22656]=0;c=Q(2,d+144|0,5656)|0;e=v[22656];v[22656]=0;if((e|0)==1){break oa}Eb(a+1298304|0,c);vb(c);v[22656]=0;c=Q(2,d+144|0,7403)|0;e=v[22656];v[22656]=0;if((e|0)==1){break na}Eb(a+1298316|0,c);vb(c);Eb(a+1298328|0,b);v[a+1298364>>2]=2;vb(b);i=1;break v}a=P()|0;O()|0;break r}a=P()|0;O()|0;break q}a=P()|0;O()|0;break q}ke(d+232|0)}gb=d+272|0;return i|0}a=P()|0;O()|0;break r}a=P()|0;O()|0;break k}xb(d+144|0)}vb(b);break b}a=P()|0;O()|0;jd(d+144|0);break b}a=P()|0;O()|0;xb(d+144|0);break k}a=P()|0;O()|0;break k}a=P()|0;O()|0;break k}a=P()|0;O()|0}jd(d+208|0);break b}a=P()|0;O()|0;break b}a=P()|0;O()|0;break f}a=P()|0;O()|0;break f}a=P()|0;O()|0}xb(d+80|0);break b}a=P()|0;O()|0;break b}a=P()|0;O()|0;xb(d+144|0);break b}a=P()|0;O()|0;xb(d+208|0)}ke(d+232|0)}S(a|0);L()}function RH(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,u=0,x=0,z=0,A=0,D=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,O=0;x=gb-48|0;gb=x;a:{if(c>>>0<=2){c=c<<2;I=v[c+76812>>2];H=v[c+76800>>2];while(1){c=v[b+4>>2];b:{if(c>>>0<y[b+104>>2]){v[b+4>>2]=c+1;c=w[c|0];break b}c=md(b)}if(vm(c)){continue}break}m=1;c:{d:{switch(c-43|0){case 0:case 2:break d;default:break c}}m=(c|0)==45?-1:1;c=v[b+4>>2];if(c>>>0<y[b+104>>2]){v[b+4>>2]=c+1;c=w[c|0];break c}c=md(b)}e:{f:{while(1){if(t[f+2048|0]==(c|32)){g:{if(f>>>0>6){break g}c=v[b+4>>2];if(c>>>0<y[b+104>>2]){v[b+4>>2]=c+1;c=w[c|0];break g}c=md(b)}f=f+1|0;if((f|0)!=8){continue}break f}break}if((f|0)!=3){if((f|0)==8){break f}if(!d|f>>>0<4){break e}if((f|0)==8){break f}}c=v[b+104>>2];if(c){v[b+4>>2]=v[b+4>>2]-1}if(!d|f>>>0<4){break f}while(1){if(c){v[b+4>>2]=v[b+4>>2]-1}f=f-1|0;if(f>>>0>3){continue}break}}b=x;h=gb-16|0;gb=h;g=(p(C(C(m|0)*C(N))),j(2));c=g&2147483647;h:{if(c-8388608>>>0<=2130706431){d=c;c=c>>>7|0;m=d<<25;d=c+1065353216|0;break h}m=g<<25;d=g>>>7|2147418112;if(c>>>0>=2139095040){break h}m=0;d=0;if(!c){break h}d=c;c=E(c);Kf(h,d,0,0,0,c+81|0);i=v[h>>2];l=v[h+4>>2];m=v[h+8>>2];d=v[h+12>>2]^65536|16265-c<<16}v[b>>2]=i;v[b+4>>2]=l;v[b+8>>2]=m;v[b+12>>2]=g&-2147483648|d;gb=h+16|0;i=v[x+8>>2];l=v[x+12>>2];h=v[x>>2];g=v[x+4>>2];break a}i:{j:{k:{if(f){break k}f=0;while(1){if(t[f+7248|0]!=(c|32)){break k}l:{if(f>>>0>1){break l}c=v[b+4>>2];if(c>>>0<y[b+104>>2]){v[b+4>>2]=c+1;c=w[c|0];break l}c=md(b)}f=f+1|0;if((f|0)!=3){continue}break}break j}m:{switch(f|0){case 0:n:{if((c|0)!=48){break n}f=v[b+4>>2];o:{if(f>>>0<y[b+104>>2]){v[b+4>>2]=f+1;f=w[f|0];break o}f=md(b)}if((f&-33)==88){f=gb-432|0;gb=f;c=b;A=v[b+104>>2];b=v[b+4>>2];p:{if(A>>>0>b>>>0){v[c+4>>2]=b+1;b=w[b|0];break p}b=md(c)}q:{r:{while(1){if((b|0)!=48){s:{if((b|0)!=46){break q}b=v[c+4>>2];if(b>>>0>=y[c+104>>2]){break s}v[c+4>>2]=b+1;b=w[b|0];break r}}else{b=v[c+4>>2];if(b>>>0<y[c+104>>2]){J=1;v[c+4>>2]=b+1;b=w[b|0]}else{J=1;b=md(c)}continue}break}b=md(c)}G=1;if((b|0)!=48){break q}while(1){b=i;i=b-1|0;l=l-!b|0;b=v[c+4>>2];t:{if(b>>>0<y[c+104>>2]){v[c+4>>2]=b+1;b=w[b|0];break t}b=md(c)}if((b|0)==48){continue}break}J=1}A=1073676288;u:{while(1){v:{o=b|32;w:{x:{D=b-48|0;if(D>>>0<10){break x}if((b|0)!=46&o-97>>>0>=6){break u}if((b|0)!=46){break x}if(G){break v}G=1;i=h;l=g;break w}b=(b|0)>57?o-87|0:D;y:{if((g|0)<=0&h>>>0<=7|(g|0)<0){k=b+(k<<4)|0;break y}if(!g&h>>>0<=28){Vg(f+48|0,b);Ed(f+32|0,r,z,F,A,0,0,0,1073414144);r=v[f+32>>2];z=v[f+36>>2];F=v[f+40>>2];A=v[f+44>>2];Ed(f+16|0,r,z,F,A,v[f+48>>2],v[f+52>>2],v[f+56>>2],v[f+60>>2]);yg(f,q,e,s,u,v[f+16>>2],v[f+20>>2],v[f+24>>2],v[f+28>>2]);s=v[f+8>>2];u=v[f+12>>2];q=v[f>>2];e=v[f+4>>2];break y}if(!b|n){break y}Ed(f+80|0,r,z,F,A,0,0,0,1073610752);yg(f- -64|0,q,e,s,u,v[f+80>>2],v[f+84>>2],v[f+88>>2],v[f+92>>2]);s=v[f+72>>2];u=v[f+76>>2];n=1;q=v[f+64>>2];e=v[f+68>>2]}b=h+1|0;g=b?g:g+1|0;h=b;J=1}b=v[c+4>>2];if(b>>>0<y[c+104>>2]){v[c+4>>2]=b+1;b=w[b|0]}else{b=md(c)}continue}break}b=46}z:{A:{B:{if(!J){if(!v[c+104>>2]){if(d){break A}break B}b=v[c+4>>2];v[c+4>>2]=b-1;if(!d){break B}v[c+4>>2]=b-2;if(!G){break A}v[c+4>>2]=b-3;break A}if((g|0)<=0&h>>>0<=7|(g|0)<0){F=h;A=g;while(1){k=k<<4;n=A;A=F+1|0;n=A?n:n+1|0;F=A;A=n;if((F|0)!=8|n){continue}break}}C:{D:{E:{if((b&-33)==80){F=QH(c,d);b=jb;A=b;if(F|(b|0)!=-2147483648){break C}if(d){if(v[c+104>>2]){break E}break D}q=0;e=0;wi(c,0,0);c=0;b=0;break z}if(!v[c+104>>2]){break D}}v[c+4>>2]=v[c+4>>2]-1}F=0;A=0}if(!k){sj(f+112|0,+(m|0)*0);q=v[f+112>>2];e=v[f+116>>2];c=v[f+124>>2];b=v[f+120>>2];break z}b=G?i:h;c=(G?l:g)<<2|b>>>30;b=F+(b<<2)|0;c=c+A|0;c=b>>>0<F>>>0?c+1|0:c;h=b-32|0;g=c-(b>>>0<32)|0;b=g;if(h>>>0>0-I>>>0&(b|0)>=0|(b|0)>0){v[115137]=68;Vg(f+160|0,m);Ed(f+144|0,v[f+160>>2],v[f+164>>2],v[f+168>>2],v[f+172>>2],-1,-1,-1,2147418111);Ed(f+128|0,v[f+144>>2],v[f+148>>2],v[f+152>>2],v[f+156>>2],-1,-1,-1,2147418111);q=v[f+128>>2];e=v[f+132>>2];c=v[f+140>>2];b=v[f+136>>2];break z}b=I-226|0;c=b;b=b>>31;if(c>>>0<=h>>>0&(g|0)>=(b|0)|(b|0)<(g|0)){if((k|0)>=0){while(1){yg(f+416|0,q,e,s,u,0,0,0,-1073807360);c=sB(q,e,s,u,1073610752);b=(c|0)<0;yg(f+400|0,q,e,s,u,b?q:v[f+416>>2],b?e:v[f+420>>2],b?s:v[f+424>>2],b?u:v[f+428>>2]);b=h;h=b-1|0;g=g-!b|0;s=v[f+408>>2];u=v[f+412>>2];q=v[f+400>>2];e=v[f+404>>2];k=k<<1|(c|0)>=0;if((k|0)>=0){continue}break}}b=h;c=I;d=(b-c|0)+32|0;c=g-((c>>31)+(b>>>0<c>>>0)|0)|0;c=d>>>0<32?c+1|0:c;b=d;c=b>>>0<H>>>0&(c|0)<=0|(c|0)<0?(b|0)>0?b:0:H;F:{if((c|0)>=113){Vg(f+384|0,m);i=v[f+392>>2];l=v[f+396>>2];r=v[f+384>>2];z=v[f+388>>2];g=0;b=0;break F}sj(f+352|0,ii(1,144-c|0));Vg(f+336|0,m);r=v[f+336>>2];z=v[f+340>>2];i=v[f+344>>2];l=v[f+348>>2];TH(f+368|0,v[f+352>>2],v[f+356>>2],v[f+360>>2],v[f+364>>2],r,z,i,l);K=v[f+376>>2];L=v[f+380>>2];g=v[f+372>>2];b=v[f+368>>2]}c=!(k&1)&((sn(q,e,s,u,0,0,0,0)|0)!=0&(c|0)<32);Yn(f+320|0,c+k|0);Ed(f+304|0,r,z,i,l,v[f+320>>2],v[f+324>>2],v[f+328>>2],v[f+332>>2]);d=b;yg(f+272|0,v[f+304>>2],v[f+308>>2],v[f+312>>2],v[f+316>>2],b,g,K,L);b=c;Ed(f+288|0,b?0:q,b?0:e,b?0:s,b?0:u,r,z,i,l);yg(f+256|0,v[f+288>>2],v[f+292>>2],v[f+296>>2],v[f+300>>2],v[f+272>>2],v[f+276>>2],v[f+280>>2],v[f+284>>2]);Nx(f+240|0,v[f+256>>2],v[f+260>>2],v[f+264>>2],v[f+268>>2],d,g,K,L);b=v[f+240>>2];c=v[f+244>>2];d=v[f+248>>2];i=v[f+252>>2];if(!sn(b,c,d,i,0,0,0,0)){v[115137]=68}SH(f+224|0,b,c,d,i,h);q=v[f+224>>2];e=v[f+228>>2];c=v[f+236>>2];b=v[f+232>>2];break z}v[115137]=68;Vg(f+208|0,m);Ed(f+192|0,v[f+208>>2],v[f+212>>2],v[f+216>>2],v[f+220>>2],0,0,0,65536);Ed(f+176|0,v[f+192>>2],v[f+196>>2],v[f+200>>2],v[f+204>>2],0,0,0,65536);q=v[f+176>>2];e=v[f+180>>2];c=v[f+188>>2];b=v[f+184>>2];break z}wi(c,0,0)}sj(f+96|0,+(m|0)*0);q=v[f+96>>2];e=v[f+100>>2];c=v[f+108>>2];b=v[f+104>>2]}v[x+16>>2]=q;v[x+20>>2]=e;v[x+24>>2]=b;v[x+28>>2]=c;gb=f+432|0;i=v[x+24>>2];l=v[x+28>>2];h=v[x+16>>2];g=v[x+20>>2];break a}if(!v[b+104>>2]){break n}v[b+4>>2]=v[b+4>>2]-1}k=b;q=m;m=0;f=0;e=gb-8976|0;gb=e;J=H+I|0;O=0-J|0;G:{H:{while(1){if((c|0)!=48){I:{if((c|0)!=46){break G}b=v[k+4>>2];if(b>>>0>=y[k+104>>2]){break I}v[k+4>>2]=b+1;c=w[b|0];break H}}else{b=v[k+4>>2];if(b>>>0<y[k+104>>2]){m=1;v[k+4>>2]=b+1;c=w[b|0]}else{m=1;c=md(k)}continue}break}c=md(k)}o=1;if((c|0)!=48){break G}while(1){b=i;i=b-1|0;l=l-!b|0;b=v[k+4>>2];J:{if(b>>>0<y[k+104>>2]){v[k+4>>2]=b+1;c=w[b|0];break J}c=md(k)}if((c|0)==48){continue}break}m=1}v[e+784>>2]=0;K:{L:{b=(c|0)==46;n=c-48|0;M:{N:{O:{P:{if(!(!b&n>>>0>9)){while(1){Q:{if(b&1){if(!o){i=h;l=g;o=1;break Q}b=!m;break P}b=h+1|0;g=b?g:g+1|0;h=b;if((f|0)<=2044){G=(c|0)==48?G:h;b=(e+784|0)+(f<<2)|0;m=b;if(D){n=(B(v[b>>2],10)+c|0)-48|0}v[m>>2]=n;m=1;c=D+1|0;b=(c|0)==9;D=b?0:c;f=b+f|0;break Q}if((c|0)==48){break Q}v[e+8960>>2]=v[e+8960>>2]|1;G=18396}b=v[k+4>>2];R:{if(b>>>0<y[k+104>>2]){v[k+4>>2]=b+1;c=w[b|0];break R}c=md(k)}b=(c|0)==46;n=c-48|0;if(b|n>>>0<10){continue}break}}i=o?i:h;l=o?l:g;if(!(!m|(c&-33)!=69)){r=QH(k,d);b=jb;z=b;S:{if(r|(b|0)!=-2147483648){break S}if(!d){break M}r=0;z=0;if(!v[k+104>>2]){break S}v[k+4>>2]=v[k+4>>2]-1}if(!m){break N}n=l+z|0;b=i+r|0;n=b>>>0<r>>>0?n+1|0:n;i=b;l=n;break L}b=!m;if((c|0)<0){break O}}if(!v[k+104>>2]){break O}v[k+4>>2]=v[k+4>>2]-1}if(!b){break L}}v[115137]=28}h=0;g=0;wi(k,0,0);c=0;b=0;break K}b=v[e+784>>2];if(!b){sj(e,+(q|0)*0);h=v[e>>2];g=v[e+4>>2];c=v[e+12>>2];b=v[e+8>>2];break K}if(!((h|0)!=(i|0)|(g|0)!=(l|0)|(h>>>0>9&(g|0)>=0|(g|0)>0)|(b>>>H|0?(H|0)<=30:0))){Vg(e+48|0,q);Yn(e+32|0,b);Ed(e+16|0,v[e+48>>2],v[e+52>>2],v[e+56>>2],v[e+60>>2],v[e+32>>2],v[e+36>>2],v[e+40>>2],v[e+44>>2]);h=v[e+16>>2];g=v[e+20>>2];c=v[e+28>>2];b=v[e+24>>2];break K}if(i>>>0>(I|0)/-2>>>0&(l|0)>=0|(l|0)>0){v[115137]=68;Vg(e+96|0,q);Ed(e+80|0,v[e+96>>2],v[e+100>>2],v[e+104>>2],v[e+108>>2],-1,-1,-1,2147418111);Ed(e- -64|0,v[e+80>>2],v[e+84>>2],v[e+88>>2],v[e+92>>2],-1,-1,-1,2147418111);h=v[e+64>>2];g=v[e+68>>2];c=v[e+76>>2];b=v[e+72>>2];break K}b=I-226|0;c=i>>>0<b>>>0;b=b>>31;if(c&(l|0)<=(b|0)|(b|0)>(l|0)){v[115137]=68;Vg(e+144|0,q);Ed(e+128|0,v[e+144>>2],v[e+148>>2],v[e+152>>2],v[e+156>>2],0,0,0,65536);Ed(e+112|0,v[e+128>>2],v[e+132>>2],v[e+136>>2],v[e+140>>2],0,0,0,65536);h=v[e+112>>2];g=v[e+116>>2];c=v[e+124>>2];b=v[e+120>>2];break K}if(D){if((D|0)<=8){b=(e+784|0)+(f<<2)|0;k=v[b>>2];while(1){k=B(k,10);D=D+1|0;if((D|0)!=9){continue}break}v[b>>2]=k}f=f+1|0}T:{o=i;if((G|0)>(i|0)|(G|0)>=9|(i|0)>17){break T}if((o|0)==9){Vg(e+192|0,q);Yn(e+176|0,v[e+784>>2]);Ed(e+160|0,v[e+192>>2],v[e+196>>2],v[e+200>>2],v[e+204>>2],v[e+176>>2],v[e+180>>2],v[e+184>>2],v[e+188>>2]);h=v[e+160>>2];g=v[e+164>>2];c=v[e+172>>2];b=v[e+168>>2];break K}if((o|0)<=8){Vg(e+272|0,q);Yn(e+256|0,v[e+784>>2]);Ed(e+240|0,v[e+272>>2],v[e+276>>2],v[e+280>>2],v[e+284>>2],v[e+256>>2],v[e+260>>2],v[e+264>>2],v[e+268>>2]);Vg(e+224|0,v[(0-o<<2)+76800>>2]);gF(e+208|0,v[e+240>>2],v[e+244>>2],v[e+248>>2],v[e+252>>2],v[e+224>>2],v[e+228>>2],v[e+232>>2],v[e+236>>2]);h=v[e+208>>2];g=v[e+212>>2];c=v[e+220>>2];b=v[e+216>>2];break K}b=(B(o,-3)+H|0)+27|0;c=v[e+784>>2];if(c>>>b|0?(b|0)<=30:0){break T}Vg(e+352|0,q);Yn(e+336|0,c);Ed(e+320|0,v[e+352>>2],v[e+356>>2],v[e+360>>2],v[e+364>>2],v[e+336>>2],v[e+340>>2],v[e+344>>2],v[e+348>>2]);Vg(e+304|0,v[(o<<2)+76728>>2]);Ed(e+288|0,v[e+320>>2],v[e+324>>2],v[e+328>>2],v[e+332>>2],v[e+304>>2],v[e+308>>2],v[e+312>>2],v[e+316>>2]);h=v[e+288>>2];g=v[e+292>>2];c=v[e+300>>2];b=v[e+296>>2];break K}while(1){c=f;f=f-1|0;if(!v[(e+784|0)+(f<<2)>>2]){continue}break}D=0;b=(o|0)%9|0;U:{if(!b){b=0;break U}d=(o|0)>=0?b:b+9|0;V:{if(!c){b=0;c=0;break V}i=v[(0-d<<2)+76800>>2];h=1e9/(i|0)|0;n=0;k=0;b=0;while(1){g=n;l=(e+784|0)+(k<<2)|0;n=v[l>>2];m=(n>>>0)/(i>>>0)|0;g=g+m|0;v[l>>2]=g;g=!g&(b|0)==(k|0);b=g?b+1&2047:b;o=g?o-9|0:o;n=B(h,n-B(i,m)|0);k=k+1|0;if((k|0)!=(c|0)){continue}break}if(!n){break V}v[(e+784|0)+(c<<2)>>2]=n;c=c+1|0}o=(o-d|0)+9|0}while(1){h=(e+784|0)+(b<<2)|0;W:{while(1){if(((o|0)!=36|y[h>>2]>10384592)&(o|0)>=36){break W}m=c+2047|0;n=0;while(1){l=n;g=m&2047;m=(e+784|0)+(g<<2)|0;d=v[m>>2];n=d>>>3|0;i=d<<29;d=l+i|0;n=d>>>0<i>>>0?n+1|0:n;i=d;l=n;if(!l&i>>>0<1000000001){n=0}else{n=nqa(i,l,1e9,0);i=i-kqa(n,jb,1e9,0)|0}v[m>>2]=i;c=(g|0)!=(c-1&2047)?c:(b|0)==(g|0)?c:i?c:g;m=g-1|0;if((b|0)!=(g|0)){continue}break}D=D-29|0;if(!n){continue}break}b=b-1&2047;if((c|0)==(b|0)){d=e+784|0;i=d+((c+2046&2047)<<2)|0;c=c-1&2047;v[i>>2]=v[i>>2]|v[d+(c<<2)>>2]}o=o+9|0;v[(e+784|0)+(b<<2)>>2]=n;continue}break}X:{Y:while(1){d=c+1&2047;g=(e+784|0)+((c-1&2047)<<2)|0;while(1){i=(o|0)>45?9:1;Z:{while(1){m=b;k=0;_:{while(1){$:{b=k+m&2047;if((b|0)==(c|0)){break $}b=v[(e+784|0)+(b<<2)>>2];h=v[(k<<2)+76752>>2];if(b>>>0<h>>>0){break $}if(b>>>0>h>>>0){break _}k=k+1|0;if((k|0)!=4){continue}}break}if((o|0)!=36){break _}i=0;l=0;k=0;h=0;g=0;while(1){b=k+m&2047;if((b|0)==(c|0)){c=c+1&2047;v[(e+(c<<2)|0)+780>>2]=0}Ed(e+768|0,i,l,h,g,0,0,1342177280,1075633366);Yn(e+752|0,v[(e+784|0)+(b<<2)>>2]);yg(e+736|0,v[e+768>>2],v[e+772>>2],v[e+776>>2],v[e+780>>2],v[e+752>>2],v[e+756>>2],v[e+760>>2],v[e+764>>2]);h=v[e+744>>2];g=v[e+748>>2];i=v[e+736>>2];l=v[e+740>>2];k=k+1|0;if((k|0)!=4){continue}break}Vg(e+720|0,q);Ed(e+704|0,i,l,h,g,v[e+720>>2],v[e+724>>2],v[e+728>>2],v[e+732>>2]);h=v[e+712>>2];g=v[e+716>>2];i=0;l=0;r=v[e+704>>2];z=v[e+708>>2];o=D+113|0;d=o-I|0;n=(d|0)<(H|0);b=n?(d|0)>0?d:0:H;if((b|0)<=112){break Z}break X}D=i+D|0;b=c;if((m|0)==(b|0)){continue}break}l=1e9>>>i|0;n=-1<<i^-1;k=0;b=m;while(1){h=k;f=(e+784|0)+(m<<2)|0;k=v[f>>2];h=h+(k>>>i|0)|0;v[f>>2]=h;h=!h&(b|0)==(m|0);b=h?b+1&2047:b;o=h?o-9|0:o;k=B(l,k&n);m=m+1&2047;if((m|0)!=(c|0)){continue}break}if(!k){continue}if((b|0)!=(d|0)){v[(e+784|0)+(c<<2)>>2]=k;c=d;continue Y}v[g>>2]=v[g>>2]|1;b=d;continue}break}break}sj(e+656|0,ii(1,225-b|0));TH(e+688|0,v[e+656>>2],v[e+660>>2],v[e+664>>2],v[e+668>>2],r,z,h,g);F=v[e+696>>2];A=v[e+700>>2];K=v[e+688>>2];L=v[e+692>>2];sj(e+640|0,ii(1,113-b|0));NE(e+672|0,r,z,h,g,v[e+640>>2],v[e+644>>2],v[e+648>>2],v[e+652>>2]);i=v[e+672>>2];l=v[e+676>>2];s=v[e+680>>2];u=v[e+684>>2];Nx(e+624|0,r,z,h,g,i,l,s,u);yg(e+608|0,K,L,F,A,v[e+624>>2],v[e+628>>2],v[e+632>>2],v[e+636>>2]);h=v[e+616>>2];g=v[e+620>>2];r=v[e+608>>2];z=v[e+612>>2]}f=m+4&2047;aa:{if((f|0)==(c|0)){break aa}f=v[(e+784|0)+(f<<2)>>2];ba:{if(f>>>0<=499999999){if(!f&(m+5&2047)==(c|0)){break ba}sj(e+496|0,+(q|0)*.25);yg(e+480|0,i,l,s,u,v[e+496>>2],v[e+500>>2],v[e+504>>2],v[e+508>>2]);s=v[e+488>>2];u=v[e+492>>2];i=v[e+480>>2];l=v[e+484>>2];break ba}if((f|0)!=5e8){sj(e+592|0,+(q|0)*.75);yg(e+576|0,i,l,s,u,v[e+592>>2],v[e+596>>2],v[e+600>>2],v[e+604>>2]);s=v[e+584>>2];u=v[e+588>>2];i=v[e+576>>2];l=v[e+580>>2];break ba}M=+(q|0);if((m+5&2047)==(c|0)){sj(e+528|0,M*.5);yg(e+512|0,i,l,s,u,v[e+528>>2],v[e+532>>2],v[e+536>>2],v[e+540>>2]);s=v[e+520>>2];u=v[e+524>>2];i=v[e+512>>2];l=v[e+516>>2];break ba}sj(e+560|0,M*.75);yg(e+544|0,i,l,s,u,v[e+560>>2],v[e+564>>2],v[e+568>>2],v[e+572>>2]);s=v[e+552>>2];u=v[e+556>>2];i=v[e+544>>2];l=v[e+548>>2]}if((b|0)>111){break aa}NE(e+464|0,i,l,s,u,0,0,0,1073676288);if(sn(v[e+464>>2],v[e+468>>2],v[e+472>>2],v[e+476>>2],0,0,0,0)){break aa}yg(e+448|0,i,l,s,u,0,0,0,1073676288);s=v[e+456>>2];u=v[e+460>>2];i=v[e+448>>2];l=v[e+452>>2]}yg(e+432|0,r,z,h,g,i,l,s,u);Nx(e+416|0,v[e+432>>2],v[e+436>>2],v[e+440>>2],v[e+444>>2],K,L,F,A);h=v[e+424>>2];g=v[e+428>>2];r=v[e+416>>2];z=v[e+420>>2];ca:{if((-2-J|0)>=(o&2147483647)){break ca}v[e+408>>2]=h;v[e+412>>2]=g&2147483647;v[e+400>>2]=r;v[e+404>>2]=z;Ed(e+384|0,r,z,h,g,0,0,0,1073610752);A=v[e+400>>2];F=v[e+404>>2];f=v[e+408>>2];o=v[e+412>>2];c=sB(A,F,f,o,1081081856);m=(c|0)<0;k=m;h=k?h:v[e+392>>2];g=k?g:v[e+396>>2];r=k?r:v[e+384>>2];z=k?z:v[e+388>>2];D=((c|0)>=0)+D|0;if((D+110|0)<=(O|0)){if((((sB(A,F,f,o,1081081856)|0)<0?n:n&(b|0)!=(d|0))|0)!=1){break ca}if(!sn(i,l,s,u,0,0,0,0)){break ca}}v[115137]=68}SH(e+368|0,r,z,h,g,D);h=v[e+368>>2];g=v[e+372>>2];c=v[e+380>>2];b=v[e+376>>2]}v[x+32>>2]=h;v[x+36>>2]=g;v[x+40>>2]=b;v[x+44>>2]=c;gb=e+8976|0;i=v[x+40>>2];l=v[x+44>>2];h=v[x+32>>2];g=v[x+36>>2];break a;case 3:break j;default:break m}}if(v[b+104>>2]){v[b+4>>2]=v[b+4>>2]-1}break i}da:{c=v[b+4>>2];ea:{if(c>>>0<y[b+104>>2]){v[b+4>>2]=c+1;c=w[c|0];break ea}c=md(b)}if((c|0)==40){f=1;break da}l=2147450880;if(!v[b+104>>2]){break a}v[b+4>>2]=v[b+4>>2]-1;break a}while(1){c=v[b+4>>2];fa:{if(c>>>0<y[b+104>>2]){v[b+4>>2]=c+1;c=w[c|0];break fa}c=md(b)}if(!(!(c-48>>>0<10|c-65>>>0<26|(c|0)==95)&c-97>>>0>=26)){f=f+1|0;continue}break}l=2147450880;if((c|0)==41){break a}c=v[b+104>>2];if(c){v[b+4>>2]=v[b+4>>2]-1}if(d){if(!f){break a}while(1){f=f-1|0;if(c){v[b+4>>2]=v[b+4>>2]-1}if(f){continue}break}break a}}v[115137]=28;wi(b,0,0)}l=0}v[a>>2]=h;v[a+4>>2]=g;v[a+8>>2]=i;v[a+12>>2]=l;gb=x+48|0}function Jna(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,y=0,z=0,A=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0;d=gb-416|0;gb=d;vc(b);e=d+408|0;g=$v(b,e);if(!g){pW(e)}a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{if(!g){break q}if(!AW(d+408|0)){break q}if(!c){p=1;break q}A=le(d+384|0,b);v[22656]=0;R(666,d+368|0,A|0);b=v[22656];v[22656]=0;r:{s:{t:{u:{v:{w:{x:{y:{z:{A:{B:{C:{D:{E:{F:{if((b|0)!=1){v[22656]=0;U(667,d+344|0,d+368|0,20041);b=v[22656];v[22656]=0;if((b|0)==1){break F}v[22656]=0;b=T(275,d+344|0)|0;e=v[22656];v[22656]=0;if((e|0)==1){break w}if(!b){break r}v[22656]=0;b=Q(668,d+344|0,d+248|0)|0;e=v[22656];v[22656]=0;if((e|0)==1){break w}if(!b){break r}v[22656]=0;R(367,a|0,16384);b=v[22656];v[22656]=0;if((b|0)==1){break w}v[a+480208>>2]=8;v[22656]=0;b=a+1074312|0;W(409,b|0,9,1)|0;e=v[22656];v[22656]=0;if((e|0)==1){break w}v[22656]=0;W(409,b|0,114,1)|0;e=v[22656];v[22656]=0;if((e|0)==1){break w}v[22656]=0;Q(410,b|0,21)|0;e=v[22656];v[22656]=0;if((e|0)==1){break w}v[22656]=0;Q(410,b|0,30)|0;b=v[22656];v[22656]=0;if((b|0)==1){break w}v[22656]=0;b=Q(2,d+208|0,5413)|0;e=v[22656];v[22656]=0;if((e|0)==1){break C}Eb(a+1298304|0,b);vb(b);v[22656]=0;b=Q(2,d+208|0,8009)|0;e=v[22656];v[22656]=0;if((e|0)==1){break B}Eb(a+1298316|0,b);vb(b);v[22656]=0;b=Q(2,d+96|0,14606)|0;e=v[22656];v[22656]=0;if((e|0)==1){break A}e=w[d+412|0];switch(e-16|0){case 1:break z;case 0:break E;default:break D}}e=P()|0;O()|0;break a}e=P()|0;O()|0;break b}v[22656]=0;Q(2,d+232|0,12232)|0;e=v[22656];v[22656]=0;if((e|0)!=1){break x}break e}if(!e){break y}v[22656]=0;Q(2,d+232|0,18726)|0;e=v[22656];v[22656]=0;if((e|0)==1){break e}break x}e=P()|0;O()|0;break c}e=P()|0;O()|0;break c}e=P()|0;O()|0;break c}v[22656]=0;Q(2,d+232|0,12250)|0;e=v[22656];v[22656]=0;if((e|0)!=1){break x}break e}v[22656]=0;Q(2,d+232|0,10607)|0;e=v[22656];v[22656]=0;if((e|0)==1){break e}}v[22656]=0;U(3,d+208|0,b|0,d+232|0);e=v[22656];v[22656]=0;if((e|0)==1){break f}e=d+208|0;Eb(a+1298328|0,e);vb(e);vb(d+232|0);vb(b);v[a+1298364>>2]=5;v[22656]=0;Ke(d+96|0,3,d+248|0);b=v[22656];v[22656]=0;if((b|0)==1){break g}v[22656]=0;R(324,d+208|0,d+96|0);b=v[22656];v[22656]=0;if((b|0)==1){break g}b=d+208|0;Eb(a+1298268|0,b);vb(b);v[22656]=0;_j(d+232|0,3,d+280|0);b=v[22656];v[22656]=0;if((b|0)==1){break h}v[22656]=0;R(324,d+96|0,d+232|0);b=v[22656];v[22656]=0;if((b|0)==1){break h}v[22656]=0;U(13,d+208|0,5,d+96|0);b=v[22656];v[22656]=0;if((b|0)==1){break i}b=d+208|0;Eb(a+1298280|0,b);vb(b);vb(d+96|0);v[a+480200>>2]=w[d+304|0]+1;H=a,I=Md(w[d+305|0],1,255),v[H+480196>>2]=I;H=a,I=B(Md(w[d+306|0],4,255),1e4),v[H+480204>>2]=I;b=a+484360|0;e=Sb(b);g=w[d+300|0]|w[d+301|0]<<8;v[22656]=0;fa(522,e|0,d+344|0,g|0,65535,65535)|0;e=v[22656];v[22656]=0;if((e|0)==1){break w}cf(Sb(b),w[d+302|0]|w[d+303|0]<<8);u[a+480188>>1]=0;b=0;while(1){v[22656]=0;e=(b<<5)+a|0;g=e+480280|0;We(g);f=v[22656];v[22656]=0;if((f|0)==1){break j}f=b+d|0;h=w[f+307|0]<<1&254;u[e+480284>>1]=(h|0)==254?256:h;G:{if(t[f+307|0]<0){v[g>>2]=v[g>>2]|1024;break G}u[a+480188>>1]=b+1}v[22656]=0;R(669,d+344|0,e+480289|0);e=v[22656];v[22656]=0;if((e|0)==1){break j}b=b+1|0;if((b|0)!=32){continue}break}v[22656]=0;U(667,d+208|0,d+368|0,17741);b=v[22656];v[22656]=0;if((b|0)==1){break k}b=d+344|0;e=d+208|0;Vc(b,e);xb(e);v[22656]=0;b=T(195,b|0)|0;e=v[22656];v[22656]=0;if((e|0)==1){break w}v[22656]=0;da(510,a+1298292|0,d+344|0,b|0,0)|0;b=v[22656];v[22656]=0;if((b|0)==1){break w}v[22656]=0;U(667,d+208|0,d+368|0,21321);b=v[22656];v[22656]=0;if((b|0)==1){break l}b=d+344|0;e=d+208|0;Vc(b,e);xb(e);v[22656]=0;b=T(275,b|0)|0;e=v[22656];v[22656]=0;if((e|0)==1){break w}H:{if(b){v[22656]=0;U(667,d+208|0,d+368|0,16723);b=v[22656];v[22656]=0;if((b|0)==1){break m}v[22656]=0;k=T(374,d+344|0)|0;b=v[22656];v[22656]=0;if((b|0)==1){break n}I:{if(!k){break I}m=c&2;g=0;while(1){v[22656]=0;e=T(374,d+344|0)|0;b=v[22656];v[22656]=0;if((b|0)==1){break n}if(!e){break I}v[22656]=0;b=Q(191,d+344|0,56)|0;f=v[22656];v[22656]=0;if((f|0)==1){break n}if(!b){break I}if(e>>>0>x[a+480190>>1]){u[a+480190>>1]=e}v[22656]=0;b=B(e,104)+a|0;f=b+484380|0;R(424,f|0,0);h=v[22656];v[22656]=0;if((h|0)==1){break n}v[22656]=0;Ku(f);h=v[22656];v[22656]=0;if((h|0)==1){break n}v[22656]=0;W(474,d+344|0,((e<<5)+a|0)+946304|0,32)|0;e=v[22656];v[22656]=0;if((e|0)==1){break n}v[22656]=0;W(477,d+344|0,b+484423|0,8)|0;e=v[22656];v[22656]=0;if((e|0)==1){break n}J:{if(w[d+412|0]<=15){v[22656]=0;e=T(287,d+344|0)|0;h=v[22656];v[22656]=0;if((h|0)!=1){break J}break n}v[22656]=0;e=T(192,d+344|0)|0;h=v[22656];v[22656]=0;if((h|0)==1){break n}}v[b+484404>>2]=e<<1;v[22656]=0;e=T(192,d+344|0)|0;h=v[22656];v[22656]=0;if((h|0)==1){break n}v[f>>2]=e;v[22656]=0;h=T(192,d+344|0)|0;e=v[22656];v[22656]=0;if((e|0)==1){break n}e=b+484384|0;v[e>>2]=h;v[22656]=0;h=T(192,d+344|0)|0;j=v[22656];v[22656]=0;if((j|0)==1){break n}j=b+484388|0;v[j>>2]=h;if(h){i=b+484414|0;u[i>>1]=x[i>>1]|2;v[j>>2]=h+v[e>>2]}v[22656]=0;h=T(374,d+344|0)|0;i=v[22656];v[22656]=0;if((i|0)==1){break H}if(w[d+412|0]<=15){u[b+484410>>1]=h}v[22656]=0;h=T(374,d+344|0)|0;i=v[22656];v[22656]=0;if((i|0)==1){break n}l=b+484414|0;b=x[l>>1];i=8;if(h&1){b=b|1;u[l>>1]=b;v[f>>2]=v[f>>2]>>>1;v[e>>2]=v[e>>2]>>>1;v[j>>2]=v[j>>2]>>>1;i=16}u[l>>1]=b&65531|h<<1&4;b=Rc(d+96|0,i,1,0,((h&12)!=0)<<3);K:{if(!m){break K}v[22656]=0;W(329,b|0,f|0,d+208|0)|0;b=v[22656];v[22656]=0;if((b|0)!=1){break K}break n}g=g+1|0;if(k>>>0>(g&255)>>>0){continue}break}}xb(d+208|0)}v[22656]=0;U(667,d+208|0,d+368|0,18761);b=v[22656];v[22656]=0;if((b|0)==1){break p}b=d+344|0;e=d+208|0;Vc(b,e);xb(e);v[22656]=0;b=T(275,b|0)|0;e=v[22656];v[22656]=0;if((e|0)==1){break w}if(b){k=dd(d+96|0);i=dd(d+232|0);l=dd(d+192|0);v[22656]=0;U(667,d+168|0,d+368|0,17750);b=v[22656];v[22656]=0;if((b|0)==1){break o}e=v[d+180>>2];b=d- -64|0;v[b>>2]=v[d+176>>2];v[b+4>>2]=e;v[d+72>>2]=v[d+184>>2];v[22656]=0;b=v[d+172>>2];v[d+56>>2]=v[d+168>>2];v[d+60>>2]=b;R(670,d+56|0,k|0);b=v[22656];v[22656]=0;if((b|0)==1){break o}v[22656]=0;U(667,d+144|0,d+368|0,17744);b=v[22656];v[22656]=0;if((b|0)==1){break o}b=v[d+156>>2];v[d+40>>2]=v[d+152>>2];v[d+44>>2]=b;v[d+48>>2]=v[d+160>>2];v[22656]=0;b=v[d+148>>2];v[d+32>>2]=v[d+144>>2];v[d+36>>2]=b;R(670,d+32|0,i|0);b=v[22656];v[22656]=0;if((b|0)==1){break o}v[22656]=0;U(667,d+120|0,d+368|0,17734);b=v[22656];v[22656]=0;if((b|0)==1){break o}b=v[d+132>>2];v[d+16>>2]=v[d+128>>2];v[d+20>>2]=b;v[d+24>>2]=v[d+136>>2];v[22656]=0;b=v[d+124>>2];v[d+8>>2]=v[d+120>>2];v[d+12>>2]=b;R(670,d+8|0,l|0);b=v[22656];v[22656]=0;if((b|0)==1){break o}j=0;v[22656]=0;o=T(374,d+344|0)|0;b=v[22656];v[22656]=0;if((b|0)==1){break o}if(o){b=d+208|0;y=b|4;z=b|2;q=b|6;r=b|5;s=b|3;e=b|1;while(1){v[22656]=0;R(403,d+80|0,d+344|0);b=v[22656];v[22656]=0;if((b|0)==1){break o}b=d+80|0;m=qd(b);L:{M:{N:{if(!w[b|0]){break N}g=w[m|0];v[22656]=0;g=Q(191,d+344|0,B(g,14)+32|0)|0;f=v[22656];v[22656]=0;if((f|0)==1){break o}if(!g){break N}b=w[b|0];v[22656]=0;h=W(376,a|0,b|0,0)|0;b=v[22656];v[22656]=0;if((b|0)==1){break o}if(h){break M}}b=w[m|0];v[22656]=0;Q(318,d+344|0,B(b,14)+32|0)|0;b=v[22656];v[22656]=0;if((b|0)!=1){break L}break o}v[22656]=0;W(474,d+344|0,h+492|0,32)|0;b=v[22656];v[22656]=0;if((b|0)==1){break o}if(!w[m|0]){break L}C=h+88|0;D=h+68|0;E=h+48|0;F=h+236|0;f=0;b=0;while(1){v[22656]=0;R(671,d+344|0,d+208|0);g=v[22656];v[22656]=0;if((g|0)==1){break o}O:{if(!w[d+208|0]|x[a+480190>>1]<w[d+208|0]){break O}g=e;if(w[e|0]>128){t[g|0]=128}if(w[e|0]>=(b&255)>>>0){while(1){g=w[d+208|0];H=vd(F,b&255),I=g,u[H>>1]=I;b=b+1|0;if(w[e|0]>=(b&255)>>>0){continue}break}}G=w[e|0];b=w[s|0];v[22656]=0;U(672,E|0,b|0,k|0);b=v[22656];v[22656]=0;if((b|0)==1){break o}b=w[r|0];v[22656]=0;U(672,D|0,b|0,i|0);b=v[22656];v[22656]=0;if((b|0)==1){break o}b=w[d+221|0];v[22656]=0;U(672,C|0,b|0,l|0);b=v[22656];v[22656]=0;if((b|0)==1){break o}v[h>>2]=(w[q|0]|w[q+1|0]<<8)+1>>>1;b=w[d+208|0];P:{if(w[s|0]&64){u[(B(b,104)+a|0)+484410>>1]=w[z|0];break P}g=(B(b,104)+a|0)+484414|0;u[g>>1]=x[g>>1]|32768}u[d+118>>1]=w[y|0]<<1;v[22656]=0;u[d+116>>1]=254;n=Pc(d+118|0,d+116|0);g=v[22656];v[22656]=0;Q:{R:{if((g|0)!=1){g=B(b,104)+a|0;u[g+484408>>1]=x[n>>1];t[g+484418|0]=w[(w[d+219|0]&3)+28885|0];n=g+484419|0;t[n|0]=w[d+218|0];p=g+484420|0;t[p|0]=w[d+217|0]+3>>>2;t[g+484421|0]=w[d+216|0];b=w[n|0];if(b){break R}p=255;break Q}break o}p=Bn(Qc((((w[p|0]<<8|b>>>1)&65407)>>>0)/(b>>>0)|0,0))}b=G+1|0;t[n|0]=p;if(!(w[r|0]&64)){break O}g=g+484414|0;u[g>>1]=x[g>>1]|32}f=f+1|0;if(w[m|0]>(f&255)>>>0){continue}break}}j=j+1|0;if(o>>>0>(j&255)>>>0){continue}break}}fp(l);fp(i);fp(k)}p=1;k=mc(d+232|0);if(!(c&1)){break s}v[22656]=0;U(667,d+208|0,d+368|0,21076);b=v[22656];v[22656]=0;S:{T:{U:{if((b|0)!=1){b=Vc(d+344|0,d+208|0);v[22656]=0;b=T(275,b|0)|0;c=v[22656];v[22656]=0;V:{W:{X:{Y:{Z:{_:{if((c|0)!=1){xb(d+208|0);$:{if(!b){break $}v[22656]=0;c=T(287,d+344|0)|0;b=v[22656];v[22656]=0;if((b|0)==1){break _}v[22656]=0;R(673,k|0,c+1|0);b=v[22656];v[22656]=0;if((b|0)==1){break _}if(!c){break $}b=1;while(1){v[22656]=0;e=T(287,d+344|0)|0;g=v[22656];v[22656]=0;if((g|0)==1){break Z}v[22656]=0;U(288,d+96|0,d+344|0,e|0);e=v[22656];v[22656]=0;if((e|0)==1){break Z}e=d+208|0;g=d+96|0;f=kc(e,g);Vc(Lg(k,b),f);f=(b|0)==(c|0);xb(e);xb(g);b=b+1|0;if(!f){continue}break}}v[22656]=0;U(667,d+208|0,d+368|0,16720);b=v[22656];v[22656]=0;if((b|0)==1){break Y}b=Vc(d+344|0,d+208|0);v[22656]=0;b=T(275,b|0)|0;c=v[22656];v[22656]=0;if((c|0)==1){break X}xb(d+208|0);if(!b){break V}f=0;v[22656]=0;l=T(374,d+344|0)|0;b=v[22656];v[22656]=0;if((b|0)==1){break u}if(l){while(1){m=32;aa:{if(w[d+412|0]>=16){v[22656]=0;R(674,d+344|0,d+208|0);b=v[22656];v[22656]=0;if((b|0)==1){break U}if(!(w[d+208|0]>32|x[a+480188>>1]>=w[d+208|0])){u[a+480188>>1]=w[d+208|0]}m=w[d+208|0];if(!m){break aa}}b=0;while(1){v[22656]=0;c=T(287,d+344|0)|0;e=v[22656];v[22656]=0;if((e|0)==1){break T}ba:{if(!c){break ba}c=b&65535;if(c>>>0>31|c>>>0<x[a+480188>>1]){break ba}u[a+480188>>1]=b+1}b=b+1|0;if((b&65535)>>>0<m>>>0){continue}break}}f=f+1|0;if(l>>>0>(f&65535)>>>0){continue}break}}v[22656]=0;Q(190,d+344|0,1)|0;b=v[22656];v[22656]=0;if((b|0)!=1){break W}break u}e=P()|0;O()|0;xb(d+208|0);break t}e=P()|0;O()|0;break t}e=P()|0;O()|0;break t}e=P()|0;O()|0;break t}e=P()|0;O()|0;xb(d+208|0);break t}v[22656]=0;o=a+484344|0;R(330,o|0,l|0);b=v[22656];v[22656]=0;if((b|0)==1){break u}if(!l){break V}b=d+208|0;C=b|2;D=b|1;g=0;while(1){q=Kb(d+96|0);r=64;s=32;if(w[d+412|0]>=16){v[22656]=0;R(674,d+344|0,d+208|0);b=v[22656];v[22656]=0;if((b|0)==1){break v}s=w[d+208|0];b=w[D|0];v[22656]=0;zW(d+80|0,3,C);c=v[22656];v[22656]=0;if((c|0)==1){break v}v[22656]=0;R(324,d+192|0,d+80|0);c=v[22656];v[22656]=0;if((c|0)==1){break v}c=d+192|0;Eb(q,c);vb(c);r=b+1|0}v[22656]=0;b=W(331,o|0,g&65535,r|0)|0;c=v[22656];v[22656]=0;if((c|0)==1){break v}ca:{if(!b){v[22656]=0;Q(318,d+344|0,s<<1)|0;b=v[22656];v[22656]=0;if((b|0)!=1){break ca}break v}b=_b(o,g);v[22656]=0;Q(428,b|0,q|0)|0;b=v[22656];v[22656]=0;if((b|0)==1){break v}j=0;if(!s){break ca}while(1){v[22656]=0;b=T(287,d+344|0)|0;c=v[22656];v[22656]=0;if((c|0)==1){break v}da:{if(!b){break da}if(Je(k)>>>0<=b>>>0){break da}n=j&65535;if(n>>>0>=x[a+480188>>1]){break da}h=Lg(k,b);vc(h);c=0;while(1){v[22656]=0;b=Q(191,h|0,1)|0;e=v[22656];v[22656]=0;ea:{fa:{ga:{ha:{ia:{ja:{if((e|0)!=1){if(!b){break da}b=_b(o,g);v[22656]=0;b=Yc(b,c,n);e=v[22656];v[22656]=0;if((e|0)==1){break v}v[22656]=0;f=T(374,h|0)|0;e=v[22656];v[22656]=0;if((e|0)==1){break v}e=f>>>2|0;switch((f&3)-1|0){case 2:break ga;case 1:break ha;case 0:break ia;default:break ja}}break v}c=(c+e|0)+1|0;break ea}if(!c){c=0;break ea}f=_b(o,g);v[22656]=0;f=Yc(f,c-1|0,n);i=v[22656];v[22656]=0;if((i|0)!=1){while(1){i=w[f|0]|w[f+1|0]<<8|(w[f+2|0]<<16|w[f+3|0]<<24);t[b|0]=i;t[b+1|0]=i>>>8;t[b+2|0]=i>>>16;t[b+3|0]=i>>>24;i=w[f+4|0]|w[f+5|0]<<8;t[b+4|0]=i;t[b+5|0]=i>>>8;c=c+1|0;if(r>>>0<=c>>>0){break ea}b=B(x[a+480188>>1],6)+b|0;i=e&255;e=e-1|0;if(i){continue}break ea}}break v}if(c>>>0<=e>>>0){break fa}f=_b(o,g);v[22656]=0;e=Yc(f,e,n);f=v[22656];v[22656]=0;if((f|0)==1){break S}f=w[e|0]|w[e+1|0]<<8|(w[e+2|0]<<16|w[e+3|0]<<24);t[b|0]=f;t[b+1|0]=f>>>8;t[b+2|0]=f>>>16;t[b+3|0]=f>>>24;e=w[e+4|0]|w[e+5|0]<<8;t[b+4|0]=e;t[b+5|0]=e>>>8;break fa}if(e&1){v[22656]=0;f=T(374,h|0)|0;i=v[22656];v[22656]=0;if((i|0)==1){break S}t[b|0]=f>>>0>120?-1:f}if(e&2){v[22656]=0;f=T(374,h|0)|0;i=v[22656];v[22656]=0;if((i|0)==1){break S}t[b+1|0]=f}f=0;m=0;if(e&4){v[22656]=0;m=T(374,h|0)|0;i=v[22656];v[22656]=0;if((i|0)==1){break v}}y=0;if(e&8){v[22656]=0;f=T(374,h|0)|0;i=v[22656];v[22656]=0;if((i|0)==1){break v}y=f>>>4|0;f=f&15}i=0;z=0;if(e&16){v[22656]=0;z=T(374,h|0)|0;E=v[22656];v[22656]=0;if((E|0)==1){break v}}if(e&32){v[22656]=0;i=T(374,h|0)|0;e=v[22656];v[22656]=0;if((e|0)==1){break v}}v[22656]=0;yW(b,m,f,y,z,i);b=v[22656];v[22656]=0;if((b|0)==1){break v}}c=c+1|0}if(c>>>0<r>>>0){continue}break}}j=j+1|0;if((j&65535)>>>0<s>>>0){continue}break}}vb(q);g=g+1|0;if((l|0)!=(g|0)){continue}break}}v[22656]=0;U(667,d+208|0,d+368|0,20048);b=v[22656];v[22656]=0;ka:{la:{ma:{if((b|0)!=1){b=Vc(d+344|0,d+208|0);v[22656]=0;b=T(275,b|0)|0;c=v[22656];v[22656]=0;if((c|0)==1){break ma}xb(d+208|0);if(!b){break s}a=a+484344|0;if(!Te(a)){break s}while(1){v[22656]=0;b=Q(191,d+344|0,16)|0;c=v[22656];v[22656]=0;if((c|0)==1){break la}if(!b){break s}v[22656]=0;R(677,d+344|0,d+208|0);b=v[22656];v[22656]=0;if((b|0)==1){break ka}b=_b(a,0);v[22656]=0;R(678,b|0,d+208|0);b=v[22656];v[22656]=0;if((b|0)==1){break ka}if(Te(a)){continue}break}break s}e=P()|0;O()|0;break t}e=P()|0;O()|0;xb(d+208|0);break t}e=P()|0;O()|0;break t}e=P()|0;O()|0;break t}e=P()|0;O()|0;break t}e=P()|0;O()|0;break t}e=P()|0;O()|0;break t}break v}break n}e=P()|0;O()|0;break c}e=P()|0;O()|0;vb(q);break t}e=P()|0;O()|0}jd(k);break c}jd(k)}xb(d+344|0);ke(d+368|0);xb(A)}gb=d+416|0;return p|0}e=P()|0;O()|0;break c}e=P()|0;O()|0;fp(l);fp(i);fp(k);break c}e=P()|0;O()|0;xb(d+208|0);break c}e=P()|0;O()|0;break c}e=P()|0;O()|0;break c}e=P()|0;O()|0;break c}e=P()|0;O()|0;break c}e=P()|0;O()|0;vb(d+96|0);break c}e=P()|0;O()|0;break c}e=P()|0;O()|0;break c}e=P()|0;O()|0;vb(d+232|0);break d}e=P()|0;O()|0}vb(b)}xb(d+344|0)}ke(d+368|0)}xb(A);S(e|0);L()}function kla(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,y=0,z=0,A=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0;e=gb-272|0;gb=e;vc(b);a:{b:{c:{if(!ev(b,e+176|0)){break c}if(!sU(e+176|0)){break c}if(!Pb(b,Qc(rU(e+176|0),jb))){break c}if(!c){s=1;break c}Gd(a,2);v[a+480260>>2]=64;v[a+480264>>2]=32767;k=Kb(e+160|0);i=e+216|0;if((w[i|0]|w[i+1|0]<<8)==20479){g=w[e+230|0]|w[e+231|0]<<8}else{g=(w[i|0]|w[i+1|0]<<8)-16464|0}d:{e:{f:{g:{h:{i:{j:{k:{switch((w[i|0]|w[i+1|0]<<8)>>>12|0){case 0:if((w[i|0]|w[i+1|0]<<8)!=520){break d}v[22656]=0;f=Q(2,e+32|0,9553)|0;d=v[22656];v[22656]=0;if((d|0)!=1){Eb(k,f);break e}b=P()|0;O()|0;break a;case 1:l:{if(w[e+238|0]|w[e+239|0]<<8|(w[i|0]|w[i+1|0]<<8)!=4896|(w[e+228|0]|w[e+208|0]&15)){break l}if((w[e+214|0]|w[e+215|0]<<8)&65455){break l}m:{if(t[e+227|0]<0){v[a+1074308>>2]=18219008;v[22656]=0;f=Q(2,e+32|0,11966)|0;d=v[22656];v[22656]=0;if((d|0)!=1){break m}b=P()|0;O()|0;break a}v[a+1074308>>2]=16777216;v[22656]=0;f=Q(2,e+32|0,10694)|0;d=v[22656];v[22656]=0;if((d|0)==1){break j}}Eb(k,f);vb(f);v[22656]=0;j=1;W(409,a+1074312|0,81,1)|0;d=v[22656];v[22656]=0;f=1;if((d|0)!=1){break d}break b}n:{if(w[e+238|0]|w[e+239|0]<<8|(w[i|0]|w[i+1|0]<<8)!=4896|(w[e+228|0]|(w[e+214|0]|w[e+215|0]<<8))){break n}if(w[e+229|0]){break n}v[22656]=0;f=Q(2,e+32|0,6633)|0;d=v[22656];v[22656]=0;if((d|0)!=1){Eb(k,f);break e}b=P()|0;O()|0;break a}v[22656]=0;d=Q(2,e+32|0,5641)|0;h=v[22656];v[22656]=0;s=1;if((h|0)!=1){Eb(k,d);vb(d);break f}b=P()|0;O()|0;break a;case 2:v[22656]=0;d=Q(2,e+32|0,3830)|0;h=v[22656];v[22656]=0;f=1;if((h|0)!=1){Eb(k,d);vb(d);break f}b=P()|0;O()|0;break a;case 3:o:{p:{q:{l=w[i|0]|w[i+1|0]<<8;r:{if(l>>>0<=12820){v[22656]=0;d=Q(2,e+32|0,5688)|0;f=v[22656];v[22656]=0;if((f|0)!=1){Eb(k,d);vb(d);break r}b=P()|0;O()|0;break a}v[22656]=0;R(597,e+144|0,1124);d=v[22656];v[22656]=0;if((d|0)==1){break q}d=w[i|0]|w[i+1|0]<<8;v[22656]=0;v[e+128>>2]=d-12820;U(598,e+32|0,e+144|0,e+128|0);d=v[22656];v[22656]=0;if((d|0)==1){break p}d=e+32|0;Eb(k,d);vb(d);Hb(e+144|0)}if((w[i|0]|w[i+1|0]<<8)>>>0<12807){break g}if(w[e+232|0]|w[e+233|0]<<8|(w[e+234|0]<<16|w[e+235|0]<<24)){break o}break g}b=P()|0;O()|0;break a}b=P()|0;O()|0;Hb(e+144|0);break a}d=w[i|0]|w[i+1|0]<<8;f=w[e+232|0]|w[e+233|0]<<8|(w[e+234|0]<<16|w[e+235|0]<<24);v[22656]=0;d=xw(d,f);f=v[22656];v[22656]=0;if((f|0)==1){break i}f=Dr(e+32|0);v[f+44>>2]=d;v[22656]=0;R(601,a+1298368|0,f|0);d=v[22656];v[22656]=0;if((d|0)!=1){break g}b=P()|0;O()|0;break a;case 4:if((w[i|0]|w[i+1|0]<<8)==16640){v[22656]=0;d=Q(2,e+32|0,5473)|0;h=v[22656];v[22656]=0;f=1;if((h|0)!=1){Eb(k,d);vb(d);v[22656]=0;W(409,a+1074312|0,81,1)|0;d=v[22656];v[22656]=0;h=0;if((d|0)==1){break b}break d}b=P()|0;O()|0;break a}d=w[i|0]|w[i+1|0]<<8;f=w[e+230|0]|w[e+231|0]<<8;v[22656]=0;U(602,e+32|0,d|0,f|0);d=v[22656];v[22656]=0;s:{if((d|0)!=1){d=e+32|0;Eb(k,d);vb(d);v[a+480260>>2]=1;if((g|0)<4201){break s}v[22656]=0;W(409,a+1074312|0,7,1)|0;d=v[22656];v[22656]=0;if((d|0)==1){break b}break h}b=P()|0;O()|0;break a}if((g|0)>=2386){break h}f=1;h=1;break d;case 5:l=(w[i|0]|w[i+1|0]<<8)&4095;d=l<<16;f=a;if(l>>>0>=297){d=d|(w[e+230|0]|w[e+231|0]<<8)}v[f+1074308>>2]=d;v[22656]=0;f=Q(2,e+144|0,14719)|0;d=v[22656];v[22656]=0;t:{u:{v:{if((d|0)!=1){v[22656]=0;R(162,e+128|0,a+1074308|0);d=v[22656];v[22656]=0;if((d|0)==1){break v}v[22656]=0;U(3,e+32|0,f|0,e+128|0);d=v[22656];v[22656]=0;if((d|0)==1){break u}d=e+32|0;Eb(k,d);vb(d);vb(e+128|0);break e}b=P()|0;O()|0;break a}b=P()|0;O()|0;break t}b=P()|0;O()|0;vb(e+128|0)}vb(f);break a;case 6:v[22656]=0;d=Q(2,e+32|0,5473)|0;f=v[22656];v[22656]=0;if((f|0)!=1){Eb(k,d);vb(d);v[22656]=0;W(409,a+1074312|0,81,1)|0;d=v[22656];v[22656]=0;f=0;if((d|0)==1){break b}break d}b=P()|0;O()|0;break a;case 7:v[22656]=0;f=Q(2,e+32|0,5499)|0;d=v[22656];v[22656]=0;if((d|0)!=1){Eb(k,f);break e}b=P()|0;O()|0;break a;default:break k}}if((w[i|0]|w[i+1|0]<<8)!=51712){break d}v[22656]=0;f=Q(2,e+32|0,6432)|0;d=v[22656];v[22656]=0;if((d|0)!=1){Eb(k,f);break e}b=P()|0;O()|0;break a}b=P()|0;O()|0;break a}b=P()|0;O()|0;break a}v[22656]=0;f=1;W(409,a+1074312|0,38,1)|0;d=v[22656];v[22656]=0;h=1;if((d|0)==1){break b}break d}v[22656]=0;d=a+1074312|0;W(409,d|0,7,1)|0;f=v[22656];v[22656]=0;if((f|0)==1){break b}v[22656]=0;W(409,d|0,23,1)|0;f=v[22656];v[22656]=0;if((f|0)==1){break b}v[22656]=0;W(409,d|0,38,1)|0;f=v[22656];v[22656]=0;if((f|0)==1){break b}v[22656]=0;W(409,d|0,107,1)|0;d=v[22656];v[22656]=0;if((d|0)==1){break b}f=1;v[a+480260>>2]=1;if(l>>>0>12820){break d}}v[22656]=0;_(877,e+144|0);d=v[22656];v[22656]=0;w:{x:{y:{if((d|0)!=1){v[e+16>>2]=w[i+1|0]&15;d=w[i|0];v[22656]=0;v[e>>2]=d;R(599,e+128|0,e|0);d=v[22656];v[22656]=0;if((d|0)==1){break y}v[22656]=0;ha(878,e+32|0,e+144|0,k|0,e+16|0,e+128|0);d=v[22656];v[22656]=0;if((d|0)==1){break x}d=e+32|0;Eb(k,d);vb(d);vb(e+128|0);Hb(e+144|0);h=0;break d}b=P()|0;O()|0;break a}b=P()|0;O()|0;break w}b=P()|0;O()|0;vb(e+128|0)}Hb(e+144|0);break a}vb(f);f=0}v[22656]=0;d=Q(2,e+32|0,12236)|0;l=v[22656];v[22656]=0;z:{A:{B:{C:{D:{E:{F:{G:{H:{I:{J:{K:{L:{M:{if((l|0)!=1){Eb(a+1298304|0,d);vb(d);v[22656]=0;d=Q(2,e+32|0,7744)|0;l=v[22656];v[22656]=0;if((l|0)==1){break M}Eb(a+1298316|0,d);vb(d);r=a+1298328|0;Eb(r,k);v[a+1298364>>2]=v[a+1074308>>2]?8:5;if(f){v[22656]=0;d=a+1074312|0;Q(410,d|0,77)|0;f=v[22656];v[22656]=0;if((f|0)==1){break b}v[22656]=0;Q(410,d|0,78)|0;f=v[22656];v[22656]=0;if((f|0)==1){break b}v[22656]=0;Q(410,d|0,79)|0;f=v[22656];v[22656]=0;if((f|0)==1){break b}v[22656]=0;Q(410,d|0,80)|0;f=v[22656];v[22656]=0;if((f|0)==1){break b}v[22656]=0;Q(410,d|0,82)|0;f=v[22656];v[22656]=0;if((f|0)==1){break b}v[22656]=0;Q(410,d|0,96)|0;f=v[22656];v[22656]=0;if((f|0)==1){break b}v[22656]=0;Q(410,d|0,113)|0;d=v[22656];v[22656]=0;if((d|0)==1){break b}}d=w[i|0]|w[i+1|0]<<8;f=d&61440;j=f>>>0<4097|(f|0)==12288&d>>>0<12820?j:1;v[22656]=0;d=a+901404|0;_(879,d|0);f=v[22656];v[22656]=0;if((f|0)==1){break b}if(!j){v[22656]=0;Xo(d);d=v[22656];v[22656]=0;if((d|0)==1){break b}}v[22656]=0;Nk(e+144|0,1,e+176|0);d=v[22656];v[22656]=0;if((d|0)==1){break L}v[22656]=0;R(324,e+32|0,e+144|0);d=v[22656];v[22656]=0;if((d|0)==1){break L}d=e+32|0;Eb(a+1298268|0,d);vb(d);if(w[e+214|0]&16){v[a+480208>>2]=v[a+480208>>2]|65536}if(t[e+214|0]&1){v[a+480208>>2]=v[a+480208>>2]|131072}if(!(w[e+214|0]&64?0:(w[i|0]|w[i+1|0]<<8)!=4864)){v[a+480208>>2]=v[a+480208>>2]|2}d=w[e+225|0];v[a+480196>>2]=d;if(!(!s|(d|0)!=255?d:0)){v[a+480196>>2]=6}v[a+480204>>2]=B(w[e+226|0],1e4);if(w[e+226|0]<=32){v[a+480204>>2]=s?125e4:32e4}t[e+32|0]=w[e+224|0];v[22656]=0;t[e+144|0]=64;d=ac(e+32|0,e+144|0);f=v[22656];v[22656]=0;if((f|0)==1){break H}d=w[d|0];v[a+480200>>2]=d<<2;if(!((w[i|0]|w[i+1|0]<<8)>>>0>4895|d)){v[a+480200>>2]=256}if((w[e+218|0]|w[e+219|0]<<8)!=1|w[e+227|0]>7){break J}v[e+32>>2]=(w[e+227|0]<<4)+16;v[22656]=0;v[e+144>>2]=127;d=pd(e+32|0,e+144|0);f=v[22656];v[22656]=0;if((f|0)==1){break K}v[a+480228>>2]=v[d>>2];break I}b=P()|0;O()|0;break a}b=P()|0;O()|0;break a}b=P()|0;O()|0;break a}b=P()|0;O()|0;break a}if(!(w[e+227|0]!=2&w[e+227|0]!=18)){v[a+480228>>2]=32;break I}if(!(w[e+227|0]&127)){v[a+480228>>2]=48;break I}v[e+32>>2]=w[e+227|0]&127;v[22656]=0;v[e+144>>2]=16;d=Gf(e+32|0,e+144|0);f=v[22656];v[22656]=0;if((f|0)==1){break G}v[a+480228>>2]=v[d>>2]}l=v[a+1074308>>2]!=0|t[e+227|0]<0;if(!l){d=v[a+480228>>2];f=d>>>29|0;H=a,I=Qc(nqa(d<<3|5,f,11,0),jb),v[H+480228>>2]=I}u[a+480188>>1]=4;v[a+480232>>2]=h?(g|0)<3299?64:36:36;d=wr(e+120|0);h=0;while(1){v[22656]=0;g=(h<<5)+a|0;o=g+480280|0;We(o);f=v[22656];v[22656]=0;if((f|0)==1){break F}f=e+h|0;j=w[f+240|0];N:{if(w[f+240|0]==255){break N}u[a+480188>>1]=h+1;if(!l){break N}u[g+480284>>1]=j&8?204:51}if(t[f+240|0]<0){v[o>>2]=1024}if(((j&127)-16&255)>>>0<=13){u[g+480284>>1]=128;g=e+32|0;Bl(g,d,h);Uf(g,1)}h=h+1|0;if((h|0)!=32){continue}break}if(!x[a+480188>>1]){u[a+480188>>1]=1}g=Sb(a+484360|0);f=w[e+208|0]|w[e+209|0]<<8;v[22656]=0;fa(522,g|0,b|0,f|0,255,254)|0;g=v[22656];v[22656]=0;O:{P:{Q:{R:{S:{if((g|0)!=1){y=mc(e+144|0);g=w[e+210|0]|w[e+211|0]<<8;v[22656]=0;W(327,b|0,y|0,g|0)|0;g=v[22656];v[22656]=0;if((g|0)==1){break S}l=mc(e+128|0);g=w[e+212|0]|w[e+213|0]<<8;v[22656]=0;W(327,b|0,l|0,g|0)|0;g=v[22656];v[22656]=0;if((g|0)==1){break O}if(w[e+229|0]==252){h=0;v[22656]=0;R(880,b|0,e+32|0);g=v[22656];v[22656]=0;if((g|0)==1){break R}while(1){f=(e+32|0)+h|0;g=w[f|0];T:{if(!(g&32)){break T}j=((h<<5)+a|0)+480284|0;if(s){g=e+16|0;Bl(g,d,h);if(Cb(g)){break T}g=w[f|0]}u[j>>1]=(((g&15)<<8|8)>>>0)/15}h=h+1|0;if((h|0)!=32){continue}break}}u[e+32>>1]=w[e+210|0]|w[e+211|0]<<8;h=0;v[22656]=0;u[e+16>>1]=3999;g=Pc(e+32|0,e+16|0);d=v[22656];v[22656]=0;if((d|0)==1){break Q}g=x[g>>1];u[a+480190>>1]=g;if(g){break P}j=0;f=0;break D}b=P()|0;O()|0;break a}b=P()|0;O()|0;break B}b=P()|0;O()|0;break C}b=P()|0;O()|0;break C}o=c&2;g=e+45|0;n=e+80|0;f=0;j=0;U:{V:{W:{while(1){d=sc(y,h);d=w[d|0]|w[d+1|0]<<8;v[22656]=0;d=Q(190,b|0,d<<4)|0;p=v[22656];v[22656]=0;if((p|0)==1){break E}X:{Y:{if(!d){break Y}v[22656]=0;d=Q(881,b|0,e+32|0)|0;p=v[22656];v[22656]=0;if((p|0)==1){break E}if(!d){break Y}v[22656]=0;d=h+1|0;p=(B(d,104)+a|0)+484380|0;U(882,e+32|0,p|0,s|0);m=v[22656];v[22656]=0;if((m|0)==1){break E}v[22656]=0;Nk(e,1,n);m=v[22656];v[22656]=0;if((m|0)==1){break X}v[22656]=0;R(324,e+16|0,e|0);m=v[22656];v[22656]=0;if((m|0)==1){break X}v[22656]=0;Q(301,((d<<5)+a|0)+946304|0,e+16|0)|0;d=v[22656];v[22656]=0;if((d|0)==1){break W}vb(e+16|0);if(w[e+32|0]>1){break Y}m=w[e+46|0];z=w[e+47|0];d=g;Z:{if(!o|!(w[e+48|0]|w[e+49|0]<<8|(w[e+50|0]<<16|w[e+51|0]<<24))){break Z}d=w[d|0];v[22656]=0;d=Q(190,b|0,z<<12|m<<4|d<<20)|0;m=v[22656];v[22656]=0;if((m|0)==1){break V}if(!d){break Z}d=w[e+218|0]|w[e+219|0]<<8;v[22656]=0;ZQ(e+16|0,e+32|0,(d|0)==1);d=v[22656];v[22656]=0;if((d|0)==1){break U}v[22656]=0;W(329,e+16|0,p|0,b|0)|0;d=v[22656];v[22656]=0;if((d|0)==1){break U}j=1}f=w[e+72|0]|w[e+73|0]<<8|f}h=h+1|0;if(h>>>0>=x[a+480190>>1]){break D}continue}break}b=P()|0;O()|0;break C}b=P()|0;O()|0;vb(e+16|0);break C}b=P()|0;O()|0;break C}b=P()|0;O()|0;break C}b=P()|0;O()|0;break C}b=P()|0;O()|0;break a}b=P()|0;O()|0;break a}b=P()|0;O()|0;break a}b=P()|0;O()|0;break C}_:{$:{aa:{ba:{if(!s){break ba}if(!(!(!j|f&65535)&(w[i|0]|w[i+1|0]<<8)!=4864)){v[22656]=0;g=a+1074312|0;d=f&65535;W(409,g|0,79,d>>>0>1|0)|0;h=v[22656];v[22656]=0;if((h|0)==1){break $}v[22656]=0;W(409,g|0,107,d>>>0<2|0)|0;g=v[22656];v[22656]=0;if((g|0)==1){break $}v[22656]=0;g=f&65535;Q(154,r|0,(g>>>0>1?14249:14256)|0)|0;d=v[22656];v[22656]=0;if((d|0)==1){break $}if(g>>>0<2){break ba}v[a+480228>>2]=48;break ba}v[22656]=0;g=Q(2,e+32|0,6892)|0;d=v[22656];v[22656]=0;if((d|0)==1){break aa}Eb(r,g);vb(g)}g=i;s=1;if(c&1){break _}break z}b=P()|0;O()|0;break C}b=P()|0;O()|0;break C}c=w[g|0]|w[g+1|0]<<8;u[e+32>>1]=w[e+212|0]|w[e+213|0]<<8;v[22656]=0;u[e+16>>1]=255;g=Pc(e+32|0,e+16|0);d=v[22656];v[22656]=0;ca:{da:{if((d|0)!=1){p=x[g>>1];v[22656]=0;g=a+484344|0;R(330,g|0,p|0);d=v[22656];v[22656]=0;if((d|0)==1){break da}m=c>>>0<4896;if(p){break ca}r=0;o=0;break A}b=P()|0;O()|0;break C}b=P()|0;O()|0;break C}c=e+32|0;C=c|5;D=c|3;z=c|4;E=c|2;F=c|1;j=0;o=0;r=0;ea:{fa:{while(1){ga:{v[22656]=0;c=W(331,g|0,j&65535,64)|0;d=v[22656];v[22656]=0;if((d|0)==1){break ga}ha:{if(!c){break ha}c=sc(l,j);if(!(w[c|0]|w[c+1|0]<<8)){break ha}c=sc(l,j);c=w[c|0]|w[c+1|0]<<8;v[22656]=0;c=Q(190,b|0,c<<4)|0;d=v[22656];v[22656]=0;if((d|0)==1){break ga}if(!c){break ha}v[22656]=0;Q(318,b|0,2)|0;c=v[22656];v[22656]=0;if((c|0)==1){break ga}f=0;c=_b(g,j);v[22656]=0;A=Tf(c,0);c=v[22656];v[22656]=0;if((c|0)==1){break fa}while(1){v[22656]=0;n=T(374,b|0)|0;c=v[22656];v[22656]=0;ia:{ja:{if((c|0)!=1){if(n){break ja}if(f>>>0>62){break ha}c=_b(g,j);v[22656]=0;f=f+1|0;A=Tf(c,f);c=v[22656];v[22656]=0;if((c|0)!=1){break ia}}b=P()|0;O()|0;break C}G=bj(e+32|0);d=n&31;c=d>>>0<x[a+480188>>1];d=B(d,6)+A|0;if(n&32){v[22656]=0;R(403,e+16|0,b|0);h=v[22656];v[22656]=0;ka:{la:{ma:{if((h|0)!=1){h=e+16|0;q=qd(h);h=w[h|0];if(h>>>0>239){break ma}h=(B(h>>>4|0,12)+(h&15)|0)+13|0;break la}b=P()|0;O()|0;break C}na:{switch(h-254|0){case 0:break la;case 1:break na;default:break ka}}h=0}t[(c?d:e+32|0)|0]=h}t[(c?d+1|0:F)|0]=w[q|0]}oa:{if(!(n&64)){break oa}v[22656]=0;h=T(374,b|0)|0;q=v[22656];v[22656]=0;pa:{if((q|0)!=1){q=c?d+2|0:E;t[e+16|0]=h;if(h>>>0>192|h<<24>>24>=0){break pa}t[q|0]=2;t[(c?d+4|0:z)|0]=w[e+16|0]^128;break oa}b=P()|0;O()|0;break C}t[q|0]=1;v[22656]=0;t[e|0]=64;h=ac(e+16|0,e);q=v[22656];v[22656]=0;if((q|0)==1){break ea}t[(c?d+4|0:z)|0]=w[h|0]}if(!(n&128)){break ia}v[22656]=0;R(403,e+16|0,b|0);h=v[22656];v[22656]=0;qa:{if((h|0)!=1){h=e+16|0;q=qd(h);n=c?d+3|0:D;t[n|0]=w[h|0];h=c?d+5|0:C;t[h|0]=w[q|0];_u(c?d:G,0);ra:{c=w[n|0];if((c|0)==20){if((w[h|0]&240)!=160){break ia}if((w[i|0]|w[i+1|0]<<8)>>>0<4896){break ra}c=w[n|0]}if((c|0)!=31){break ia}c=w[h|0];if(c>>>0<=15){break qa}m=0;break ia}t[h|0]=w[h|0]&15^136;break ia}b=P()|0;O()|0;break C}if(c>>>0<=7){o=o+1|0;break ia}r=((c|0)!=8)+r|0}if(f>>>0<64){continue}break}}j=j+1|0;if((p|0)!=(j|0)){continue}break A}break}b=P()|0;O()|0;break C}b=P()|0;O()|0;break C}b=P()|0;O()|0}Qk(l)}Qk(y);break a}if(!m){break z}a=x[a+480188>>1];if((a|0)>(o+r|0)|(a|0)<=(r-o|0)){break z}c=Te(g)-1&65535;a=0;i=0;if(Te(g)>>>0>c>>>0){while(1){if(hi(bf(g,a))){b=Vb(bf(g,a));d=Zb(bf(g,a));a=gb-16|0;gb=a;v[a>>2]=d;v[a+8>>2]=b;if(Gb(a+8|0,a)){while(1){d=a+8|0;b=v[d>>2];if(w[b+3|0]==31){t[b+3|0]=20;t[b+5|0]=w[b+5|0]|128}bk(d);if(Gb(d,a)){continue}break}}gb=a+16|0}i=i+1|0;a=i&65535;if(c>>>0>=a>>>0){continue}break}}}Qk(l);Qk(y);vb(k)}gb=e+272|0;return s|0}b=P()|0;O()|0}vb(k);S(b|0);L()}function cka(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,z=0,A=0,C=0,D=0,E=0,F=0,G=0;d=gb-512|0;gb=d;vc(b);g=d+432|0;f=$V(b,g);if(!f){yC(g)}a:{if(!f){break a}if(!cT(d+432|0)){break a}if(!Pb(b,Qc(bT(d+432|0),jb))){break a}b:{if(!c){break b}Gd(a,4);Bg(a);t[a+1074368|0]=4;k=Kb(d+416|0);c:{d:{e:{f:{i=d+470|0;g:{if(!(sd(i,14892,20)|(w[d+492|0]|w[d+493|0]<<8|(w[d+494|0]<<16|w[d+495|0]<<24))!=276)){if((w[d+490|0]|w[d+491|0]<<8)>>>0<260){break g}v[22656]=0;g=Cv(d+449|0,0,20);e=v[22656];v[22656]=0;if((e|0)==1){break d}e=g?1154:34;break e}if(!sd(i,14871,20)){e=1;break e}v[22656]=0;_j(d+16|0,3,i);g=v[22656];v[22656]=0;h:{i:{j:{if((g|0)==1){break j}v[22656]=0;R(324,d+56|0,d+16|0);g=v[22656];v[22656]=0;if((g|0)==1){break j}v[22656]=0;U(13,d+128|0,5,d+56|0);g=v[22656];v[22656]=0;if((g|0)==1){break i}g=d+128|0;Eb(k,g);vb(g);vb(d+56|0);if((w[i|0]|w[i+1|0]<<8|(w[i+2|0]<<16|w[i+3|0]<<24))!=1852141647|(w[i+4|0]|w[i+5|0]<<8|(w[i+6|0]<<16|w[i+7|0]<<24))!=542396493){break h}e=1048;break e}f=P()|0;O()|0;break c}f=P()|0;O()|0;vb(d+56|0);break c}if(!sd(i,14619,12)){e=16;if((x[d+482>>1]|x[d+484>>1]<<16)==538976288&(x[d+486>>1]|x[d+488>>1]<<16)==538976288){break e}t[a+1074368|0]=5;break e}if(sd(i,8911,20)){break f}}e=48;break e}if(!sd(i,33408,15)){v[22656]=0;g=a+1074312|0;Q(410,g|0,54)|0;e=v[22656];v[22656]=0;C=1;if((e|0)==1){break d}v[22656]=0;Q(410,g|0,51)|0;g=v[22656];v[22656]=0;e=16;if((g|0)==1){break d}break e}if(!sd(i,33424,14)){v[22656]=0;Q(410,a+1074312|0,57)|0;g=v[22656];v[22656]=0;e=16;if((g|0)!=1){break e}break d}e=sd(i,14707,11)?16:256}v[22656]=0;s=d+449|0;_j(d+56|0,3,s);g=v[22656];v[22656]=0;k:{l:{m:{n:{o:{if((g|0)==1){break o}v[22656]=0;R(324,d+128|0,d+56|0);g=v[22656];v[22656]=0;if((g|0)==1){break o}g=d+128|0;Eb(a+1298268|0,g);vb(g);v[a+480260>>2]=1;v[a+480264>>2]=31999;p=a+484360|0;cf(Sb(p),w[d+498|0]|w[d+499|0]<<8);u[a+480188>>1]=w[d+500|0]|w[d+501|0]<<8;u[d+128>>1]=w[d+504|0]|w[d+505|0]<<8;v[22656]=0;u[d+56>>1]=255;g=Pc(g,d+56|0);f=v[22656];v[22656]=0;if((f|0)==1){break n}u[a+480192>>1]=x[g>>1];if(w[d+508|0]|w[d+509|0]<<8){v[a+480196>>2]=w[d+508|0]|w[d+509|0]<<8}if(w[d+510|0]|w[d+511|0]<<8){F=a,G=Md(B(w[d+510|0]|w[d+511|0]<<8,1e4),32e4,1e7),v[F+480204>>2]=G}v[a+480208>>2]=0;v[a+480208>>2]=v[a+480208>>2]&-17|(w[d+506|0]|w[d+507|0]<<8)<<4&16;g=(w[d+506|0]|w[d+507|0]<<8)<<3&32768;v[a+480208>>2]=g|v[a+480208>>2]&-32769;f=Sb(p);m=w[d+496|0]|w[d+497|0]<<8;v[22656]=0;fa(522,f|0,b|0,m|0,65535,65535)|0;f=v[22656];v[22656]=0;if((f|0)==1){break d}f=g>>>15|0?(e|0)==34?146:e:e;if(!(f&1024|(w[d+496|0]|w[d+497|0]<<8))){g=Sb(p);v[22656]=0;U(958,g|0,1,0);g=v[22656];v[22656]=0;if((g|0)==1){break d}}g=w[d+492|0]|w[d+493|0]<<8|(w[d+494|0]<<16|w[d+495|0]<<24);v[22656]=0;Q(190,b|0,g+60|0)|0;g=v[22656];v[22656]=0;if((g|0)==1){break d}if((w[d+490|0]|w[d+491|0]<<8)>>>0>=260){v[22656]=0;U(959,b|0,d+432|0,a|0);g=v[22656];v[22656]=0;if((g|0)==1){break d}}t[d+415|0]=0;z=c&2;m=mc(d+400|0);g=-1;if(x[a+480192>>1]){break m}break l}f=P()|0;O()|0;break c}f=P()|0;O()|0;break c}D=d+74|0;E=d+161|0;e=1;n=1;while(1){p:{v[22656]=0;j=T(192,b|0)|0;h=v[22656];v[22656]=0;q:{r:{s:{t:{u:{v:{if((h|0)!=1){pg(b,4);v[22656]=0;U(960,b|0,d+128|0,(j?j:263)|0);j=v[22656];v[22656]=0;if((j|0)==1){break p}w:{if((f|0)==1){if((w[d+128|0]|w[d+129|0]<<8|(w[d+130|0]<<16|w[d+131|0]<<24))==245){v[a+1074308>>2]=16777381;v[22656]=0;f=Q(2,d+56|0,10694)|0;j=v[22656];v[22656]=0;if((j|0)!=1){Eb(k,f);vb(f);f=17;break w}f=P()|0;O()|0;break k}f=16;if((w[d+128|0]|w[d+129|0]<<8|(w[d+130|0]<<16|w[d+131|0]<<24))!=263){break w}v[a+1074308>>2]=16777395;v[22656]=0;f=Q(2,d+56|0,10618)|0;j=v[22656];v[22656]=0;if((j|0)!=1){Eb(k,f);vb(f);f=17;break w}f=P()|0;O()|0;break k}if(w[d+155|0]|w[d+156|0]<<8){break w}if(!(!(f&2)|(w[d+157|0]|w[d+158|0]<<8|(w[d+159|0]<<16|w[d+160|0]<<24))|(w[d+128|0]|w[d+129|0]<<8|(w[d+130|0]<<16|w[d+131|0]<<24))!=263)){f=f|16;break w}if(!(!(f&256)|(w[d+128|0]|w[d+129|0]<<8|(w[d+130|0]<<16|w[d+131|0]<<24))==29)){f=f&-257;break w}if(!(f&160)){break w}f=(w[d+128|0]|w[d+129|0]<<8|(w[d+130|0]<<16|w[d+131|0]<<24))==33?f:0}v[22656]=0;j=W(376,a|0,n&65535,0)|0;h=v[22656];v[22656]=0;if((h|0)==1){break p}if(!j){break q}j=((e<<2)+a|0)+900380|0;e=v[j>>2];v[22656]=0;R(961,d+128|0,e|0);e=v[22656];v[22656]=0;if((e|0)==1){break p}e=w[d+154|0];x:{if((g|0)==-1){g=e;break x}if(!(f&32)|(e|0)==(g|0)){break x}f=f&-161|128}if(!(w[d+155|0]|w[d+156|0]<<8)){break q}e=w[d+369|0];h=w[d+370|0];o=w[d+371|0]|w[d+372|0]<<8;l=w[d+375|0];q=w[d+155|0]|w[d+156|0]<<8;v[22656]=0;U(962,d+112|0,a|0,q|0);q=v[22656];v[22656]=0;if((q|0)==1){break v}f=l|(o|(e|h))?f&-4:f;e=12;while(1){h=x[vd(v[j>>2]+236|0,e)>>1];if(tc(d+112|0)>>>0>h>>>0){h=x[sc(d+112|0,x[vd(v[j>>2]+236|0,e)>>1])>>1];F=vd(v[j>>2]+236|0,e),G=h,u[F>>1]=G}e=e+1|0;if((e|0)!=108){continue}break}if((w[d+490|0]|w[d+491|0]<<8)>>>0>259){Nb(m);cr(m);tw(m)}e=w[d+155|0]|w[d+156|0]<<8;v[22656]=0;j=Q(963,d+96|0,e|0)|0;e=v[22656];v[22656]=0;y:{if((e|0)!=1){e=0;if(w[d+155|0]|w[d+156|0]<<8){break y}break u}f=P()|0;O()|0;break s}z:{A:{B:{C:{while(1){v[22656]=0;Q(964,b|0,d+56|0)|0;h=v[22656];v[22656]=0;if((h|0)==1){break z}v[22656]=0;QN(d+16|0,d+56|0);h=v[22656];v[22656]=0;D:{if((h|0)==1){break D}v[22656]=0;R(966,m|0,d+16|0);h=v[22656];v[22656]=0;if((h|0)==1){break D}h=w[d+56|0]|w[d+57|0]<<8|(w[d+58|0]<<16|w[d+59|0]<<24);F=Mb(j,e),G=h,v[F>>2]=G;o=w[d+73|0];if(tc(d+112|0)>>>0>e>>>0){h=x[sc(d+112|0,e)>>1];v[22656]=0;l=(B(h,104)+a|0)+484380|0;R(967,d+56|0,l|0);q=v[22656];v[22656]=0;if((q|0)==1){break C}v[22656]=0;RN(E,l);l=v[22656];v[22656]=0;if((l|0)==1){break C}v[22656]=0;Rk(d+40|0,3,D);l=v[22656];v[22656]=0;if((l|0)==1){break B}v[22656]=0;R(324,d+16|0,d+40|0);l=v[22656];v[22656]=0;if((l|0)==1){break B}v[22656]=0;Q(301,((h<<5)+a|0)+946304|0,d+16|0)|0;h=v[22656];v[22656]=0;if((h|0)==1){break A}vb(d+16|0);f=(w[d+70|0]&3)==3?(f&2)>>>1|0?f|4:f:f}r=o|r;e=e+1|0;if(e>>>0>=(w[d+155|0]|w[d+156|0]<<8)>>>0){break u}continue}break}f=P()|0;O()|0;break t}f=P()|0;O()|0;break t}f=P()|0;O()|0;break t}f=P()|0;O()|0;vb(d+16|0);break t}f=P()|0;O()|0;break t}f=P()|0;O()|0;break k}f=P()|0;O()|0;break k}if((w[d+490|0]|w[d+491|0]<<8)>>>0<260){break r}e=0;if(!(w[d+155|0]|w[d+156|0]<<8)){break r}E:{while(1){F:{o=w[Mb(m,e)+3|0];h=v[Mb(j,e)>>2];v[22656]=0;U(288,d+16|0,b|0,((o|0)==10?(h+1>>>1|0)+16|0:h)|0);h=v[22656];v[22656]=0;if((h|0)==1){break F}h=d+16|0;o=kc(d+56|0,h);xb(h);if(!(!z|tc(d+112|0)>>>0<=e>>>0)){l=x[sc(d+112|0,e)>>1];h=Mb(m,e);h=w[h|0]|w[h+1|0]<<8|(w[h+2|0]<<16|w[h+3|0]<<24);v[22656]=0;v[d+12>>2]=h;v[d+8>>2]=h;h=da(969,(B(l,104)+a|0)+484380|0,d+8|0,o|0,d+415|0)|0;o=v[22656];v[22656]=0;if((o|0)==1){break E}A=h^1|A}xb(d+56|0);e=e+1|0;if(e>>>0<(w[d+155|0]|w[d+156|0]<<8)>>>0){continue}break r}break}f=P()|0;O()|0;break t}f=P()|0;O()|0;xb(d+56|0)}Nc(j)}Ze(d+112|0);break k}Nc(j);Ze(d+112|0)}n=n+1|0;e=n&65535;if(e>>>0<=x[a+480192>>1]){continue}break l}break}f=P()|0;O()|0;break k}G:{H:{I:{J:{K:{L:{M:{N:{O:{P:{Q:{R:{S:{T:{U:{V:{W:{X:{if(!(!(f&2)|r&255)){v[22656]=0;e=Cv(s,0,20);j=v[22656];v[22656]=0;if((j|0)==1){break X}f=e?f|16:f}Y:{if((w[d+490|0]|w[d+491|0]<<8)>>>0>259){break Y}if(c&3){v[22656]=0;U(959,b|0,d+432|0,a|0);c=v[22656];v[22656]=0;if((c|0)==1){break X}}if(!z|!x[a+480190>>1]){break Y}e=1;c=1;while(1){j=Mb(m,e-1|0);v[22656]=0;W(329,j|0,(B(e,104)+a|0)+484380|0,b|0)|0;e=v[22656];v[22656]=0;if((e|0)==1){break M}c=c+1|0;e=c&65535;if(e>>>0<=x[a+480190>>1]){continue}break}}if(A&1){v[22656]=0;c=Q(2,d+128|0,13726)|0;e=v[22656];v[22656]=0;if((e|0)==1){break W}v[22656]=0;U(560,a|0,2,c|0);e=v[22656];v[22656]=0;if((e|0)==1){break V}vb(c)}v[22656]=0;c=Q(555,b|0,2650)|0;e=v[22656];v[22656]=0;if((e|0)==1){break X}if(c){v[22656]=0;c=T(192,b|0)|0;e=v[22656];v[22656]=0;if((e|0)==1){break X}v[22656]=0;da(510,a+1298292|0,b|0,c|0,0)|0;c=v[22656];v[22656]=0;if((c|0)==1){break X}f=f|16}v[22656]=0;j=Q(555,b|0,11374)|0;c=v[22656];v[22656]=0;if((c|0)==1){break G}if(j){v[22656]=0;c=T(192,b|0)|0;e=v[22656];v[22656]=0;if((e|0)==1){break G}v[22656]=0;e=a+901404|0;U(970,b|0,e|0,c|0);c=v[22656];v[22656]=0;if((c|0)==1){break G}v[22656]=0;Nu(e);c=v[22656];v[22656]=0;if((c|0)==1){break G}f=f|16}v[22656]=0;c=Q(555,b|0,11155)|0;e=v[22656];v[22656]=0;if((e|0)==1){break G}if(c){v[22656]=0;c=T(192,b|0)|0;e=v[22656];v[22656]=0;if((e|0)==1){break U}u[d+128>>1]=c>>>5;c=a+484344|0;e=Te(c);v[22656]=0;u[d+56>>1]=e;e=Pc(d+128|0,d+56|0);n=v[22656];v[22656]=0;if((n|0)==1){break T}n=x[e>>1];if(n){e=0;while(1){v[22656]=0;W(766,b|0,d+128|0,32)|0;h=v[22656];v[22656]=0;if((h|0)==1){break S}h=_b(c,e);v[22656]=0;Q(767,h|0,d+128|0)|0;h=v[22656];v[22656]=0;if((h|0)==1){break S}e=e+1|0;if((n|0)!=(e|0)){continue}break}}f=f|16}v[22656]=0;c=Q(555,b|0,11160)|0;e=v[22656];v[22656]=0;if((e|0)==1){break G}if(c){v[22656]=0;c=T(192,b|0)|0;e=v[22656];v[22656]=0;if((e|0)==1){break R}u[d+128>>1]=(c>>>0)/20;c=x[a+480188>>1];v[22656]=0;u[d+56>>1]=c;c=Pc(d+128|0,d+56|0);e=v[22656];v[22656]=0;if((e|0)==1){break Q}c=x[c>>1];if(c){e=0;while(1){v[22656]=0;W(571,b|0,((e<<5)+a|0)+480289|0,20)|0;n=v[22656];v[22656]=0;if((n|0)==1){break L}e=e+1|0;if((c|0)!=(e|0)){continue}break}}f=f|16}v[22656]=0;c=Q(191,b|0,8)|0;e=v[22656];v[22656]=0;if((e|0)==1){break G}if(c){c=v[b+8>>2];v[22656]=0;Q(572,a|0,b|0)|0;e=v[22656];v[22656]=0;if((e|0)==1){break K}f=(c|0)==v[b+8>>2]?f:f|16}if(!(f&16)){break N}if(!(f&4)){break O}v[a+1074308>>2]=17367040;v[22656]=0;c=Q(2,d+128|0,11896)|0;e=v[22656];v[22656]=0;if((e|0)==1){break P}Eb(k,c);vb(c);break N}f=P()|0;O()|0;break k}f=P()|0;O()|0;break k}f=P()|0;O()|0;vb(c);break k}f=P()|0;O()|0;break k}f=P()|0;O()|0;break k}f=P()|0;O()|0;break k}f=P()|0;O()|0;break k}f=P()|0;O()|0;break k}f=P()|0;O()|0;break k}if(!(f&2)){break N}v[a+1074308>>2]=18219008;v[22656]=0;c=Q(2,d+128|0,12053)|0;e=v[22656];v[22656]=0;if((e|0)==1){break J}Eb(k,c);vb(c)}Z:{if((w[i|0]|w[i+1|0]<<8|(w[i+2|0]<<16|w[i+3|0]<<24))==1852141647&(w[i+4|0]|w[i+5|0]<<8|(w[i+6|0]<<16|w[i+7|0]<<24))==542396493){v[22656]=0;c=Q(971,d+128|0,d+478|0)|0;e=v[22656];v[22656]=0;_:{$:{aa:{if((e|0)!=1){v[22656]=0;U(13,d+56|0,1,c|0);e=v[22656];v[22656]=0;if((e|0)==1){break aa}v[22656]=0;f=T(972,d+56|0)|0;i=v[22656];v[22656]=0;e=1;if((i|0)==1){break $}v[a+1074308>>2]=f;vb(d+56|0);t[a+1074368|0]=y[a+1074308>>2]<19007257?4:5;vb(c);c=a+1074308|0;f=24;break Z}f=P()|0;O()|0;break k}f=P()|0;O()|0;break _}f=P()|0;O()|0;vb(d+56|0)}vb(c);break k}if(!(!v[a+1074308>>2]|f&8)){t[a+1074368|0]=0;Av(a+1074312|0)}c=a+1074308|0;if(!(f&32)){e=1;break Z}t[a+1074368|0]=5;if(!j){v[22656]=0;Xo(a+901404|0);e=v[22656];v[22656]=0;if((e|0)==1){break G}}e=0;if((w[d+490|0]|w[d+491|0]<<8)>>>0<260){break Z}v[22656]=0;W(409,a+1074312|0,4,1)|0;i=v[22656];v[22656]=0;if((i|0)==1){break G}}ba:{if(!gd(k)){break ba}if(!(!(f&256)|r&255|g+1>>>0>1)){v[22656]=0;g=Q(2,d+128|0,5425)|0;e=v[22656];v[22656]=0;if((e|0)!=1){Eb(k,g);vb(g);break ba}f=P()|0;O()|0;break k}if(!e){v[22656]=0;g=Q(2,d+128|0,9323)|0;e=v[22656];v[22656]=0;if((e|0)!=1){Eb(k,g);vb(g);break ba}f=P()|0;O()|0;break k}v[22656]=0;g=Q(2,d+128|0,6892)|0;e=v[22656];v[22656]=0;if((e|0)==1){break I}Eb(k,g);vb(g)}t[d+40|0]=0;ca:{if(x[a+480192>>1]){v[22656]=0;g=Q(588,a|0,b|0)|0;e=v[22656];v[22656]=0;if((e|0)==1){break ca}t[d+40|0]=g}v[22656]=0;Y(589,a|0,b|0,1,d+40|0);b=v[22656];v[22656]=0;if((b|0)==1){break ca}e=v[c>>2];da:{ea:{fa:{ga:{ha:{ia:{ja:{ka:{la:{ma:{na:{oa:{pa:{qa:{ra:{if(w[d+40|0]){if(e>>>0>18284543){break ra}v[a+1074308>>2]=18284544;break ra}if(e>>>0<18284544){break qa}}v[22656]=0;b=Q(2,d+56|0,14719)|0;g=v[22656];v[22656]=0;if((g|0)==1){break pa}v[22656]=0;R(973,d+16|0,c|0);g=v[22656];v[22656]=0;if((g|0)==1){break oa}v[22656]=0;U(3,d+128|0,b|0,d+16|0);g=v[22656];v[22656]=0;if((g|0)==1){break na}g=d+128|0;Eb(k,g);vb(g);vb(d+16|0);vb(b);e=v[c>>2]}sa:{if(e-1>>>0>19005952){break sa}v[22656]=0;b=a+484344|0;c=me(b,254);g=v[22656];v[22656]=0;if((g|0)==1){break ca}if(!c){c=Sb(p);v[22656]=0;R(974,c|0,254);c=v[22656];v[22656]=0;if((c|0)==1){break ca}}v[22656]=0;b=me(b,255);c=v[22656];v[22656]=0;if((c|0)==1){break ca}if(b){break sa}b=Sb(p);v[22656]=0;c=v[22656];v[22656]=0;if((c|0)==1){break ca}v[22656]=0;iv(b,255,65535);b=v[22656];v[22656]=0;if((b|0)==1){break ca}}v[22656]=0;R(976,d+56|0,1211);b=v[22656];v[22656]=0;if((b|0)==1){break la}v[d+112>>2]=w[d+491|0];b=w[d+490|0];v[22656]=0;v[d+96>>2]=b;R(599,d+16|0,d+96|0);b=v[22656];v[22656]=0;if((b|0)==1){break ka}v[22656]=0;Y(582,d+128|0,d+56|0,d+112|0,d+16|0);b=v[22656];v[22656]=0;if((b|0)==1){break ja}b=a+1298304|0;c=d+128|0;Eb(b,c);vb(c);vb(d+16|0);Hb(d+56|0);Eb(a+1298328|0,k);v[a+1298364>>2]=C?8:v[a+1074308>>2]?8:5;if(!w[d+415|0]){break ea}Eb(a+1298340|0,b);v[22656]=0;c=Q(2,d+128|0,12404)|0;g=v[22656];v[22656]=0;if((g|0)==1){break ha}Eb(b,c);vb(c);v[22656]=0;b=Q(2,d+128|0,7371)|0;c=v[22656];v[22656]=0;if((c|0)==1){break ga}Eb(a+1298316|0,b);vb(b);v[22656]=0;b=Q(2,d+128|0,7372)|0;c=v[22656];v[22656]=0;if((c|0)==1){break fa}Eb(a+1298352|0,b);break da}f=P()|0;O()|0;break k}f=P()|0;O()|0;break ma}f=P()|0;O()|0;vb(d+16|0)}vb(b);break k}f=P()|0;O()|0;break k}f=P()|0;O()|0;break ia}f=P()|0;O()|0;vb(d+16|0)}Hb(d+56|0);break k}f=P()|0;O()|0;break k}f=P()|0;O()|0;break k}f=P()|0;O()|0;break k}v[22656]=0;b=Q(2,d+128|0,7372)|0;c=v[22656];v[22656]=0;if((c|0)==1){break H}Eb(a+1298316|0,b)}vb(b);di(m);vb(k);break b}f=P()|0;O()|0;break k}f=P()|0;O()|0;break k}f=P()|0;O()|0;break k}f=P()|0;O()|0;break k}f=P()|0;O()|0;break k}f=P()|0;O()|0;break k}f=P()|0;O()|0;break k}f=P()|0;O()|0}di(m);break c}f=P()|0;O()|0}vb(k);S(f|0);L()}e=1}gb=d+512|0;return e|0}function q6(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,y=0,A=0,D=0,E=0,F=C(0),G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=C(0),R=0,S=0,T=C(0),U=C(0),V=0,W=C(0),X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,ca=0,da=0,ea=C(0);D=gb-17168|0;gb=D;v[D+17164>>2]=0;a:{b:{c:{if(w[a+6152|0]!=255|(c|0)<5){break c}if(!fq(a+6152|0,b)){break c}k=vy(b,v[a+6148>>2])+eq(b)|0;v[D+17164>>2]=k;if((c|0)==(k|0)){k=c;break b}d:{if((k+4|0)<=(c|0)){if(fq(b,b+k|0)){break d}}v[D+17164>>2]=0;break c}if(k){break b}}g=b;p=Qb(a,0,6668)+6148|0;I=D+17164|0;f=c;e:{if((f|0)>=5){J=f-4|0;while(1){if(sJ(g)){y=vy(g,v[p>>2]);k=y+eq(g)|0;j=0;f:{g:{if(y){break g}l=4;q=h+4|0;while(1){if((J|0)<=((l<<1)+h|0)){break f}y=0;r=g+l|0;h:{if(!fq(g,r)){break h}s=l-eq(g)|0;G=eq(r)+s|0;if((f|0)<(G+(l+q|0)|0)){break h}if(!fq(g,r+G|0)){break h}v[p>>2]=s;y=s;k=l}j=!y;if(y){break g}s=l>>>0<2303;l=l+1|0;if(s){continue}break}}if((f|0)<(h+k|0)|j){break f}s=g;l=f-h|0;j=0;n=0;i:{while(1){G=j+s|0;j=(vy(G,y)+j|0)+eq(G)|0;q=(n|0)!=0;if((l|0)<(j+4|0)){break i}q=0;if(!fq(s,j+s|0)){break i}n=n+1|0;if((n|0)!=10){continue}break}q=1}if(q){break e}}if(!((f|0)!=(k|0)|h)){h=0;k=f;break e}v[p>>2]=0}g=g+1|0;h=h+1|0;if((J|0)!=(h|0)){continue}break}}k=0;h=f}v[I>>2]=k;n=h;k=v[D+17164>>2];if((h+k|0)<=(c|0)?k:0){break b}v[e>>2]=n;n=0;break a}G=b+n|0;v[a+6152>>2]=w[G|0]|w[G+1|0]<<8|(w[G+2|0]<<16|w[G+3|0]<<24);v[e+4>>2]=n;v[e>>2]=k+n;v[e+8>>2]=w[G+3|0]>191?1:2;ca=e,da=vJ(G),v[ca+12>>2]=da;v[e+16>>2]=4-(w[G+1|0]>>>1&3);ca=e,da=uy(G),v[ca+20>>2]=da;if(!d){n=ty(G);break a}uJ(D+17152|0,G+4|0,k-4|0);if(!(t[G+1|0]&1)){ae(D+17152|0,16)}j:{if(v[e+16>>2]==3){n=0;r=D+17152|0;k=D+3740|0;h=0;c=G;g=w[c+1|0];b=B((g>>>3&1)+(g>>>4&1)|0,3)+(w[c+2|0]>>>2&3)|0;f=b-((b|0)!=0)|0;l=w[c+3|0]>191?1:2;k:{if(g&8){j=ae(r,9);l=l<<1;h=ae(r,l+7|0);break k}j=ae(r,l|8)>>>l|0}b=B(f,40);I=b+62032|0;q=b+62352|0;s=B(f,23)+61840|0;A=-1;l:{while(1){g=w[c+3|0];f=ae(r,12);u[k+4>>1]=f;b=ae(r,9);u[k+6>>1]=b;if((b&65535)>>>0>288){break l}y=g>>>0>191?h<<4:h;ca=k,da=ae(r,8),t[ca+10|0]=da;b=ae(r,w[c+1|0]&8?4:9);t[k+13|0]=22;t[k+14|0]=0;v[k>>2]=s;u[k+8>>1]=b;m:{if(ae(r,1)){b=ae(r,2);t[k+11|0]=b;if(!(b&255)){break l}h=ae(r,1);u[k+18>>1]=65287;t[k+12|0]=h;if(w[k+11|0]==2){b=k;n:{if(!(h&255)){v[k>>2]=I;t[k+18|0]=8;g=39;h=0;break n}v[k>>2]=q;g=30;h=w[c+1|0]&8?8:6}t[b+14|0]=g;t[k+13|0]=h;y=y&3855}b=ae(r,10);ca=k,da=ae(r,3),t[ca+21|0]=da;ca=k,da=ae(r,3),t[ca+22|0]=da;ca=k,da=ae(r,3),t[ca+23|0]=da;h=b<<5;break m}t[k+11|0]=0;t[k+12|0]=0;h=ae(r,15);ca=k,da=ae(r,4),t[ca+18|0]=da;b=ae(r,3);t[k+20|0]=255;t[k+19|0]=b}t[k+17|0]=h&31;t[k+15|0]=h>>>10;t[k+16|0]=h>>>5&31;i=(f&65535)+i|0;b=k;o:{if(w[c+1|0]&8){f=ae(r,1);break o}f=x[k+8>>1]>499}t[b+24|0]=f;ca=k,da=ae(r,1),t[ca+25|0]=da;b=ae(r,1);t[k+27|0]=y>>>12&15;t[k+26|0]=b;k=k+28|0;h=y<<4;l=l-1|0;if(l){continue}break}A=(v[r+4>>2]+i|0)>(v[r+8>>2]+(j<<3)|0)?-1:j}if(!((A|0)<0|v[D+17156>>2]>v[D+17160>>2])){s=D+17152|0;h=v[s+4>>2];k=v[s+8>>2];c=D+912|0;f=v[a+6144>>2];b=f-A|0;g=(f|0)>(A|0)?A:f;f=hc(c+12|0,(((b|0)>0?b:0)+a|0)+6156|0,g);b=(k-h|0)/8|0;hc(f+g|0,v[s>>2]+(v[s+4>>2]/8|0)|0,b);uJ(c,f,b+g|0);k=v[a+6144>>2]>=(A|0);if(k){Z=a+2304|0;n=v[e+8>>2];_=D+8620|0;$=D+3852|0;b=0;while(1){aa=Qb($,0,4608);s=D+912|0;y=(B(B(b,n),28)+D|0)+3740|0;l=0;r=a;J=r+6152|0;if((n|0)>0){h=s+7548|0;while(1){f=B(l,28)+y|0;L=x[f+4>>1];M=v[s+4>>2];N=(s+B(l,39)|0)+16156|0;q=s;i=h;g=l;p=gb-48|0;gb=p;j=f;R=!w[f+13|0]+(w[f+14|0]!=0)|0;V=w[f+25|0];c=p;A=c+44|0;I=J;p:{if(w[J+1|0]&8){o=w[j+27|0];m=w[x[j+8>>1]+62768|0];g=m&3;t[p+47|0]=g;t[p+46|0]=g;g=m>>>2|0;t[p+45|0]=g;t[p+44|0]=g;g=B(R,28)+62672|0;break p}g=w[I+3|0]>>>4&(g|0)!=0;H=g?12:0;P=x[j+8>>1]>>>g|0;while(1){E=1;m=3;while(1){g=m;o=w[(g+H|0)+62784|0];t[g+(p+44|0)|0]=((P|0)/(E|0)|0)%(o|0);m=g-1|0;E=B(o,E);if(g){continue}break}H=H+4|0;P=P-E|0;if((P|0)>=0){continue}break}o=-16;g=(B(R,28)+H|0)+62672|0}E=0;while(1){O=w[g+E|0];if(O){q:{if(o&8){hc(c,N,O);break q}S=w[A+E|0];if(!S){Qb(c,0,O);Qb(N,0,O);break q}m=(o|0)>=0?-1:-1<<S^-1;H=0;while(1){R=ae(q,S);t[H+N|0]=(m|0)==(R|0)?-1:R;t[c+H|0]=R;H=H+1|0;if((O|0)!=(H|0)){continue}break}}o=o<<1;c=c+O|0;N=N+O|0;E=E+1|0;if((E|0)!=4){continue}}break}t[c+2|0]=0;t[c|0]=0;t[c+1|0]=0;m=w[j+14|0];r:{if(m){c=2-V|0;o=w[j+23|0]<<c;q=w[j+22|0]<<c;g=w[j+21|0]<<c;c=w[j+13|0];E=0;while(1){A=p+(c+E|0)|0;t[A|0]=g+w[A|0];t[A+1|0]=q+w[A+1|0];t[A+2|0]=o+w[A+2|0];E=E+3|0;if(m>>>0>E>>>0){continue}break}break r}if(!w[j+24|0]){break r}o=0;while(1){c=o+p|0;t[c+11|0]=w[c+11|0]+w[o+62808|0];o=o+1|0;if((o|0)!=10){continue}break}}T=ry(C(2048),((((w[I+3|0]&224)==96)<<1)-w[j+10|0]|0)+258|0);o=0;if((m|0)!=(0-w[j+13|0]|0)){c=V+1|0;while(1){ca=i+(o<<2)|0,ea=ry(T,w[o+p|0]<<c),z[ca>>2]=ea;o=o+1|0;if(o>>>0<w[j+14|0]+w[j+13|0]>>>0){continue}break}}gb=p+48|0;p=(s+B(l,2304)|0)+2940|0;c=h;R=L+M|0;F=C(0);Y=0;I=s;g=v[s+4>>2];q=v[s>>2]+((g|0)/8|0)|0;i=w[q|0]|w[q+1|0]<<8|(w[q+2|0]<<16|w[q+3|0]<<24);i=(i<<24|i<<8&16711680|(i>>>8&65280|i>>>24))<<(g&7);m=g|-8;K=q+4|0;q=f;E=v[f>>2];H=x[f+6>>1];s:{if(!H){H=0;break s}while(1){f=q+Y|0;g=w[f+15|0];X=(u[(g<<1)+67232>>1]<<1)+62848|0;N=w[f+18|0];t:{if(g>>>0>=16){L=w[g+67296|0];A=32-L|0;while(1){M=w[E|0]>>>1|0;o=H>>>0>M>>>0?M:H;F=z[c>>2];while(1){j=u[X+(i>>>26&62)>>1];if((j|0)<0){f=5;while(1){i=i<<f;m=f+m|0;g=j&7;f=g;j=u[X+((i>>>32-f|0)-(j<<16>>19)<<1)>>1];if((j|0)<0){continue}break}}O=j&65535;f=O>>>8|0;m=f+m|0;i=i<<f;P=1;while(1){ba=p;f=O&15;u:{if((f|0)==15){j=i<<L;f=(i>>>A|0)+15|0;m=m+L|0;if((m|0)>=0){while(1){j=w[K|0]<<m|j;i=m>>>0>7;m=m-8|0;K=K+1|0;if(i){continue}break}}W=F;i=f;v:{if((f|0)<=128){U=z[(i<<2)+67392>>2];break v}S=i<<3;g=i;i=i>>>0<1024;V=i?S:g;S=V<<1&64;Q=C(C((V&63)-S|0)/C(S+(V&-64)|0));U=C((i?C(16):C(256))*C(C(C(Q*C(C(Q*C(.2222222238779068))+C(1.3333333730697632)))+C(1))*z[(V+S>>6<<2)+67392>>2]))}W=C(C(W*U)*C(j>>31|1));break u}j=i;W=C(F*z[(((i>>>27&16|f)^16)<<2)+67328>>2])}z[ba>>2]=W;O=O>>>4|0;p=p+4|0;f=(f|0)!=0;m=f+m|0;i=j<<f;f=P&1;P=0;if(f){continue}break}if((m|0)>=0){while(1){i=w[K|0]<<m|i;f=m>>>0>7;m=m-8|0;K=K+1|0;if(f){continue}break}}o=o-1|0;if(o){continue}break}c=c+4|0;E=E+1|0;H=H-M|0;if((H|0)<=0){break t}f=(N|0)>0;N=N-1|0;if(f){continue}break}break t}while(1){o=w[E|0]>>>1|0;P=o>>>0<H>>>0?o:H;F=z[c>>2];while(1){j=u[X+(i>>>26&62)>>1];if((j|0)<0){f=5;while(1){i=i<<f;m=f+m|0;g=j&7;f=g;j=u[X+((i>>>32-f|0)-(j<<16>>19)<<1)>>1];if((j|0)<0){continue}break}}j=j&65535;f=j>>>8|0;m=f+m|0;i=i<<f;f=1;while(1){g=j&15;z[p>>2]=F*z[(((g|i>>>27&16)^16)<<2)+67328>>2];j=j>>>4|0;p=p+4|0;g=(g|0)!=0;m=g+m|0;i=i<<g;g=f&1;f=0;if(g){continue}break}if((m|0)>=0){while(1){i=w[K|0]<<m|i;f=m>>>0>7;m=m-8|0;K=K+1|0;if(f){continue}break}}P=P-1|0;if(P){continue}break}c=c+4|0;E=E+1|0;H=H-o|0;if((H|0)<=0){break t}f=(N|0)>0;N=N-1|0;if(f){continue}break}}Y=Y+1|0;if((H|0)>0){continue}break}}f=1-H|0;while(1){w:{g=w[q+26|0]?67216:67184;j=w[g+(i>>>28|0)|0];if(!(j&8)){j=w[g+((i<<4>>>32-(j&3))+(j>>>3)|0)|0]}g=j&7;m=g+m|0;if((R|0)<((m+(K-v[I>>2]<<3)|0)-24|0)){break w}f=f-1|0;if(!f){f=w[E|0];if(f>>>0<2){break w}E=E+1|0;F=z[c>>2];f=f>>>1|0;c=c+4|0}i=i<<g;if(j&128){z[p>>2]=(i|0)<0?C(-F):F;m=m+1|0;i=i<<1}if(j&64){z[p+4>>2]=(i|0)<0?C(-F):F;m=m+1|0;i=i<<1}f=f-1|0;if(!f){f=w[E|0];if(f>>>0<2){break w}E=E+1|0;F=z[c>>2];f=f>>>1|0;c=c+4|0}if(j&32){z[p+8>>2]=(i|0)<0?C(-F):F;m=m+1|0;i=i<<1}if(j&16){z[p+12>>2]=(i|0)<0?C(-F):F;m=m+1|0;i=i<<1}if((m|0)>=0){while(1){i=w[K|0]<<m|i;g=m>>>0>7;m=m-8|0;K=K+1|0;if(g){continue}break}}p=p+16|0;continue}break}v[I+4>>2]=R;l=l+1|0;if((n|0)!=(l|0)){continue}break}}c=w[r+6155|0];x:{if(c&16){j=0;L=gb-16|0;gb=L;o=s+2940|0;f=o+2304|0;i=y;m=v[i>>2];p=w[i+14|0];A=p+w[i+13|0]|0;I=A;M=L+4|0;v[M+8>>2]=-1;v[M>>2]=-1;v[M+4>>2]=-1;if(A){while(1){c=0;q=j+m|0;g=w[q|0];h=0;y:{if(!g){break y}z:{while(1){l=c<<2;if(z[l+f>>2]!=C(0)|z[(l|4)+f>>2]!=C(0)){break z}c=c+2|0;if(g>>>0>c>>>0){continue}break}h=g;break y}v[M+((j>>>0)%3<<2)>>2]=j;h=w[q|0]}f=((h&255)<<2)+f|0;j=j+1|0;if((I|0)!=(j|0)){continue}break}}if(w[i+13|0]){f=v[L+12>>2];h=v[L+8>>2];c=v[L+4>>2];c=(c|0)<(h|0)?h:c;c=(c|0)<(f|0)?f:c;v[L+12>>2]=c;v[L+8>>2]=c;v[L+4>>2]=c}M=s+16195|0;g=p?3:1;f=A-g|0;j=0;while(1){h=f+j|0;c=h-g|0;if((c|0)<=v[(L+4|0)+(j<<2)>>2]){c=w[J+1|0]<<28>>31&3}else{c=w[c+M|0]}t[h+M|0]=c;j=j+1|0;if((g|0)!=(j|0)){continue}break}p=L+4|0;I=u[i+36>>1]&1;f=0;l=v[i>>2];c=w[l|0];if(c){q=w[J+1|0]&8?7:64;g=l;while(1){i=w[J+3|0]&32;A:{B:{if(v[p+((f>>>0)%3<<2)>>2]>=(f|0)){break B}j=w[f+M|0];if(j>>>0>=q>>>0){break B}h=o;U=i?C(1.4142135381698608):C(1);W=U;C:{if(w[J+1|0]&8){i=j<<3;F=z[i+67924>>2];Q=z[i+67920>>2];break C}T=ry(C(1),j+1>>>1<<I);i=j&1;F=i?C(1):T;Q=i?T:C(1)}Q=C(W*Q);T=C(U*F);m=0;while(1){i=h+(m<<2)|0;F=z[i>>2];z[i+2304>>2]=F*T;z[i>>2]=F*Q;m=m+1|0;if((m|0)!=(c|0)){continue}break}break A}if(!i){break A}rJ(o,c)}o=(w[g|0]<<2)+o|0;f=f+1|0;g=l+f|0;c=w[g|0];if(c){continue}break}}gb=L+16|0;break x}if((c&224)!=96){break x}rJ(s+2940|0,576)}if((n|0)>0){c=s+7708|0;l=0;while(1){h=w[r+6153|0];J=(w[y+12|0]!=0)<<1<<((B((h>>>3&1)+(h>>>4&1)|0,3)+(w[r+6154|0]>>>2&3)|0)==2);q=(s+B(l,2304)|0)+2940|0;m=q;if(w[y+14|0]){g=((s+B(l,2304)|0)+B(J,72)|0)+2940|0;f=c;o=f;K=v[y>>2]+w[y+13|0]|0;A=w[K|0];if(A){h=g;while(1){I=A<<1;p=0;while(1){z[o>>2]=z[h>>2];z[o+4>>2]=z[(A<<2)+h>>2];i=I<<2;z[o+8>>2]=z[i+h>>2];h=h+4|0;o=o+12|0;p=p+1|0;if((p|0)!=(A|0)){continue}break}h=i+h|0;A=w[K+3|0];K=K+3|0;if(A){continue}break}}hc(g,f,o-f|0);i=J-1|0}else{i=31}if((i|0)>0){while(1){h=0;while(1){g=h<<2;f=g+m|0;U=z[f+72>>2];I=f;Q=z[g+67984>>2];f=(17-h<<2)+m|0;F=z[f>>2];T=z[g+68016>>2];z[I+72>>2]=C(U*Q)-C(F*T);z[f>>2]=C(F*Q)+C(U*T);h=h+1|0;if((h|0)!=8){continue}break}m=m+72|0;h=(i|0)>1;i=i-1|0;if(h){continue}break}}h=q;i=r+B(l,1152)|0;f=w[y+11|0];if(J){qJ(h,i,68048,J);i=B(J,36)+i|0;h=B(J,72)+h|0}D:{if((f|0)==2){j=gb-80|0;gb=j;g=32-J|0;if((g|0)>0){p=j|8;J=j|4;while(1){I=hc(j,h,72);f=v[i+20>>2];v[h+16>>2]=v[i+16>>2];v[h+20>>2]=f;f=v[i+12>>2];v[h+8>>2]=v[i+8>>2];v[h+12>>2]=f;f=v[i+4>>2];v[h>>2]=v[i>>2];v[h+4>>2]=f;f=i+24|0;qy(I,h+24|0,f);qy(J,h+48|0,f);qy(p,i,f);h=h+72|0;i=i+36|0;f=g>>>0>1;g=g-1|0;if(f){continue}break}}gb=j+80|0;break D}qJ(h,i,B((f|0)==3,72)+68048|0,32-J|0)}g=0;j=q+72|0;while(1){h=1;while(1){f=(h<<2)+j|0;z[f>>2]=-z[f>>2];f=h>>>0<16;h=h+2|0;if(f){continue}break}j=j+144|0;h=g>>>0<30;g=g+2|0;if(h){continue}break}y=y+28|0;l=l+1|0;if((n|0)!=(l|0)){continue}break}}tJ(Z,aa,18,v[e+8>>2],d,_);n=v[e+8>>2];d=B(n,1152)+d|0;b=b+1|0;if(b>>>0<(w[G+1|0]&8?2:1)>>>0){continue}break}}b=a;g=D+912|0;d=v[g+8>>2]>>>3|0;c=v[g+4>>2]+7>>>3|0;f=d-c|0;h=(f|0)>511;e=h?511:f;if((f|0)>0){yh(b+6156|0,(g+(h?d-511|0:c)|0)+12|0,e)}v[b+6144>>2]=e;break j}tt(a);break a}q=D+17152|0;n=0;k=0;y=0;b=D;s=b;h=0;E:{F:{G:{c=G;f=w[c+3|0];g=f>>>6|0;switch(g-1|0){case 2:break E;case 0:break G;default:break F}}h=(f>>>2&12)+4|0;break E}h=32}f=w[c+1|0];H:{if((f&6)==6){l=32;c=69452;break H}if(!(f&8)){l=30;c=69455;break H}f=w[c+2|0]>>>2&3;c=uy(c)>>>((g|0)!=3)|0;c=c?c:192;if(c>>>0<=55){l=(f|0)==2?12:8;c=69476;break H}l=c>>>0>95?(f|0)!=1?30:27:27;c=69464}t[s+768|0]=l;t[s+769|0]=h>>>0>l>>>0?l:h;h=c;I:{if(!w[b+768|0]){break I}j=69360;while(1){if((n|0)==(y|0)){j=w[h|0]+69360|0;y=w[h+2|0]+y|0;k=w[h+1|0];h=h+3|0}c=n<<1;g=w[ae(q,k)+j|0];t[(c+b|0)+770|0]=g;i=w[b+769|0];if(n>>>0<i>>>0){g=w[ae(q,k)+j|0];i=w[b+769|0]}t[(b+(c|1)|0)+770|0]=i?g:0;g=w[b+768|0];n=n+1|0;if(g>>>0>n>>>0){continue}break}if(!g){k=g<<1;break I}n=0;while(1){c=b+n|0;J:{if(!w[c+770|0]){k=6;break J}k=2;if((w[G+1|0]&6)==6){break J}k=ae(q,2);g=w[b+768|0]}t[c+834|0]=k;k=g<<1&510;n=n+1|0;if(k>>>0>n>>>0){continue}break}}l=b+770|0;G=b+834|0;c=b;h=0;if((k|0)>0){while(1){g=w[l|0];f=g?19>>>w[h+G|0]&3|4:0;l=l+1|0;s=B(g,3)-6|0;y=4;F=C(0);while(1){if(f&y){g=ae(q,6);i=(g|0)/3|0;F=C(z[(s+(g-B(i,3)|0)<<2)+69488>>2]*C(2097152>>>i|0))}z[c>>2]=F;c=c+4|0;g=y>>>0>1;y=y>>>1|0;if(g){continue}break}h=h+1|0;if((k|0)!=(h|0)){continue}break}}n=w[b+769|0];c=w[b+768|0];if(n>>>0<c>>>0){while(1){t[(b+(n<<1)|0)+771|0]=0;n=n+1|0;if((c|0)!=(n|0)){continue}break}}n=0;f=Qb(D+3852|0,0,4608);y=a+2304|0;G=D+8620|0;c=0;K:{while(1){s=((c<<2)+D|0)+3852|0;I=D+17152|0;r=v[e+16>>2]|1;i=0;h=D;l=w[h+768|0];b=576;while(1){L:{if(!(l&255)){l=0;break L}j=s+(B(i,r)<<2)|0;A=0;while(1){k=b;l=w[(h+A|0)+770|0];M:{if(!l){break M}if(l>>>0<=16){if((r|0)<=0){break M}g=(-1<<l-1)+1|0;b=0;while(1){ca=(b<<2)+j|0,ea=C(ae(I,l)+g|0),z[ca>>2]=ea;b=b+1|0;if((r|0)!=(b|0)){continue}break}break M}l=2<<l-17;b=ae(I,(l-(l>>>3|0)|0)+3|0);if((r|0)<=0){break M}g=l>>>1|0;q=l|1;l=0;while(1){p=b;b=(b>>>0)/(q>>>0)|0;z[(l<<2)+j>>2]=(p-B(q,b)|0)-g|0;l=l+1|0;if((r|0)!=(l|0)){continue}break}}b=18-k|0;j=(k<<2)+j|0;A=A+1|0;l=w[h+768|0];if(A>>>0<l<<1>>>0){continue}break}}i=i+1|0;if((i|0)!=4){continue}break}c=(r<<2)+c|0;if((c|0)==12){g=(n<<2)+D|0;b=f;c=D;h=w[c+769|0];k=f+B(h,72)|0;hc(k+2304|0,k,B(w[c+768|0]-h|0,72));if(w[c+768|0]){l=0;while(1){h=0;while(1){k=(h<<2)+b|0;z[k>>2]=z[g>>2]*z[k>>2];k=k+2304|0;z[k>>2]=z[g+12>>2]*z[k>>2];h=h+1|0;if((h|0)!=12){continue}break}g=g+24|0;b=b+72|0;l=l+1|0;if(l>>>0<w[c+768|0]){continue}break}}tJ(y,f,12,v[e+8>>2],d,G);Qb(f,0,4608);d=B(v[e+8>>2],768)+d|0;c=0}if(v[D+17156>>2]<=v[D+17160>>2]){n=n+1|0;if((n|0)==3){break K}continue}break}tt(a);n=0;break a}k=1}n=B(ty(a+6152|0),k)}gb=D+17168|0;return n|0}function wJ(a,b,c,d,e,f,g){var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,z=0,A=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,M=0,N=0,O=0,P=0;M=gb-144|0;gb=M;k=v[f>>2];N=g&4;K=N?-1:k+((d^-1)+e|0)|0;s=K+1|0;a:{if(!(!(s&K)&d>>>0<=e>>>0)){v[f>>2]=0;v[c>>2]=0;l=-3;break a}D=e+k|0;r=v[c>>2];z=r+b|0;E=v[a+60>>2];q=v[a+40>>2];k=v[a+36>>2];C=v[a+32>>2];m=v[a+56>>2];i=v[a+4>>2];j=b;p=e;l=-1;b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{t:{u:{v:{w:{x:{y:{z:{A:{B:{C:{D:{E:{F:{G:{H:{switch(v[a>>2]){case 37:v[a>>2]=37;break b;case 21:v[a>>2]=21;break b;case 17:v[a>>2]=17;break b;case 35:v[a>>2]=35;break b;case 10:v[a>>2]=10;break b;case 39:v[a>>2]=39;break b;case 36:v[a>>2]=36;break b;case 34:break g;case 42:break j;case 41:break k;case 53:break l;case 52:break m;case 51:break n;case 38:break o;case 27:break p;case 26:break q;case 25:break r;case 24:break s;case 23:break t;case 18:break u;case 16:break v;case 14:break w;case 11:break x;case 9:break y;case 7:break z;case 6:break A;case 3:break B;case 32:break C;case 5:break D;case 2:break F;case 1:break G;case 0:break H;default:break b}}v[a+28>>2]=1;m=0;v[a+8>>2]=0;v[a+12>>2]=0;v[a+16>>2]=1;q=0;k=0;C=0;i=0;if(g&1){break G}break E}l=1;if((r|0)<=0){break c}v[a+8>>2]=w[b|0];j=b+1|0}l=2;if(j>>>0>=z>>>0){break c}n=w[j|0];v[a+12>>2]=n;h=1;j=j+1|0;l=-1;A=36;k=v[a+8>>2];if(((n|k<<8)>>>0)%31|n&32){break d}n=k&15;if(!N){if((n|0)!=8){break d}n=256<<(k>>>4);if(n>>>0>32768){break d}k=0;if(n>>>0<=s>>>0){break E}break d}k=0;if((n|0)!=8){break d}}h=0;break i}if((r|0)<=0){l=5;break c}O=i+8|0;j=b+1|0;m=w[b|0]<<i|m;h=2;break i}if((r|0)<=0){l=32;break c}j=b+1|0;m=w[b|0]<<i|m;i=i+8|0;break h}h=1;break i}h=4;break i}h=3;break i}h=7;break i}h=9;break i}h=10;break i}h=11;break i}h=12;break i}h=13;break i}h=14;break i}h=15;break i}h=16;break i}h=17;break i}h=8;break i}h=5;break i}h=6;break i}h=18;break i}o=2;break e}o=1;break e}I:while(1){J:{K:{L:{M:{N:{O:{P:{Q:{R:{S:{T:{U:{V:{W:{X:{Y:{Z:{_:{$:{aa:{ba:{ca:{da:{ea:{fa:{ga:{ha:{ia:{ja:{ka:{la:{ma:{na:{oa:{pa:{qa:{ra:{sa:{ta:{ua:{va:{wa:{xa:{switch(h|0){case 0:if(i>>>0>2){break wa}h=1;continue;case 17:break ea;case 16:break fa;case 15:break ga;case 14:break ha;case 13:break ia;case 12:break ja;case 11:break ka;case 10:break la;case 9:break ma;case 8:break oa;case 7:break pa;case 6:break qa;case 5:break ra;case 4:break ta;case 3:break ua;case 2:break va;case 1:break xa;default:break da}}l=3;while(1){if(j>>>0>=z>>>0){break c}m=w[j|0]<<i|m;h=j+1|0;j=h;i=i+8|0;if(i>>>0<3){continue}break}j=h}h=m&7;v[a+20>>2]=h;s=h>>>1|0;v[a+24>>2]=s;i=i-3|0;m=m>>>3|0;if(h>>>0>=2){break na}O=i;break ca}i=O&-8;m=m>>>(O&7)|0;k=0;h=0;break aa}if(j>>>0<z>>>0){break sa}l=7;break c}while(1){if(j>>>0>=z>>>0){l=6;break c}m=w[j|0]<<i|m;l=i>>>0>4294967287;n=j+1|0;j=n;h=i+8|0;i=h;if(l){continue}break}j=n;i=h;h=1;break aa}t[(a+k|0)+10528|0]=w[j|0];j=j+1|0;h=2;break aa}while(1){if(j>>>0>=z>>>0){l=51;break c}m=w[j|0]<<i|m;l=i>>>0>4294967287;n=j+1|0;j=n;h=i+8|0;i=h;if(l){continue}break}j=n;i=h;break M}if(p>>>0>=D>>>0){l=2;A=52;h=k;break d}t[p|0]=C;k=k-1|0;p=p+1|0;break N}if(p>>>0<D>>>0){break ba}l=2;A=9;h=k;break d}if(j>>>0<z>>>0){n=D-p|0;h=z-j|0;h=h>>>0>n>>>0?n:h;h=h>>>0<k>>>0?h:k;k=k-h|0;p=hc(p,j,h)+h|0;j=h+j|0;break L}l=38;break c}l=-1;A=10;n=0;h=k;ya:{switch(s-1|0){case 0:break ya;case 2:break d;default:break $}}v[a+44>>2]=288;v[a+48>>2]=32;h=a+3552|0;v[h>>2]=84215045;v[h+4>>2]=84215045;h=a+3560|0;v[h>>2]=84215045;v[h+4>>2]=84215045;h=a+3568|0;v[h>>2]=84215045;v[h+4>>2]=84215045;h=a+3576|0;v[h>>2]=84215045;v[h+4>>2]=84215045;Qb(a- -64|0,8,144);Qb(a+208|0,9,112);t[a+336|0]=7;t[a+337|0]=7;t[a+338|0]=7;t[a+339|0]=7;t[a+340|0]=7;t[a+341|0]=7;t[a+342|0]=7;t[a+343|0]=7;t[a+328|0]=7;t[a+329|0]=7;t[a+330|0]=7;t[a+331|0]=7;t[a+332|0]=7;t[a+333|0]=7;t[a+334|0]=7;t[a+335|0]=7;t[a+320|0]=7;t[a+321|0]=7;t[a+322|0]=7;t[a+323|0]=7;t[a+324|0]=7;t[a+325|0]=7;t[a+326|0]=7;t[a+327|0]=7;t[a+344|0]=8;t[a+345|0]=8;t[a+346|0]=8;t[a+347|0]=8;t[a+348|0]=8;t[a+349|0]=8;t[a+350|0]=8;t[a+351|0]=8;F=1;break R}l=k+18707|0;while(1){if(j>>>0>=z>>>0){l=11;break c}m=w[j|0]<<i|m;n=j+1|0;j=n;h=i+8|0;i=h;G=t[l|0];if(h>>>0<G>>>0){continue}break}j=n;n=k;i=h;k=1;break T}while(1){if(j>>>0>=z>>>0){l=14;break c}m=w[j|0]<<i|m;h=j+1|0;j=h;i=i+8|0;if(i>>>0<3){continue}break}j=h;h=1;break S}if(j>>>0>=z>>>0){l=16;break c}m=w[j|0]<<i|m;j=j+1|0;i=i+8|0;if(i>>>0<15){break _}break Z}while(1){if(j>>>0>=z>>>0){l=18;break c}m=w[j|0]<<i|m;h=j+1|0;j=h;i=i+8|0;if(q>>>0>i>>>0){continue}break}P=C-16|0;j=h;h=3;break Q}if(j>>>0>=z>>>0){l=23;break c}m=w[j|0]<<i|m;j=j+1|0;i=i+8|0;if(i>>>0<15){break Y}break X}if(p>>>0>=D>>>0){l=2;A=24;h=k;break d}t[p|0]=k;p=p+1|0;break P}while(1){if(j>>>0>=z>>>0){l=25;break c}m=w[j|0]<<i|m;h=j+1|0;j=h;i=i+8|0;if(q>>>0>i>>>0){continue}break}j=h;h=3;break O}if(j>>>0>=z>>>0){l=26;break c}m=w[j|0]<<i|m;j=j+1|0;i=i+8|0;if(i>>>0<15){break W}break V}while(1){if(j>>>0>=z>>>0){l=27;break c}m=w[j|0]<<i|m;h=j+1|0;j=h;i=i+8|0;if(q>>>0>i>>>0){continue}break}j=h;h=6;break O}if(p>>>0>=D>>>0){l=2;A=53;h=k;break d}t[p|0]=w[(E-C&K)+d|0];p=p+1|0;E=E+1|0;break U}h=2;continue}h=8;continue}while(1){za:{Aa:{Ba:{Ca:{Da:{switch(h|0){case 0:if(k>>>0>3){break Ca}if(!i){i=0;h=3;continue I}if(i>>>0>7){break Aa}h=4;continue I;case 1:t[(a+k|0)+10528|0]=m;i=i-8|0;m=m>>>8|0;break za;default:break Da}}k=k+1|0;break Ba}h=x[a+10528>>1];if((h|0)==(x[a+10530>>1]^65535)){k=h;break N}l=-1;A=39;break d}h=0;continue}h=1;continue}h=2;continue}}k=0;break T}h=1;break Q}h=2;break Q}h=0;break O}h=1;break O}h=4;break O}h=5;break O}h=7;break O}while(1){Ea:{Fa:{Ga:{if(!k){if(n>>>0>2){break Ga}k=n;G=t[k+18707|0];if(G>>>0<=i>>>0){break Ea}h=9;continue I}k=n<<2;v[(k+a|0)+44>>2]=v[k+61716>>2]+((-1<<G^-1)&m);n=n+1|0;i=i-G|0;m=m>>>G|0;break Fa}k=0;Qb(a+7040|0,0,288);h=0;break S}k=0;continue}k=1;continue}}while(1){Ha:{Ia:{Ja:{if(!h){if(y[a+52>>2]<=k>>>0){break Ja}if(i>>>0>2){break Ha}h=10;continue I}t[(w[k+61696|0]+a|0)+7040|0]=m&7;k=k+1|0;i=i-3|0;m=m>>>3|0;break Ia}v[a+52>>2]=19;F=v[a+24>>2];break R}h=0;continue}h=1;continue}}h=0}while(1){Ka:{La:{Ma:{Na:{Oa:{Pa:{Qa:{Ra:{Sa:{Ta:{Ua:{switch(h|0){case 0:h=0;if((F|0)<0){break P}H=Qb(M,0,64);l=B(F,3488)+a|0;Qb(l+352|0,0,3200);r=v[a+24>>2];s=v[((r<<2)+a|0)+44>>2];if(s){while(1){n=(w[(h+l|0)- -64|0]<<2)+H|0;v[n>>2]=v[n>>2]+1;h=h+1|0;if((s|0)!=(h|0)){continue}break}}v[H+64>>2]=0;v[H+68>>2]=0;n=0;A=0;h=1;while(1){l=h<<2;h=h+1|0;l=v[l+H>>2];n=l+n<<1;v[(H- -64|0)+(h<<2)>>2]=n;A=l+A|0;if((h|0)!=16){continue}break};if(!((n|0)==65536|A>>>0<=1)){l=-1;A=35;h=k;break d}if(s){l=-1;I=0;J=B(F,3488)+a|0;while(1){r=w[(I+J|0)- -64|0];Va:{if(!r){break Va}n=(H- -64|0)+(r<<2)|0;h=v[n>>2];v[n>>2]=h+1;n=0;A=r;while(1){s=n;n=h&1|n<<1;h=h>>>1|0;A=A-1|0;if(A){continue}break}if(r>>>0<=10){if(n>>>0>1023){break Va}s=1<<r;h=r<<9|I;while(1){u[((n<<1)+J|0)+352>>1]=h;n=n+s|0;if(n>>>0<1024){continue}break}break Va}n=((n&1023)<<1)+J|0;h=u[n+352>>1];Wa:{if(h){n=l;l=h;break Wa}u[n+352>>1]=l;n=l-2|0}h=s>>>8&8388607;if(r>>>0>=12){while(1){h=h>>>1|0;s=(((h&1)+(l^-1)<<1)+J|0)+2400|0;l=u[s>>1];if(!l){u[s>>1]=n;l=n;n=n-2|0}r=r-1|0;if(r>>>0>11){continue}break}}u[(((h>>>1&1)+(l^-1)<<1)+J|0)+2400>>1]=I;l=n}I=I+1|0;r=v[a+24>>2];if(I>>>0<y[((r<<2)+a|0)+44>>2]){continue}break}}h=0;if((r|0)!=2){break Na}break Ra;case 1:h=u[(((m&1023)<<1)+a|0)+7328>>1];Xa:{if((h|0)>=0){if((h&65535)>>>0<512|h>>9>>>0>i>>>0){break Xa}break Qa}if(i>>>0<11){break Xa}l=10;while(1){h=u[(((m>>>l&1)+(h^-1)<<1)+a|0)+9376>>1];if((h|0)<0){n=l+2|0;l=l+1|0;if(i>>>0>=n>>>0){continue}}break}if((h|0)>=0){break Qa}}h=11;continue I;case 2:l=u[(((m&1023)<<1)+a|0)+7328>>1];if((l|0)>=0){break Ta}h=10;while(1){n=m>>>h|0;h=h+1|0;l=u[(((n&1)+(l^-1)<<1)+a|0)+9376>>1];if((l|0)<0){continue}break};break Sa;default:break Ua}}l=t[P+14925|0]+((-1<<q^-1)&m)|0;i=i-q|0;m=m>>>q|0;n=a+k|0;Qb(n+10532|0,(C|0)==16?w[n+10531|0]:0,l);h=l+k|0;break Ra}h=l>>9;l=l&511}i=i-h|0;m=m>>>h|0;C=l;if(l>>>0>15){break Pa}t[(a+k|0)+10532|0]=C;h=k+1|0}n=v[a+48>>2];l=v[a+44>>2];k=n+l|0;if(k>>>0<=h>>>0){break Oa}if(i>>>0<=14){if((z-j|0)<=1){k=h;h=1;continue}m=w[j|0]<<i|m|w[j+1|0]<<i+8;i=i+16|0;j=j+2|0}k=h}h=2;continue}if(!((C|0)!=16|k)){l=-1;h=0;A=17;C=16;break d}q=t[C+18682|0];if(q>>>0>i>>>0){break Ma}P=C-16|0;break Ka}if((h|0)!=(k|0)){l=-1;A=21;break d}k=a+10532|0;hc(a- -64|0,k,l);hc(a+3552|0,l+k|0,n);r=v[a+24>>2];k=h}F=r-1|0;v[a+24>>2]=F;break La}h=12;continue I}h=0;continue}h=3;continue}}o=m;h=2}Ya:while(1){Za:{_a:{$a:{ab:{bb:{cb:{db:{eb:{fb:{gb:{hb:{ib:{jb:{kb:{lb:{switch(h|0){case 0:h=u[(((m&1023)<<1)+a|0)+352>>1];mb:{if((h|0)>=0){if((h&65535)>>>0<512|h>>9>>>0>i>>>0){break mb}break Za}if(i>>>0<11){break mb}l=10;while(1){h=u[(((m>>>l&1)+(h^-1)<<1)+a|0)+2400>>1];if((h|0)<0){n=l+2|0;l=l+1|0;if(i>>>0>=n>>>0){continue}}break}if((h|0)>=0){break Za}}h=13;continue I;case 1:l=u[(((m&1023)<<1)+a|0)+352>>1];if((l|0)>=0){break kb}h=10;while(1){k=m>>>h|0;h=h+1|0;l=u[(((k&1)+(l^-1)<<1)+a|0)+2400>>1];if((l|0)<0){continue}break};k=l;break jb;case 3:break ab;case 4:break bb;case 5:break fb;case 6:break gb;case 2:break lb;default:break hb}}while(1){h=z-j|0;if(!((D-p|0)>1&(h|0)>=4)){if(i>>>0>14){m=o;break Za}if((h|0)<=1){m=o;h=0;continue Ya}m=w[j|0]<<i|o|w[j+1|0]<<i+8;i=i+16|0;j=j+2|0;break Za}nb:{if(i>>>0>14){m=i;h=j;break nb}m=i+16|0;o=(w[j|0]|w[j+1|0]<<8)<<i|o;h=j+2|0}k=u[(((o&1023)<<1)+a|0)+352>>1];ob:{if((k|0)<0){j=10;while(1){i=o>>>j|0;j=j+1|0;k=u[(((i&1)+(k^-1)<<1)+a|0)+2400>>1];if((k|0)<0){continue}break}break ob}j=k>>9}i=m-j|0;m=o>>>j|0;if(k&256){j=h;break ib}if(!(i>>>0>14)){m=(w[h|0]|w[h+1|0]<<8)<<i|m;h=h+2|0;i=i+16|0}l=i;j=h;h=u[(((m&1023)<<1)+a|0)+352>>1];pb:{if((h|0)<0){o=10;while(1){i=m>>>o|0;o=o+1|0;h=u[(((i&1)+(h^-1)<<1)+a|0)+2400>>1];if((h|0)<0){continue}break}break pb}o=h>>9}t[p|0]=k;i=l-o|0;o=m>>>o|0;if(!(h&256)){t[p+1|0]=h;p=p+2|0;continue}break}p=p+1|0;m=o;k=h;break ib}h=l>>9;k=l&511}i=i-h|0;m=m>>>h|0;if(k>>>0>255){break ib}h=14;continue I}l=k&511;k=256;if((l|0)==256){break K}q=0;h=m;n=l<<2;k=v[n+60156>>2];s=k;if(l-265>>>0>19){break $a}q=v[n+60284>>2];if(q>>>0>i>>>0){h=15;continue I}h=3;continue}if(!k){o=m;k=-1;break db}k=k-1|0;h=18;continue I}i=i-q|0;o=m>>>q|0;C=((-1<<q^-1)&m)+C|0;break eb}q=u[(((m&1023)<<1)+a|0)+3840>>1];qb:{if((q|0)<0){h=10;while(1){n=m>>>h|0;h=h+1|0;q=u[(((n&1)+(q^-1)<<1)+a|0)+5888>>1];if((q|0)<0){continue}break}n=q;break qb}h=q>>9;n=q&511}i=i-h|0;m=m>>>h|0;h=n<<2;C=v[h+61440>>2];q=0;if(n-4>>>0>25){o=m;break eb}q=v[h+61568>>2];if(q>>>0<=i>>>0){break cb}h=17;continue I}E=p-d|0;if(!(!N|E>>>0>=C>>>0)){l=-1;A=37;m=o;h=k;break d}h=(E-C&K)+d|0;if((h>>>0<p>>>0?p:h)+k>>>0>D>>>0){m=o;h=7;continue}if(k>>>0>2){while(1){t[p|0]=w[h|0];t[p+1|0]=w[h+1|0];t[p+2|0]=w[h+2|0];h=h+3|0;p=p+3|0;k=k-3|0;if(k>>>0>2){continue}break}}if(!k){break db}t[p|0]=w[h|0];if((k|0)!=1){t[p+1|0]=w[h+1|0]}p=k+p|0}h=2;continue}h=6;continue}h=u[(((m&1023)<<1)+a|0)+3840>>1];rb:{if((h|0)>=0){if((h&65535)>>>0<512|h>>9>>>0>i>>>0){break rb}break _a}if(i>>>0<11){break rb}l=10;while(1){h=u[(((m>>>l&1)+(h^-1)<<1)+a|0)+5888>>1];if((h|0)<0){n=l+2|0;l=l+1|0;if(i>>>0>=n>>>0){continue}}break}if((h|0)>=0){break _a}}h=16;continue I}i=i-q|0;h=m>>>q|0;s=((-1<<q^-1)&m)+k|0}k=s;m=h;if(i>>>0>14){break _a}if((z-j|0)<=1){h=4;continue}m=m|w[j|0]<<i|w[j+1|0]<<i+8;i=i+16|0;j=j+2|0}h=5;continue}h=1;continue}}if(!k|!i){break L}if(i>>>0>7){break M}h=5;continue}i=i-8|0;C=m&255;m=m>>>8|0;h=6;continue}if(k){break J}k=0}if(t[a+20|0]&1){break h}h=0;continue}h=7;continue}}o=i&-8;sb:{if(!o|b>>>0>=j>>>0){break sb}while(1){o=o-8|0;j=j-1|0;if(j>>>0<=b>>>0){break sb}if(o){continue}break}}if(o){break f}m=(((o&63)>>>0>=32?0:-1<<o)^-1)&m>>>(i&7);h=0;n=0;i=0;if(!(g&1)){break g}o=0;break e}v[a>>2]=34;l=0;break b}aa(3896,10512,2787,3906);L()}while(1){tb:{ub:{vb:{wb:{xb:{yb:{switch(o|0){case 0:if(h>>>0>3){l=0;A=34;i=n;break d}if(n){break xb}i=0;k=h;o=1;continue;case 1:break yb;default:break wb}}if(j>>>0<z>>>0){break ub}l=42;break c}k=h;i=n;if(i>>>0>7){break vb}o=2;continue}while(1){if(j>>>0>=z>>>0){l=41;break c}m=w[j|0]<<i|m;h=i>>>0>4294967287;d=j+1|0;j=d;n=i+8|0;i=n;if(h){continue}break}j=d;h=k}o=m&255;m=m>>>8|0;n=n-8|0;break tb}o=w[j|0];j=j+1|0;h=k;n=i}v[a+16>>2]=v[a+16>>2]<<8|o;h=h+1|0;o=0;continue}}v[a>>2]=A;zb:{if(i>>>0<8|b>>>0>=j>>>0){break zb}while(1){i=i-8|0;j=j-1|0;if(j>>>0<=b>>>0){break zb}if(i>>>0>7){continue}break}}k=h;break b}v[a>>2]=l;l=g&2?1:-4}v[a+4>>2]=i;v[a+60>>2]=E;v[a+40>>2]=q;v[a+36>>2]=k;v[a+32>>2]=C;v[a+56>>2]=(((i&63)>>>0>=32?0:-1<<i)^-1)&m;v[c>>2]=j-b;c=p-e|0;v[f>>2]=c;if(!(g&9)|(l|0)<0){break a}b=v[a+28>>2];i=b>>>16|0;j=b&65535;if(c){o=(c>>>0)%5552|0;while(1){k=0;if(o>>>0>7){while(1){p=w[e|0]+j|0;n=p+w[e+1|0]|0;m=n+w[e+2|0]|0;h=m+w[e+3|0]|0;f=h+w[e+4|0]|0;d=f+w[e+5|0]|0;b=d+w[e+6|0]|0;j=b+w[e+7|0]|0;i=j+(b+(d+(f+(h+(m+(n+(i+p|0)|0)|0)|0)|0)|0)|0)|0;e=e+8|0;k=k+8|0;if((k|7)>>>0<o>>>0){continue}break}k=o&8184}m=e;h=k;if(o>>>0>h>>>0){while(1){j=w[m|0]+j|0;i=j+i|0;m=m+1|0;h=h+1|0;if((o|0)!=(h|0)){continue}break}e=(o-k|0)+e|0}c=c-o|0;i=(i>>>0)%65521|0;j=(j>>>0)%65521|0;o=5552;if(c){continue}break}}b=i<<16|j;v[a+28>>2]=b;if(l){break a}l=0;if(!(g&1)){break a}l=(b|0)==v[a+16>>2]?0:-2}gb=M+144|0;return l}function bla(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,z=0,A=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,M=0,N=0,V=0,X=0,Y=0;f=gb-400|0;gb=f;vc(b);j=gb-32|0;gb=j;e=j+24|0;i=f+192|0;aU(e,i);h=yb(e);e=v[j+28>>2];g=v[j+24>>2];v[j+8>>2]=g;v[j+12>>2]=e;v[j>>2]=g;v[j+4>>2]=e;g=j+16|0;e=b;cc(g,e,j);g=yb(g);if((g|0)==(h|0)){Rb(e,yb(j+24|0))}gb=j+32|0;e=(g|0)==(h|0);if(!e){$T(i)}a:{if(!e){break a}if(!iU(f+192|0)){break a}if(!c){d=1;break a}Gd(a,134217728);d=f+136|0;Df(d,1084);v[22656]=0;n=f+192|4;U(886,f+8|0,d|0,n|0);d=v[22656];v[22656]=0;b:{c:{d:{e:{f:{g:{h:{i:{if((d|0)!=1){d=f+8|0;Eb(a+1298304|0,d);vb(d);Hb(f+136|0);d=Tb(d,6105);Eb(a+1298316|0,d);vb(d);v[a+480188>>2]=4;v[a+1298364>>2]=2;X=a,Y=Ib(w[f+328|0]|w[f+329|0]<<8),v[X+480196>>2]=Y;d=Ib(w[f+332|0]|w[f+333|0]<<8);v[a+480260>>2]=56;v[a+480264>>2]=13696;X=a,Y=hU(d),v[X+480204>>2]=Y;Er(Sb(a+484360|0),f+200|0,w[f+192|6]);r=a+480190|0;o=dd(f+176|0);q=mc(f+160|0);j:{k:{l:{m:{if(Ib(w[f+392|0]|w[f+393|0]<<8)){while(1){v[22656]=0;d=T(416,b|0)|0;e=v[22656];v[22656]=0;if((e|0)==1){break i}u[f+112>>1]=d;if((d-1&65535)>>>0>=3999){break c}d=Ib(w[f+394|0]|w[f+395|0]<<8);if((Ib(w[n|0]|w[n+1|0]<<8)|0)==2){v[22656]=0;d=T(426,b|0)|0;e=v[22656];v[22656]=0;if((e|0)==1){break j}d=d-2|0}v[22656]=0;U(288,f+136|0,b|0,d|0);d=v[22656];v[22656]=0;n:{o:{p:{if((d|0)!=1){e=f+136|0;d=kc(f+8|0,e);xb(e);v[22656]=0;e=Le(r,f+112|0);j=v[22656];v[22656]=0;if((j|0)==1){break p}C=x[e>>1];u[a+480190>>1]=C;v[22656]=0;e=B(x[f+112>>1],104)+a|0;h=e+484380|0;R(424,h|0,1);j=v[22656];v[22656]=0;q:{if((j|0)==1){break q}if(Ib(w[n|0]|w[n+1|0]<<8)>>>0>1){break o}v[22656]=0;R(887,d|0,e+484423|0);j=v[22656];v[22656]=0;if((j|0)==1){break q}v[22656]=0;Q(318,f+8|0,1)|0;j=v[22656];v[22656]=0;if((j|0)==1){break q}v[22656]=0;W(503,d|0,((x[f+112>>1]<<5)+a|0)+946304|0,30)|0;j=v[22656];v[22656]=0;if((j|0)!=1){break n}}d=P()|0;O()|0;break f}d=P()|0;O()|0;break e}d=P()|0;O()|0;break f}j=Kb(f+136|0);v[22656]=0;W(534,d|0,j|0,257)|0;i=v[22656];v[22656]=0;r:{s:{if((i|0)==1){break s}v[22656]=0;Q(303,e+484423|0,j|0)|0;i=v[22656];v[22656]=0;if((i|0)==1){break s}v[22656]=0;Q(318,f+8|0,1)|0;i=v[22656];v[22656]=0;if((i|0)==1){break s}v[22656]=0;W(534,d|0,j|0,31)|0;i=v[22656];v[22656]=0;if((i|0)==1){break s}v[22656]=0;Q(301,((x[f+112>>1]<<5)+a|0)+946304|0,j|0)|0;i=v[22656];v[22656]=0;if((i|0)==1){break s}if(!(v[f+16>>2]&1)){break r}v[22656]=0;Q(318,f+8|0,1)|0;i=v[22656];v[22656]=0;if((i|0)!=1){break r}}d=P()|0;O()|0;vb(j);break f}vb(j)}v[22656]=0;R(888,d|0,f+136|0);d=v[22656];v[22656]=0;if((d|0)==1){break m}v[22656]=0;gU(f+136|0,h);d=v[22656];v[22656]=0;if((d|0)==1){break m}if((Ib(w[n|0]|w[n+1|0]<<8)|0)==2){t[e+484417|0]=w[f+154|0]<<3}t:{if(!Ib(w[n|0]|w[n+1|0]<<8)){break t}v[22656]=0;R(317,q|0,C|0);d=v[22656];v[22656]=0;if((d|0)==1){break m}v[22656]=0;R(890,o|0,C|0);d=v[22656];v[22656]=0;if((d|0)==1){break m}h=Ad(o,x[f+112>>1]-1|0);Od(h);v[22656]=0;j=T(416,b|0)|0;d=v[22656];v[22656]=0;if((d|0)==1){break g}v[22656]=0;d=Q(191,b|0,j<<3)|0;i=v[22656];v[22656]=0;if((i|0)==1){break g}if(!d){xb(f+8|0);break c}v[22656]=0;R(891,h|0,j|0);d=v[22656];v[22656]=0;if((d|0)==1){break g}d=0;v[f+128>>2]=0;if(!j){if(!(w[e+484414|0]&2)){break t}d=v[e+484384>>2];v[f+120>>2]=d;e=v[e+484388>>2];v[22656]=0;v[f+124>>2]=e-d;R(892,h|0,f+120|0);d=v[22656];v[22656]=0;if((d|0)!=1){break t}d=P()|0;O()|0;break f}while(1){v[22656]=0;e=T(426,b|0)|0;i=v[22656];v[22656]=0;if((i|0)==1){break k}v[22656]=0;v[f+120>>2]=e;e=T(426,b|0)|0;i=v[22656];v[22656]=0;if((i|0)==1){break k}v[22656]=0;v[f+124>>2]=e;R(892,h|0,f+120|0);e=v[22656];v[22656]=0;if((e|0)==1){break k}d=d+1|0;if(j>>>0>(d&65535)>>>0){continue}break}}xb(f+8|0);p=p+1|0;if(Ib(w[f+392|0]|w[f+393|0]<<8)>>>0>(p&65535)>>>0){continue}break}}D=128;if(Ib(w[n|0]|w[n+1|0]<<8)){break l}v[22656]=0;D=T(416,b|0)|0;d=v[22656];v[22656]=0;if((d|0)!=1){break l}d=P()|0;O()|0;break e}d=P()|0;O()|0;break f}d=a+480188|0;E=w[f+192|7];u[f+118>>1]=4;u:{v:{if(Ib(w[n|0]|w[n+1|0]<<8)){p=v[b+8>>2];w:{if(!D){break w}g=0;while(1){v[22656]=0;e=T(416,b|0)|0;j=v[22656];v[22656]=0;if((j|0)==1){break v}if((e|0)==65535){break w}v[22656]=0;E=T(416,b|0)|0;e=v[22656];v[22656]=0;if((e|0)==1){break v}v[22656]=0;e=T(416,b|0)|0;j=v[22656];v[22656]=0;if((j|0)==1){break v}u[f+118>>1]=e;if(e>>>0>127){break c}v[22656]=0;e=Le(d,f+118|0);j=v[22656];v[22656]=0;if((j|0)==1){break v}u[d>>1]=x[e>>1];v[22656]=0;Q(318,b|0,B(x[f+118>>1],E)<<2)|0;e=v[22656];v[22656]=0;if((e|0)==1){break v}g=g+1|0;if((g&65535)>>>0<D>>>0){continue}break}}v[22656]=0;Q(190,b|0,p|0)|0;e=v[22656];v[22656]=0;if((e|0)==1){break u}}d=x[d>>1];v[22656]=0;G=Q(893,f+136|0,d|0)|0;d=v[22656];v[22656]=0;if((d|0)!=1){H=Ib(w[f+330|0]|w[f+331|0]<<8);x:{if(!D){break x}K=a+484344|0;V=c&1;j=0;p=0;while(1){y:{if(!Ib(w[n|0]|w[n+1|0]<<8)){d=x[f+118>>1];e=p;break y}v[22656]=0;e=T(416,b|0)|0;d=v[22656];v[22656]=0;if((d|0)==1){break h}if((e|0)==65535){break x}v[22656]=0;E=T(416,b|0)|0;d=v[22656];v[22656]=0;if((d|0)==1){break h}v[22656]=0;d=T(416,b|0)|0;h=v[22656];v[22656]=0;if((h|0)==1){break h}u[f+118>>1]=d}v[22656]=0;g=d&65535;F=E&65535;d=F<<2;h=Q(191,b|0,B(g,d)|0)|0;i=v[22656];v[22656]=0;if((i|0)==1){break h}if(!h){break x}z:{A:{B:{if(!V){break B}v[22656]=0;M=e&65535;e=W(331,K|0,M|0,F|0)|0;h=v[22656];v[22656]=0;if((h|0)==1){break h}if(!e){break B}s=0;if(F){break A}break z}v[22656]=0;Q(318,b|0,B(d,x[f+118>>1])|0)|0;d=v[22656];v[22656]=0;if((d|0)!=1){break z}break h}while(1){d=_b(K,M);v[22656]=0;i=Tf(d,s);d=v[22656];v[22656]=0;C:{if((d|0)!=1){e=0;A=0;D:{E:{switch((H&3)-1|0){case 0:A=!(s&3);break D;case 1:A=!(s&1);break D;case 2:break E;default:break D}}A=(s&3)!=3}I=0;if(!x[f+118>>1]){break C}while(1){d=v[G>>2];v[22656]=0;R(532,f+120|0,b|0);h=v[22656];v[22656]=0;if((h|0)==1){break h}h=B(e,9)+d|0;d=f+120|0;g=qd(d);z=Ve(d);k=ej(d);l=i+B(e,6)|0;t[l+1|0]=w[d|0];d=w[g|0];t[l|0]=d;g=w[k|0];t[l+5|0]=g;k=l+5|0;if(d){t[l|0]=d+25;t[h+8|0]=0;t[h|0]=0;t[h+1|0]=0;t[h+2|0]=0;t[h+3|0]=0;t[h+4|0]=0;t[h+5|0]=0;t[h+6|0]=0;t[h+7|0]=0;g=w[k|0]}m=g&255;z=w[z|0];F:{if(z>>>0>=240){d=m|(z&15)<<8;if(d){v[22656]=0;d=gn(+(hU(d)>>>0)/1e4);g=v[22656];v[22656]=0;if((g|0)!=1){t[k|0]=d;t[l+3|0]=17;break F}break h}t[l+3|0]=0;break F}J=m>>>4|0;N=m<<4;d=J|N;G:{switch(z|0){case 0:d=i+B(e,6)|0;if(g&255){t[d+3|0]=1;break F}t[d+3|0]=0;break F;case 1:t[(i+B(e,6)|0)+3|0]=2;break F;case 2:t[(i+B(e,6)|0)+3|0]=3;break F;case 3:v[22656]=0;t[f+8|0]=15;d=ac(k,f+8|0);g=v[22656];v[22656]=0;if((g|0)!=1){t[h|0]=w[d|0]|16;t[h+7|0]=0;t[h+1|0]=0;t[h+2|0]=0;t[(i+B(e,6)|0)+3|0]=0;break F}break h;case 4:v[22656]=0;t[f+8|0]=15;d=ac(k,f+8|0);g=v[22656];v[22656]=0;if((g|0)!=1){t[h|0]=w[d|0]|32;t[h+7|0]=0;t[h+1|0]=0;t[h+2|0]=0;t[(i+B(e,6)|0)+3|0]=0;break F}break h;case 5:t[h+7|0]=0;t[h+2|0]=0;t[h+1|0]=g;t[h|0]=0;t[(i+B(e,6)|0)+3|0]=0;break F;case 6:t[h+7|0]=0;t[h+2|0]=g;t[h|0]=0;t[h+1|0]=0;t[(i+B(e,6)|0)+3|0]=0;break F;case 7:t[(i+B(e,6)|0)+3|0]=23;j=0;break F;case 8:t[(i+B(e,6)|0)+3|0]=0;j=d;break F;case 9:t[(i+B(e,6)|0)+3|0]=19;v[22656]=0;t[f+8|0]=15;d=ac(k,f+8|0);g=v[22656];v[22656]=0;if((g|0)!=1){t[k|0]=w[d|0]|16;break F}break h;case 10:t[(i+B(e,6)|0)+3|0]=19;v[22656]=0;t[f+8|0]=15;d=ac(k,f+8|0);g=v[22656];v[22656]=0;if((g|0)!=1){t[k|0]=w[d|0]|32;break F}break h;case 11:t[h+3|0]=d;t[(i+B(e,6)|0)+3|0]=0;break F;case 12:d=i+B(e,6)|0;t[d+4|0]=g;t[d+2|0]=1;t[h+3|0]=0;t[d+3|0]=0;break F;case 13:z=i+B(e,6)|0;H:{I:{if(m&240){t[(i+B(e,6)|0)+2|0]=4;d=(g&240)>>>4|0;break I}if(!(m&15)){break H}t[(i+B(e,6)|0)+2|0]=3;d=g&15}t[z+4|0]=d}t[h+3|0]=0;t[(i+B(e,6)|0)+3|0]=0;break F;case 14:t[(i+B(e,6)|0)+3|0]=19;t[k|0]=!(g&255);break F;case 15:t[(i+B(e,6)|0)+3|0]=16;t[k|0]=(g&240)>>>4;H=g&15;break F;case 16:t[h+5|0]=0;t[h+4|0]=g;t[(i+B(e,6)|0)+3|0]=0;break F;case 17:t[h+6|0]=m&15?g:0;t[(i+B(e,6)|0)+3|0]=0;break F;case 18:t[(i+B(e,6)|0)+3|0]=14;break F;case 19:t[h+8|0]=0;t[h+7|0]=g;t[h+2|0]=0;t[h|0]=0;t[h+1|0]=0;t[(i+B(e,6)|0)+3|0]=0;break F;case 20:t[(i+B(e,6)|0)+3|0]=12;break F;case 22:J:{d=w[l+1|0];K:{if(!d){break K}if(Ec(o)>>>0<d>>>0){break K}d=Ad(o,d-1|0);g=g-1|0;t[k|0]=g;v[22656]=0;Q(895,f+8|0,0)|0;m=v[22656];v[22656]=0;if((m|0)==1){break h}v[f+112>>2]=9;d=Ec(d);v[22656]=0;v[f+4>>2]=d;d=Fb(f+112|0,f+4|0);m=v[22656];v[22656]=0;if((m|0)==1){break J}if(y[d>>2]<=(g&255)>>>0){break K}d=i+B(e,6)|0;t[d+2|0]=15;t[d+4|0]=w[k|0]}t[(i+B(e,6)|0)+3|0]=0;break F}break h;case 23:d=w[l+1|0];L:{if(!d){break L}if(Ec(o)>>>0<d>>>0){break L}d=Ad(o,d-1|0);g=g-1|0;t[k|0]=g;g=g&255;if(Ec(d)>>>0<=g>>>0){break L}M:{if(x[Ad(d,g)+8>>1]){break M}if(!ei(a)){g=w[k|0];break M}m=x[r>>1]+1|0;u[r>>1]=m;g=w[k|0];X=Ad(d,g),Y=m,u[X+8>>1]=Y}X=l,Y=w[Ad(d,g)+8|0],t[X+1|0]=Y}t[(i+B(e,6)|0)+3|0]=0;break F;case 24:N:{d=w[l+1|0];O:{if(!d){break O}if(Ec(o)>>>0<d>>>0){break O}d=Ad(o,d-1|0);g=g-1|0;t[k|0]=g;v[22656]=0;Q(895,f+8|0,0)|0;m=v[22656];v[22656]=0;if((m|0)==1){break h}v[f+112>>2]=9;d=Ec(d);v[22656]=0;v[f+4>>2]=d;d=Fb(f+112|0,f+4|0);m=v[22656];v[22656]=0;if((m|0)==1){break N}if(y[d>>2]>(g&255)>>>0){d=i+B(e,6)|0;t[d+2|0]=15;t[d+4|0]=w[k|0]}P:{if(x[sc(q,w[l+1|0]-1|0)>>1]){break P}if(!ei(a)){break P}d=x[r>>1]+1|0;u[r>>1]=d;X=sc(q,w[l+1|0]-1|0),Y=d,u[X>>1]=Y}X=l,Y=w[sc(q,w[l+1|0]-1|0)|0],t[X+1|0]=Y}t[(i+B(e,6)|0)+3|0]=0;break F}break h;case 25:d=w[l+1|0];Q:{if(!d){break Q}if(Ec(o)>>>0<d>>>0){break Q}d=Ad(o,d-1|0);g=g-1|0;t[k|0]=g;g=g&255;if(Ec(d)>>>0<=g>>>0){break Q}R:{if(x[Ad(d,g)+10>>1]){break R}if(!ei(a)){g=w[k|0];break R}m=x[r>>1]+1|0;u[r>>1]=m;g=w[k|0];X=Ad(d,g),Y=m,u[X+10>>1]=Y}X=l,Y=w[Ad(d,g)+10|0],t[X+1|0]=Y}t[(i+B(e,6)|0)+3|0]=0;break F;case 29:t[(i+B(e,6)|0)+3|0]=11;t[k|0]=d;if(m&15){t[k|0]=N|15;break F}if((g&255)>>>0<16){break F}t[k|0]=J|240;break F;case 32:if(m&240){t[h+3|0]=J;t[(i+B(e,6)|0)+3|0]=0;break F}t[(i+B(e,6)|0)+3|0]=19;t[k|0]=g&15|192;break F;case 33:t[(i+B(e,6)|0)+3|0]=19;v[22656]=0;t[f+8|0]=15;d=ac(k,f+8|0);g=v[22656];v[22656]=0;if((g|0)!=1){t[k|0]=w[d|0]|208;break F}break h;case 34:t[(i+B(e,6)|0)+3|0]=19;v[22656]=0;t[f+8|0]=15;d=ac(k,f+8|0);g=v[22656];v[22656]=0;if((g|0)!=1){t[k|0]=w[d|0]|144;break F}break h;case 73:t[(i+B(e,6)|0)+3|0]=10;break F;case 78:if((g&112|128)==224){t[(i+B(e,6)|0)+3|0]=19;break F}t[(i+B(e,6)|0)+3|0]=0;break F;case 79:d=i+B(e,6)|0;if((g&255)>>>0<=31){t[d+3|0]=16;H=0;break F}t[d+3|0]=17;break F;default:break G}}t[(i+B(e,6)|0)+3|0]=0}m=0;g=w[h+3|0];if(!(w[l+2|0]|!g)){S:{if(g>>>0>=16){t[l+2|0]=5;g=g>>>4|0;break S}t[l+2|0]=6}t[l+4|0]=g;m=1}T:{if(w[l+3|0]){break T}d=w[h+1|0];U:{if(d){t[l+3|0]=2;break U}d=w[h+2|0];if(d){t[l+3|0]=3;break U}d=w[h|0];if(d){t[l+3|0]=19;break U}d=w[h+7|0];if(d){t[l+3|0]=4;t[h+8|0]=d;break U}d=w[h+4|0];if(d){t[l+3|0]=5;t[h+5|0]=d;break U}d=w[h+3|0];if(!(!d|m)){t[l+3|0]=11;t[k|0]=d;if(d&15){d=d|-16;break U}if(!(d&240)){break T}d=d|15;break U}d=w[h+6|0];if(d){t[l+3|0]=8;break U}if(A){t[l+3|0]=20;A=0;d=97;break U}A=0;if(I){break T}d=j&255;if(!d){break T}t[l+3|0]=24;t[k|0]=j;if(j&15){d=j|-16}else{if(!(d&240)){I=1;break T}d=j|15}I=1}t[k|0]=d}e=e+1|0;if(e>>>0<x[f+118>>1]){continue}break}break C}break h}s=s+1|0;if((F|0)!=(s|0)){continue}break}}p=p+1|0;if((p&65535)>>>0<D>>>0){continue}break}}v[a+480228>>2]=256/x[a+480188>>1];v[22656]=0;xh(a,1);d=v[22656];v[22656]=0;if((d|0)==1){break h}if(Ib(w[n|0]|w[n+1|0]<<8)){V:{while(1){v[22656]=0;d=Q(191,b|0,2)|0;e=v[22656];v[22656]=0;if((e|0)==1){break h}if(!d){break V}v[22656]=0;d=T(416,b|0)|0;e=v[22656];v[22656]=0;if((e|0)==1){break h}if((d|0)==65535){break V}v[22656]=0;Q(318,b|0,2)|0;d=v[22656];v[22656]=0;if((d|0)==1){break h}v[22656]=0;d=T(426,b|0)|0;e=v[22656];v[22656]=0;if((e|0)!=1){v[22656]=0;Q(318,b|0,d|0)|0;d=v[22656];v[22656]=0;if((d|0)!=1){continue}}break}break h}v[22656]=0;Q(318,b|0,34)|0;d=v[22656];v[22656]=0;if((d|0)==1){break h}}W:{if(!(!(c&2)|!C)){d=1;p=1;while(1){c=(B(d,104)+a|0)+484380|0;X:{if(!v[c>>2]){break X}e=Rc(f+8|0,8,1,0,0);v[22656]=0;W(329,e|0,c|0,b|0)|0;e=v[22656];v[22656]=0;if((e|0)==1){break W}if(Ec(o)>>>0<d>>>0){break X}d=d-1|0;e=Ad(o,d);v[22656]=0;R(896,c|0,e|0);e=v[22656];v[22656]=0;Y:{if((e|0)!=1){if(!x[sc(q,d)>>1]){break Y}e=x[sc(q,d)>>1];j=v[c>>2];v[22656]=0;ha(897,c|0,(B(e,104)+a|0)+484380|0,0,j|0,0);e=v[22656];v[22656]=0;if((e|0)!=1){break Y}}break h}d=Ad(o,d);X=f,Y=Vb(d),v[X+8>>2]=Y;X=f,Y=Zb(d),v[X+120>>2]=Y;if(!Gb(f+8|0,f+120|0)){break X}while(1){d=v[f+8>>2];e=x[d+8>>1];if(e){j=v[d+4>>2];h=v[d>>2];v[22656]=0;ha(897,c|0,(B(e,104)+a|0)+484380|0,h|0,j|0,1);e=v[22656];v[22656]=0;if((e|0)==1){break h}}e=x[d+10>>1];if(e){j=v[d+4>>2];d=v[d>>2];v[22656]=0;ha(897,c|0,(B(e,104)+a|0)+484380|0,d|0,j|0,0);d=v[22656];v[22656]=0;if((d|0)==1){break h}}d=f+8|0;sr(d);if(Gb(d,f+120|0)){continue}break}}p=p+1|0;d=p&65535;if(C>>>0>=d>>>0){continue}break}}VB(G);d=1;break b}break h}d=P()|0;O()|0;break e}d=P()|0;O()|0;break e}d=P()|0;O()|0;break e}d=P()|0;O()|0;break f}d=P()|0;O()|0;break e}d=P()|0;O()|0;Hb(f+136|0);break d}d=P()|0;O()|0;break e}d=P()|0;O()|0;VB(G);break e}d=P()|0;O()|0}xb(f+8|0)}Ze(q);bU(o)}S(d|0);L()}d=0}Ze(q);bU(o)}gb=f+400|0;return d|0}function wpa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,y=0,z=0,A=0,C=0,D=0,E=0;e=gb-352|0;gb=e;vc(b);f=e+328|0;g=VD(b,f);if(!g){Zv(f)}a:{b:{c:{d:{e:{f:{if(!g){break f}if(!XX(e+328|0)){break f}if(!Pb(b,Qc(72,0))){break f}if(!c){d=1;break f}Gd(a,1);v[a+480208>>2]=v[a+480208>>2]&-25231361|16842752;d=w[e+337|0];u[a+480190>>1]=63;u[a+480188>>1]=d;g:{if(d){d=0;while(1){gu(a,d&65535);u[((d<<5)+a|0)+480284>>1]=(d&3)-1>>>0<2?64:192;d=d+1|0;if(d>>>0<x[a+480188>>1]){continue}break}if(!x[a+480190>>1]){break g}}d=1;f=1;while(1){g=(B(d,104)+a|0)+484380|0;ud(g,1);h=(e+256|0)+d|0;d=Ae(b);t[h|0]=d;if(d<<24>>24>=0){D=g,E=UX(b)<<1,v[D>>2]=E}f=f+1|0;d=f&65535;if(d>>>0<=x[a+480190>>1]){continue}break}}dE(b,a+1298268|0,-1);g=e+248|0;f=gb-32|0;gb=f;d=b;h:{if(!Pb(d,8)){t[f+16|0]=0;ni(g,8,f+16|0);break h}fs(f+24|0,g);g=v[f+28>>2];v[f+8>>2]=v[f+24>>2];v[f+12>>2]=g;kd(f+16|0,d,f+8|0)}gb=f+32|0;m=mc(e+232|0);i:{if(w[e+338|0]|w[e+339|0]<<8){f=w[e+338|0]|w[e+339|0]<<8;g=w[e+337|0];d=0;v[22656]=0;f=W(498,b|0,m|0,B(f,g)<<1)|0;g=v[22656];v[22656]=0;if((g|0)==1){f=P()|0;O()|0;break a}if(!f){break i}}kn(e+224|0,v[m>>2],oc(m)>>>1|0);l=mc(e+208|0);d=w[e+340|0]|w[e+341|0]<<8;f=0;v[22656]=0;R(499,l|0,d<<8);d=v[22656];v[22656]=0;j:{k:{l:{m:{if((d|0)!=1){if(w[e+340|0]|w[e+341|0]<<8){while(1){v[e+136>>2]=(w[e+340|0]|w[e+341|0]<<8)-f;v[22656]=0;v[e+160>>2]=2e3;d=pd(e+136|0,e+160|0);g=v[22656];v[22656]=0;n:{if((g|0)!=1){g=v[d>>2];d=mc(e+136|0);v[22656]=0;g=W(498,b|0,d|0,g<<8)|0;h=v[22656];v[22656]=0;if((h|0)==1){break c}if(g){break n}gc(d);d=0;break j}f=P()|0;O()|0;break b}D=e,E=Zb(l),v[D+160>>2]=E;Fd(e+200|0,e+160|0);g=Vb(d);h=Zb(d);v[22656]=0;Y(500,l|0,v[e+200>>2],g|0,h|0);g=v[22656];v[22656]=0;if((g|0)==1){break c}gc(d);f=f+2e3&65535;if(f>>>0<(w[e+340|0]|w[e+341|0]<<8)>>>0){continue}break}}v[22656]=0;Vd(e+184|0,l);d=v[22656];v[22656]=0;if((d|0)==1){break l}d=v[e+188>>2];v[e+64>>2]=v[e+184>>2];v[e+68>>2]=d;rh(e+192|0,e- -64|0);q=a+484360|0;d=Sb(q);f=w[e+338|0]|w[e+339|0]<<8;v[22656]=0;R(502,d|0,f|0);d=v[22656];v[22656]=0;if((d|0)==1){break l}i=1;if(!(w[e+338|0]|w[e+339|0]<<8)){break k}r=a+484344|0;y=c&1;h=0;while(1){o:{D=sc(Sb(q),h),E=h,u[D>>1]=E;p:{if(!y){break p}v[22656]=0;s=h&65535;d=W(331,r|0,s|0,64)|0;f=v[22656];v[22656]=0;if((f|0)==1){break o}k=0;f=x[a+480188>>1];if(!(d&(f|0)!=0)){break p}while(1){d=sc(e+224|0,B(f&65535,h)+k|0);f=w[d|0]|w[d+1|0]<<8;q:{if(f>>>0>=(w[e+340|0]|w[e+341|0]<<8)>>>0){f=x[a+480188>>1];break q}d=_b(r,h);v[22656]=0;d=Yc(d,0,k&65535);g=v[22656];v[22656]=0;if((g|0)==1){break m}p=0;z=0-k|0;A=f<<8;while(1){f=e+136|0;wd(f,v[e+192>>2]+((p<<2)+A|0)|0,4);n=w[lc(f,0)|0]&63;t[d|0]=n?n+48|0:0;g=lc(f,0);D=d,E=w[lc(f,1)|0]<<2&60|w[g|0]>>>6,t[D+1|0]=E;g=w[lc(f,1)|0];o=w[lc(f,2)|0];C=lc(f,2);j=w[lc(f,3)|0];f=j<<4|w[C|0]>>>4;u[e+182>>1]=f;g=o<<2&60|g>>>6;r:{if(!(w[ic(e+248|0,g>>>3|0)|0]>>>(g&7)&1)|!(f?1:g)){break r}t[d+5|0]=f;t[d+3|0]=g;o=j>>>4|0;t[d+4|0]=o;s:{t:{u:{v:{w:{x:{y:{z:{A:{B:{C:{D:{E:{switch(g|0){case 0:case 1:case 2:case 32:case 33:case 34:t[d+3|0]=g&15;v[22656]=0;Of(d);f=v[22656];v[22656]=0;if((f|0)==1){break D}if(!w[d+4|0]){break r}t[d+2|0]=g>>>0<32?3:4;break r;case 3:case 4:case 5:case 6:case 7:case 12:v[22656]=0;Of(d);f=v[22656];v[22656]=0;if((f|0)==1){break D}break r;case 9:t[d+3|0]=10;t[d+5|0]=f>>>1;if(f>>>0<512){break r}t[d+2|0]=15;t[d+4|0]=j>>>5;break r;case 50:break t;case 48:break u;case 43:break v;case 47:break w;case 17:case 18:case 26:case 27:break x;case 22:case 25:case 28:case 29:case 30:break y;case 16:case 19:case 20:case 21:case 23:case 31:break z;case 13:break A;case 11:case 15:break B;case 10:case 42:break E;default:break s}}if(f>>>0>254){break C}t[d+3|0]=g&15;v[22656]=0;Of(d);f=v[22656];v[22656]=0;if((f|0)!=1){break r}}f=P()|0;O()|0;break b}t[d+3|0]=19;t[d+5|0]=o|(g>>>0<32?16:32);if(j&15){t[d+2|0]=3;t[d+4|0]=(f&240)>>>4;break r}t[d+2|0]=4;t[d+4|0]=f&15;break r}t[d+3|0]=(g|0)==11?12:16;D=d,E=Iv(f),t[D+5|0]=E;break r}t[d+3|0]=14;if((f&255)>>>0<64){break r}t[d+5|0]=0;break r}t[d+3|0]=19;t[d+5|0]=f&15|g<<4;break r}t[d+3|0]=19;v[22656]=0;u[e+160>>1]=15;f=Pc(e+182|0,e+160|0);j=v[22656];v[22656]=0;if((j|0)!=1){t[d+5|0]=w[f|0]|g<<4;break r}f=P()|0;O()|0;break b}t[d+3|0]=19;if(f&255){t[d+5|0]=f&15|((g|0)==17?16:(g|0)==26?16:32);if(!(j&240)){break r}t[d+2|0]=g>>>0>25?6:5;break r}t[d+5|0]=o|(g>>>0>25?-80:-96);break r}if(!f){break s}t[d+3|0]=17;v[e+160>>2]=8;v[22656]=0;v[e+176>>2]=f+4;f=Gf(e+160|0,e+176|0);g=v[22656];v[22656]=0;if((g|0)!=1){D=d,E=Xi(v[f>>2]/8|0),t[D+5|0]=E;break r}f=P()|0;O()|0;break b}t[d+3|0]=14;g=x[a+480188>>1];if(!g){break r}n=B(z,6)+d|0;f=0;while(1){j=n+B(f,6)|0;if(!w[j+3|0]){t[j+3|0]=12;D=j,E=Iv(s),t[D+5|0]=E;g=x[a+480188>>1]}f=f+1|0;if(g>>>0>f>>>0){continue}break}break r}t[d+3|0]=9;g=f&7;if(g){t[d+5|0]=w[g+28585|0];break r}g=f>>>4|0;if((g|0)==128){break s}t[d+5|0]=g;if(!(f&2048)){t[d+5|0]=g^128;break r}t[d+5|0]=g^-1;break r}t[d+5|0]=0;t[d+3|0]=0;if(!n){t[d|0]=255;break r}t[d+3|0]=25;break r}t[d+3|0]=0}f=x[a+480188>>1];d=B(f,6)+d|0;p=p+1|0;if((p|0)!=64){continue}break}}k=k+1|0;if(k>>>0<(f&65535)>>>0){continue}break}}h=h+1|0;if(h>>>0<(w[e+338|0]|w[e+339|0]<<8)>>>0){continue}break k}break}f=P()|0;O()|0;break b}f=P()|0;O()|0;break b}f=P()|0;O()|0;break b}f=P()|0;O()|0;break b}if(x[a+480190>>1]){k=c&2;f=1;while(1){v[22656]=0;c=w[(e+256|0)+i|0];W(503,b|0,((i<<5)+a|0)+946304|0,c&63)|0;d=v[22656];v[22656]=0;F:{G:{H:{I:{J:{K:{if((d|0)!=1){if(c<<24>>24<0){break F}v[22656]=0;d=T(504,b|0)|0;c=v[22656];v[22656]=0;L:{M:{N:{O:{P:{Q:{R:{S:{T:{U:{V:{if((c|0)==1){break V}c=B(i,104)+a|0;g=c+484392|0;v[g>>2]=d<<1;v[22656]=0;d=T(504,b|0)|0;h=v[22656];v[22656]=0;if((h|0)==1){break U}d=d<<1;if(d>>>0>=3){v[c+484396>>2]=d+v[g>>2];d=c+484414|0;u[d>>1]=x[d>>1]|8}v[22656]=0;d=T(374,b|0)|0;g=v[22656];v[22656]=0;if((g|0)==1){break T}t[e+136|0]=d;v[22656]=0;t[e+160|0]=64;d=ac(e+136|0,e+160|0);g=v[22656];v[22656]=0;if((g|0)==1){break S}u[c+484410>>1]=w[d|0]<<2;v[22656]=0;d=T(374,b|0)|0;g=v[22656];v[22656]=0;if((g|0)==1){break V}t[c+484417|0]=d<<4;v[22656]=0;c=c+484380|0;Ku(c);d=v[22656];v[22656]=0;if((d|0)==1){break V}if(!v[c>>2]){break F}v[22656]=0;h=T(374,b|0)|0;d=v[22656];v[22656]=0;if((d|0)==1){break I}d=0;switch(h|0){case 4:case 5:break O;case 2:case 3:break P;case 1:break Q;case 0:break R;default:break j}}f=P()|0;O()|0;break b}f=P()|0;O()|0;break b}f=P()|0;O()|0;break b}f=P()|0;O()|0;break b}if(!k){break M}g=mc(e+160|0);h=v[c>>2];v[22656]=0;h=Q(191,b|0,h|0)|0;i=v[22656];v[22656]=0;if((i|0)==1){break K}if(!h){break N}d=v[c>>2];v[22656]=0;W(506,b|0,g|0,d|0)|0;d=v[22656];v[22656]=0;if((d|0)==1){break K}D=e,E=Vb(g),v[D+136>>2]=E;D=e,E=Zb(g),v[D+176>>2]=E;if(Gb(e+136|0,e+176|0)){break J}break H}g=mc(e+160|0);d=v[c>>2];v[22656]=0;U(507,e+136|0,b|0,d|0);d=v[22656];v[22656]=0;W:{X:{Y:{Z:{if((d|0)!=1){d=e+136|0;op(g,d);gc(d);if(!k){break Y}v[22656]=0;Vd(e+112|0,g);d=v[22656];v[22656]=0;if((d|0)!=1){d=Ud(e+104|0);v[22656]=0;h=v[e+116>>2];v[e+40>>2]=v[e+112>>2];v[e+44>>2]=h;h=v[d+4>>2];v[e+32>>2]=v[d>>2];v[e+36>>2]=h;d=W(508,e+136|0,e+40|0,e+32|0)|0;h=v[22656];v[22656]=0;if((h|0)!=1){break Z}}f=P()|0;O()|0;break W}f=V(27364)|0;if((O()|0)!=(ea(27364)|0)){break W}Z(f|0)|0;d=0;v[22656]=0;X(20);a=v[22656];v[22656]=0;if((a|0)!=1){break L}f=P()|0;O()|0;break W}h=Rc(e+176|0,8,1,0,2);v[22656]=0;W(329,h|0,c|0,d|0)|0;c=v[22656];v[22656]=0;if((c|0)==1){break X}xb(e+136|0)}gc(g);break F}f=P()|0;O()|0;xb(e+136|0)}gc(g);break b}if(k){d=Rc(e+136|0,(h|0)==2?8:16,1,0,0);v[22656]=0;W(329,d|0,c|0,b|0)|0;c=v[22656];v[22656]=0;if((c|0)!=1){break F}f=P()|0;O()|0;break b}c=v[c>>2];v[22656]=0;Q(318,b|0,B(c,h-1|0)|0)|0;c=v[22656];v[22656]=0;if((c|0)!=1){break F}break I}g=mc(e+160|0);d=v[c>>2];v[22656]=0;U(509,e+136|0,b|0,d|0);d=v[22656];v[22656]=0;_:{$:{aa:{if((d|0)!=1){d=e+136|0;op(g,d);gc(d);if(k){ba:{if((h|0)!=5){break ba}D=e,E=Vb(g),v[D+136>>2]=E;D=e,E=Zb(g),v[D+176>>2]=E;if(!Gb(e+136|0,e+176|0)){break ba}while(1){d=e+136|0;j=v[d>>2];i=zb(w[j|0]);D=j,E=zb((i^w[(i>>>7|0)+28593|0])&255),t[D|0]=E;Pe(d);if(Gb(d,e+176|0)){continue}break}}v[22656]=0;Vd(e+96|0,g);d=v[22656];v[22656]=0;if((d|0)==1){break aa}d=Ud(e+88|0);v[22656]=0;i=v[e+100>>2];v[e+56>>2]=v[e+96>>2];v[e+60>>2]=i;i=v[d+4>>2];v[e+48>>2]=v[d>>2];v[e+52>>2]=i;d=W(508,e+136|0,e+56|0,e+48|0)|0;i=v[22656];v[22656]=0;if((i|0)==1){break aa}h=(h|0)==5;h=Rc(e+176|0,h?16:8,1,0,h?16:1);v[22656]=0;W(329,h|0,c|0,d|0)|0;c=v[22656];v[22656]=0;if((c|0)==1){break $}xb(e+136|0)}gc(g);break F}f=V(27364)|0;if((O()|0)!=(ea(27364)|0)){break _}Z(f|0)|0;d=0;v[22656]=0;X(20);a=v[22656];v[22656]=0;if((a|0)==1){f=P()|0;O()|0;break _}gc(g);break j}f=P()|0;O()|0;break _}f=P()|0;O()|0;xb(e+136|0)}gc(g);break b}gc(g);break j}c=v[c>>2];v[22656]=0;Q(318,b|0,c|0)|0;c=v[22656];v[22656]=0;if((c|0)==1){break I}break F}gc(g);break j}f=P()|0;O()|0;break b}f=P()|0;O()|0;break G}while(1){d=e+136|0;i=v[d>>2];h=zb(w[i|0]);D=i,E=zb((h<<7|(h^-1)<<24>>>25)&255),t[D|0]=E;Pe(d);if(Gb(d,e+176|0)){continue}break}break H}f=P()|0;O()|0;break b}v[22656]=0;Vd(e+128|0,g);d=v[22656];v[22656]=0;ca:{da:{if((d|0)==1){break da}d=Ud(e+120|0);v[22656]=0;h=v[e+132>>2];v[e+24>>2]=v[e+128>>2];v[e+28>>2]=h;h=v[d+4>>2];v[e+16>>2]=v[d>>2];v[e+20>>2]=h;d=W(508,e+136|0,e+24|0,e+16|0)|0;h=v[22656];v[22656]=0;if((h|0)==1){break da}h=Rc(e+176|0,16,1,0,16);v[22656]=0;W(329,h|0,c|0,d|0)|0;c=v[22656];v[22656]=0;if((c|0)==1){break ca}xb(e+136|0);gc(g);break F}f=P()|0;O()|0;break G}f=P()|0;O()|0;xb(e+136|0)}gc(g);break b}f=f+1|0;i=f&65535;if(i>>>0<=x[a+480190>>1]){continue}break}}ea:{fa:{ga:{ha:{ia:{ja:{ka:{d=w[e+342|0]|w[e+343|0]<<8|w[e+344|0]<<16;if(d){c=mc(e+160|0);v[22656]=0;b=W(498,b|0,c|0,d|0)|0;f=v[22656];v[22656]=0;if((f|0)==1){break e}if(!b){break ia}v[22656]=0;Vd(e+80|0,c);b=v[22656];v[22656]=0;if((b|0)==1){break ka}b=Ud(e+72|0);v[22656]=0;f=v[e+84>>2];v[e+8>>2]=v[e+80>>2];v[e+12>>2]=f;f=v[b+4>>2];v[e>>2]=v[b>>2];v[e+4>>2]=f;b=W(508,e+136|0,e+8|0,e|0)|0;f=v[22656];v[22656]=0;if((f|0)==1){break ka}v[22656]=0;da(510,a+1298292|0,b|0,d|0,1)|0;d=v[22656];v[22656]=0;if((d|0)==1){break ja}xb(b);gc(c)}v[22656]=0;_(511,e+160|0);b=v[22656];v[22656]=0;if((b|0)==1){break ha}v[22656]=0;U(316,e+136|0,e+160|0,e+336|0);b=v[22656];v[22656]=0;if((b|0)==1){break ga}b=e+136|0;Eb(a+1298304|0,b);vb(b);Hb(e+160|0);v[22656]=0;b=Q(2,b|0,7366)|0;c=v[22656];v[22656]=0;if((c|0)==1){break fa}Eb(a+1298316|0,b);vb(b);v[22656]=0;b=Q(2,e+136|0,2197)|0;c=v[22656];v[22656]=0;if((c|0)==1){break ea}Eb(a+1298328|0,b);vb(b);v[a+1298364>>2]=2;d=1;break j}f=P()|0;O()|0;break d}f=P()|0;O()|0;xb(b);break d}gc(c);d=0;break j}f=P()|0;O()|0;break b}f=P()|0;O()|0;Hb(e+160|0);break b}f=P()|0;O()|0;break b}f=P()|0;O()|0;break b}gc(l)}gc(m)}gb=e+352|0;return d|0}f=P()|0;O()|0}gc(c);break b}f=P()|0;O()|0;gc(d)}gc(l)}gc(m);S(f|0);L()}function Cd(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;l=gb-16|0;gb=l;a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{if(a>>>0<=244){e=v[116506];h=a>>>0<11?16:a+11&-8;c=h>>>3|0;b=e>>>c|0;if(b&3){d=c+((b^-1)&1)|0;b=d<<3;f=v[b+466072>>2];a=f+8|0;c=v[f+8>>2];b=b+466064|0;l:{if((c|0)==(b|0)){m=466024,n=oqa(-2,d)&e,v[m>>2]=n;break l}v[c+12>>2]=b;v[b+8>>2]=c}b=d<<3;v[f+4>>2]=b|3;b=b+f|0;v[b+4>>2]=v[b+4>>2]|1;break a}k=v[116508];if(k>>>0>=h>>>0){break k}if(b){a=2<<c;a=(0-a|a)&b<<c;b=(0-a&a)-1|0;a=b>>>12&16;c=a;b=b>>>a|0;a=b>>>5&8;c=c|a;b=b>>>a|0;a=b>>>2&4;c=c|a;b=b>>>a|0;a=b>>>1&2;c=c|a;b=b>>>a|0;a=b>>>1&1;c=(c|a)+(b>>>a|0)|0;a=c<<3;g=v[a+466072>>2];b=v[g+8>>2];a=a+466064|0;m:{if((b|0)==(a|0)){e=oqa(-2,c)&e;v[116506]=e;break m}v[b+12>>2]=a;v[a+8>>2]=b}a=g+8|0;v[g+4>>2]=h|3;d=g+h|0;b=c<<3;f=b-h|0;v[d+4>>2]=f|1;v[b+g>>2]=f;if(k){b=k>>>3|0;c=(b<<3)+466064|0;g=v[116511];b=1<<b;n:{if(!(b&e)){v[116506]=b|e;b=c;break n}b=v[c+8>>2]}v[c+8>>2]=g;v[b+12>>2]=g;v[g+12>>2]=c;v[g+8>>2]=b}v[116511]=d;v[116508]=f;break a}j=v[116507];if(!j){break k}b=(j&0-j)-1|0;a=b>>>12&16;c=a;b=b>>>a|0;a=b>>>5&8;c=c|a;b=b>>>a|0;a=b>>>2&4;c=c|a;b=b>>>a|0;a=b>>>1&2;c=c|a;b=b>>>a|0;a=b>>>1&1;b=v[((c|a)+(b>>>a|0)<<2)+466328>>2];d=(v[b+4>>2]&-8)-h|0;c=b;while(1){o:{a=v[c+16>>2];if(!a){a=v[c+20>>2];if(!a){break o}}c=(v[a+4>>2]&-8)-h|0;f=c>>>0<d>>>0;d=f?c:d;b=f?a:b;c=a;continue}break}i=v[b+24>>2];f=v[b+12>>2];if((f|0)!=(b|0)){a=v[b+8>>2];v[a+12>>2]=f;v[f+8>>2]=a;break b}c=b+20|0;a=v[c>>2];if(!a){a=v[b+16>>2];if(!a){break j}c=b+16|0}while(1){g=c;f=a;c=a+20|0;a=v[c>>2];if(a){continue}c=f+16|0;a=v[f+16>>2];if(a){continue}break}v[g>>2]=0;break b}h=-1;if(a>>>0>4294967231){break k}a=a+11|0;h=a&-8;j=v[116507];if(!j){break k}d=0-h|0;e=0;p:{if(h>>>0<256){break p}e=31;if(h>>>0>16777215){break p}a=a>>>8|0;g=a+1048320>>>16&8;a=a<<g;c=a+520192>>>16&4;a=a<<c;b=a+245760>>>16&2;a=(a<<b>>>15|0)-(b|(c|g))|0;e=(a<<1|h>>>a+21&1)+28|0}c=v[(e<<2)+466328>>2];q:{r:{s:{if(!c){a=0;break s}a=0;b=h<<((e|0)==31?0:25-(e>>>1|0)|0);while(1){t:{g=(v[c+4>>2]&-8)-h|0;if(g>>>0>=d>>>0){break t}f=c;d=g;if(d){break t}d=0;a=c;break r}g=v[c+20>>2];c=v[((b>>>29&4)+c|0)+16>>2];a=g?(g|0)==(c|0)?a:g:a;b=b<<1;if(c){continue}break}}if(!(a|f)){f=0;a=2<<e;a=(0-a|a)&j;if(!a){break k}b=(a&0-a)-1|0;a=b>>>12&16;c=a;b=b>>>a|0;a=b>>>5&8;c=c|a;b=b>>>a|0;a=b>>>2&4;c=c|a;b=b>>>a|0;a=b>>>1&2;c=c|a;b=b>>>a|0;a=b>>>1&1;a=v[((c|a)+(b>>>a|0)<<2)+466328>>2]}if(!a){break q}}while(1){b=(v[a+4>>2]&-8)-h|0;c=b>>>0<d>>>0;d=c?b:d;f=c?a:f;b=v[a+16>>2];if(b){a=b}else{a=v[a+20>>2]}if(a){continue}break}}if(!f|v[116508]-h>>>0<=d>>>0){break k}e=v[f+24>>2];b=v[f+12>>2];if((f|0)!=(b|0)){a=v[f+8>>2];v[a+12>>2]=b;v[b+8>>2]=a;break c}c=f+20|0;a=v[c>>2];if(!a){a=v[f+16>>2];if(!a){break i}c=f+16|0}while(1){g=c;b=a;c=a+20|0;a=v[c>>2];if(a){continue}c=b+16|0;a=v[b+16>>2];if(a){continue}break}v[g>>2]=0;break c}c=v[116508];if(c>>>0>=h>>>0){d=v[116511];b=c-h|0;u:{if(b>>>0>=16){v[116508]=b;a=d+h|0;v[116511]=a;v[a+4>>2]=b|1;v[c+d>>2]=b;v[d+4>>2]=h|3;break u}v[116511]=0;v[116508]=0;v[d+4>>2]=c|3;a=c+d|0;v[a+4>>2]=v[a+4>>2]|1}a=d+8|0;break a}i=v[116509];if(i>>>0>h>>>0){b=i-h|0;v[116509]=b;c=v[116512];a=c+h|0;v[116512]=a;v[a+4>>2]=b|1;v[c+4>>2]=h|3;a=c+8|0;break a}a=0;j=h+47|0;b=j;if(v[116624]){c=v[116626]}else{v[116627]=-1;v[116628]=-1;v[116625]=4096;v[116626]=4096;v[116624]=l+12&-16^1431655768;v[116629]=0;v[116617]=0;c=4096}g=b+c|0;f=0-c|0;c=g&f;if(c>>>0<=h>>>0){break a}d=v[116616];if(d){b=v[116614];e=b+c|0;if(d>>>0<e>>>0|b>>>0>=e>>>0){break a}}if(w[466468]&4){break f}v:{w:{d=v[116512];if(d){a=466472;while(1){b=v[a>>2];if(b>>>0<=d>>>0&d>>>0<b+v[a+4>>2]>>>0){break w}a=v[a+8>>2];if(a){continue}break}}b=Up(0);if((b|0)==-1){break g}e=c;d=v[116625];a=d-1|0;if(a&b){e=(c-b|0)+(a+b&0-d)|0}if(e>>>0<=h>>>0|e>>>0>2147483646){break g}d=v[116616];if(d){a=v[116614];f=a+e|0;if(d>>>0<f>>>0|a>>>0>=f>>>0){break g}}a=Up(e);if((b|0)!=(a|0)){break v}break e}e=f&g-i;if(e>>>0>2147483646){break g}b=Up(e);if((b|0)==(v[a>>2]+v[a+4>>2]|0)){break h}a=b}if(!((a|0)==-1|h+48>>>0<=e>>>0)){b=v[116626];b=b+(j-e|0)&0-b;if(b>>>0>2147483646){b=a;break e}if((Up(b)|0)!=-1){e=b+e|0;b=a;break e}Up(0-e|0);break g}b=a;if((a|0)!=-1){break e}break g}f=0;break b}b=0;break c}if((b|0)!=-1){break e}}v[116617]=v[116617]|4}if(c>>>0>2147483646){break d}b=v[22654];c=c+3&-4;a=b+c|0;x:{y:{if(a>>>0<=b>>>0?c:0){break y}if(dx()>>>0<a>>>0){if(!(va(a|0)|0)){break y}}v[22654]=a;break x}v[115137]=48;a=v[22654];b=-1}z:{if(dx()>>>0>=a>>>0){break z}if(va(a|0)|0){break z}v[115137]=48;break d}v[22654]=a;if((b|0)==-1|(a|0)==-1|a>>>0<=b>>>0){break d}e=a-b|0;if(e>>>0<=h+40>>>0){break d}}a=v[116614]+e|0;v[116614]=a;if(a>>>0>y[116615]){v[116615]=a}A:{B:{C:{g=v[116512];if(g){a=466472;while(1){d=v[a>>2];c=v[a+4>>2];if((d+c|0)==(b|0)){break C}a=v[a+8>>2];if(a){continue}break}break B}a=v[116510];if(!(a>>>0<=b>>>0?a:0)){v[116510]=b}a=0;v[116619]=e;v[116618]=b;v[116514]=-1;v[116515]=v[116624];v[116621]=0;while(1){d=a<<3;c=d+466064|0;v[d+466072>>2]=c;v[d+466076>>2]=c;a=a+1|0;if((a|0)!=32){continue}break}d=e-40|0;a=b+8&7?-8-b&7:0;c=d-a|0;v[116509]=c;a=a+b|0;v[116512]=a;v[a+4>>2]=c|1;v[(b+d|0)+4>>2]=40;v[116513]=v[116628];break A}if(w[a+12|0]&8|d>>>0>g>>>0|b>>>0<=g>>>0){break B}v[a+4>>2]=c+e;a=g+8&7?-8-g&7:0;c=a+g|0;v[116512]=c;b=v[116509]+e|0;a=b-a|0;v[116509]=a;v[c+4>>2]=a|1;v[(b+g|0)+4>>2]=40;v[116513]=v[116628];break A}if(y[116510]>b>>>0){v[116510]=b}c=b+e|0;a=466472;D:{E:{F:{G:{H:{I:{while(1){if((c|0)!=v[a>>2]){a=v[a+8>>2];if(a){continue}break I}break}if(!(w[a+12|0]&8)){break H}}a=466472;while(1){c=v[a>>2];if(c>>>0<=g>>>0){f=c+v[a+4>>2]|0;if(f>>>0>g>>>0){break G}}a=v[a+8>>2];continue}}v[a>>2]=b;v[a+4>>2]=v[a+4>>2]+e;j=(b+8&7?-8-b&7:0)+b|0;v[j+4>>2]=h|3;e=c+(c+8&7?-8-c&7:0)|0;i=h+j|0;c=e-i|0;if((e|0)==(g|0)){v[116512]=i;a=v[116509]+c|0;v[116509]=a;v[i+4>>2]=a|1;break E}if(v[116511]==(e|0)){v[116511]=i;a=v[116508]+c|0;v[116508]=a;v[i+4>>2]=a|1;v[a+i>>2]=a;break E}a=v[e+4>>2];if((a&3)==1){g=a&-8;J:{if(a>>>0<=255){d=v[e+8>>2];a=a>>>3|0;b=v[e+12>>2];if((b|0)==(d|0)){m=466024,n=v[116506]&oqa(-2,a),v[m>>2]=n;break J}v[d+12>>2]=b;v[b+8>>2]=d;break J}h=v[e+24>>2];b=v[e+12>>2];K:{if((e|0)!=(b|0)){a=v[e+8>>2];v[a+12>>2]=b;v[b+8>>2]=a;break K}L:{a=e+20|0;d=v[a>>2];if(d){break L}a=e+16|0;d=v[a>>2];if(d){break L}b=0;break K}while(1){f=a;b=d;a=b+20|0;d=v[a>>2];if(d){continue}a=b+16|0;d=v[b+16>>2];if(d){continue}break}v[f>>2]=0}if(!h){break J}d=v[e+28>>2];a=(d<<2)+466328|0;M:{if(v[a>>2]==(e|0)){v[a>>2]=b;if(b){break M}m=466028,n=v[116507]&oqa(-2,d),v[m>>2]=n;break J}v[h+(v[h+16>>2]==(e|0)?16:20)>>2]=b;if(!b){break J}}v[b+24>>2]=h;a=v[e+16>>2];if(a){v[b+16>>2]=a;v[a+24>>2]=b}a=v[e+20>>2];if(!a){break J}v[b+20>>2]=a;v[a+24>>2]=b}e=e+g|0;c=c+g|0}v[e+4>>2]=v[e+4>>2]&-2;v[i+4>>2]=c|1;v[c+i>>2]=c;if(c>>>0<=255){a=c>>>3|0;b=(a<<3)+466064|0;c=v[116506];a=1<<a;N:{if(!(c&a)){v[116506]=a|c;a=b;break N}a=v[b+8>>2]}v[b+8>>2]=i;v[a+12>>2]=i;v[i+12>>2]=b;v[i+8>>2]=a;break E}a=31;if(c>>>0<=16777215){a=c>>>8|0;f=a+1048320>>>16&8;a=a<<f;d=a+520192>>>16&4;a=a<<d;b=a+245760>>>16&2;a=(a<<b>>>15|0)-(b|(d|f))|0;a=(a<<1|c>>>a+21&1)+28|0}v[i+28>>2]=a;v[i+16>>2]=0;v[i+20>>2]=0;f=(a<<2)+466328|0;d=v[116507];b=1<<a;O:{if(!(d&b)){v[116507]=b|d;v[f>>2]=i;v[i+24>>2]=f;break O}a=c<<((a|0)==31?0:25-(a>>>1|0)|0);b=v[f>>2];while(1){d=b;if((v[b+4>>2]&-8)==(c|0)){break F}b=a>>>29|0;a=a<<1;f=d+(b&4)|0;b=v[f+16>>2];if(b){continue}break}v[f+16>>2]=i;v[i+24>>2]=d}v[i+12>>2]=i;v[i+8>>2]=i;break E}d=e-40|0;a=b+8&7?-8-b&7:0;c=d-a|0;v[116509]=c;a=a+b|0;v[116512]=a;v[a+4>>2]=c|1;v[(b+d|0)+4>>2]=40;v[116513]=v[116628];a=(f+(f-39&7?39-f&7:0)|0)-47|0;c=a>>>0<g+16>>>0?g:a;v[c+4>>2]=27;a=v[116621];v[c+16>>2]=v[116620];v[c+20>>2]=a;a=v[116619];v[c+8>>2]=v[116618];v[c+12>>2]=a;v[116620]=c+8;v[116619]=e;v[116618]=b;v[116621]=0;a=c+24|0;while(1){v[a+4>>2]=7;b=a+8|0;a=a+4|0;if(b>>>0<f>>>0){continue}break}if((c|0)==(g|0)){break A}v[c+4>>2]=v[c+4>>2]&-2;f=c-g|0;v[g+4>>2]=f|1;v[c>>2]=f;if(f>>>0<=255){a=f>>>3|0;b=(a<<3)+466064|0;c=v[116506];a=1<<a;P:{if(!(c&a)){v[116506]=a|c;a=b;break P}a=v[b+8>>2]}v[b+8>>2]=g;v[a+12>>2]=g;v[g+12>>2]=b;v[g+8>>2]=a;break A}a=31;v[g+16>>2]=0;v[g+20>>2]=0;if(f>>>0<=16777215){a=f>>>8|0;d=a+1048320>>>16&8;a=a<<d;c=a+520192>>>16&4;a=a<<c;b=a+245760>>>16&2;a=(a<<b>>>15|0)-(b|(c|d))|0;a=(a<<1|f>>>a+21&1)+28|0}v[g+28>>2]=a;d=(a<<2)+466328|0;c=v[116507];b=1<<a;Q:{if(!(c&b)){v[116507]=b|c;v[d>>2]=g;v[g+24>>2]=d;break Q}a=f<<((a|0)==31?0:25-(a>>>1|0)|0);b=v[d>>2];while(1){c=b;if((f|0)==(v[b+4>>2]&-8)){break D}b=a>>>29|0;a=a<<1;d=c+(b&4)|0;b=v[d+16>>2];if(b){continue}break}v[d+16>>2]=g;v[g+24>>2]=c}v[g+12>>2]=g;v[g+8>>2]=g;break A}a=v[d+8>>2];v[a+12>>2]=i;v[d+8>>2]=i;v[i+24>>2]=0;v[i+12>>2]=d;v[i+8>>2]=a}a=j+8|0;break a}a=v[c+8>>2];v[a+12>>2]=g;v[c+8>>2]=g;v[g+24>>2]=0;v[g+12>>2]=c;v[g+8>>2]=a}a=v[116509];if(a>>>0<=h>>>0){break d}b=a-h|0;v[116509]=b;c=v[116512];a=c+h|0;v[116512]=a;v[a+4>>2]=b|1;v[c+4>>2]=h|3;a=c+8|0;break a}v[115137]=48;a=0;break a}R:{if(!e){break R}c=v[f+28>>2];a=(c<<2)+466328|0;S:{if(v[a>>2]==(f|0)){v[a>>2]=b;if(b){break S}j=oqa(-2,c)&j;v[116507]=j;break R}v[e+(v[e+16>>2]==(f|0)?16:20)>>2]=b;if(!b){break R}}v[b+24>>2]=e;a=v[f+16>>2];if(a){v[b+16>>2]=a;v[a+24>>2]=b}a=v[f+20>>2];if(!a){break R}v[b+20>>2]=a;v[a+24>>2]=b}T:{if(d>>>0<=15){a=d+h|0;v[f+4>>2]=a|3;a=a+f|0;v[a+4>>2]=v[a+4>>2]|1;break T}v[f+4>>2]=h|3;e=f+h|0;v[e+4>>2]=d|1;v[d+e>>2]=d;if(d>>>0<=255){a=d>>>3|0;b=(a<<3)+466064|0;c=v[116506];a=1<<a;U:{if(!(c&a)){v[116506]=a|c;a=b;break U}a=v[b+8>>2]}v[b+8>>2]=e;v[a+12>>2]=e;v[e+12>>2]=b;v[e+8>>2]=a;break T}a=31;if(d>>>0<=16777215){a=d>>>8|0;g=a+1048320>>>16&8;a=a<<g;c=a+520192>>>16&4;a=a<<c;b=a+245760>>>16&2;a=(a<<b>>>15|0)-(b|(c|g))|0;a=(a<<1|d>>>a+21&1)+28|0}v[e+28>>2]=a;v[e+16>>2]=0;v[e+20>>2]=0;b=(a<<2)+466328|0;V:{c=1<<a;W:{if(!(c&j)){v[116507]=c|j;v[b>>2]=e;break W}a=d<<((a|0)==31?0:25-(a>>>1|0)|0);h=v[b>>2];while(1){b=h;if((v[b+4>>2]&-8)==(d|0)){break V}c=a>>>29|0;a=a<<1;c=(c&4)+b|0;h=v[c+16>>2];if(h){continue}break}v[c+16>>2]=e}v[e+24>>2]=b;v[e+12>>2]=e;v[e+8>>2]=e;break T}a=v[b+8>>2];v[a+12>>2]=e;v[b+8>>2]=e;v[e+24>>2]=0;v[e+12>>2]=b;v[e+8>>2]=a}a=f+8|0;break a}X:{if(!i){break X}c=v[b+28>>2];a=(c<<2)+466328|0;Y:{if(v[a>>2]==(b|0)){v[a>>2]=f;if(f){break Y}m=466028,n=oqa(-2,c)&j,v[m>>2]=n;break X}v[i+(v[i+16>>2]==(b|0)?16:20)>>2]=f;if(!f){break X}}v[f+24>>2]=i;a=v[b+16>>2];if(a){v[f+16>>2]=a;v[a+24>>2]=f}a=v[b+20>>2];if(!a){break X}v[f+20>>2]=a;v[a+24>>2]=f}Z:{if(d>>>0<=15){a=d+h|0;v[b+4>>2]=a|3;a=a+b|0;v[a+4>>2]=v[a+4>>2]|1;break Z}v[b+4>>2]=h|3;f=b+h|0;v[f+4>>2]=d|1;v[d+f>>2]=d;if(k){a=k>>>3|0;c=(a<<3)+466064|0;g=v[116511];a=1<<a;_:{if(!(a&e)){v[116506]=a|e;a=c;break _}a=v[c+8>>2]}v[c+8>>2]=g;v[a+12>>2]=g;v[g+12>>2]=c;v[g+8>>2]=a}v[116511]=f;v[116508]=d}a=b+8|0}gb=l+16|0;return a|0}function h9(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0;f=gb-32|0;gb=f;a:{b:{c:{d:{e:{f:{if(qe(b,18726)){Kb(a);break f}if(qe(b,7151)){b=gb-96|0;gb=b;c=Kb(a);v[22656]=0;_(155,b- -64|0);a=v[22656];v[22656]=0;g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{if((a|0)!=1){v[22656]=0;v[b+32>>2]=0;R(2036,b+48|0,b+32|0);a=v[22656];v[22656]=0;if((a|0)==1){break p}v[22656]=0;Q(1168,c|0,b+48|0)|0;a=v[22656];v[22656]=0;if((a|0)==1){break o}vb(b+48|0);v[22656]=0;Q(1917,c|0,13845)|0;a=v[22656];v[22656]=0;q:{if((a|0)==1){break q}v[22656]=0;v[b+32>>2]=6;R(2036,b+48|0,b+32|0);a=v[22656];v[22656]=0;if((a|0)==1){break n}v[22656]=0;Q(1168,c|0,b+48|0)|0;a=v[22656];v[22656]=0;if((a|0)==1){break m}vb(b+48|0);v[22656]=0;Q(1917,c|0,13845)|0;a=v[22656];v[22656]=0;if((a|0)==1){break q}v[22656]=0;v[b+32>>2]=0;R(2036,b+48|0,b+32|0);a=v[22656];v[22656]=0;if((a|0)==1){break l}v[22656]=0;Q(1168,c|0,b+48|0)|0;a=v[22656];v[22656]=0;if((a|0)==1){break k}a=b+48|0;vb(a);v[22656]=0;a=Q(70,a|0,12145)|0;e=v[22656];v[22656]=0;if((e|0)==1){break j}e=Ab(a);vb(a);if(!e){break i}v[22656]=0;Q(1917,c|0,12145)|0;a=v[22656];v[22656]=0;if((a|0)!=1){break i}}a=P()|0;O()|0;break h}a=P()|0;O()|0;break c}a=P()|0;O()|0;break h}a=P()|0;O()|0;vb(b+48|0);break h}a=P()|0;O()|0;break h}a=P()|0;O()|0;vb(b+48|0);break h}a=P()|0;O()|0;break h}a=P()|0;O()|0;vb(b+48|0);break h}a=P()|0;O()|0;break h}e=mc(b+48|0);r:{s:{t:{u:{v:{w:{x:{y:{z:{A:{B:{C:{D:{if(v[(b- -64|0)+12>>2]){a=v[(b- -64|0)+12>>2];v[22656]=0;v[b+12>>2]=a;R(2036,b+16|0,b+12|0);a=v[22656];v[22656]=0;if((a|0)==1){break D}v[22656]=0;U(2037,b+32|0,6095,b+16|0);a=v[22656];v[22656]=0;if((a|0)==1){break C}v[22656]=0;R(1423,e|0,b+32|0);a=v[22656];v[22656]=0;if((a|0)==1){break B}vb(b+32|0);vb(b+16|0)}if(!w[(b- -64|0)+16|0]){break x}v[22656]=0;d=Q(70,b+32|0,10085)|0;a=v[22656];v[22656]=0;if((a|0)==1){break z}v[22656]=0;R(1423,e|0,d|0);a=v[22656];v[22656]=0;if((a|0)==1){break y}vb(d);break w}a=P()|0;O()|0;break r}a=P()|0;O()|0;break A}a=P()|0;O()|0;vb(b+32|0)}vb(b+16|0);break r}a=P()|0;O()|0;break r}a=P()|0;O()|0;vb(d);break r}if(!w[(b- -64|0)+17|0]){break w}v[22656]=0;d=Q(70,b+32|0,9785)|0;a=v[22656];v[22656]=0;if((a|0)==1){break v}v[22656]=0;R(1423,e|0,d|0);a=v[22656];v[22656]=0;if((a|0)==1){break u}vb(d)}if(w[(b- -64|0)+18|0]){break t}break s}a=P()|0;O()|0;break r}a=P()|0;O()|0;vb(d);break r}v[22656]=0;d=Q(70,b+32|0,8321)|0;a=v[22656];v[22656]=0;E:{if((a|0)!=1){v[22656]=0;R(1423,e|0,d|0);a=v[22656];v[22656]=0;if((a|0)==1){break E}vb(d);break s}a=P()|0;O()|0;break r}a=P()|0;O()|0;vb(d);break r}if(cd(e)){break g}v[22656]=0;Q(1917,c|0,13875)|0;a=v[22656];v[22656]=0;if((a|0)!=1){v[22656]=0;d=Q(70,b+16|0,13845)|0;a=v[22656];v[22656]=0;F:{G:{H:{if((a|0)!=1){v[22656]=0;U(2038,b+32|0,e|0,d|0);a=v[22656];v[22656]=0;if((a|0)==1){break H}v[22656]=0;Q(1168,c|0,b+32|0)|0;a=v[22656];v[22656]=0;if((a|0)==1){break G}vb(b+32|0);vb(d);break g}a=P()|0;O()|0;break r}a=P()|0;O()|0;break F}a=P()|0;O()|0;vb(b+32|0)}vb(d);break r}a=P()|0;O()|0}yd(e)}Ef(b- -64|0);break c}yd(e);Ef(b- -64|0);gb=b+96|0;break f}if(qe(b,5265)){v[f>>2]=0;Mq(a,f);break f}if(qe(b,5243)){v[f>>2]=6;Mq(a,f);break f}if(qe(b,8086)){v[f>>2]=0;Mq(a,f);break f}if(qe(b,7883)){Tb(a,12145);break f}if(qe(b,8693)){b=Tb(f,12145);e=Ab(b);v[22656]=0;Q(70,a|0,(e?12908:12589)|0)|0;a=v[22656];v[22656]=0;if((a|0)==1){break e}vb(b);break f}if(qe(b,4456)){b=gb-48|0;gb=b;QG(b+16|0);v[22656]=0;_(173,b|0);e=v[22656];v[22656]=0;I:{J:{K:{L:{if((e|0)!=1){v[22656]=0;U(174,b+32|0,b+16|0,b|0);e=v[22656];v[22656]=0;if((e|0)==1){break L}v[22656]=0;R(2039,a|0,b+32|0);a=v[22656];v[22656]=0;if((a|0)==1){break K}vb(b+32|0);vb(b);vb(b+16|0);gb=b+48|0;break f}a=P()|0;O()|0;break I}a=P()|0;O()|0;break J}a=P()|0;O()|0;vb(b+32|0)}vb(b)}vb(b+16|0);break a}if(qe(b,7179)){b=gb-16|0;gb=b;i=gb-16|0;gb=i;v[i+8>>2]=101;e=b;d=gb-112|0;gb=d;h=mc(d+96|0);M:{N:{O:{P:{Q:{R:{S:{T:{U:{V:{W:{X:{Y:{Z:{_:{$:{c=v[i+8>>2];if(c&1){v[22656]=0;v[d+48>>2]=19923028;R(162,d- -64|0,d+48|0);c=v[22656];v[22656]=0;if((c|0)==1){break $}v[22656]=0;R(142,h|0,d- -64|0);c=v[22656];v[22656]=0;if((c|0)==1){break _}vb(d- -64|0);c=v[i+8>>2]}if(!(c&4)){break Y}v[22656]=0;c=ga(163)|0;g=v[22656];v[22656]=0;if((g|0)==1){break X}if(!c){break Z}break Y}c=P()|0;O()|0;break N}c=P()|0;O()|0;vb(d- -64|0);break N}v[22656]=0;_(164,d- -64|0);c=v[22656];v[22656]=0;aa:{if((c|0)!=1){v[22656]=0;R(142,h|0,d- -64|0);c=v[22656];v[22656]=0;if((c|0)==1){break aa}vb(d- -64|0);break Y}c=P()|0;O()|0;break N}c=P()|0;O()|0;vb(d- -64|0);break N}ba:{c=v[i+8>>2];if(!(c&32)){break ba}v[22656]=0;_(155,d- -64|0);c=v[22656];v[22656]=0;ca:{da:{ea:{fa:{ga:{ha:{ia:{ja:{ka:{la:{ma:{na:{oa:{pa:{qa:{ra:{sa:{ta:{ua:{if((c|0)!=1){v[22656]=0;R(165,d+48|0,d- -64|0);c=v[22656];v[22656]=0;if((c|0)==1){break da}c=d+48|0;g=gd(c);vb(c);if(!g){v[22656]=0;_(166,d+32|0);c=v[22656];v[22656]=0;if((c|0)==1){break ua}v[22656]=0;R(165,d+16|0,d- -64|0);c=v[22656];v[22656]=0;if((c|0)==1){break ta}v[22656]=0;U(167,d+48|0,d+32|0,d+16|0);c=v[22656];v[22656]=0;if((c|0)==1){break sa}v[22656]=0;R(142,h|0,d+48|0);c=v[22656];v[22656]=0;if((c|0)==1){break ra}vb(d+48|0);vb(d+16|0);Hb(d+32|0)}if(!gd(Yp(d- -64|0))){v[22656]=0;_(168,d+32|0);c=v[22656];v[22656]=0;if((c|0)==1){break oa}c=Yp(d- -64|0);v[22656]=0;U(169,d+48|0,d+32|0,c|0);c=v[22656];v[22656]=0;if((c|0)==1){break na}v[22656]=0;R(142,h|0,d+48|0);c=v[22656];v[22656]=0;if((c|0)==1){break ma}vb(d+48|0);Hb(d+32|0)}v[22656]=0;R(170,d+48|0,d- -64|0);c=v[22656];v[22656]=0;if((c|0)==1){break ka}c=d+48|0;g=gd(c);vb(c);if(!g){v[22656]=0;_(166,d+32|0);c=v[22656];v[22656]=0;if((c|0)==1){break ja}v[22656]=0;R(170,d+16|0,d- -64|0);c=v[22656];v[22656]=0;if((c|0)==1){break ia}v[22656]=0;U(167,d+48|0,d+32|0,d+16|0);c=v[22656];v[22656]=0;if((c|0)==1){break ha}v[22656]=0;R(142,h|0,d+48|0);c=v[22656];v[22656]=0;if((c|0)==1){break ga}vb(d+48|0);vb(d+16|0);Hb(d+32|0)}Ef(d- -64|0);c=v[i+8>>2];break ba}c=P()|0;O()|0;break N}c=P()|0;O()|0;break ca}c=P()|0;O()|0;break pa}c=P()|0;O()|0;break qa}c=P()|0;O()|0;vb(d+48|0)}vb(d+16|0)}Hb(d+32|0);break ca}c=P()|0;O()|0;break ca}c=P()|0;O()|0;break la}c=P()|0;O()|0;vb(d+48|0)}Hb(d+32|0);break ca}c=P()|0;O()|0;break ca}c=P()|0;O()|0;break ca}c=P()|0;O()|0;break ea}c=P()|0;O()|0;break fa}c=P()|0;O()|0;vb(d+48|0)}vb(d+16|0)}Hb(d+32|0);break ca}c=P()|0;O()|0}Ef(d- -64|0);break N}va:{if(!(c&64)){break va}v[22656]=0;c=ga(163)|0;g=v[22656];v[22656]=0;if((g|0)==1){break X}if(c){break va}c=d- -64|0;Kb(c);v[22656]=0;R(142,h|0,c|0);c=v[22656];v[22656]=0;if((c|0)==1){break O}vb(d- -64|0)}if(w[i+8|0]&128){v[22656]=0;_(171,d- -64|0);c=v[22656];v[22656]=0;if((c|0)==1){break W}v[22656]=0;R(142,h|0,d- -64|0);c=v[22656];v[22656]=0;if((c|0)==1){break V}vb(d- -64|0)}v[22656]=0;g=Q(2,d- -64|0,18726)|0;c=v[22656];v[22656]=0;if((c|0)==1){break U}v[22656]=0;U(172,d|0,h|0,g|0);c=v[22656];v[22656]=0;if((c|0)==1){break T}v[22656]=0;_(173,d+48|0);c=v[22656];v[22656]=0;if((c|0)==1){break S}v[22656]=0;U(174,e|0,d|0,d+48|0);e=v[22656];v[22656]=0;if((e|0)==1){break R}vb(d+48|0);vb(d);vb(g);sm(h);gb=d+112|0;break M}c=P()|0;O()|0;break N}c=P()|0;O()|0;break N}c=P()|0;O()|0;vb(d- -64|0);break N}c=P()|0;O()|0;break N}c=P()|0;O()|0;break P}c=P()|0;O()|0;break Q}c=P()|0;O()|0;vb(d+48|0)}vb(d)}vb(g);break N}c=P()|0;O()|0;vb(d- -64|0)}sm(h);S(c|0);L()}gb=i+16|0;v[22656]=0;R(2039,a|0,b|0);a=v[22656];v[22656]=0;if((a|0)!=1){vb(b);gb=b+16|0;break f}break b}if(qe(b,7795)){b=gb-48|0;gb=b;Os(b);v[22656]=0;R(165,b+32|0,b|0);e=v[22656];v[22656]=0;wa:{xa:{if((e|0)!=1){v[22656]=0;R(2039,a|0,b+32|0);a=v[22656];v[22656]=0;if((a|0)==1){break xa}vb(b+32|0);Ef(b);gb=b+48|0;break f}a=P()|0;O()|0;break wa}a=P()|0;O()|0;vb(b+32|0)}Ef(b);break a}if(qe(b,8656)){b=gb-32|0;gb=b;Os(b);e=Yp(b);v[22656]=0;R(2039,a|0,e|0);a=v[22656];v[22656]=0;if((a|0)!=1){Ef(b);gb=b+32|0;break f}a=P()|0;O()|0;Ef(b);break a}if(qe(b,7192)){b=gb-48|0;gb=b;Os(b+16|0);ya:{if(v[b+28>>2]){e=v[b+28>>2];v[22656]=0;v[b+12>>2]=e;R(2036,a|0,b+12|0);a=v[22656];v[22656]=0;if((a|0)!=1){break ya}a=P()|0;O()|0;Ef(b+16|0);break a}Kb(a)}Ef(b+16|0);gb=b+48|0;break f}if(qe(b,10075)){Os(f);b=w[f+16|0];v[22656]=0;Q(70,a|0,(b?12589:12908)|0)|0;a=v[22656];v[22656]=0;if((a|0)!=1){Ef(f);break f}a=P()|0;O()|0;Ef(f);break a}if(qe(b,7208)){Os(f);b=w[f+17|0];v[22656]=0;Q(70,a|0,(b?12589:12908)|0)|0;a=v[22656];v[22656]=0;if((a|0)!=1){Ef(f);break f}a=P()|0;O()|0;Ef(f);break a}if(qe(b,9467)){Os(f);b=w[f+18|0];v[22656]=0;Q(70,a|0,(b?12589:12908)|0)|0;a=v[22656];v[22656]=0;if((a|0)!=1){Ef(f);break f}a=P()|0;O()|0;Ef(f);break a}if(qe(b,9759)){b=gb-16|0;gb=b;e=gb-32|0;gb=e;d=Kb(b);v[22656]=0;_(155,e|0);c=v[22656];v[22656]=0;za:{Aa:{Ba:{if((c|0)!=1){c=Yp(e);v[22656]=0;Q(156,d|0,c|0)|0;c=v[22656];v[22656]=0;if((c|0)==1){break Ba}Ef(e);gb=e+32|0;break za}a=P()|0;O()|0;break Aa}a=P()|0;O()|0;Ef(e)}vb(d);break a}v[22656]=0;R(2039,a|0,b|0);a=v[22656];v[22656]=0;if((a|0)!=1){vb(b);gb=b+16|0;break f}break b}if(qe(b,5386)){b=gb-16|0;gb=b;e=gb-48|0;gb=e;d=Kb(b);v[22656]=0;R(158,e+16|0,1244);c=v[22656];v[22656]=0;Ca:{Da:{Ea:{Fa:{Ga:{if((c|0)!=1){v[e+12>>2]=14;v[e+8>>2]=0;v[22656]=0;v[e+4>>2]=0;ha(159,e+32|0,e+16|0,e+12|0,e+8|0,e+4|0);c=v[22656];v[22656]=0;if((c|0)==1){break Ga}v[22656]=0;Q(113,d|0,e+32|0)|0;c=v[22656];v[22656]=0;if((c|0)==1){break Fa}vb(e+32|0);Hb(e+16|0);gb=e+48|0;break Ca}a=P()|0;O()|0;break Da}a=P()|0;O()|0;break Ea}a=P()|0;O()|0;vb(e+32|0)}Hb(e+16|0)}vb(d);S(a|0);L()}v[22656]=0;R(2039,a|0,b|0);a=v[22656];v[22656]=0;if((a|0)!=1){vb(b);gb=b+16|0;break f}break b}if(qe(b,3879)){b=gb-16|0;gb=b;mo(b,0,16672);v[22656]=0;R(2039,a|0,b|0);a=v[22656];v[22656]=0;if((a|0)!=1){vb(b);gb=b+16|0;break f}break b}if(qe(b,3512)){b=gb-48|0;gb=b;c=Tb(b+16|0,14756);v[22656]=0;R(2040,b|0,2);e=v[22656];v[22656]=0;Ha:{Ia:{Ja:{Ka:{if((e|0)!=1){v[22656]=0;U(3,b+32|0,c|0,b|0);e=v[22656];v[22656]=0;if((e|0)==1){break Ka}v[22656]=0;R(2039,a|0,b+32|0);a=v[22656];v[22656]=0;if((a|0)==1){break Ja}vb(b+32|0);vb(b);vb(c);gb=b+48|0;break f}a=P()|0;O()|0;break Ha}a=P()|0;O()|0;break Ia}a=P()|0;O()|0;vb(b+32|0)}vb(b)}break c}if(qe(b,8679)){b=gb-16|0;gb=b;mo(b,0,15072);v[22656]=0;R(2039,a|0,b|0);a=v[22656];v[22656]=0;if((a|0)!=1){vb(b);gb=b+16|0;break f}break b}if(qe(b,7802)){b=gb-16|0;gb=b;ys(b,0);v[22656]=0;R(2039,a|0,b|0);a=v[22656];v[22656]=0;if((a|0)!=1){vb(b);gb=b+16|0;break f}break b}if(qe(b,7777)){b=gb-16|0;gb=b;ys(b,2);v[22656]=0;R(2039,a|0,b|0);a=v[22656];v[22656]=0;if((a|0)!=1){vb(b);gb=b+16|0;break f}break b}if(qe(b,7762)){b=gb-16|0;gb=b;ys(b,3);v[22656]=0;R(2039,a|0,b|0);a=v[22656];v[22656]=0;if((a|0)!=1){vb(b);gb=b+16|0;break f}break b}Kb(a)}gb=f+32|0;break d}a=P()|0;O()|0;vb(b);break a}return}vb(c);break a}a=P()|0;O()|0;vb(b)}S(a|0);L()}function qZ(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;e=gb-288|0;gb=e;vc(b);if(Tr(b,14913)){o=Kb(e+272|0);v[22656]=0;f=W(352,b|0,o|0,-1)|0;h=v[22656];v[22656]=0;a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{if((h|0)!=1){if(!f){break a}v[22656]=0;f=Q(366,b|0,e+264|0)|0;h=v[22656];v[22656]=0;s:{if((h|0)==1){break s}if(!f){break a}if(!cE(e+264|0)){break a}f=Qc(bE(e+264|0),jb);v[22656]=0;f=Q(191,b|0,f|0)|0;h=v[22656];v[22656]=0;if((h|0)==1){break s}if(!f){break a}if(!c){break b}v[22656]=0;R(367,a|0,4096);d=v[22656];v[22656]=0;if((d|0)==1){break s}v[22656]=0;Q(368,a+1298268|0,o|0)|0;d=v[22656];v[22656]=0;if((d|0)==1){break s}d=w[e+264|2];u[a+480188>>1]=32;u[a+480192>>1]=d;v[22656]=0;xh(a,1);d=v[22656];v[22656]=0;if((d|0)==1){break s}v[22656]=0;d=Q(2,e+112|0,6633)|0;f=v[22656];v[22656]=0;t:{u:{v:{w:{x:{y:{z:{A:{B:{if((f|0)!=1){Eb(a+1298304|0,d);vb(d);v[22656]=0;d=Q(2,e+112|0,4107)|0;f=v[22656];v[22656]=0;if((f|0)==1){break B}Eb(a+1298316|0,d);vb(d);v[22656]=0;_(370,e+56|0);d=v[22656];v[22656]=0;if((d|0)==1){break A}t[e+232|0]=w[e+264|1];d=w[e+264|0];v[22656]=0;t[e+16|0]=d;R(371,e+248|0,e+16|0);d=v[22656];v[22656]=0;if((d|0)==1){break z}v[22656]=0;Y(372,e+112|0,e+56|0,e+232|0,e+248|0);d=v[22656];v[22656]=0;if((d|0)==1){break y}d=e+112|0;Eb(a+1298328|0,d);vb(d);vb(e+248|0);Hb(e+56|0);v[a+1298364>>2]=5;if(w[e+264|0]<2){break u}u[e+112>>1]=8192;v[22656]=0;d=T(287,b|0)|0;f=v[22656];v[22656]=0;if((f|0)==1){break w}v[22656]=0;u[e+56>>1]=d;d=Le(e+112|0,e+56|0);f=v[22656];v[22656]=0;if((f|0)==1){break w}v[a+480204>>2]=B(x[d>>1],1e4)>>>8;v[22656]=0;t[e+112|0]=1;d=T(374,b|0)|0;f=v[22656];v[22656]=0;if((f|0)==1){break v}v[22656]=0;t[e+56|0]=d;d=df(e+112|0,e+56|0);f=v[22656];v[22656]=0;if((f|0)==1){break v}v[a+480196>>2]=w[d|0];v[22656]=0;Q(318,b|0,3)|0;d=v[22656];v[22656]=0;if((d|0)!=1){v[22656]=0;d=T(287,b|0)|0;f=v[22656];v[22656]=0;if((f|0)!=1){break t}}b=P()|0;O()|0;break c}b=P()|0;O()|0;break c}b=P()|0;O()|0;break c}b=P()|0;O()|0;break c}b=P()|0;O()|0;break x}b=P()|0;O()|0;vb(e+248|0)}Hb(e+56|0);break c}b=P()|0;O()|0;break c}b=P()|0;O()|0;break c}t[e+112|0]=32;v[22656]=0;d=T(374,b|0)|0;f=v[22656];v[22656]=0;C:{D:{if((f|0)==1){break D}v[22656]=0;t[e+56|0]=d;d=df(e+112|0,e+56|0);f=v[22656];v[22656]=0;if((f|0)==1){break D}v[a+480204>>2]=B(w[d|0],1e4);v[22656]=0;t[e+112|0]=1;d=T(374,b|0)|0;f=v[22656];v[22656]=0;if((f|0)==1){break C}v[22656]=0;t[e+56|0]=d;d=df(e+112|0,e+56|0);f=v[22656];v[22656]=0;if((f|0)==1){break C}v[a+480196>>2]=w[d|0];v[22656]=0;d=T(374,b|0)|0;f=v[22656];v[22656]=0;if((f|0)!=1){break t}b=P()|0;O()|0;break c}b=P()|0;O()|0;break c}b=P()|0;O()|0;break c}v[a+480208>>2]=d>>>2&16|12;n=mc(e+248|0);m=mc(e+232|0);E:{F:{G:{H:{I:{J:{if(!x[a+480192>>1]){break J}i=1;h=e+88|1;p=e+112|12;while(1){v[22656]=0;f=W(376,a|0,i&65535,0)|0;d=v[22656];v[22656]=0;K:{L:{M:{if((d|0)==1){break M}if(!f){break J}v[22656]=0;d=W(353,b|0,f+492|0,-1)|0;k=v[22656];v[22656]=0;if((k|0)==1){break M}if(!d){break J}v[22656]=0;k=T(374,b|0)|0;d=v[22656];v[22656]=0;N:{O:{P:{Q:{R:{if((d|0)!=1){Qb(e+112|0,0,120);if(!k){break K}if(w[e+264|0]){v[22656]=0;d=Q(377,b|0,e+112|0)|0;g=v[22656];v[22656]=0;if((g|0)==1){break R}if(!d){break K}}if(!w[e+264|0]){d=wd(e+104|0,p,96);v[22656]=0;g=v[d+4>>2];v[e+8>>2]=v[d>>2];v[e+12>>2]=g;U(201,e+56|0,b|0,e+8|0);d=v[22656];v[22656]=0;if((d|0)==1){break Q}if(!yb(e+56|0)){break K}}g=f+236|0;d=0;while(1){j=w[(e+112|0)+d|0];l=x[a+480190>>1];r=vd(g,d),s=(j+l|0)+1|0,u[r>>1]=s;d=d+1|0;if((d|0)!=120){continue}break}v[22656]=0;d=f+48|0;U(378,e+16|0,d|0,b|0);g=v[22656];v[22656]=0;if((g|0)==1){break P}v[22656]=0;g=f+68|0;U(378,e+40|0,g|0,b|0);j=v[22656];v[22656]=0;if((j|0)==1){break P}v[22656]=0;j=f+88|0;U(378,e+96|0,j|0,b|0);l=v[22656];v[22656]=0;if((l|0)==1){break P}v[22656]=0;R(379,b|0,e+88|0);l=v[22656];v[22656]=0;if((l|0)==1){break O}v[f>>2]=(w[h|0]|w[h+1|0]<<8)&4095;l=w[h|0]|w[h+1|0]<<8;f=e+88|0;cw(f,d,0);cw(f,g,1);cw(f,j,2);r=e,s=Vb(d),v[r+56>>2]=s;r=e,s=Zb(d),v[r+80>>2]=s;if(Gb(e+56|0,e+80|0)){break N}break L}b=P()|0;O()|0;break d}b=P()|0;O()|0;break d}b=P()|0;O()|0;break d}b=P()|0;O()|0;break d}b=P()|0;O()|0;break d}while(1){S:{d=v[e+56>>2];t[e+76|0]=64;f=w[d+2|0];v[22656]=0;t[e+79|0]=((f<<6)- -64>>>0)/127;f=ac(e+76|0,e+79|0);q=v[22656];v[22656]=0;if((q|0)==1){break S}t[d+2|0]=w[f|0];d=e+56|0;Qe(d);if(Gb(d,e+80|0)){continue}break L}break}b=P()|0;O()|0;break d}b=P()|0;O()|0;break d}r=e,s=Vb(g),v[r+56>>2]=s;r=e,s=Zb(g),v[r+80>>2]=s;T:{if(!Gb(e+56|0,e+80|0)){break T}while(1){U:{d=v[e+56>>2];t[e+76|0]=64;f=w[d+2|0];v[22656]=0;t[e+79|0]=((f<<6)+128>>>0)/255;f=ac(e+76|0,e+79|0);g=v[22656];v[22656]=0;if((g|0)==1){break U}t[d+2|0]=w[f|0];d=e+56|0;Qe(d);if(Gb(d,e+80|0)){continue}break T}break}b=P()|0;O()|0;break d}r=e,s=Vb(j),v[r+56>>2]=s;r=e,s=Zb(j),v[r+80>>2]=s;if(Gb(e+56|0,e+80|0)){j=1<<(l>>>12&3);while(1){l=v[e+56>>2];d=t[l+2|0];d=kqa(d^-128,d>>31^-1,j,0);g=jb;f=g;V:{if((f|0)>=-1&d>>>0>=4294967292|(f|0)>=0){d=d+4|0;f=d>>>0<4?f+1|0:f;d=((f&7)<<29|d>>>3)&536870911;f=0;break V}f=0-((d>>>0>3)+f|0)|0;d=3-d|0;f=((f&7)<<29|d>>>3)&536870911;d=0-f|0;f=0-((f|0)!=0)|0}r=l,s=Ac(d,f)^128,t[r+2|0]=s;d=e+56|0;Qe(d);if(Gb(d,e+80|0)){continue}break}}d=x[a+480190>>1]+1|0;u[e+76>>1]=d;W:{X:{Y:{Z:{g=d&65535;if(g>>>0<=3999){d=0;f=0;while(1){v[22656]=0;W(353,b|0,((g<<5)+a|0)+946304|0,-1)|0;g=v[22656];v[22656]=0;if((g|0)==1){break Z}v[22656]=0;R(381,b|0,e+56|0);g=v[22656];v[22656]=0;if((g|0)==1){break Y}v[22656]=0;R(382,e+56|0,(B(x[e+76>>1]+f|0,104)+a|0)+484380|0);f=v[22656];v[22656]=0;if((f|0)==1){break Y}f=w[e+88|0];g=w[e+75|0];v[22656]=0;u[e+80>>1]=f|d<<8&32512|((g&3)!=0)<<15;R(383,m|0,e+80|0);f=v[22656];v[22656]=0;if((f|0)==1){break X}d=d+1|0;f=d&65535;if(k>>>0<=f>>>0){break W}g=x[e+76>>1]+f|0;if(g>>>0<=3999){continue}break}}v[22656]=0;Q(318,b|0,20)|0;d=v[22656];v[22656]=0;if((d|0)!=1){break W}b=P()|0;O()|0;break d}b=P()|0;O()|0;break d}b=P()|0;O()|0;break d}b=P()|0;O()|0;break d}v[22656]=0;R(383,n|0,e+76|0);d=v[22656];v[22656]=0;if((d|0)==1){break I}v[e+56>>2]=3999;d=x[a+480190>>1];v[22656]=0;v[e+80>>2]=d+k;d=pd(e+56|0,e+80|0);f=v[22656];v[22656]=0;if((f|0)==1){break H}u[a+480190>>1]=v[d>>2]}i=i+1|0;if(x[a+480192>>1]>=(i&65535)>>>0){continue}break}}d=Kb(e+112|0);v[22656]=0;f=W(352,b|0,d|0,-1)|0;h=v[22656];v[22656]=0;if((h|0)==1){break n}if(f){v[22656]=0;U(13,e+56|0,7,d|0);f=v[22656];v[22656]=0;if((f|0)==1){break E}f=e+56|0;Eb(a+1298280|0,f);vb(f)}vb(d);d=0;while(1){v[22656]=0;f=(d<<5)+a|0;We(f+480280|0);h=v[22656];v[22656]=0;if((h|0)==1){break G}v[22656]=0;U(355,b|0,f+480289|0,-1);f=v[22656];v[22656]=0;if((f|0)==1){break G}d=d+1|0;if((d|0)!=32){continue}break}v[22656]=0;d=Q(385,b|0,e+40|0)|0;f=v[22656];v[22656]=0;if((f|0)==1){break l}if(!d){break i}if((w[e+40|0]|w[e+41|0]<<8|(w[e+42|0]<<16|w[e+43|0]<<24))>>>0<12){break m}d=w[e+40|0]|w[e+41|0]<<8|(w[e+42|0]<<16|w[e+43|0]<<24);v[22656]=0;d=Q(191,b|0,d-11|0)|0;f=v[22656];v[22656]=0;if((f|0)==1){break l}if(d){break F}break m}b=P()|0;O()|0;break d}b=P()|0;O()|0;break d}b=P()|0;O()|0;break d}v[e+96>>2]=(w[e+40|0]|w[e+41|0]<<8|(w[e+42|0]<<16|w[e+43|0]<<24))-11;i=mc(e+112|0);v[22656]=0;W(358,b|0,i|0,v[e+96>>2])|0;d=v[22656];v[22656]=0;if((d|0)==1){break p}v[22656]=0;v[e+56>>2]=50529027;d=Fb(e+96|0,e+56|0);f=v[22656];v[22656]=0;if((f|0)==1){break q}v[e+88>>2]=B(v[d>>2],85);h=Kb(e+56|0);d=e+40|4;d=w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24);v[22656]=0;v[e+16>>2]=d;d=Fb(e+88|0,e+16|0);f=v[22656];v[22656]=0;if((f|0)==1){break r}d=v[d>>2];v[22656]=0;R(60,h|0,d|0);d=v[22656];v[22656]=0;if((d|0)==1){break r}if(v[e+96>>2]){f=0;while(1){_:{k=w[lc(i,f)|0];d=f+1|0;if(!((k|0)!=255|v[e+96>>2]-d>>>0<2)){d=t[lc(i,d)|0];k=w[lc(i,f+2|0)|0];r=e,s=gf(h),v[r+16>>2]=s;Fd(e+32|0,e+16|0);v[22656]=0;da(359,h|0,v[e+32>>2],k|0,d|0)|0;d=v[22656];v[22656]=0;if((d|0)!=1){d=f+3|0;break _}break r}v[22656]=0;R(61,h|0,k<<24>>24);f=v[22656];v[22656]=0;if((f|0)!=1){break _}break r}f=d;if(y[e+96>>2]>d>>>0){continue}break}}v[22656]=0;Y(360,e+16|0,5,7,h|0);d=v[22656];v[22656]=0;$:{if((d|0)!=1){d=e+16|0;Eb(h,d);vb(d);d=zb(Jb(h));f=Ab(h);v[22656]=0;fa(361,a+1298292|0,d|0,f|0,74,0)|0;d=v[22656];v[22656]=0;if((d|0)==1){break $}vb(h);gc(i);break m}break r}break r}break n}b=P()|0;O()|0;break c}b=P()|0;O()|0;break c}b=P()|0;O()|0;vb(h);break o}b=P()|0;O()|0;break o}b=P()|0;O()|0}gc(i);break d}b=P()|0;O()|0;vb(d);break d}d=Sb(a+484360|0);f=e+264|5;f=w[f|0]|w[f+1|0]<<8;v[22656]=0;fa(362,d|0,b|0,f|0,65535,65535)|0;d=v[22656];v[22656]=0;if((d|0)==1){break l}k=c&1;if(k){d=e+264|3;d=w[d|0]|w[d+1|0]<<8;v[22656]=0;R(330,a+484344|0,d|0);d=v[22656];v[22656]=0;if((d|0)==1){break l}}f=e+264|3;aa:{if(!(w[f|0]|w[f+1|0]<<8)){break aa}h=a+484344|0;d=0;while(1){v[22656]=0;i=Q(191,b|0,4)|0;g=v[22656];v[22656]=0;ba:{if((g|0)!=1){if(i){break ba}break aa}b=P()|0;O()|0;break d}v[22656]=0;i=T(192,b|0)|0;g=v[22656];v[22656]=0;if((g|0)==1){break f}v[22656]=0;U(288,e+56|0,b|0,i|0);i=v[22656];v[22656]=0;if((i|0)==1){break g}g=e+56|0;i=kc(e+112|0,g);xb(g);ca:{if(!k){break ca}v[22656]=0;g=T(374,i|0)|0;j=v[22656];v[22656]=0;if((j|0)==1){break e}v[22656]=0;Q(318,e+112|0,1)|0;j=v[22656];v[22656]=0;if((j|0)==1){break e}v[22656]=0;g=W(331,h|0,d&65535,g+1|0)|0;j=v[22656];v[22656]=0;if((j|0)==1){break e}if(!g){break ca}v[22656]=0;U(356,i|0,e+56|0,-1);g=v[22656];v[22656]=0;if((g|0)==1){break e}g=_b(h,d);v[22656]=0;R(357,g|0,e+56|0);g=v[22656];v[22656]=0;if((g|0)==1){break e}g=_b(h,d);v[22656]=0;U(364,g|0,1,i|0);i=v[22656];v[22656]=0;if((i|0)==1){break e}}xb(e+112|0);d=d+1|0;if(d>>>0<(w[f|0]|w[f+1|0]<<8)>>>0){continue}break}}if(!(c&2)){break i}if(!x[a+480190>>1]){break j}d=0;while(1){if(w[sc(m,d)|0]){c=d+1|0}else{c=d+1|0;f=B(c,104)+a|0;d=Rc(e+112|0,u[f+484414>>1]&1?16:8,1,0,u[sc(m,d)>>1]>=0?0:6);v[22656]=0;W(329,d|0,f+484380|0,b|0)|0;d=v[22656];v[22656]=0;if((d|0)==1){break k}}d=c;if(d>>>0<x[a+480190>>1]){continue}break}break j}b=P()|0;O()|0;break d}b=P()|0;O()|0;break d}if(!x[a+480190>>1]){break i}b=0;while(1){c=w[sc(m,b)|0];da:{if(!c){break da}c=c-1&65535;if(tc(n)>>>0<=c>>>0){break da}c=(w[sc(m,b)+1|0]&127)+x[sc(n,c)>>1]&65535;if(c>>>0>x[a+480190>>1]){break da}f=B(c,104);d=(f+a|0)+484380|0;if(!Jd(d)){break da}h=a+484380|0;c=h+B(b+1|0,104)|0;f=f+h|0;u[c+34>>1]=x[c+34>>1]&65534|u[f+34>>1]&1;v[c>>2]=v[d>>2];v[22656]=0;h=T(386,c|0)|0;i=v[22656];v[22656]=0;if((i|0)==1){break h}if(!h){break da}hc(zb(v[c+20>>2]),zb(v[f+20>>2]),aj(d))}b=b+1|0;if(b>>>0<x[a+480190>>1]){continue}break}}Ze(m);Ze(n);break b}b=P()|0;O()|0;break d}b=P()|0;O()|0;break d}b=P()|0;O()|0;break d}b=P()|0;O()|0;xb(e+112|0)}Ze(m);Ze(n)}vb(o);S(b|0);L()}d=1}vb(o)}gb=e+288|0;return d|0}function h8(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;e=gb-48|0;gb=e;d=Tb(e+32|0,8890);f=ah(c,d);vb(d);a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{if(f){yl(a,v[b+24>>2]+1298316|0);break k}d=Tb(e+32|0,8238);f=ah(c,d);vb(d);if(f){yl(a,v[b+24>>2]+1298304|0);break k}d=Tb(e+32|0,8720);f=ah(c,d);vb(d);if(f){yl(a,v[b+24>>2]+1298352|0);break k}d=Tb(e+32|0,8230);f=ah(c,d);vb(d);if(f){yl(a,v[b+24>>2]+1298340|0);break k}d=Tb(e+32|0,5376);f=ah(c,d);vb(d);if(f){d=e+32|0;c=d;f=v[v[b+24>>2]+480184>>2];b=39056;l:{while(1){if((f|0)==v[b>>2]){mo(c,0,v[b+8>>2]);break l}b=b+12|0;if((b|0)!=39104){continue}break}Kb(c)}v[22656]=0;R(2039,a|0,d|0);a=v[22656];v[22656]=0;if((a|0)==1){break j}vb(e+32|0);break k}d=Tb(e+32|0,8215);f=ah(c,d);vb(d);if(f){h=v[v[b+24>>2]+480184>>2];c=gb-48|0;gb=c;b=39056;g=Jk(c+32|0);j=e+32|0;d=Kb(j);while(1){if((h|0)==v[b>>2]){f=v[b+4>>2];v[22656]=0;f=Q(2,c+16|0,f|0)|0;i=v[22656];v[22656]=0;m:{n:{o:{p:{q:{r:{if((i|0)!=1){v[22656]=0;U(1414,c|0,g|0,f|0);i=v[22656];v[22656]=0;if((i|0)==1){break p}if(!w[c+4|0]){break m}if(!gd(d)){v[22656]=0;i=Q(2,c|0,14867)|0;k=v[22656];v[22656]=0;if((k|0)==1){break r}v[22656]=0;Q(113,d|0,i|0)|0;k=v[22656];v[22656]=0;if((k|0)==1){break q}vb(i)}v[22656]=0;Q(113,d|0,f|0)|0;i=v[22656];v[22656]=0;if((i|0)!=1){break m}b=P()|0;O()|0;break o}b=P()|0;O()|0;break n}b=P()|0;O()|0;break o}b=P()|0;O()|0;vb(i);break o}b=P()|0;O()|0}vb(f)}vb(d);bO(g);S(b|0);L()}vb(f)}b=b+12|0;if((b|0)!=39104){continue}break}bO(g);gb=c+48|0;v[22656]=0;R(2039,a|0,j|0);a=v[22656];v[22656]=0;if((a|0)!=1){vb(e+32|0);break k}c=P()|0;O()|0;vb(e+32|0);break a}d=Tb(e+32|0,5442);f=ah(c,d);vb(d);if(f){yl(a,v[b+24>>2]+1298328|0);break k}d=Tb(e+32|0,2712);f=ah(c,d);vb(d);if(f){yl(a,v[b+24>>2]+1298280|0);break k}d=Tb(e+32|0,9258);f=ah(c,d);vb(d);if(f){c=e+32|0;gg(c,v[b+24>>2]+1298268|0);v[22656]=0;U(2092,a|0,b|0,c|0);a=v[22656];v[22656]=0;if((a|0)!=1){vb(e+32|0);break k}c=P()|0;O()|0;vb(e+32|0);break a}d=Tb(e+32|0,8663);f=ah(c,d);vb(d);if(f){s:{if(!cd(My(v[b+24>>2]))){if(v[aL(My(v[b+24>>2]))+12>>2]){break s}}Kb(a);break k}p=e+32|0;q=p;b=aL(My(v[b+24>>2]));j=gb-192|0;gb=j;hc(j+144|0,b,44);g=v[b+44>>2];if(g){hc(j+44|0,b,44);c=gb-16|0;gb=c;b=mz(v[j+64>>2]+1900|0,v[j+60>>2]+1|0,v[j+56>>2])-mz(1970,1,1)|0;b=kqa(b,b>>31,86400,0);d=B(v[j+52>>2],3600);f=d;b=b+d|0;d=jb+(d>>31)|0;d=b>>>0<f>>>0?d+1|0:d;f=b;b=B(v[j+48>>2],60);i=b;f=f+b|0;b=(b>>31)+d|0;b=f>>>0<i>>>0?b+1|0:b;d=v[j+44>>2];i=d;f=d+f|0;d=(d>>31)+b|0;b=AN(c+8|0,f,f>>>0<i>>>0?d+1|0:d);d=v[b+4>>2];b=v[b>>2];gb=c+16|0;v[j+96>>2]=b;v[j+100>>2]=d;d=j+88|0;r=j+96|0;k=r;b=k;f=v[b>>2];i=v[b+4>>2];c=2147483647;n=ee(+(g>>>0)/18.2);b=-1;t:{if(n>=0x8000000000000000){break t}c=-2147483648;b=0;if(n<=-0x8000000000000000){break t}if(D(n)<0x8000000000000000){c=D(n)>=1?~~(n>0?F(H(n*2.3283064365386963e-10),4294967295):I((n-+(~~n>>>0>>>0))*2.3283064365386963e-10))>>>0:0;b=~~n>>>0;break t}b=0}l=d;d=c+i|0;f=b+f|0;d=f>>>0<b>>>0?d+1|0:d;b=AN(l,f,d);m=gb-16|0;gb=m;g=v[b>>2];o=v[b+4>>2];v[m+12>>2]=0;v[m+8>>2]=0;v[m+4>>2]=0;b=mz(1970,1,1)+lqa(g,o,86400,0)|0;h=b>>31;c=b;d=kqa(b,h,1e4,0)+14780|0;b=jb;i=d;b=d>>>0<14780?b+1|0:b;f=b;d=lqa(d,b,-14609700,-1);b=c;l=d+b|0;d=h+jb|0;d=b>>>0>l>>>0?d+1|0:d;b=l;l=lqa(i,f,365242500,0);b=b+l|0;d=jb+d|0;d=b>>>0<l>>>0?d+1|0:d;l=lqa(i,f,-146097e4,-1);b=l+b|0;d=jb+d|0;d=b>>>0<l>>>0?d+1|0:d;l=b;b=lqa(i,f,3652425,0);f=jb;s=f;i=l;l=kqa(b,f,-365,-1);i=i+l|0;f=jb+d|0;f=i>>>0<l>>>0?f+1|0:f;d=f;if(!((d|0)>0|(d|0)>=0)){d=s-!b|0;b=b-1|0;f=kqa(b,d,-365,-1)+c|0;d=h+jb|0;d=c>>>0>f>>>0?d+1|0:d;c=f;f=(b|0)/-4|0;i=f;c=c+f|0;f=(f>>31)+d|0;f=c>>>0<i>>>0?f+1|0:f;d=c;c=(b|0)/100|0;i=c;d=d+c|0;c=(c>>31)+f|0;c=d>>>0<i>>>0?c+1|0:c;f=d;d=(b|0)/-400|0;i=d;f=f+d|0;d=(d>>31)+c|0;d=f>>>0<i>>>0?d+1|0:d;i=f}f=b;c=kqa(i,d,100,0)+52|0;b=jb;b=lqa(c,c>>>0<52?b+1|0:b,3060,0);c=b+2|0;d=(c|0)/12|0;v[m+12>>2]=f+d;v[m+8>>2]=(c-B(d,12)|0)+1;b=kqa(b,jb,306,0)+5|0;d=jb;b=lqa(b,b>>>0<5?d+1|0:d,-10,-1)+i|0;v[m+4>>2]=b+1;v[k+40>>2]=0;v[k+32>>2]=0;v[k+36>>2]=0;v[k+24>>2]=0;v[k+28>>2]=0;v[k+20>>2]=v[m+12>>2]-1900;v[k+16>>2]=v[m+8>>2]-1;b=v[m+4>>2];t=k,u=mqa(lqa(g,o,3600,0),jb,24),v[t+8>>2]=u;v[k+12>>2]=b;b=lqa(g,o,60,0);c=jb;t=k,u=mqa(b,c,60),v[t+4>>2]=u;t=k,u=g-kqa(b,c,60,0)|0,v[t>>2]=u;gb=m+16|0;hc(j+144|0,r,44)}i=hc(j,j+144|0,44);c=i;b=gb-112|0;gb=b;d=Kb(b+96|0);v[22656]=0;f=Q(2,b+80|0,10810)|0;g=v[22656];v[22656]=0;u:{v:{w:{x:{y:{if((g|0)!=1){g=v[c+20>>2];if(!g){break v}v[22656]=0;v[b+48>>2]=g+1900;R(112,b- -64|0,b+48|0);g=v[22656];v[22656]=0;if((g|0)!=1){v[22656]=0;Q(113,d|0,b- -64|0)|0;g=v[22656];v[22656]=0;if((g|0)==1){break y}vb(b- -64|0);if(y[c+16>>2]>11){break v}v[22656]=0;g=Q(2,b+48|0,13873)|0;h=v[22656];v[22656]=0;z:{A:{B:{C:{D:{E:{if((h|0)!=1){h=v[c+16>>2];v[22656]=0;v[b+16>>2]=h+1;R(114,b+32|0,b+16|0);h=v[22656];v[22656]=0;if((h|0)==1){break E}v[22656]=0;U(3,b- -64|0,g|0,b+32|0);h=v[22656];v[22656]=0;if((h|0)==1){break D}v[22656]=0;Q(113,d|0,b- -64|0)|0;h=v[22656];v[22656]=0;if((h|0)==1){break C}vb(b- -64|0);vb(b+32|0);vb(g);if(v[c+12>>2]-1>>>0<=30){break z}break v}a=P()|0;O()|0;break x}a=P()|0;O()|0;break A}a=P()|0;O()|0;break B}a=P()|0;O()|0;vb(b- -64|0)}vb(b+32|0)}vb(g);break x}v[22656]=0;g=Q(2,b+48|0,13873)|0;h=v[22656];v[22656]=0;F:{G:{H:{I:{J:{K:{L:{M:{N:{O:{P:{Q:{R:{S:{T:{U:{V:{W:{X:{Y:{Z:{_:{$:{aa:{ba:{ca:{if((h|0)!=1){v[22656]=0;R(114,b+32|0,c+12|0);h=v[22656];v[22656]=0;if((h|0)==1){break ca}v[22656]=0;U(3,b- -64|0,g|0,b+32|0);h=v[22656];v[22656]=0;if((h|0)==1){break ba}v[22656]=0;Q(113,d|0,b- -64|0)|0;h=v[22656];v[22656]=0;if((h|0)==1){break aa}vb(b- -64|0);vb(b+32|0);vb(g);g=v[c+8>>2];h=v[c+4>>2];if(!(v[c>>2]|(g|h))|g>>>0>23|h>>>0>59){break v}v[22656]=0;g=Q(2,b- -64|0,10977)|0;h=v[22656];v[22656]=0;if((h|0)==1){break Z}v[22656]=0;Q(113,d|0,g|0)|0;h=v[22656];v[22656]=0;if((h|0)==1){break Y}vb(g);if(v[c+32>>2]>0){v[22656]=0;g=Q(2,b- -64|0,12682)|0;h=v[22656];v[22656]=0;if((h|0)==1){break X}Eb(f,g);vb(g)}v[22656]=0;R(114,b+32|0,c+8|0);g=v[22656];v[22656]=0;if((g|0)==1){break W}v[22656]=0;g=Q(2,b+16|0,11846)|0;h=v[22656];v[22656]=0;if((h|0)==1){break V}v[22656]=0;U(3,b+48|0,b+32|0,g|0);h=v[22656];v[22656]=0;if((h|0)==1){break U}v[22656]=0;R(114,b|0,c+4|0);h=v[22656];v[22656]=0;if((h|0)==1){break T}v[22656]=0;U(3,b- -64|0,b+48|0,b|0);h=v[22656];v[22656]=0;if((h|0)==1){break S}v[22656]=0;Q(113,d|0,b- -64|0)|0;h=v[22656];v[22656]=0;if((h|0)==1){break R}vb(b- -64|0);vb(b);vb(b+48|0);vb(g);vb(b+32|0);if(y[c>>2]<62){break M}v[22656]=0;U(115,q|0,d|0,f|0);c=v[22656];v[22656]=0;if((c|0)==1){break L}break u}a=P()|0;O()|0;break x}a=P()|0;O()|0;break _}a=P()|0;O()|0;break $}a=P()|0;O()|0;vb(b- -64|0)}vb(b+32|0)}vb(g);break x}a=P()|0;O()|0;break x}a=P()|0;O()|0;vb(g);break x}a=P()|0;O()|0;break x}a=P()|0;O()|0;break x}a=P()|0;O()|0;break N}a=P()|0;O()|0;break O}a=P()|0;O()|0;break P}a=P()|0;O()|0;break Q}a=P()|0;O()|0;vb(b- -64|0)}vb(b)}vb(b+48|0)}vb(g)}vb(b+32|0);break x}v[22656]=0;g=Q(2,b+48|0,11846)|0;h=v[22656];v[22656]=0;if((h|0)==1){break K}v[22656]=0;R(114,b+32|0,c|0);c=v[22656];v[22656]=0;if((c|0)==1){break J}v[22656]=0;U(3,b- -64|0,g|0,b+32|0);c=v[22656];v[22656]=0;if((c|0)==1){break I}v[22656]=0;Q(113,d|0,b- -64|0)|0;c=v[22656];v[22656]=0;if((c|0)==1){break H}vb(b- -64|0);vb(b+32|0);vb(g);v[22656]=0;Q(113,d|0,f|0)|0;c=v[22656];v[22656]=0;if((c|0)!=1){break v}}a=P()|0;O()|0;break x}a=P()|0;O()|0;break x}a=P()|0;O()|0;break F}a=P()|0;O()|0;break G}a=P()|0;O()|0;vb(b- -64|0)}vb(b+32|0)}vb(g);break x}a=P()|0;O()|0;break x}a=P()|0;O()|0;break w}a=P()|0;O()|0;vb(b- -64|0)}vb(f)}vb(d);S(a|0);L()}Dc(q,d)}vb(f);vb(d);gb=b+112|0;gb=i+192|0;v[22656]=0;R(2039,a|0,p|0);a=v[22656];v[22656]=0;if((a|0)!=1){vb(e+32|0);break k}c=P()|0;O()|0;vb(e+32|0);break a}d=Tb(e+32|0,9459);f=ah(c,d);vb(d);if(f){c=b;d=e+32|0;PS(d,v[b+24>>2]+1298292|0);da:{ea:{fa:{if(!gd(d)){break fa}c=v[c+24>>2];v[22656]=0;c=JO(c);d=v[22656];v[22656]=0;if((d|0)==1){break da}ga:{switch(c|0){case 0:v[22656]=0;R(2094,e+16|0,b|0);c=v[22656];v[22656]=0;if((c|0)!=1){c=e+16|0;Eb(e+32|0,c);vb(c);break fa}c=P()|0;O()|0;break b;case 1:v[22656]=0;R(2095,e+16|0,b|0);c=v[22656];v[22656]=0;if((c|0)!=1){c=e+16|0;Eb(e+32|0,c);vb(c);break fa}c=P()|0;O()|0;break b;case 2:if(gd(e+32|0)){v[22656]=0;R(2094,e+16|0,b|0);c=v[22656];v[22656]=0;if((c|0)==1){break i}c=e+16|0;Eb(e+32|0,c);vb(c)}if(!gd(e+32|0)){break fa}v[22656]=0;R(2095,e+16|0,b|0);c=v[22656];v[22656]=0;if((c|0)!=1){c=e+16|0;Eb(e+32|0,c);vb(c);break fa}c=P()|0;O()|0;break b;case 3:if(gd(e+32|0)){v[22656]=0;R(2095,e+16|0,b|0);c=v[22656];v[22656]=0;if((c|0)==1){break h}c=e+16|0;Eb(e+32|0,c);vb(c)}if(!gd(e+32|0)){break fa}v[22656]=0;R(2094,e+16|0,b|0);c=v[22656];v[22656]=0;if((c|0)!=1){c=e+16|0;Eb(e+32|0,c);vb(c);break fa}c=P()|0;O()|0;break b;case 4:v[22656]=0;R(2094,e+16|0,b|0);c=v[22656];v[22656]=0;ha:{ia:{if((c|0)!=1){v[22656]=0;R(2095,e|0,b|0);c=v[22656];v[22656]=0;if((c|0)==1){break ha}if(gd(e+16|0)){break ia}v[22656]=0;Q(1168,e+32|0,e+16|0)|0;c=v[22656];v[22656]=0;if((c|0)!=1){break ia}break d}c=P()|0;O()|0;break b}if(!gd(e)){v[22656]=0;Q(1168,e+32|0,e|0)|0;c=v[22656];v[22656]=0;if((c|0)==1){break d}}vb(e);vb(e+16|0);break fa}c=P()|0;O()|0;break c;case 5:break ga;default:break fa}}v[22656]=0;R(2094,e+16|0,b|0);c=v[22656];v[22656]=0;ja:{if((c|0)!=1){v[22656]=0;R(2095,e|0,b|0);c=v[22656];v[22656]=0;if((c|0)==1){break ea}if(gd(e)){break ja}v[22656]=0;Q(1168,e+32|0,e|0)|0;c=v[22656];v[22656]=0;if((c|0)!=1){break ja}break f}c=P()|0;O()|0;break b}if(!gd(e+16|0)){v[22656]=0;Q(1168,e+32|0,e+16|0)|0;c=v[22656];v[22656]=0;if((c|0)==1){break f}}vb(e);vb(e+16|0)}v[22656]=0;U(2092,a|0,b|0,e+32|0);a=v[22656];v[22656]=0;if((a|0)==1){break da}vb(e+32|0);break k}c=P()|0;O()|0;break e}c=P()|0;O()|0;break b}d=Tb(e+32|0,2564);f=ah(c,d);vb(d);if(f){c=e+32|0;PS(c,v[b+24>>2]+1298292|0);v[22656]=0;U(2092,a|0,b|0,c|0);a=v[22656];v[22656]=0;if((a|0)!=1){vb(e+32|0);break k}c=P()|0;O()|0;vb(e+32|0);break a}i=c;c=Tb(e+32|0,4379);d=ah(i,c);vb(c);if(d){a=Kb(a);b=b+68|0;t=e,u=Vb(b),v[t+32>>2]=u;t=e,u=Zb(b),v[t+16>>2]=u;if(!Gb(e+32|0,e+16|0)){break k}c=1;while(1){b=v[e+32>>2];if(!(c&1)){v[22656]=0;Q(1917,a|0,18696)|0;c=v[22656];v[22656]=0;if((c|0)==1){break g}}v[22656]=0;Q(1168,a|0,b|0)|0;b=v[22656];v[22656]=0;if((b|0)==1){break g}b=e+32|0;v[b>>2]=v[b>>2]+12;c=0;if(Gb(b,e+16|0)){continue}break}break k}Tb(a,18726)}gb=e+48|0;return}c=P()|0;O()|0;vb(e+32|0);break a}c=P()|0;O()|0;break b}c=P()|0;O()|0;break b}c=P()|0;O()|0;vb(a);break a}c=P()|0;O()|0;vb(e)}vb(e+16|0);break b}c=P()|0;O()|0;vb(e)}vb(e+16|0)}vb(e+32|0)}S(c|0);L()}function qfa(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,z=0,A=0,C=0,D=0,E=0,F=0,G=0;g=gb-48|0;gb=g;b=v[a+1074308>>2];if(!(b>>>0>18285125|(b|0)==18284544)){Rf(a+1074312|0,0)}b=g+32|0;h=a+1074312|0;Db(b,h,0);if(Cb(b)){q=(v[a+480180>>2]&16777248)!=0}b=g+32|0;Db(b,h,0);if(Cb(b)){E=v[a+480180>>2]==4}k=a+1074308|0;b=v[k>>2];if(b>>>0<=18874367){a:{if(!x[a+480192>>1]){break a}c=1;while(1){b:{b=v[(((c&65535)<<2)+a|0)+900380>>2];if(!b){break b}v[g+32>>2]=B(w[b+20|0],100)>>>6;v[g+16>>2]=100;F=b,G=v[Fb(g+32|0,g+16|0)>>2],t[F+20|0]=G;c:{d:{e:{if(q){e=v[k>>2];if(e>>>0>18350079){break b}l=t[b+26|0];t[b+26|0]=((l>>31|1)+l|0)/2;if(e>>>0<18285314){break e}break d}e=t[b+26|0];t[b+26|0]=((e>>31|1)+e|0)/2}oB(ji(b,2),4,v[a+480180>>2]);e=v[a+1074308>>2];if(e>>>0<18284544){break c}if(e>>>0>18285135){break b}if(!w[b+34|0]){break d}if(!Kj(b)){break d}Ob(h,2,1)}if(y[k>>2]>18285135){break b}}if(!(w[b+24|0]|(w[b+23|0]|(w[b+19|0]|w[b+20|0])))){break b}Ob(h,1,1);break a}c=c+1|0;if(x[a+480192>>1]>=(c&65535)>>>0){continue}break}}f:{if(!(v[a+480180>>2]&16777248)){break f}b=1;if(!x[a+480190>>1]|y[k>>2]>=18285314&q){break f}while(1){c=B(b&65535,104)+a|0;e=c+484419|0;if(!(w[e|0]|!(w[c+484421|0]|w[c+484420|0]))){t[e|0]=255}b=b+1|0;if(x[a+480190>>1]>=(b&65535)>>>0){continue}break}}b=a+901404|0;c=b;d=SS(b);if((d|0)!=(b|0)){while(1){b=c;i=b+32|0;while(1){e=w[b|0];g:{h:{if((e-97&255)>>>0<=5){l=e-32|0;break h}l=99;i:{if(e>>>0<=106){if(e-88>>>0<2){break i}if((e|0)==75){break h}break g}if(e-120>>>0<2){break i}if((e|0)==107){break h}break g}l=122}t[b|0]=l}b=b+1|0;if((i|0)!=(b|0)){continue}break}c=c+32|0;if((d|0)!=(c|0)){continue}break}}b=v[a+1074308>>2]}j:{if(!x[a+480192>>1]|(!(v[a+480180>>2]&16777252)|((b|0)==18874368|b>>>0>18874895))){break j}b=1;c=0;while(1){k:{e=v[(((b&65535)<<2)+a|0)+900380>>2];if(!(w[e+31|0]?e:0)){b=b+1|0;if(x[a+480192>>1]>=(b&65535)>>>0){continue}if(c){break k}break j}t[e+33|0]=13;c=1;b=b+1|0;if(x[a+480192>>1]>=(b&65535)>>>0){continue}}break}Ob(h,3,1)}b=v[k>>2];l:{if(!(v[a+480180>>2]&16777248)|(b>>>0>19006225|(b|0)==19005440)){break l}b=g+32|0;Db(b,h,0);if(!Cb(b)){b=g+16|0;Db(b,h,1);if(!Cb(b)){break l}}if(!x[a+480192>>1]){break l}b=1;while(1){c=v[(((b&65535)<<2)+a|0)+900380>>2];if(!(!c|!w[c+19|0]|!(t[c+80|0]&1))){t[c+19|0]=0}b=b+1|0;if(x[a+480192>>1]>=(b&65535)>>>0){continue}break}}m:{n:{o:{if(y[k>>2]<=19007232){c=a+946300|0;b=a+906300|0;while(1){e=g+16|0;l=b+80|0;PO(e,l);v[22656]=0;Y(360,g+32|0,0,8,e|0);e=v[22656];v[22656]=0;if((e|0)==1){break n}vb(g+16|0);v[22656]=0;Jr(l,g+32|0);e=v[22656];v[22656]=0;if((e|0)==1){break o}vb(g+32|0);b=b+160|0;if((c|0)!=(b|0)){continue}break}}p:{q:{r:{s:{if(v[a+480180>>2]!=4){break s}b=v[k>>2];if(b>>>0<19007257){break q}if(b>>>0>19071235){break r}if(w[a+1074368|0]!=4){break s}nA(a,5)}b=v[k>>2]}if((b|0)==19202048|b>>>0>19202054){break p}}if(!x[a+480192>>1]){break p}c=1;while(1){l=(((c&65535)<<2)+a|0)+900380|0;b=v[l>>2];t:{if(!b|!w[b+20|0]|!w[b+31|0]){break t}b=b+236|0;e=Ou(b);if((b|0)!=(e|0)){while(1){if(x[b>>1]){break t}b=b+2|0;if((e|0)!=(b|0)){continue}break}}t[v[l>>2]+20|0]=0}c=c+1|0;if(x[a+480192>>1]>=(c&65535)>>>0){continue}break}}b=v[k>>2];if(b>>>0<=19267583){if(x[a+480192>>1]){b=1;e=!q;while(1){c=v[(((b&65535)<<2)+a|0)+900380>>2];u:{if(!c){break u}l=t[c+26|0];t[c+26|0]=((l>>31|1)+l|0)/2;if(!(e|y[k>>2]<18350080)){break u}t[c+19|0]=w[c+19|0]+3>>>2}b=b+1|0;if(x[a+480192>>1]>=(b&65535)>>>0){continue}break}}b=v[k>>2]}v:{if(!x[a+480192>>1]|b>>>0>19398673){break v}b=1;while(1){c=v[(((b&65535)<<2)+a|0)+900380>>2];if(!(!c|w[c+65|0]==255)){Ob(h,94,1);break v}b=b+1|0;if(x[a+480192>>1]>=(b&65535)>>>0){continue}break}}b=v[k>>2];if(b>>>0<=19399427){w:{if(!x[a+480192>>1]){break w}b=1;while(1){c=v[(((b&65535)<<2)+a|0)+900380>>2];if(!(!c|w[c+36|0]>1)){Ob(h,101,1);break w}b=b+1|0;if(x[a+480192>>1]>=(b&65535)>>>0){continue}break}}b=v[k>>2]}x:{if(!x[a+480190>>1]|b>>>0>19923027){break x}b=1;while(1){c=B(b&65535,104)+a|0;if(!(!Jd(c+484380|0)|!(w[c+484414|0]&20))){Ob(h,116,1);break x}b=b+1|0;if(x[a+480190>>1]>=(b&65535)>>>0){continue}break}}b=gb-16|0;gb=b;u[g+12>>1]=0;v[g+8>>2]=a;c=b+8|0;Db(c,a+1074312|0,0);F=g,G=Cb(c),t[F+14|0]=G;gb=b+16|0;b=v[g+12>>2];v[g>>2]=v[g+8>>2];v[g+4>>2]=b;c=gb-16|0;gb=c;o=a+484344|0;l=Te(o);b=v[g+4>>2];e=v[g>>2];v[c>>2]=e;v[c+4>>2]=b;v[c+8>>2]=e;v[c+12>>2]=b;b=c;e=gb-32|0;gb=e;D=l-1&65535;y:{if(Te(o)>>>0>D>>>0){r=v[b>>2];s=v[b+4>>2];while(1){b=z&65535;if(hi(bf(o,b))){d=Vb(bf(o,b));i=Zb(bf(o,b));b=e;v[b+24>>2]=r;v[b+28>>2]=s;v[b+8>>2]=r;v[b+12>>2]=s;l=b+8|0;m=gb-16|0;gb=m;v[m>>2]=i;v[m+8>>2]=d;if(Gb(m+8|0,m)){while(1){A=m+8|0;d=v[A>>2];C=gb-16|0;gb=C;b=l;n=x[b+4>>1];i=n+1|0;u[b+4>>1]=i;if(x[v[b>>2]+480188>>1]<=(i&65535)>>>0){u[b+4>>1]=0}z:{if(Cg(d)){break z}f=v[b>>2];i=v[f+1074308>>2];p=v[f+480180>>2];A:{B:{C:{if((p|0)==2){if(w[d+3|0]!=23|i>>>0>18415615){break C}yf(d+5|0,64);break B}if(p&16777248){D:{E:{if(i>>>0>=18285314){if(w[b+6|0]){break E}f=0;j=0;if(i>>>0>18874367){break D}}F:{switch(w[d+3|0]-20|0){case 3:yf(d+5|0,128);break E;case 0:break F;default:break E}}f=w[d+5|0];if((f|0)!=208){if((f|0)!=192){break E}t[d|0]=254;t[d+3|0]=0;break E}t[d+3|0]=0}G:{H:{I:{if(i>>>0>=18350080){if(w[b+6|0]){break I}f=0;j=0;if(i>>>0>18874367){break D}}j=w[d+3|0];if(j>>>0>29){break H}f=1;if(!(1<<j&536873152)){break H}break G}f=0;j=0;if(i>>>0>18874367){break D}j=w[d+3|0]}f=0}j=(j|0)==24|(j|0)==22}J:{if(!(j?1:f)){break J}j=w[d+5|0];f=j&15;if(!f|(f|0)==15){break J}j=j&240;if(!j|(j|0)==240){break J}t[d+5|0]=w[d+3|0]==24?j:f}if(!(!x[v[b>>2]+480192>>1]|((i|0)==19005440|i>>>0>19005699)|(w[b+6|0]|x[v[b>>2]+480192>>1]>=w[d+1|0]))){t[d+4|0]=0;t[d+2|0]=1}if(w[d+3|0]!=18|w[d+5|0]!=17){break C}if(i>>>0>19468801){break A}f=C+8|0;Db(f,v[b>>2]+1074312|0,22);if(!Cb(f)|v[v[b>>2]+480208>>2]&4){break C}t[d+5|0]=0;break C}if((p|0)!=4){break C}f=w[b+6|0];if(!((!f|i>>>0<18285314)&i>>>0<=18874367|i>>>0>19137025|w[d+3|0]!=23|w[d+5|0]<65)){t[d+3|0]=0}K:{L:{M:{if(!(f|i>>>0>18874367?i>>>0>=18415616:0)){j=w[d+3|0];f=w[d+2|0];if((j|0)!=10|(f|0)!=11){break M}t[d+3|0]=0;break K}if(i>>>0>18874639){break L}j=w[d+3|0];f=w[d+2|0]}if((f|0)!=11|(j|0)!=4){break K}f=w[d+4|0];if(!(f|w[b+6|0])){break K}j=w[d+5|0];if(!j){break K}t[d+2|0]=0;F=d,G=Iv(j+(f<<4)|0),t[F+5|0]=G;break K}if(i>>>0>19007240){break A}}if(w[d+5|0]|w[d+3|0]!=16){break C}t[d+3|0]=0}if(i>>>0>18874367){break A}}N:{O:{P:{f=w[d+3|0];j=w[d+5|0]&240;if((f|0)!=28|(j|0)!=96){b=0}else{if(!w[b+6|0]|(p|0)!=4){break P}b=i>>>0<18350080}if(!(b|(f|0)==20&(j|0)==96)|!n){break N}break O}if(!n){break A}}b=d+B(n,-6)|0;while(1){if(!((w[b+3|0]|8)!=28|(w[b+5|0]&240)!=96)){t[b+3|0]=0}b=b+6|0;if(d>>>0>b>>>0){continue}break}f=w[d+3|0]}if(!n|((f|0)!=20|(j|0)!=224)){break A}b=d+B(n,-6)|0;while(1){if(!(w[b+3|0]!=20|(w[b+5|0]&240)!=224)){t[b+3|0]=0}b=b+6|0;if(d>>>0>b>>>0){continue}break}}b=w[d+2|0];if((b|0)==8){if((i|0)==19333120|i>>>0>19333174){break z}i=w[d+4|0];b=w[d+3|0];if(!(!i|(b|0)!=7)){t[d+3|0]=11;break z}Q:{R:{switch(b-5|0){default:if((b|0)!=26){break z}break;case 2:break Q;case 0:break R;case 1:break z}}f=w[d+5|0];if(!(f&15)){t[d+3|0]=5;t[d+5|0]=f|i&15;break Q}S:{switch(b-5|0){case 0:case 2:break Q;case 1:break z;default:break S}}if((b|0)!=26){break z}}t[d+2|0]=0;break z}if(!(w[d+3|0]|((p|0)==16777216|(b|0)!=15))){t[d+2|0]=0;t[d+3|0]=10;t[d+5|0]=w[d+4|0]<<3;break z}if(w[d+3|0]!=10|i>>>0>19922963|(b|0)!=15){break z}if(w[d+4|0]?w[d+5|0]:1){t[d+2|0]=0;break z}t[d+3|0]=0}gb=C+16|0;bk(A);if(Gb(A,m)){continue}break}}b=v[l+4>>2];v[e+16>>2]=v[l>>2];v[e+20>>2]=b;gb=m+16|0}z=z+1|0;if((z&65535)>>>0<=D>>>0){continue}break}v[g+32>>2]=r;v[g+36>>2]=s;break y}l=v[b+4>>2];v[g+32>>2]=v[b>>2];v[g+36>>2]=l}gb=e+32|0;gb=c+16|0;b=v[a+1074308>>2];c=b>>>0<19267584;T:{if(c&q){Ob(h,8,(b|0)==18284544|b>>>0>18285313);b=48232;while(1){c=v[k>>2];e=v[b+4>>2];Ob(h,v[b>>2],c>>>0>=e>>>0|(c|0)==(e&-65536));b=b+8|0;if((b|0)!=48568){continue}break}break T}if(!(c&E)){break T}Ob(h,8,b>>>0>18285313);b=48584;while(1){Ob(h,v[b>>2],y[k>>2]>=y[b+4>>2]);b=b+8|0;if((b|0)!=48816){continue}break}}U:{if(v[a+480180>>2]&16777248){b=48816;while(1){c=v[k>>2];e=v[b+4>>2];l=e&-65536;if(!(c>>>0>=l>>>0&(c>>>0<=l>>>0|c>>>0>=e>>>0))){Rf(h,v[b>>2])}b=b+8|0;if((b|0)!=48872){continue}break}break U}if(v[a+480180>>2]==4){b=48880;while(1){if(y[k>>2]<y[b+4>>2]){Rf(h,v[b>>2])}b=b+8|0;if((b|0)!=48944){continue}break}break U}if(v[a+480180>>2]!=2){break U}b=48944;while(1){if(y[k>>2]<y[b+4>>2]){Rf(h,v[b>>2])}b=b+8|0;if((b|0)!=49032){continue}break}}V:{if(v[a+480180>>2]==4){b=v[k>>2];if(b>>>0>18415615){break V}Ob(h,98,1)}b=v[k>>2]}if(b-19333159>>>0<=33){b=0;while(1){c=g+32|0;e=b+77|0;Db(c,h,e);Ob(h,b+86|0,Cb(c));Rf(h,e);b=b+1|0;if((b|0)!=5){continue}break}b=v[k>>2]}c=8;W:{if(b>>>0>=18284544){if(b>>>0>18874627){break W}c=6;if((b|0)==18874368){break W}}Ob(h,c,1);b=v[k>>2]}X:{if(w[a+480208|0]&16){if(b>>>0<=19136511){Rf(h,7);break X}if(!(v[a+480180>>2]&16777248)|b>>>0>19267583){break X}Ob(h,7,1);break X}if((b|0)==19922944|b>>>0>19922997){break X}Rf(h,7)}b=g+32|0;Db(b,h,31);Y:{if(!Cb(b)){break Y}b=v[k>>2];if(!x[a+480192>>1]|(b>>>0<19071234|b>>>0>19398722)){break Y}b=1;while(1){Z:{c=v[(((b&65535)<<2)+a|0)+900380>>2];if(!c){break Z}e=w[c+65|0];if(!(w[c+60|0]&4)|(e|0)==255|e>>>0<=w[c- -64|0]){break Z}Ob(h,97,1);break Y}b=b+1|0;if(x[a+480192>>1]>=(b&65535)>>>0){continue}break}}_:{if(!(v[a+480180>>2]&16777218)|!x[a+480190>>1]){break _}b=1;while(1){if(!(w[(B(b&65535,104)+a|0)+484415|0]&2)){b=b+1|0;if(x[a+480190>>1]>=(b&65535)>>>0){continue}break _}break}$:{aa:{ba:{if(!(!x[a+480192>>1]|v[a+480180>>2]!=16777216)){b=v[k>>2];if(b>>>0<19398688){break aa}if(b>>>0>19464277){break ba}Ob(h,109,1)}b=v[k>>2]}if((b|0)==19922944|b>>>0>19922996){break $}}Rf(h,111)}if(!(v[a+480180>>2]!=2|y[a+1074308>>2]>19464191)){Ob(h,108,1);break _}if(v[a+480180>>2]==2){break _}Rf(h,108)}ca:{if(!(!(v[a+480180>>2]&16777252)|v[k>>2]-19333186>>>0>589827)){c=a+946300|0;a=a+906300|0;while(1){da:{if((w[a+16|0]|w[a+17|0]<<8|(w[a+18|0]<<16|w[a+19|0]<<24))!=1146637647|(w[a+20|0]|w[a+21|0]<<8|(w[a+22|0]<<16|w[a+23|0]<<24))!=-271958638){break da}if((oc(a+4|0)|0)!=32){break da}b=Tb(g+32|0,13926);v[22656]=0;Jr(a+80|0,b);e=v[22656];v[22656]=0;if((e|0)==1){break ca}vb(b)}a=a+160|0;if((c|0)!=(a|0)){continue}break}}gb=g+48|0;return}a=P()|0;O()|0;vb(b);break m}a=P()|0;O()|0;vb(g+32|0);break m}a=P()|0;O()|0;vb(g+16|0)}S(a|0);L()}function c_(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,z=0;p=Gh(b,11134);a:{if(!p){break a}if(!Pb(b,6)){break a}while(1){b:{l=sg(b);c:{if((l|0)==(An(10984)|0)){break c}i=w[18702]|w[18703]<<8|(w[18704]<<16|w[18705]<<24);if(!(l&1616928864)|l&-2139062144){break c}if((i|0)!=(l|0)){break b}}pg(b,4);break a}m=1;r=Og(b);if(x[a+480192>>1]){while(1){j=v[(((m&65535)<<2)+a|0)+900380>>2];if(j){d:{i=r;n=b;q=l;if((An(13829)|0)==(l|0)){Rb(n,i);break d}e=q;c=i;d=n;g=0;h=gb-48|0;gb=h;e:{f:{g:{h:{i:{j:{k:{l:{m:{f=j;n:{if(!f){break n}o:{p:{q:{r:{s:{t:{u:{v:{w:{x:{y:{z:{A:{B:{C:{D:{E:{F:{G:{H:{I:{J:{K:{L:{M:{N:{O:{P:{Q:{R:{S:{T:{U:{V:{W:{X:{if((e|0)<=1347628589){if((e|0)<=1297100333){if((e|0)<=1179931727){if((e|0)<=1145263149){if((e|0)==1095062094){break y}if((e|0)==1095126087){break v}if((e|0)!=1129524782|c>>>0>1){break n}if(!Pb(d,c)){break n}s=f,z=xd(d,c),t[s+23|0]=z;g=1;break n}if((e|0)<=1179463213){if((e|0)==1145263150){break N}if((e|0)!=1145979182|c>>>0>1){break n}if(!Pb(d,c)){break n}s=f,z=xd(d,c),t[s+18|0]=z;g=1;break n}if((e|0)==1179463214){break B}if((e|0)!=1179594286|c>>>0>4){break n}if(!Pb(d,c)){break n}s=f,z=rw(d,c),v[s>>2]=z;g=1;break n}if((e|0)<=1229345325){if((e|0)==1179931728){break o}if((e|0)==1196830254){break X}if((e|0)!=1229341486|c>>>0>1){break n}if(!Pb(d,c)){break n}s=f,z=xd(d,c),t[s+21|0]=z;g=1;break n}if((e|0)<=1296182829){if((e|0)==1229345326){break K}if((e|0)!=1264266798|c>>>0>256){break n}e=f+236|0;Td(h,d,c);c=kc(h+24|0,h);xb(h);d=0;while(1){v[22656]=0;f=T(307,c|0)|0;g=v[22656];v[22656]=0;if((g|0)==1){break F}s=vd(e,d),z=f,u[s>>1]=z;d=d+1|0;if(d>>>0<128){continue}break}xb(c);g=1;break n}if((e|0)==1296182830){break J}if((e|0)!=1296248366|c>>>0>1){break n}if(!Pb(d,c)){break n}s=f,z=xd(d,c),t[s+31|0]=z;g=1;break n}if((e|0)<=1346720333){if((e|0)<=1313692461){if((e|0)==1297100334){break I}if((e|0)==1297110852){break t}if((e|0)!=1298747438|c>>>0>1){break n}if(!Pb(d,c)){break n}s=f,z=xd(d,c),t[s+34|0]=z;g=1;break n}if((e|0)<=1345203757){if((e|0)==1313692462){break G}if((e|0)!=1313751342|c>>>0>1){break n}if(!Pb(d,c)){break n}s=f,z=xd(d,c),t[s+16|0]=z;g=1;break n}if((e|0)==1345203758){break W}if((e|0)!=1346711086){break n}v[h+24>>2]=240;s=h,z=xp(d,c),v[s>>2]=z;kh(f+68|0,v[Fb(h+24|0,h)>>2]);g=1;break n}if((e|0)<=1347179309){if((e|0)<=1346784326){if((e|0)==1346720334){break z}if((e|0)!=1346722606){break n}Td(h,d,c);c=kc(h+24|0,h);xb(h);d=0;v[22656]=0;e=ji(f,1);f=v[22656];v[22656]=0;if((f|0)==1){break k}if(Nb(e)){while(1){v[22656]=0;f=T(309,c|0)|0;g=v[22656];v[22656]=0;if((g|0)==1){break k}s=Mb(e,d),z=f,t[s+2|0]=z;d=d+1|0;if(Nb(e)>>>0>d>>>0){continue}break}}xb(c);g=1;break n}if((e|0)==1346784327){break w}if((e|0)!=1347175726|c>>>0>1){break n}if(!Pb(d,c)){break n}s=f,z=xd(d,c),t[s+82|0]=z;g=1;break n}if((e|0)<=1347441453){if((e|0)==1347179310){break T}if((e|0)!=1347437358|c>>>0>1){break n}if(!Pb(d,c)){break n}s=f,z=xd(d,c),t[s+27|0]=z;g=1;break n}if((e|0)==1347441454){break H}if((e|0)!=1347443502){break n}Td(h,d,c);c=kc(h+24|0,h);xb(h);d=0;v[22656]=0;e=ji(f,1);f=v[22656];v[22656]=0;if((f|0)==1){break h}if(Nb(e)){while(1){v[22656]=0;f=T(307,c|0)|0;g=v[22656];v[22656]=0;if((g|0)==1){break h}s=Mb(e,d),z=f,u[s>>1]=z;d=d+1|0;if(Nb(e)>>>0>d>>>0){continue}break}}xb(c);g=1;break n}if((e|0)<=1447374381){if((e|0)<=1349078084){if((e|0)<=1347831111){if((e|0)<=1347634477){if((e|0)==1347628590){break M}if((e|0)!=1347633710|c>>>0>1){break n}if(!Pb(d,c)){break n}s=f,z=xd(d,c),t[s+83|0]=z;g=1;break n}if((e|0)==1347634478){break S}if((e|0)!=1347703884){break n}s=f,z=B(qw(d,c),1e4)+(y[f+40>>2]%1e4|0)|0,v[s+40>>2]=z;g=1;break n}if((e|0)<=1349076269){if((e|0)==1347831112){break A}if((e|0)!=1347833672|c>>>0>1){break n}if(!Pb(d,c)){break n}s=f,z=xd(d,c),t[s+36|0]=z;g=1;break n}if((e|0)==1349076270){break q}if((e|0)!=1349076315){break n}Td(h,d,c);c=kc(h+24|0,h);xb(h);d=0;v[22656]=0;e=ji(f,2);f=v[22656];v[22656]=0;if((f|0)==1){break l}if(Nb(e)){while(1){v[22656]=0;f=T(309,c|0)|0;g=v[22656];v[22656]=0;if((g|0)==1){break l}s=Mb(e,d),z=f,t[s+2|0]=z;d=d+1|0;if(Nb(e)>>>0>d>>>0){continue}break}}xb(c);g=1;break n}if((e|0)<=1349079873){if((e|0)==1349078085){break Q}if((e|0)==1349078099){break R}if((e|0)!=1349079131){break n}Td(h,d,c);c=kc(h+24|0,h);xb(h);d=0;v[22656]=0;e=ji(f,2);f=v[22656];v[22656]=0;if((f|0)==1){break i}if(Nb(e)){while(1){v[22656]=0;f=T(307,c|0)|0;g=v[22656];v[22656]=0;if((g|0)==1){break i}s=Mb(e,d),z=f,u[s>>1]=z;d=d+1|0;if(Nb(e)>>>0>d>>>0){continue}break}}xb(c);g=1;break n}Y:{switch(e-1349079874|0){case 1:case 2:break n;case 3:break O;case 0:break P;default:break Y}}if((e|0)==1378758190){break s}if((e|0)!=1381183022|c>>>0>1){break n}if(!Pb(d,c)){break n}s=f,z=xd(d,c),t[s+24|0]=z;g=1;break n}if((e|0)<=1448226349){if((e|0)<=1447447622){if((e|0)==1447374382){break r}if((e|0)==1447383630){break x}if((e|0)!=1447385902){break n}Td(h,d,c);c=kc(h+24|0,h);xb(h);d=0;v[22656]=0;e=ji(f,0);f=v[22656];v[22656]=0;if((f|0)==1){break j}if(Nb(e)){while(1){v[22656]=0;f=T(309,c|0)|0;g=v[22656];v[22656]=0;if((g|0)==1){break j}s=Mb(e,d),z=f,t[s+2|0]=z;d=d+1|0;if(Nb(e)>>>0>d>>>0){continue}break}}xb(c);g=1;break n}if((e|0)<=1447842605){if((e|0)==1447447623){break u}if((e|0)!=1447839022|c>>>0>1){break n}if(!Pb(d,c)){break n}s=f,z=xd(d,c),t[s+62|0]=z;g=1;break n}if((e|0)==1447842606){break V}if((e|0)!=1448106798){break n}Td(h,d,c);c=kc(h+24|0,h);xb(h);d=0;v[22656]=0;e=ji(f,0);f=v[22656];v[22656]=0;if((f|0)==1){break g}if(Nb(e)){while(1){v[22656]=0;f=T(307,c|0)|0;g=v[22656];v[22656]=0;if((g|0)==1){break g}s=Mb(e,d),z=f,u[s>>1]=z;d=d+1|0;if(Nb(e)>>>0>d>>>0){continue}break}}xb(c);g=1;break n}if((e|0)<=1448297773){if((e|0)==1448226350){break C}if((e|0)==1448291886){break L}if((e|0)!=1448297006|c>>>0>1){break n}if(!Pb(d,c)){break n}s=f,z=xd(d,c),t[s+63|0]=z;g=1;break n}if((e|0)<=1718508333){if((e|0)==1448297774){break U}if((e|0)!=1682320942|c>>>0>1){break n}if(!Pb(d,c)){break n}s=f,z=xd(d,c),t[s+15|0]=z;g=1;break n}if((e|0)==1718508334){break D}if((e|0)!=1851469358|c>>>0>32){break n}Td(h,d,c);k=kc(h+24|0,h);xb(h);e=Kb(h);if(c){d=0;while(1){v[22656]=0;g=T(310,k|0)|0;o=v[22656];v[22656]=0;if((o|0)==1){break E}v[22656]=0;R(311,e|0,g|0);g=v[22656];v[22656]=0;if((g|0)==1){break E}d=d+1|0;if((c|0)!=(d|0)){continue}break}}v[22656]=0;Q(301,f+492|0,e|0)|0;c=v[22656];v[22656]=0;g=1;if((c|0)==1){break E}vb(e);xb(k);break n}if(c>>>0>4){break n}if(!Pb(d,c)){break n}s=f,z=rw(d,c),v[s+4>>2]=z;g=1;break n}if(c>>>0>4){break n}if(!Pb(d,c)){break n}s=f,z=rw(d,c),v[s+8>>2]=z;g=1;break n}if(c>>>0>1){break n}if(!Pb(d,c)){break n}s=f,z=xd(d,c),t[s+61|0]=z;g=1;break n}if(c>>>0>1){break n}if(!Pb(d,c)){break n}s=f- -64|0,z=xd(d,c),t[s|0]=z;g=1;break n}if(c>>>0>1){break n}if(!Pb(d,c)){break n}s=f,z=xd(d,c),t[s+81|0]=z;g=1;break n}if(c>>>0>1){break n}if(!Pb(d,c)){break n}s=f,z=xd(d,c),t[s+84|0]=z;g=1;break n}if(c>>>0>1){break n}if(!Pb(d,c)){break n}s=f,z=xd(d,c),t[s+101|0]=z;g=1;break n}if(c>>>0>1){break n}if(!Pb(d,c)){break n}s=f,z=xd(d,c),t[s+102|0]=z;g=1;break n}if(c>>>0>1){break n}if(!Pb(d,c)){break n}s=f,z=xd(d,c),t[s+103|0]=z;g=1;break n}if(c>>>0>1){break n}if(!Pb(d,c)){break n}s=f,z=xd(d,c),t[s+104|0]=z;g=1;break n}if(c>>>0>1){break n}if(!Pb(d,c)){break n}s=f,z=xd(d,c),t[s+17|0]=z;g=1;break n}if(c>>>0>1){break n}if(!Pb(d,c)){break n}s=f,z=xd(d,c),t[s+19|0]=z;g=1;break n}if(c>>>0>1){break n}if(!Pb(d,c)){break n}s=f,z=xd(d,c),t[s+20|0]=z;g=1;break n}if(c>>>0>1){break n}if(!Pb(d,c)){break n}s=f,z=xd(d,c),t[s+22|0]=z;g=1;break n}if(c>>>0>2){break n}if(!Pb(d,c)){break n}s=f,z=VE(d,c),u[s+28>>1]=z;g=1;break n}if(c>>>0>1){break n}if(!Pb(d,c)){break n}s=f,z=xd(d,c),t[s+30|0]=z;g=1;break n}if(c>>>0>1){break n}if(!Pb(d,c)){break n}s=f,z=UE(d,c),t[s+26|0]=z;g=1;break n}if(c>>>0>128){break n}e=f+108|0;Td(h,d,c);c=kc(h+24|0,h);xb(h);d=0;while(1){v[22656]=0;f=T(309,c|0)|0;g=v[22656];v[22656]=0;if((g|0)==1){break p}s=ic(e,d),z=f,t[s|0]=z;d=d+1|0;if(d>>>0<128){continue}break}xb(c);g=1;break n}d=P()|0;O()|0;xb(c);break f}d=P()|0;O()|0;vb(e);xb(k);break f}if(c>>>0>32){break n}Td(h,d,c);k=kc(h+24|0,h);xb(h);e=Kb(h);if(c){d=0;while(1){v[22656]=0;g=T(310,k|0)|0;o=v[22656];v[22656]=0;if((o|0)==1){break m}v[22656]=0;R(311,e|0,g|0);g=v[22656];v[22656]=0;if((g|0)==1){break m}d=d+1|0;if((c|0)!=(d|0)){continue}break}}v[22656]=0;Q(301,f+524|0,e|0)|0;c=v[22656];v[22656]=0;g=1;if((c|0)!=1){vb(e);xb(k);break n}break m}if(c>>>0>2){break n}if(!Pb(d,c)){break n}s=f,z=VE(d,c),u[s+12>>1]=z;g=1;break n}if(c>>>0>1){break n}if(!Pb(d,c)){break n}s=f,z=xd(d,c),t[s+25|0]=z;g=1;break n}if(c>>>0>1){break n}if(!Pb(d,c)){break n}s=f,z=xd(d,c),t[s+35|0]=z;g=1;break n}if(c>>>0>1){break n}if(!Pb(d,c)){break n}s=f,z=xd(d,c),t[s+105|0]=z;g=1;break n}if(c>>>0>1){break n}if(!Pb(d,c)){break n}s=f,z=xd(d,c),t[s+85|0]=z;g=1;break n}if(c>>>0>1){break n}if(!Pb(d,c)){break n}s=f,z=xd(d,c),t[s+65|0]=z;g=1;break n}if(c>>>0>1){break n}if(!Pb(d,c)){break n}s=f,z=xd(d,c),t[s+100|0]=z;g=1;break n}if(c>>>0>1){break n}if(!Pb(d,c)){break n}s=f,z=xd(d,c),t[s+80|0]=z;g=1;break n}if(c>>>0>1){break n}if(!Pb(d,c)){break n}s=f,z=xd(d,c),t[s+60|0]=z;g=1;break n}if(c>>>0>1){break n}if(!Pb(d,c)){break n}s=f,z=UE(d,c),t[s+33|0]=z;g=1;break n}g=1;c=xp(d,c);if(!vp(c)){break n}t[f+14|0]=c;break n}v[h+24>>2]=240;s=h,z=xp(d,c),v[s>>2]=z;kh(f+48|0,v[Fb(h+24|0,h)>>2]);g=1;break n}v[h+24>>2]=240;s=h,z=xp(d,c),v[s>>2]=z;kh(f+88|0,v[Fb(h+24|0,h)>>2]);g=1;break n}d=P()|0;O()|0;xb(c);break f}c=qw(d,c);d=v[f+40>>2];v[f+40>>2]=d-((d>>>0)%1e4|0)+(c>>>0)%1e4;g=1}gb=h+48|0;break e}d=P()|0;O()|0;vb(e);xb(k);break f}d=P()|0;O()|0;xb(c);break f}d=P()|0;O()|0;xb(c);break f}d=P()|0;O()|0;xb(c);break f}d=P()|0;O()|0;xb(c);break f}d=P()|0;O()|0;xb(c);break f}d=P()|0;O()|0;xb(c)}S(d|0);L()}if(!g){Rb(n,i);break d}if((An(13834)|0)==(q|0)){i=w[j+15|0];t[j+15|0]=0;t[j+100|0]=w[j+100|0]&224|(i>>>5&4|i>>>6&1);t[j+60|0]=i>>>1&2|(i<<1&4|(w[j+60|0]&240|i&1));t[j+80|0]=w[j+80|0]&240|(i>>>4&2|(i>>>2&4|i>>>3&1))}}}m=m+1|0;if(x[a+480192>>1]>=(m&65535)>>>0){continue}break}}if(Pb(b,6)){continue}break}}return p|0}function Mpa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,y=0,z=0,A=0,C=0,D=0;f=gb+-64|0;gb=f;vc(a);a:{b:{if(b>>>0<=2){b=f+56|0;C=b,D=Ae(a),t[C|0]=D;Rb(a,2);e=b|2;g=Og(a);t[e|0]=g;t[e+1|0]=g>>>8;b=b|4;e=sg(a);t[b|0]=e;t[b+1|0]=e>>>8;t[b+2|0]=e>>>16;t[b+3|0]=e>>>24;break b}Cr(a,f+56|0);if(b>>>0>5){break a}}t[f+56|1]=0}c:{m=d+484344|0;b=f+56|2;s=Md(w[b|0]|w[b+1|0]<<8,1,1024);l=nz(m,s,0);if((l|0)!=65535){g=Tf(_b(m,l),0);u[f>>1]=x[d+480188>>1]-1;u[f+40>>1]=w[f+56|0];y=x[Pc(f,f+40|0)>>1];e=y+1|0;if(x[d+480188>>1]>(e&65535)>>>0){b=e&65535;while(1){t[g+B(b,6)|0]=254;b=b+1|0;if(b>>>0<x[d+480188>>1]){continue}break}}t[c+13|0]=w[f+56|1]>>>4;b=w[c+12|0];t[f|0]=0;o=Pv(f+40|0,e,f);if(s){b=(b|0)!=0;while(1){d:{e:{f:{if(!w[lc(o,0)|0]){v[22656]=0;e=T(374,a|0)|0;g=v[22656];v[22656]=0;if((g|0)==1){break c}e=e<<24>>24;if((e|0)<0){v[22656]=0;g=T(374,a|0)|0;h=v[22656];v[22656]=0;if((h|0)==1){break c}C=lc(o,0),D=g,t[C|0]=D}t[f|0]=0;g:{e=e&63;if(!e){break g}v[22656]=0;j=T(374,a|0)|0;g=v[22656];v[22656]=0;if((g|0)==1){break c}t[f|0]=j;h:{i:{switch(e-1|0){case 0:t[c+12|0]=0;v[22656]=0;t[f+36|0]=1;b=df(f+36|0,f);e=v[22656];v[22656]=0;if((e|0)!=1){t[c+14|0]=w[b|0];t[c+15|0]=0;break h}break c;case 1:if(!j){break g}t[c+15|0]=j;t[c+12|0]=1;b=w[c+13|0];if(!b){break h}t[c+14|0]=B(B(b,j),15);break h;case 2:t[c+13|0]=j>>>4;if(j>>>0<16){break f}b=w[c+12|0];j=0;v[f+36>>2]=0;v[f+32>>2]=0;p=0;if(b){break e}break d;case 3:p=0;v[f+36>>2]=0;v[f+32>>2]=0;if(b&1){break e}break d;case 5:if(!j){break g}e=(w[c+12|0]?15:14)+c|0;b=w[e|0];t[e|0]=b>>>0<256-j>>>0?b+j|0:-1;break h;case 6:break i;default:break g}}if(!j){break g}e=(w[c+12|0]?15:14)+c|0;b=w[e|0];t[e|0]=b>>>0>j+1>>>0?b-j|0:1}j=0;v[f+36>>2]=0;v[f+32>>2]=0;break e}j=0;v[f+36>>2]=0;v[f+32>>2]=0;p=0;if(b&1){break e}break d}j=0;e=lc(o,0);t[e|0]=w[e|0]-1;v[f+36>>2]=0;v[f+32>>2]=0;p=0;if(!(b&1)){break d}break e}j=0;t[c+12|0]=0;v[f+36>>2]=0;v[f+32>>2]=0;p=0;if(b&1){break e}break d}b=w[c+13|0];e=w[c+12|0];if(e){p=0;if(!b){break d}}j:{if(e){v[f>>2]=1;e=w[c+15|0];v[22656]=0;v[f+28>>2]=B(b,e)<<1;b=Gf(f,f+28|0);e=v[22656];v[22656]=0;if((e|0)==1){break c}e=v[b>>2];break j}e=B(w[c+14|0],30)+30|0}b=255;k:{while(1){g=B(b,e);if(g-1536>>>0<10752){e=g;break k}g=b>>>0>1;b=b-1|0;if(g){continue}break}b=0}v[f+36>>2]=b;v[f+32>>2]=(e|0)/48;Zd(f+32|0,32,255);v[22656]=0;v[f>>2]=1;b=Gf(f,f+36|0);e=v[22656];v[22656]=0;if((e|0)!=1){t[c+16|0]=v[b>>2];p=1;break d}break c}b=_b(m,l);v[22656]=0;b=Yc(b,k,1);e=v[22656];v[22656]=0;if((e|0)==1){break c}if(y){z=k-1|0;h=1;q=1;while(1){l:{m:{n:{o:{if(!w[lc(o,h)|0]){v[22656]=0;i=T(374,a|0)|0;e=v[22656];v[22656]=0;if((e|0)==1){break c}if(i&128){v[22656]=0;e=T(374,a|0)|0;g=v[22656];v[22656]=0;if((g|0)==1){break c}C=lc(o,h),D=e,t[C|0]=D}A=1;if(i&64){v[22656]=0;e=T(374,a|0)|0;g=v[22656];v[22656]=0;if((g|0)==1){break c}t[b+1|0]=e;A=!e}if(!(i&32)){e=w[b|0];break o}v[22656]=0;e=T(374,a|0)|0;g=v[22656];v[22656]=0;if((g|0)==1){break c}t[b|0]=e;if((e-1&255)>>>0<=107){e=on(e+24|0);t[b|0]=e;C=ad(c,h),D=e,t[C+1|0]=D;break o}if((e+127&255)>>>0<=107){e=on((e&127)+24|0);t[b|0]=e;C=ad(c,h),D=e,t[C|0]=D;t[b|0]=0;break n}if((e|0)!=255){break o}t[b|0]=254;break m}e=lc(o,h);t[e|0]=w[e|0]-1;break l}if(e&255){break m}}if(!w[b+1|0]){break m}e=w[ad(c,h)+1|0];t[b+1|0]=0;t[b|0]=e}v[22656]=0;e=Rd(b);g=v[22656];v[22656]=0;if((g|0)==1){break c}if(e){C=ad(c,h),D=0,t[C+5|0]=D}t[f+28|0]=0;t[f+27|0]=0;t[f+26|0]=0;t[f+25|0]=0;t[f+24|0]=0;t[f+23|0]=0;if(i&16){t[b+2|0]=1;v[22656]=0;e=T(374,a|0)|0;g=v[22656];v[22656]=0;if((g|0)==1){break c}t[b+4|0]=e+2>>>2}p:{if(!(i&8)){break p}v[22656]=0;e=T(374,a|0)|0;g=v[22656];v[22656]=0;if((g|0)==1){break c}v[22656]=0;t[f+28|0]=e;e=T(374,a|0)|0;g=v[22656];v[22656]=0;if((g|0)==1){break c}t[f+25|0]=e;q:{r:{s:{t:{u:{v:{w:{x:{g=w[f+28|0];switch(g-1|0){case 0:break r;case 9:break s;case 5:case 6:case 7:case 8:break t;case 4:break u;case 3:break v;case 2:break w;case 1:break x;default:break q}}t[b|0]=255;break q}C=b,D=w[ad(c,h)+1|0],t[C|0]=D;C=ad(c,h),D=0,t[C+5|0]=D;break q}e=Ov(e,w[c+16|0]);t[f+25|0]=e;y:{if(e){t[f+28|0]=20;t[f+25|0]=e|208;break y}t[f+28|0]=0}if(w[b|0]){break p}C=b,D=w[ad(c,h)+1|0],t[C|0]=D;C=ad(c,h),D=0,t[C+5|0]=D;break p}t[f|0]=1;e=Ov(e,w[c+16|0]);v[22656]=0;t[f+22|0]=e;e=df(f,f+22|0);g=v[22656];v[22656]=0;if((g|0)!=1){t[f+25|0]=w[e|0];t[f+28|0]=15;C=ad(c,h),D=0,t[C+5|0]=D;break p}break c}z:{if(!k){break z}if((g|0)==w[ad(c,h)+4|0]){break z}e=_b(m,l);v[22656]=0;g=Be(f,20,(w[f+28|0]+122|160)&255);n=v[22656];v[22656]=0;if((n|0)==1){break c}g=qp(pp(Ue(g,z),q&65535));v[22656]=0;e=Q(431,e|0,g|0)|0;g=v[22656];v[22656]=0;if((g|0)==1){break c}if(!e){break z}C=ad(c,h),D=w[f+28|0],t[C+4|0]=D}t[f+28|0]=10;if(!w[b|0]){C=b,D=w[ad(c,h)+1|0],t[C|0]=D}C=ad(c,h),D=0,t[C+5|0]=D;break p}t[f+28|0]=20;C=f,D=w[ad(c,h)+5|0]?-98:-97,t[C+25|0]=D;e=ad(c,h);t[e+5|0]=w[e+5|0]^1;break p}t[b|0]=254}t[f+28|0]=0}n=0;e=0;A:{if(!(i&4)){break A}v[22656]=0;e=T(374,a|0)|0;g=v[22656];v[22656]=0;if((g|0)==1){break c}v[22656]=0;t[f+27|0]=e;e=T(374,a|0)|0;g=v[22656];v[22656]=0;if((g|0)==1){break c}t[f+24|0]=e;g=f;B:{C:{D:{E:{F:{G:{H:{I:{J:{K:{L:{r=w[f+27|0];switch(r-1|0){case 11:break D;case 10:break E;case 7:case 8:case 9:break F;case 6:break G;case 5:break H;case 3:case 4:break I;case 2:break J;case 1:break K;case 0:break L;default:break C}}v[22656]=0;mt(f,e<<24>>24<<3,128);e=v[22656];v[22656]=0;if((e|0)==1){break c}v[22656]=0;e=Rd(b);g=v[22656];v[22656]=0;if((g|0)==1){break c}if(e){C=b,D=on(v[f>>2]+w[b|0]|0),t[C|0]=D}t[f+27|0]=35;t[f+24|0]=w[f+4|0]^128;e=0;break A}e=Ov(e,w[c+16|0]);t[f+24|0]=e;if(e){t[f+27|0]=20;t[f+24|0]=e|208;e=1;break A}t[f+27|0]=0;e=1;break A}e=1;break B}g=w[c+16|0];v[22656]=0;e=uD(e,g,1);g=v[22656];v[22656]=0;if((g|0)==1){break c}t[f+24|0]=e;t[f+27|0]=w[f+27|0]==4?2:3;e=1;break A}if(!w[b|0]){C=b,D=w[ad(c,h)|0],t[C|0]=D;e=w[f+24|0]}g=w[c+16|0];v[22656]=0;e=uD(e&255,g,0);g=v[22656];v[22656]=0;if((g|0)==1){break c}t[f+27|0]=4;t[f+24|0]=e;e=1;break A}C=b,D=on(e+25|0),t[C|0]=D;t[f+24|0]=255;t[f+27|0]=4;e=1;break A}M:{if(!k){break M}if((r|0)==w[ad(c,h)+2|0]){break M}e=_b(m,l);v[22656]=0;g=Be(f,20,(w[f+27|0]-8|48)&255);r=v[22656];v[22656]=0;if((r|0)==1){break c}g=qp(pp(Ue(g,z),q&65535));v[22656]=0;e=Q(431,e|0,g|0)|0;g=v[22656];v[22656]=0;if((g|0)==1){break c}if(!e){break M}C=ad(c,h),D=w[f+27|0],t[C+2|0]=D}t[f+27|0]=5;e=w[c+16|0];v[22656]=0;e=Nv(w[f+24|0],e);g=v[22656];v[22656]=0;if((g|0)==1){break c}t[f+24|0]=e;e=1;break A}e=qY(e,w[c+16|0]);t[f+27|0]=18;t[f+24|0]=e;e=1;break A}e=Ov(e,w[c+16|0]);t[f+24|0]=e;if(e){t[f+27|0]=20;t[f+24|0]=e|192;e=1;break A}t[f+27|0]=0;t[b|0]=254;e=1;break A}e=0}t[g+27|0]=e}N:{if(!(i&2)){break N}v[22656]=0;g=T(374,a|0)|0;i=v[22656];v[22656]=0;if((i|0)==1){break c}v[22656]=0;t[f+26|0]=g;g=T(374,a|0)|0;i=v[22656];v[22656]=0;if((i|0)==1){break c}t[f+23|0]=g;O:{P:{Q:{R:{S:{T:{U:{i=w[f+26|0];switch(i-1|0){case 9:break P;case 7:case 8:break Q;case 6:break R;case 3:case 4:case 5:break S;case 2:break T;case 0:case 1:break U;default:break O}}h=w[c+16|0];v[22656]=0;g=tD(g,h,(i|0)==1);h=v[22656];v[22656]=0;if((h|0)==1){break c}t[f+26|0]=11;t[f+23|0]=g;n=1;break N}g=qY(g,w[c+16|0]);t[f+26|0]=18;t[f+23|0]=g;n=1;break N}V:{if(!k){break V}if((i|0)==w[ad(c,h)+3|0]){break V}g=_b(m,l);v[22656]=0;i=Be(f,20,(w[f+26|0]-4|64)&255);n=v[22656];v[22656]=0;if((n|0)==1){break c}i=qp(pp(Ue(i,z),q&65535));v[22656]=0;g=Q(431,g|0,i|0)|0;i=v[22656];v[22656]=0;if((i|0)==1){break c}if(!g){break V}C=ad(c,h),D=w[f+26|0],t[C+3|0]=D}t[f+26|0]=8;g=w[c+16|0];v[22656]=0;g=Nv(w[f+23|0],g);h=v[22656];v[22656]=0;if((h|0)==1){break c}t[f+23|0]=g;n=1;break N}t[f+26|0]=9;break N}h=w[c+16|0];v[22656]=0;g=tD(g,h,(i|0)==8);h=v[22656];v[22656]=0;if((h|0)==1){break c}t[f+26|0]=29;t[f+23|0]=g;n=1;break N}t[f+26|0]=27;h=w[c+16|0];v[22656]=0;g=Nv(g,h);h=v[22656];v[22656]=0;if((h|0)==1){break c}t[f+23|0]=g;n=1;break N}t[f+26|0]=0}if(e){pY(b,k,x[d+480188>>1],w[f+27|0],f+24|0)}if(n){pY(b,k,x[d+480188>>1],w[f+26|0],f+23|0)}W:{if(!A){break W}v[22656]=0;e=Rd(b);g=v[22656];v[22656]=0;if((g|0)==1){break c}if(!e){break W}e=w[f+27|0];if(!e){t[f+24|0]=255;t[f+27|0]=4;break W}if(w[f+26|0]|(e|0)==4){break W}t[f+23|0]=255;t[f+26|0]=4}X:{if(w[b+2|0]!=1){break X}Y:{if(!w[f+27|0]){t[f+27|0]=13;t[f+24|0]=w[b+4|0];break Y}if(w[f+26|0]){break X}t[f+26|0]=13;t[f+23|0]=w[b+4|0]}t[b+2|0]=0}v[22656]=0;vo(f,f+27|0,f+24|0,f+26|0,f+23|0);e=v[22656];v[22656]=0;if((e|0)==1){break c}Z:{if(w[b+2|0]){break Z}e=w[f+27|0];if(!e){break Z}t[b+2|0]=e;t[b+4|0]=w[f+24|0]}_:{if(w[f+28|0]){v[22656]=0;vo(f,f+26|0,f+23|0,f+28|0,f+25|0);e=v[22656];v[22656]=0;if((e|0)==1){break c}$:{if(w[b+2|0]){break $}e=w[f+26|0];if(!e){break $}t[b+2|0]=e;t[b+4|0]=w[f+23|0]}h=f+25|0;e=w[f+28|0];break _}h=f+23|0;e=w[f+26|0];if(!e){break l}}t[b+3|0]=e;t[b+5|0]=w[h|0]}b=b+6|0;q=q+1|0;h=q&65535;if(y>>>0>=h>>>0){continue}break}}aa:{if(!p){break aa}b=_b(m,l);v[22656]=0;e=Be(f,17,w[f+32|0]);g=v[22656];v[22656]=0;if((g|0)==1){break c}e=Fh(pp(Ue(e,k),0));v[22656]=0;Q(431,b|0,e|0)|0;b=v[22656];v[22656]=0;if((b|0)==1){break c}b=_b(m,l);v[22656]=0;e=Be(f,16,w[f+36|0]);g=v[22656];v[22656]=0;if((g|0)!=1){e=Fh(Ue(e,k));v[22656]=0;Q(431,b|0,e|0)|0;b=v[22656];v[22656]=0;if((b|0)!=1){break aa}}break c}ba:{if(!(j&240)){break ba}b=_b(m,l);v[22656]=0;e=Be(f,20,j>>>4|224);g=v[22656];v[22656]=0;if((g|0)!=1){e=oY(Ue(e,k));v[22656]=0;Q(431,b|0,e|0)|0;b=v[22656];v[22656]=0;if((b|0)!=1){break ba}}break c}ca:{b=j&15;if(!b){break ca}e=w[c+16|0];g=_b(m,l);b=Md((B(b,e)>>>0)/15&255,1,15);v[22656]=0;b=Be(f,20,b|96);e=v[22656];v[22656]=0;if((e|0)!=1){b=oY(Ue(b,k));v[22656]=0;Q(431,g|0,b|0)|0;b=v[22656];v[22656]=0;if((b|0)!=1){break ca}}break c}b=0;k=k+1|0;if((s|0)!=(k|0)){continue}break}}gc(o)}gb=f- -64|0;return l|0}a=P()|0;O()|0;gc(o);S(a|0);L()}function cfa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;d=gb-784|0;gb=d;vc(b);a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{t:{u:{v:{w:{x:{y:{z:{A:{B:{C:{D:{E:{F:{G:{H:{I:{J:{K:{if(!Ih(b,d+776|0)){break K}if(!PN(d+776|0)){break K}if(!BC(b,d+768|0)){break K}if(!ON(d+768|0)){break K}e=1313423693;i=w[d+768|0]|w[d+769|0]<<8|(w[d+770|0]<<16|w[d+771|0]<<24);if((i|0)!=1179012417){e=1414090313;if((i|0)!=538987841){break K}}l=le(d+744|0,b);j=hh(d+728|0);L:{if(!c){v[22656]=0;Y(1451,d+144|0,l|0,((i|0)==1179012417?1:2)|0,e|0);b=v[22656];v[22656]=0;if((b|0)!=1){break L}b=P()|0;O()|0;break a}v[22656]=0;U(1452,d+144|0,l|0,((i|0)==1179012417?1:2)|0);b=v[22656];v[22656]=0;if((b|0)==1){break v}}b=d+144|0;OU(j,b);ke(b);v[22656]=0;U(1453,d+704|0,j|0,e|0);b=v[22656];v[22656]=0;if((b|0)==1){break w}v[22656]=0;b=T(275,d+704|0)|0;e=v[22656];v[22656]=0;if((e|0)==1){break u}M:{if(!b){break M}v[22656]=0;b=Q(1454,d+704|0,d+624|0)|0;e=v[22656];v[22656]=0;if((e|0)==1){break u}if(!b|!w[d+689|0]){break M}b=w[d+689|0];v[22656]=0;g=Q(191,d+704|0,b|0)|0;b=v[22656];v[22656]=0;if((b|0)==1){break u}if(!g|!c){break M}v[22656]=0;R(367,a|0,8388608);b=v[22656];v[22656]=0;if((b|0)==1){break u}v[a+480208>>2]=12;v[a+480208>>2]=v[a+480208>>2]&-17|(w[d+688|0]<<4^-1)&16;u[d+144>>1]=w[d+689|0];v[22656]=0;u[d+512>>1]=127;b=Pc(d+144|0,d+512|0);e=v[22656];v[22656]=0;if((e|0)==1){break c}u[a+480188>>1]=x[b>>1];v[a+480196>>2]=w[d+690|0];v[a+480204>>2]=B(w[d+691|0],1e4);v[a+480200>>2]=w[d+696|0]<<1;v[22656]=0;Q(157,a+1298304|0,((i|0)==1179012417?14044:14010)|0)|0;b=v[22656];v[22656]=0;if((b|0)==1){break u}v[22656]=0;b=Q(2,d+144|0,10603)|0;e=v[22656];v[22656]=0;if((e|0)==1){break d}Eb(a+1298316|0,b);vb(b);v[a+1298364>>2]=5;v[22656]=0;Gr(d+512|0,2,d+624|0);b=v[22656];v[22656]=0;if((b|0)==1){break e}v[22656]=0;R(324,d+144|0,d+512|0);b=v[22656];v[22656]=0;if((b|0)==1){break e}b=d+144|0;Eb(a+1298268|0,b);vb(b);if(x[a+480188>>1]){b=0;h=(i|0)==1179012417;while(1){v[22656]=0;g=(b<<5)+a|0;f=g+480280|0;We(f);e=v[22656];v[22656]=0;N:{O:{P:{Q:{R:{if((e|0)!=1){v[22656]=0;e=T(374,d+704|0)|0;k=v[22656];v[22656]=0;if((k|0)==1){break R}if(h){break Q}if(e>>>0<129){break P}break O}b=P()|0;O()|0;break b}b=P()|0;O()|0;break b}if(e<<24>>24<0){break O}v[d+144>>2]=e<<2;v[22656]=0;v[d+512>>2]=256;e=pd(d+144|0,d+512|0);f=v[22656];v[22656]=0;if((f|0)!=1){u[g+480284>>1]=v[e>>2];break N}b=P()|0;O()|0;break b}u[g+480284>>1]=e<<1;break N}v[f>>2]=1024}b=b+1|0;if(b>>>0<x[a+480188>>1]){continue}break}}g=gb-16|0;gb=g;e=Vb(j);h=Zb(j);b=gb-32|0;gb=b;v[b+16>>2]=h;v[b+24>>2]=e;v[b+8>>2]=1380209231;if(Gb(b+24|0,b+16|0)){while(1){if(!pD(b+8|0,v[b+24>>2])){e=b+24|0;pn(e);if(Gb(e,b+16|0)){continue}}break}e=v[b+24>>2]}gb=b+32|0;v[g+8>>2]=e;m=g,n=Zb(j),v[m>>2]=n;b=Gb(g+8|0,g);gb=g+16|0;if(b){v[22656]=0;U(1453,d+144|0,j|0,1380209231);b=v[22656];v[22656]=0;if((b|0)==1){break f}v[22656]=0;b=T(374,d+144|0)|0;e=v[22656];v[22656]=0;if((e|0)==1){break g}e=Sb(a+484360|0);v[22656]=0;fa(522,e|0,d+144|0,b+1&255,255,254)|0;b=v[22656];v[22656]=0;if((b|0)==1){break g}xb(d+144|0)}if(c&1){u[d+496>>1]=0;v[22656]=0;U(1456,d+576|0,j|0,1414807888);b=v[22656];v[22656]=0;if((b|0)==1){break h}b=Je(d+576|0);v[22656]=0;e=a+484344|0;R(330,e|0,b&65535);b=v[22656];v[22656]=0;if((b|0)==1){break o}b=d+576|0;m=d,n=Vb(b),v[m+88>>2]=n;m=d,n=Zb(b),v[m+56>>2]=n;if(Gb(d+88|0,d+56|0)){g=(i|0)!=1179012417;while(1){b=le(d+144|0,v[d+88>>2]);v[22656]=0;h=T(374,b|0)|0;f=v[22656];v[22656]=0;if((f|0)==1){break k}v[22656]=0;u[d+128>>1]=h;b=T(192,b|0)|0;h=v[22656];v[22656]=0;if((h|0)==1){break l}v[22656]=0;U(288,d+512|0,d+144|0,b|0);b=v[22656];v[22656]=0;if((b|0)==1){break m}b=kc(d+600|0,d+512|0);v[22656]=0;h=v[b+12>>2];v[d+8>>2]=v[b+8>>2];v[d+12>>2]=h;v[d+16>>2]=v[b+16>>2];h=v[b+4>>2];v[d>>2]=v[b>>2];v[d+4>>2]=h;Y(1457,d|0,x[d+128>>1],g|0,a|0);b=v[22656];v[22656]=0;if((b|0)==1){break n}xb(d+512|0);v[22656]=0;b=Le(d+496|0,d+128|0);h=v[22656];v[22656]=0;if((h|0)==1){break l}u[d+496>>1]=x[b>>1];xb(d+144|0);b=d+88|0;Eh(b);if(Gb(b,d+56|0)){continue}break}}if(x[d+496>>1]){b=0;while(1){v[22656]=0;g=b&65535;h=me(e,g);f=v[22656];v[22656]=0;S:{if((f|0)!=1){if(h){break S}v[22656]=0;W(331,e|0,g|0,64)|0;g=v[22656];v[22656]=0;if((g|0)!=1){break S}}b=P()|0;O()|0;break i}b=b+1|0;if(x[d+496>>1]>(b&65535)>>>0){continue}break}}jd(d+576|0)}T:{if((i|0)==1179012417){v[22656]=0;U(1456,d+88|0,j|0,1414745673);b=v[22656];v[22656]=0;if((b|0)==1){break I}b=d+88|0;m=d,n=Vb(b),v[m+128>>2]=n;m=d,n=Zb(b),v[m+40>>2]=n;U:{if(Gb(d+128|0,d+40|0)){i=c&2;g=d+520|0;h=d+144|1;while(1){c=le(d+576|0,v[d+128>>2]);v[22656]=0;b=Q(1458,c|0,d+144|0)|0;e=v[22656];v[22656]=0;if((e|0)==1){break U}V:{if(!b){break V}b=w[h|0];if((b|0)==255){break V}v[22656]=0;b=W(376,a|0,b+1|0,0)|0;e=v[22656];v[22656]=0;if((e|0)==1){break H}if(!b){break V}e=x[a+480190>>1];v[22656]=0;U(1459,d+144|0,b|0,e|0);b=v[22656];v[22656]=0;if((b|0)==1){break H}b=0;if(!w[d+174|0]){break V}while(1){W:{if(!ei(a)){break W}v[22656]=0;e=Q(1460,c|0,d+512|0)|0;f=v[22656];v[22656]=0;if((f|0)==1){break G}if(!e){break W}e=x[a+480190>>1]+1|0;u[a+480190>>1]=e;if((w[d+512|0]|w[d+513|0]<<8|(w[d+514|0]<<16|w[d+515|0]<<24))!=1347240275){break W}v[22656]=0;Nk(d+496|0,2,g);f=v[22656];v[22656]=0;X:{Y:{Z:{if((f|0)==1){break Z}v[22656]=0;R(324,d+56|0,d+496|0);f=v[22656];v[22656]=0;if((f|0)==1){break Z}v[22656]=0;e=e&65535;Q(301,((e<<5)+a|0)+946304|0,d+56|0)|0;f=v[22656];v[22656]=0;if((f|0)==1){break Y}vb(d+56|0);v[22656]=0;e=(B(e,104)+a|0)+484380|0;U(1461,d+512|0,d+144|0,e|0);f=v[22656];v[22656]=0;if((f|0)==1){break q}if(!i){break X}f=d+56|0;k=d+550|0;Rc(f,(w[k|0]|w[k+1|0]<<8)&4?16:8,1,0,0);v[22656]=0;W(329,f|0,e|0,c|0)|0;e=v[22656];v[22656]=0;if((e|0)!=1){break W}b=P()|0;O()|0;break p}b=P()|0;O()|0;break p}b=P()|0;O()|0;vb(d+56|0);break p}e=aj(e);v[22656]=0;Q(318,d+576|0,e|0)|0;e=v[22656];v[22656]=0;if((e|0)==1){break q}}b=b+1|0;if(b>>>0<w[d+174|0]){continue}break}}xb(d+576|0);b=d+128|0;Eh(b);if(Gb(b,d+40|0)){continue}break}}jd(d+88|0);break T}b=P()|0;O()|0;break p}v[22656]=0;U(1456,d+496|0,j|0,1179011410);b=v[22656];v[22656]=0;if((b|0)==1){break F}b=d+496|0;m=d,n=Vb(b),v[m+488>>2]=n;m=d,n=Zb(b),v[m+480>>2]=n;if(Gb(d+488|0,d+480|0)){i=c&2;g=d+512|4;b=d+80|4;h=d+144|5;while(1){c=le(d+576|0,v[d+488>>2]);v[22656]=0;e=T(192,c|0)|0;f=v[22656];v[22656]=0;if((f|0)==1){break E}_:{if((e|0)!=538986817){break _}v[22656]=0;e=Q(1462,c|0,d+472|0)|0;f=v[22656];v[22656]=0;if((f|0)==1){break D}if(!e|(w[d+472|0]|w[d+473|0]<<8|(w[d+474|0]<<16|w[d+475|0]<<24))!=1414745673){break _}v[22656]=0;e=Q(1463,c|0,d+144|0)|0;f=v[22656];v[22656]=0;if((f|0)==1){break C}if(!e){break _}e=w[h|0];if((e|0)==255){break _}v[22656]=0;e=W(376,a|0,e+1|0,0)|0;f=v[22656];v[22656]=0;if((f|0)==1){break B}if(!e){break _}f=x[a+480190>>1];v[22656]=0;U(1464,d+144|0,e|0,f|0);e=v[22656];v[22656]=0;if((e|0)==1){break B}v[22656]=0;U(1452,d+512|0,c|0,2);c=v[22656];v[22656]=0;if((c|0)==1){break J}v[22656]=0;U(1456,d+128|0,d+512|0,1179011410);c=v[22656];v[22656]=0;if((c|0)==1){break A}ke(d+512|0);c=d+128|0;m=d,n=Vb(c),v[m+120>>2]=n;m=d,n=Zb(c),v[m+112>>2]=n;$:{if(!Gb(d+120|0,d+112|0)){break $}aa:{while(1){c=le(d+88|0,v[d+120>>2]);v[22656]=0;e=T(192,c|0)|0;f=v[22656];v[22656]=0;if((f|0)==1){break z}ba:{ca:{if((e|0)!=538989377){break ca}if(!ei(a)){break ca}e=w[d+468|0]|w[d+469|0]<<8;f=e-1|0;t[d+468|0]=f;t[d+469|0]=f>>>8;if(!e){xb(d+88|0);break $}f=x[a+480190>>1]+1|0;u[a+480190>>1]=f;v[22656]=0;c=Q(1462,c|0,d+80|0)|0;e=v[22656];v[22656]=0;if((e|0)==1){break y}if(!c|(w[d+80|0]|w[d+81|0]<<8|(w[d+82|0]<<16|w[d+83|0]<<24))!=1347240275){break aa}c=w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24);v[22656]=0;U(288,d+512|0,d+88|0,c|0);c=v[22656];v[22656]=0;da:{ea:{if((c|0)!=1){c=d+512|0;e=kc(d+56|0,c);xb(c);v[22656]=0;c=Q(1465,e|0,c|0)|0;k=v[22656];v[22656]=0;if((k|0)==1){break ba}if(!c){break da}v[22656]=0;Ke(d+24|0,2,g);c=v[22656];v[22656]=0;if((c|0)!=1){v[22656]=0;R(324,d+40|0,d+24|0);c=v[22656];v[22656]=0;if((c|0)!=1){break ea}}b=P()|0;O()|0;break t}b=P()|0;O()|0;break s}v[22656]=0;c=f&65535;Q(301,((c<<5)+a|0)+946304|0,d+40|0)|0;f=v[22656];v[22656]=0;if((f|0)==1){break x}vb(d+40|0);v[22656]=0;c=(B(c,104)+a|0)+484380|0;U(1466,d+512|0,d+144|0,c|0);f=v[22656];v[22656]=0;if((f|0)==1){break ba}fa:{if(!i){break fa}f=w[d+512|0]|w[d+513|0]<<8|(w[d+514|0]<<16|w[d+515|0]<<24);v[22656]=0;Q(190,d+56|0,f+4|0)|0;f=v[22656];v[22656]=0;if((f|0)==1){break ba}f=d+40|0;k=d+552|0;Rc(f,(w[k|0]|w[k+1|0]<<8)&4?16:8,1,0,0);v[22656]=0;W(329,f|0,c|0,e|0)|0;c=v[22656];v[22656]=0;if((c|0)!=1){break fa}b=P()|0;O()|0;break t}xb(d+56|0);break ca}xb(d+56|0);xb(d+88|0);break $}xb(d+88|0);c=d+120|0;Eh(c);if(Gb(c,d+112|0)){continue}break $}break}b=P()|0;O()|0;break t}xb(d+88|0)}jd(d+128|0)}xb(d+576|0);c=d+488|0;Eh(c);if(Gb(c,d+480|0)){continue}break}}jd(d+496|0)}g=1}xb(d+704|0);ke(j);xb(l)}gb=d+784|0;return g|0}b=P()|0;O()|0;break r}b=P()|0;O()|0;break b}b=P()|0;O()|0;break p}b=P()|0;O()|0;break p}b=P()|0;O()|0;break b}b=P()|0;O()|0;break r}b=P()|0;O()|0;break r}b=P()|0;O()|0;break r}b=P()|0;O()|0;break r}b=P()|0;O()|0;ke(d+512|0);break r}b=P()|0;O()|0;break s}b=P()|0;O()|0;break s}b=P()|0;O()|0;vb(d+40|0);break t}b=P()|0;O()|0;break a}b=P()|0;O()|0;break a}b=P()|0;O()|0;break b}xb(d+56|0)}xb(d+88|0);jd(d+128|0)}xb(d+576|0);jd(d+496|0);break b}b=P()|0;O()|0}xb(d+576|0);jd(d+88|0);break b}b=P()|0;O()|0;break i}b=P()|0;O()|0;xb(d+512|0);break j}b=P()|0;O()|0;break j}b=P()|0;O()|0;break j}b=P()|0;O()|0}xb(d+144|0)}jd(d+576|0);break b}b=P()|0;O()|0;break b}b=P()|0;O()|0;xb(d+144|0);break b}b=P()|0;O()|0;break b}b=P()|0;O()|0;break b}b=P()|0;O()|0;break b}b=P()|0;O()|0}xb(d+704|0)}ke(j);xb(l);S(b|0);L()}function Gka(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,z=0,A=0;i=gb-240|0;gb=i;a:{if(!Tu(a)){e=i+80|0;hc(e,a,128);f=i+208|0;pf(f,e,128,2);e=i+224|0;Bc(e,f);v[22656]=0;Q(301,b+492|0,e|0)|0;e=v[22656];v[22656]=0;if((e|0)==1){break a}vb(i+224|0)}u[c+34>>1]=x[c+34>>1]&65489;o=i+224|0;m=o;e=c;h=gb-48|0;gb=h;f=a;b:{if(!(w[f+128|0]==4|w[f+128|0]==8)){v[h+44>>2]=0;v[h+40>>2]=0;break b}t[h+40|0]=w[f+129|0];t[h+36|0]=100;n=h+36|0;g=w[ac(h+40|0,n)|0];v[h+44>>2]=g;t[h+36|0]=w[f+130|0];t[h+32|0]=100;n=w[ac(n,h+32|0)|0];v[h+40>>2]=n;c:{if(w[f+140|0]&16){k=Ib(w[f+150|0]|w[f+151|0]<<8);f=Ib(w[f+152|0]|w[f+153|0]<<8);s=+y[e>>2]/6553600;g=hr(s*+((k|g<<16)>>>0));v[h+44>>2]=g;v[h+36>>2]=v[e>>2]-g;z=h,A=hr(s*+((f|n<<16)>>>0)),v[z+32>>2]=A;z=h,A=v[Fb(h+36|0,h+32|0)>>2],v[z+40>>2]=A;break c}if(!Jd(e)){break c}f=v[e>>2];k=f>>>7|0;g=B(k,(g<<7>>>0)/100|0);v[h+44>>2]=g;v[h+36>>2]=f-g;v[h+32>>2]=B(k,(n<<7>>>0)/100|0);f=v[Fb(h+36|0,h+32|0)>>2];n=h;d:{if(t[e+34|0]&1){kn(h+24|0,v[e+20>>2],B(v[e>>2],fd(e)));k=fd(e);e=v[h+28>>2];v[h+8>>2]=v[h+24>>2];v[h+12>>2]=e;e=v[h+8>>2];e:{if(f){p=u[e+(B(g,k)<<1)>>1];e=e+(B(k,f+g|0)<<1)|0;r=0-k<<1;while(1){g=u[e>>1]-p|0;k=g>>31;q=f;if((k^g+k)>>>0<1536){break e}e=e+r|0;f=f-1|0;if(f){continue}break}}q=0}break d}bc(h+16|0,v[e+20>>2],B(v[e>>2],fd(e)));e=fd(e);k=v[h+20>>2];v[h>>2]=v[h+16>>2];v[h+4>>2]=k;k=v[h>>2];f:{if(f){p=0-e|0;r=t[k+B(e,g)|0];e=k+B(e,f+g|0)|0;while(1){g=t[e|0]-r|0;k=g>>31;q=f;if((k^g+k)>>>0<6){break f}e=e+p|0;f=f-1|0;if(f){continue}break}}q=0}}v[n+40>>2]=q}}v[m>>2]=v[h+44>>2];v[m+4>>2]=v[h+40>>2];gb=h+48|0;e=128;n=fc(o);if(!(!v[n>>2]|w[a+128|0]!=4)){u[c+34>>1]=x[c+34>>1]|2;v[c+4>>2]=v[o>>2];v[c+8>>2]=v[n>>2]+v[o>>2]}f=i;if(!(!w[a+134|0]|w[a+134|0]>199)){t[i+80|0]=w[a+134|0];t[i+208|0]=100;e=(w[ac(i+80|0,i+208|0)|0]<<7>>>0)/100|0}t[f+79|0]=e;t[i+80|0]=64;e=i+79|0;f=i+80|0;z=c,A=w[df(e,f)|0]>>>1|0,u[z+32>>1]=A;t[i+80|0]=64;z=b,A=w[ac(e,f)|0],v[z+4>>2]=A;v[c+24>>2]=40460;Qo(c,+t[a+139|0]/12+ +(0-w[a+143|0]|0)+ +t[a+138|0]/1536);t[b+34|0]=w[a+142|0]&2?2:1;if(w[a+142|0]&2){hm(b,127,1);gm(b,0,1)}g:{if(!Jd(c)){break g}if(t[a+140|0]&1){f=d;b=c;h:{if(!Jd(b)){break h}e=v[b>>2];if(e>>>0<2){break h}i:{if((jj(b)|0)==4){h=v[b+20>>2];g=0;k=e>>>1|0;while(1){xc(h+(g<<2)|0,h+((g^-1)+e<<2)|0);g=g+1|0;if((k|0)!=(g|0)){continue}break}break i}if((jj(b)|0)==2){h=v[b+20>>2];g=0;k=e>>>1|0;while(1){Rz(h+(g<<1)|0,h+((g^-1)+e<<1)|0);g=g+1|0;if((k|0)!=(g|0)){continue}break}break i}if((jj(b)|0)!=1){break h}h=v[b+20>>2];g=0;k=e>>>1|0;while(1){m=h+g|0;p=w[m|0];q=m;m=h+((g^-1)+e|0)|0;t[q|0]=w[m|0];t[m|0]=p;g=g+1|0;if((k|0)!=(g|0)){continue}break}}_h(b,f,0)}}if(w[a+140|0]&4){f=d;b=c;j:{if(!Jd(b)){break j}e=v[b>>2];fd(b);g=0;h=B(fd(b),e);k:{if((ij(b)|0)==2){k=v[b+20>>2]+(g<<1)|0;e=0;g=h-g|0;if(g){while(1){h=k+(e<<1)|0;u[h>>1]=x[h>>1]^-1;e=e+1|0;if((g|0)!=(e|0)){continue}break}}break k}if((ij(b)|0)!=1){break j}k=g+v[b+20>>2]|0;e=0;g=h-g|0;if(g){while(1){h=e+k|0;t[h|0]=w[h|0]^-1;e=e+1|0;if((g|0)!=(e|0)){continue}break}}}_h(b,f,0)}}l=w[a+170|0]!=2|w[a+171|0]>100?l:w[a+172|0]<101;if(!(!(w[a+141|0]?1:l|w[a+160|0]!=0)|t[c+34|0]&1)){e=Sq(v[c>>2],fd(c)<<1);if(!e){break g}b=e;h=B(v[c>>2],fd(c));f=v[c+20>>2];k=aj(c);g=gb-16|0;gb=g;v[g+12>>2]=h;qc(g+12|0,k);h=v[g+12>>2];if(h){while(1){u[b>>1]=t[f|0]<<8;f=f+1|0;b=b+2|0;h=h-1|0;if(h){continue}break}v[g+12>>2]=-1}gb=g+16|0;u[c+34>>1]=x[c+34>>1]|1;LN(c,e,v[c>>2],d)}l:{if(t[a+141|0]>=0){break l}kn(i+80|0,v[c+20>>2],B(v[c>>2],fd(c)));if(t[a+141|0]>=0){break l}while(1){b=v[i+80>>2];f=v[i+84>>2];if((b|0)!=(f|0)){e=u[v[i+80>>2]>>1];while(1){e=id(u[b>>1]-id(e,1)|0,1);u[b>>1]=e;b=b+2|0;if((f|0)!=(b|0)){continue}break}}j=j+1|0;if((j|0)<(0-t[a+141|0]|0)){continue}break}}m:{if(!l){break m}e=i+80|0;kn(e,v[c+20>>2],B(v[c>>2],fd(c)));h=w[a+171|0];b=w[a+172|0];f=w[a+171|0];g=0-(b>>>0<f>>>0)|0;f=b-f|0;b=g<<24|f>>>8;g=f<<24;f=QB(e);j=(f|0)/2|0;g=g+j|0;b=(j>>31)+b|0;g=Ac(lqa(g,g>>>0<j>>>0?b+1|0:b,f,f>>31),jb);b=v[e>>2];l=v[e+4>>2];if((b|0)==(l|0)){break m}e=h<<24;h=e;f=e>>31;e=g;k=e>>31;while(1){g=u[b>>1];g=kqa(h,f,g,g>>31)+838860800|0;j=jb;z=b,A=Ac(lqa(g,g>>>0<838860800?j+1|0:j,1677721600,0),jb),u[z>>1]=A;f=f+k|0;h=e+h|0;f=h>>>0<e>>>0?f+1|0:f;b=b+2|0;if((l|0)!=(b|0)){continue}break}}n:{if(!w[a+160|0]){break n}kn(i+208|0,v[c+20>>2],B(v[c>>2],fd(c)));l=w[a+162|0];k=w[a+163|0];h=0;g=0;if(w[a+161|0]>=2){b=w[a+164|0];e=w[a+162|0];f=0-(b>>>0<e>>>0)|0;b=b-e|0;j=f<<23|b>>>9;f=b<<23;e=QB(i+208|0);b=(e|0)/2|0;g=b;f=f+b|0;b=(b>>31)+j|0;g=Ac(lqa(f,f>>>0<g>>>0?b+1|0:b,e,e>>31),jb)}if(w[a+161|0]>=2){b=w[a+165|0];e=w[a+163|0];f=0-(b>>>0<e>>>0)|0;b=b-e|0;j=f<<23|b>>>9;e=b<<23;b=QB(i+208|0);f=(b|0)/2|0;h=f;e=e+f|0;f=(f>>31)+j|0;h=Ac(lqa(e,e>>>0<h>>>0?f+1|0:f,b,b>>31),jb)}b=v[i+208>>2];m=v[i+212>>2];if((b|0)==(m|0)){break n}e=l<<23;f=k<<23;k=(i+80|0)+((w[a+160|0]&2)<<2)|0;j=0;l=0;while(1){p=(u[b>>1]>>1)-l|0;v[i+88>>2]=p;r=(e|0)/8388608|0;j=id(B(p,r),8)+j|0;v[i+84>>2]=j;l=id(B(j,r),6)+l|0;l=id(id(B(l,(f|0)/8388608|0),6)+l|0,2);v[i+80>>2]=l;z=b,A=Uc(v[k>>2]),u[z>>1]=A;f=f+h|0;e=e+g|0;b=b+2|0;if((m|0)!=(b|0)){continue}break}}o:{if(t[a+141|0]<=0){break o}kn(i+80|0,v[c+20>>2],B(v[c>>2],fd(c)));j=0;if(t[a+141|0]<=0){break o}while(1){b=v[i+80>>2];f=v[i+84>>2];if((b|0)!=(f|0)){e=u[v[i+80>>2]>>1];while(1){e=((u[b>>1]<<1)+e|0)/3|0;u[b>>1]=e;b=b+2|0;if((f|0)!=(b|0)){continue}break}}j=j+1|0;if((j|0)<t[a+141|0]){continue}break}}p:{if(t[c+34|0]&1){kn(i- -64|0,v[c+20>>2],B(v[c>>2],fd(c)));b=v[i+68>>2];v[i+32>>2]=v[i+64>>2];v[i+36>>2]=b;l=gb-16|0;gb=l;k=v[i+36>>2];j=gb-16|0;gb=j;v[j+12>>2]=v[i+32>>2];m=l+8|0;b=j+12|0;f=Su(m,b,b);e=v[j+12>>2];q:{if((e|0)==(k|0)){break q}b=e+2|0;v[j+12>>2]=b;if((b|0)==(k|0)){break q}z=(Oj(b,v[f>>2])?0:4)+f|0,A=b,v[z>>2]=A;e=e+4|0;if((k|0)==(e|0)){break q}g=f+4|0;while(1){h=b;b=b+4|0;v[j+12>>2]=b;if((b|0)==(k|0)){if(!Oj(e,v[f>>2])){f=g;if(Oj(e,v[f>>2])){break q}}v[f>>2]=e;break q}p=v[f>>2];r:{s:{if(Oj(b,e)){if(Oj(b,p)){v[f>>2]=b}if(!Oj(e,v[g>>2])){break s}break r}if(Oj(e,p)){v[f>>2]=e}e=b;if(Oj(b,v[g>>2])){break r}}v[g>>2]=e}e=h+6|0;v[j+12>>2]=e;if((e|0)!=(k|0)){continue}break}}gb=j+16|0;v[l+4>>2]=0-u[v[m>>2]>>1];z=l,A=u[v[fc(m)>>2]>>1],v[z>>2]=A;b=v[Gf(l+4|0,l)>>2];t:{if((b|0)>=32767|!b){break t}e=v[i+32>>2];f=v[i+36>>2];if((e|0)==(f|0)){break t}while(1){u[e>>1]=(B(u[e>>1],32767)|0)/(b|0);e=e+2|0;if((f|0)!=(e|0)){continue}break}}gb=l+16|0;break p}bc(i+56|0,v[c+20>>2],B(v[c>>2],fd(c)));b=v[i+60>>2];v[i+24>>2]=v[i+56>>2];v[i+28>>2]=b;j=gb-16|0;gb=j;l=v[i+28>>2];f=gb-16|0;gb=f;v[f+4>>2]=v[i+24>>2];k=j+8|0;b=f+4|0;b=Su(k,b,b);e=v[f+4>>2];u:{if((e|0)==(l|0)){break u}e=e+1|0;v[f+4>>2]=e;if((e|0)==(l|0)){break u}e=(Tl(e,v[b>>2])?0:4)+b|0;h=v[f+4>>2];v[e>>2]=h;g=h+1|0;if((l|0)==(g|0)){break u}e=b+4|0;while(1){h=h+2|0;v[f+4>>2]=h;if((h|0)==(l|0)){if(!Tl(g,v[b>>2])){b=e;if(Tl(g,v[b>>2])){break u}}v[b>>2]=g;break u}v:{w:{if(Tl(h,g)){if(Tl(v[f+4>>2],v[b>>2])){v[b>>2]=v[f+4>>2]}if(!Tl(g,v[e>>2])){break w}break v}if(Tl(g,v[b>>2])){v[b>>2]=g}if(Tl(v[f+4>>2],v[e>>2])){break v}g=v[f+4>>2]}v[e>>2]=g}h=v[f+4>>2];g=h+1|0;v[f+4>>2]=g;if((g|0)!=(l|0)){continue}break}}gb=f+16|0;v[j+4>>2]=0-t[v[k>>2]];z=j,A=t[v[fc(k)>>2]],v[z>>2]=A;b=v[Gf(j+4|0,j)>>2];x:{if((b|0)>=127|!b){break x}e=v[i+24>>2];f=v[i+28>>2];if((e|0)==(f|0)){break x}while(1){t[e|0]=(B(t[e|0],127)|0)/(b|0);e=e+1|0;if((f|0)!=(e|0)){continue}break}}gb=j+16|0}y:{if(w[a+134|0]<101|w[a+134|0]>199){break y}b=B(v[c>>2],fd(c));if(t[c+34|0]&1){e=v[c+20>>2];b=td(i+48|0,e,e+(b<<1)|0);e=w[a+134|0];f=v[b+4>>2];v[i+16>>2]=v[b>>2];v[i+20>>2]=f;f=(3276800-(e<<14)|0)/100|0;b=v[i+16>>2];j=v[i+20>>2];if((b|0)!=(j|0)){l=0-f|0;g=32768-f|0;while(1){e=b;h=u[b>>1];z:{if((h|0)>(f|0)){m=g+((B(f,h-f|0)|0)/(g|0)|0)|0;break z}m=((B(f,f+h|0)|0)/(g|0)|0)-g|0;if((h|0)<(l|0)){break z}m=(B(h,g)|0)/(f|0)|0}z=e,A=Uc(m),u[z>>1]=A;b=b+2|0;if((j|0)!=(b|0)){continue}break}}break y}e=v[c+20>>2];b=td(i+40|0,e,b+e|0);e=w[a+134|0];f=v[b+4>>2];v[i+8>>2]=v[b>>2];v[i+12>>2]=f;f=(3276800-(e<<14)|0)/100|0;b=v[i+8>>2];j=v[i+12>>2];if((b|0)!=(j|0)){l=0-f|0;g=32768-f|0;while(1){e=b;h=t[b|0]<<8;A:{if((h|0)>(f|0)){m=g+((B(f,h-f|0)|0)/(g|0)|0)|0;break A}m=((B(f,f+h|0)|0)/(g|0)|0)-g|0;if((h|0)<(l|0)){break A}m=(B(h,g)|0)/(f|0)|0}z=e,A=FV((m|0)/256|0),t[z|0]=A;b=b+1|0;if((j|0)!=(b|0)){continue}break}}}if(!v[n>>2]|(!w[a+131|0]|w[a+128|0]!=8)){break g}v[c+12>>2]=v[o>>2];v[c+16>>2]=v[n>>2]+v[o>>2];if(y[n>>2]>268435456/w[a+131|0]>>>0|y[c>>2]>268435456-B(v[n>>2],w[a+131|0])>>>0){break g}b=jj(c);h=v[o>>2];j=v[n>>2];l=w[a+131|0];g=v[c>>2]+B(v[n>>2],w[a+131|0])|0;e=Sq(g,b);if(!e){break g}v[c>>2]=g;f=hc(e,zb(v[c+20>>2]),B(b,v[n>>2]+v[o>>2]|0));if(w[a+131|0]){e=0;while(1){e=e+1|0;hc(f+B(b,v[o>>2]+B(e,v[n>>2])|0)|0,zb(v[c+20>>2])+B(b,v[o>>2])|0,B(b,v[n>>2]));if(w[a+131|0]>e>>>0){continue}break}}a=h+B(j,l+1|0)|0;hc(f+B(a,b)|0,zb(v[c+20>>2])+B(b,v[n>>2]+v[o>>2]|0)|0,B(b,g-a|0));LN(c,f,v[c>>2],d)}gb=i+240|0;return}a=P()|0;O()|0;vb(i+224|0);S(a|0);L()}function NH(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,x=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=C(0),L=0;d=gb-144|0;gb=d;D=Qb(d,0,144);v[D+76>>2]=-1;v[D+44>>2]=a;v[D+32>>2]=2422;v[D+84>>2]=a;E=c;c=0;k=gb-304|0;gb=k;f=D;e=b;a=w[b|0];a:{if(!a){break a}b:{c:{d:{e:{while(1){f:{g:{if(vm(a&255)){while(1){a=e;e=e+1|0;if(vm(w[a+1|0])){continue}break}wi(f,0,0);while(1){b=v[f+4>>2];h:{if(b>>>0<y[f+104>>2]){v[f+4>>2]=b+1;b=w[b|0];break h}b=md(f)}if(vm(b)){continue}break}e=v[f+4>>2];if(v[f+104>>2]){e=e-1|0;v[f+4>>2]=e}b=e-v[f+8>>2]|0;h=b>>31;e=b;g=o+v[f+124>>2]|0;b=r+v[f+120>>2]|0;g=b>>>0<r>>>0?g+1|0:g;d=b;b=e+b|0;h=h+g|0;r=b;o=b>>>0<d>>>0?h+1|0:h;break g}i:{j:{k:{b=w[e|0];if((b|0)==37){a=w[e+1|0];if((a|0)==42){break k}if((a|0)!=37){break j}}wi(f,0,0);a=((b|0)==37)+e|0;b=v[f+4>>2];l:{if(b>>>0<y[f+104>>2]){v[f+4>>2]=b+1;b=w[b|0];break l}b=md(f)}if((b|0)!=w[a|0]){if(v[f+104>>2]){v[f+4>>2]=v[f+4>>2]-1}if((b|0)>=0){break a}x=0;if(F){break a}break c}b=r+1|0;o=b?o:o+1|0;r=b;break g}m=0;a=e+2|0;break i}if(!(!Qh(a)|w[e+2|0]!=36)){a=w[e+1|0]-48|0;b=gb-16|0;v[b+12>>2]=E;a=(a>>>0>1?(a<<2)-4|0:0)+E|0;v[b+8>>2]=a+4;m=v[a>>2];a=e+3|0;break i}m=v[E>>2];E=E+4|0;a=e+1|0}x=0;e=0;if(Qh(w[a|0])){while(1){e=(w[a|0]+B(e,10)|0)-48|0;b=w[a+1|0];a=a+1|0;if(Qh(b)){continue}break}}d=w[a|0];if((d|0)==109){c=0;x=(m|0)!=0;d=w[a+1|0];q=0;a=a+1|0}b=a;a=b+1|0;g=3;m:{n:{switch(d-65|0){case 39:d=b+2|0;b=w[b+1|0]==104;a=b?d:a;g=b?-2:-1;break m;case 43:d=b+2|0;b=w[b+1|0]==108;a=b?d:a;g=b?3:1;break m;case 51:case 57:g=1;break m;case 11:g=2;break m;case 41:break m;case 0:case 2:case 4:case 5:case 6:case 18:case 23:case 26:case 32:case 34:case 35:case 36:case 37:case 38:case 40:case 45:case 46:case 47:case 50:case 52:case 55:break n;default:break d}}g=0;a=b}b=w[a|0];d=(b&47)==3;G=d?1:g;s=d?b|32:b;o:{if((s|0)==91){break o}p:{if((s|0)!=110){if((s|0)!=99){break p}e=(e|0)>1?e:1;break o}OH(m,G,r,o);break g}wi(f,0,0);while(1){b=v[f+4>>2];q:{if(b>>>0<y[f+104>>2]){v[f+4>>2]=b+1;b=w[b|0];break q}b=md(f)}if(vm(b)){continue}break}b=v[f+4>>2];if(v[f+104>>2]){b=b-1|0;v[f+4>>2]=b}b=b-v[f+8>>2]|0;h=b>>31;l=b;b=o+v[f+124>>2]|0;d=r+v[f+120>>2]|0;b=d>>>0<r>>>0?b+1|0:b;o=d;d=l+d|0;h=b+h|0;r=d;o=d>>>0<o>>>0?h+1|0:h}l=e;j=e>>31;wi(f,e,j);b=v[f+104>>2];d=v[f+4>>2];r:{if(b>>>0>d>>>0){v[f+4>>2]=d+1;break r}if((md(f)|0)<0){break d}b=v[f+104>>2]}if(b){v[f+4>>2]=v[f+4>>2]-1}b=16;s:{t:{u:{v:{w:{x:{y:{switch(s-88|0){default:b=s-65|0;if(b>>>0>6|!(1<<b&113)){break s}case 9:case 13:case 14:case 15:RH(k+8|0,f,G,0);b=v[f+4>>2]-v[f+8>>2]|0;if(v[f+120>>2]==(0-b|0)&v[f+124>>2]==(0-((b>>31)+((b|0)!=0)|0)|0)){break b}if(!m){break s}b=v[k+16>>2];d=v[k+20>>2];h=v[k+8>>2];e=v[k+12>>2];switch(G|0){case 2:break u;case 1:break v;case 0:break w;default:break s};case 3:case 11:case 27:if((s&239)==99){Qb(k+32|0,-1,257);t[k+32|0]=0;if((s|0)!=115){break t}t[k+65|0]=0;t[k+46|0]=0;u[k+42>>1]=0;u[k+44>>1]=0;break t}d=w[a+1|0];h=(d|0)==94;Qb(k+32|0,h,257);t[k+32|0]=0;b=h?a+2|0:a+1|0;z:{A:{B:{a=w[(h?2:1)+a|0];if((a|0)!=45){if((a|0)==93){break B}g=(d|0)!=94;a=b;break z}g=(d|0)!=94;t[k+78|0]=g;break A}g=(d|0)!=94;t[k+126|0]=g}a=b+1|0}while(1){b=w[a|0];C:{if((b|0)!=45){if(!b){break d}if((b|0)!=93){break C}break t}b=45;d=w[a+1|0];if(!d|(d|0)==93){break C}h=a+1|0;a=w[a-1|0];D:{if(d>>>0<=a>>>0){b=d;break D}while(1){a=a+1|0;t[a+(k+32|0)|0]=g;b=w[h|0];if(b>>>0>a>>>0){continue}break}}a=h}t[(b+k|0)+33|0]=g;a=a+1|0;continue};case 23:b=8;break x;case 12:case 29:b=10;break x;case 1:case 2:case 4:case 5:case 6:case 7:case 8:case 10:case 16:case 18:case 19:case 20:case 21:case 22:case 25:case 26:case 28:case 30:case 31:break s;case 0:case 24:case 32:break x;case 17:break y}}b=0}i=f;l=0;h=0;j=0;g=0;I=0;H=gb-16|0;gb=H;E:{F:{G:{H:{I:{J:{if(b>>>0<=36){while(1){d=v[i+4>>2];K:{if(d>>>0<y[i+104>>2]){v[i+4>>2]=d+1;d=w[d|0];break K}d=md(i)}if(vm(d)){continue}break}L:{M:{switch(d-43|0){case 0:case 2:break M;default:break L}}I=(d|0)==45?-1:0;d=v[i+4>>2];if(d>>>0<y[i+104>>2]){v[i+4>>2]=d+1;d=w[d|0];break L}d=md(i)}N:{if(!(b&-17|(d|0)!=48)){d=v[i+4>>2];O:{if(d>>>0<y[i+104>>2]){v[i+4>>2]=d+1;d=w[d|0];break O}d=md(i)}if((d&-33)==88){b=16;d=v[i+4>>2];P:{if(d>>>0<y[i+104>>2]){v[i+4>>2]=d+1;d=w[d|0];break P}d=md(i)}if(w[d+76481|0]<16){break I}if(!v[i+104>>2]){break F}v[i+4>>2]=v[i+4>>2]-1;break F}if(b){break N}b=8;break I}b=b?b:10;if(b>>>0>w[d+76481|0]){break N}if(v[i+104>>2]){v[i+4>>2]=v[i+4>>2]-1}wi(i,0,0);v[115137]=28;b=0;d=0;break E}if((b|0)!=10){break I}j=d-48|0;if(j>>>0<=9){b=0;while(1){b=B(b,10)+j|0;e=b>>>0<429496729;d=v[i+4>>2];Q:{if(d>>>0<y[i+104>>2]){v[i+4>>2]=d+1;d=w[d|0];break Q}d=md(i)}j=d-48|0;if(e&j>>>0<=9){continue}break}l=b}if(j>>>0>9){break J}n=kqa(l,0,10,0);p=jb;e=j;while(1){b=v[i+4>>2];R:{if(b>>>0<y[i+104>>2]){v[i+4>>2]=b+1;d=w[b|0];break R}d=md(i)}j=d-48|0;g=j>>>0>9;h=p;b=e+n|0;h=b>>>0<n>>>0?h+1|0:h;l=b;if((h|0)==429496729&b>>>0>=2576980378|h>>>0>429496729|g){break J}n=kqa(l,h,10,0);b=n;p=jb;g=p;e=j;if((g|0)==-1&(e^-1)>>>0>=b>>>0|(g|0)!=-1){continue}break}b=10;break H}v[115137]=28;b=0;d=0;break E}b=10;if(j>>>0<=9){break H}break G}if(b-1&b){g=w[d+76481|0];if(g>>>0<b>>>0){while(1){j=B(b,j)+g|0;e=j>>>0<119304647;d=v[i+4>>2];S:{if(d>>>0<y[i+104>>2]){v[i+4>>2]=d+1;d=w[d|0];break S}d=md(i)}g=w[d+76481|0];if(e&g>>>0<b>>>0){continue}break}l=j}if(b>>>0<=g>>>0){break H}j=b;n=kqa(l,0,b,0);p=jb;e=g;if((p|0)==-1&(e^-1)>>>0<n>>>0){break H}while(1){h=p;d=e+n|0;h=d>>>0<n>>>0?h+1|0:h;l=d;d=v[i+4>>2];T:{if(d>>>0<y[i+104>>2]){v[i+4>>2]=d+1;d=w[d|0];break T}d=md(i)}e=w[d+76481|0];if(e>>>0>=b>>>0){break H}qf(H,j,0,0,0,l,h,0,0);if(v[H+8>>2]|v[H+12>>2]){break H}n=kqa(l,h,j,0);g=n;p=jb;if((p|0)==-1&(e^-1)>>>0>=g>>>0|(p|0)!=-1){continue}break}break H}e=t[(B(b,23)>>>5&7)+76737|0];j=w[d+76481|0];if(j>>>0<b>>>0){while(1){g=g<<e|j;l=g>>>0<134217728;d=v[i+4>>2];U:{if(d>>>0<y[i+104>>2]){v[i+4>>2]=d+1;d=w[d|0];break U}d=md(i)}j=w[d+76481|0];if(l&j>>>0<b>>>0){continue}break}l=g}if(b>>>0<=j>>>0){break H}n=e&31;if((e&63)>>>0>=32){g=0;p=-1>>>n|0}else{p=-1>>>n|0;g=p;p=g|(1<<n)-1<<32-n}if(!g&l>>>0>p>>>0){break H}while(1){n=j&255;j=l;d=e;l=d&31;if((d&63)>>>0>=32){h=j<<l;d=0}else{h=(1<<l)-1&j>>>32-l|h<<l;d=j<<l}l=n|d;n=b;d=v[i+4>>2];V:{if(d>>>0<y[i+104>>2]){v[i+4>>2]=d+1;d=w[d|0];break V}d=md(i)}j=w[d+76481|0];if(n>>>0<=j>>>0){break H}if((h|0)==(g|0)&l>>>0<=p>>>0|h>>>0<g>>>0){continue}break}}if(w[d+76481|0]>=b>>>0){break G}while(1){h=v[i+4>>2];W:{if(h>>>0<y[i+104>>2]){v[i+4>>2]=h+1;d=w[h|0];break W}d=md(i)}if(w[d+76481|0]<b>>>0){continue}break}v[115137]=68;I=0;l=-1;h=-1}if(v[i+104>>2]){v[i+4>>2]=v[i+4>>2]-1}if(I|1?0:(l|0)==-1&(h|0)==-1){v[115137]=68;b=-2;d=-1;break E}b=I;e=b^l;d=b;b=e-b|0;l=h;h=d>>31;d=(l^h)-((d>>>0>e>>>0)+h|0)|0;break E}wi(i,0,0);b=0;d=0}gb=H+16|0;h=v[f+4>>2]-v[f+8>>2]|0;e=h;if(v[f+120>>2]==(0-e|0)&v[f+124>>2]==(0-((e>>31)+((e|0)!=0)|0)|0)){break b}if(!(!m|(s|0)!=112)){v[m>>2]=b;break s}OH(m,G,b,d);break s}J=m,K=PH(h,e,b,d),z[J>>2]=K;break s}J=m,L=ey(h,e,b,d),A[J>>3]=L;break s}v[m>>2]=h;v[m+4>>2]=e;v[m+8>>2]=b;v[m+12>>2]=d;break s}d=(s|0)==99;g=d?e+1|0:31;h=(G|0)!=1;X:{if(!h){b=m;if(x){b=Cd(g<<2);if(!b){break e}}v[k+296>>2]=0;v[k+300>>2]=0;e=0;c=x;while(1){q=b;Y:{while(1){b=v[f+4>>2];Z:{if(b>>>0<y[f+104>>2]){v[f+4>>2]=b+1;b=w[b|0];break Z}b=md(f)}if(!w[(b+k|0)+33|0]){break Y}t[k+27|0]=b;b=aq(k+28|0,k+27|0,1,k+296|0);if((b|0)==-2){continue}if((b|0)==-1){break f}if(q){v[(e<<2)+q>>2]=v[k+28>>2];e=e+1|0}if(!(c&(e|0)==(g|0))){continue}break}g=g<<1|1;b=Vp(q,g<<2);if(b){continue}break f}break}if(k+296|0?v[k+296>>2]:0){break f}c=0;break X}if(x){e=0;b=Cd(g);if(!b){break e}while(1){c=b;while(1){b=v[f+4>>2];_:{if(b>>>0<y[f+104>>2]){v[f+4>>2]=b+1;b=w[b|0];break _}b=md(f)}if(!w[(b+k|0)+33|0]){q=0;break X}t[c+e|0]=b;e=e+1|0;if((g|0)!=(e|0)){continue}break}q=0;g=g<<1|1;b=Vp(c,g);if(b){continue}break}break d}e=0;if(m){while(1){b=v[f+4>>2];$:{if(b>>>0<y[f+104>>2]){v[f+4>>2]=b+1;b=w[b|0];break $}b=md(f)}if(w[(b+k|0)+33|0]){t[e+m|0]=b;e=e+1|0;continue}else{q=0;c=m;break X}}}while(1){b=v[f+4>>2];aa:{if(b>>>0<y[f+104>>2]){v[f+4>>2]=b+1;b=w[b|0];break aa}b=md(f)}if(w[(b+k|0)+33|0]){continue}break}c=0;q=0}b=v[f+4>>2];if(v[f+104>>2]){b=b-1|0;v[f+4>>2]=b}g=b-v[f+8>>2]|0;n=g;b=g+v[f+120>>2]|0;g=v[f+124>>2]+(g>>31)|0;g=b>>>0<n>>>0?g+1|0:g;if(!(g|b)|((b|0)!=(l|0)|(g|0)!=(j|0))&(s|0)==99){break b}ba:{if(!x){break ba}if(!h){v[m>>2]=q;break ba}v[m>>2]=c}if(d){break s}if(q){v[(e<<2)+q>>2]=0}if(!c){c=0;break s}t[c+e|0]=0}b=v[f+4>>2]-v[f+8>>2]|0;h=b>>31;e=b;o=o+v[f+124>>2]|0;b=r+v[f+120>>2]|0;o=b>>>0<r>>>0?o+1|0:o;d=b;b=e+b|0;o=h+o|0;o=b>>>0<d>>>0?o+1|0:o;r=b;F=((m|0)!=0)+F|0}e=a+1|0;a=w[a+1|0];if(a){continue}break a}break}c=0;break d}c=0;q=0}if(F){break b}}F=-1}if(!x){break a}Yb(c);Yb(q)}gb=k+304|0;gb=D+144|0;return F}function dha(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,y=0;j=gb-288|0;gb=j;h=gb-128|0;gb=h;g=j+104|0;i=le(g,c);v[22656]=0;n=T(215,g+20|0)|0;c=v[22656];v[22656]=0;a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{t:{u:{v:{w:{x:{y:{z:{A:{if((c|0)!=1){v[22656]=0;p=T(215,g+40|0)|0;c=v[22656];v[22656]=0;if((c|0)==1){break A}v[22656]=0;q=T(215,g+60|0)|0;c=v[22656];v[22656]=0;if((c|0)==1){break z}v[22656]=0;r=T(215,g+80|0)|0;c=v[22656];v[22656]=0;if((c|0)==1){break y}v[22656]=0;o=T(215,g+100|0)|0;c=v[22656];v[22656]=0;if((c|0)==1){break x}v[22656]=0;k=T(215,g+120|0)|0;c=v[22656];v[22656]=0;if((c|0)==1){break w}m=Io(g+140|0);vc(g);v[g+172>>2]=1873739776;u[g+176>>1]=0;v[22656]=0;f=Q(1428,i|0,h+112|0)|0;c=v[22656];v[22656]=0;if((c|0)==1){break v}if(!f){break m}c=h+112|0;if((w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24))!=1179011410){c=h+112|0;if((w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24))!=1414744396){break m}}l=h+120|0;f=w[l+1|0]<<8;c=w[l+2|0]<<16|w[l+3|0]<<24;if((w[l|0]|f|c)!=1163280727&(c|(f|w[l|0]))!=1702257015){break m}c=h+112|0;t[g+176|0]=(w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24))==1414744396;v[22656]=0;U(1429,h+96|0,i|0,2);c=v[22656];v[22656]=0;if((c|0)==1){break u}B:{if(_i(h+96|0)>>>0<4){break B}c=h+40|0;Zi(c,au(h+96|0,1));if((w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24))!=1635017060){break B}c=h- -64|0;Zi(c,au(h+96|0,1));if(!(cn(c)&1)){break B}c=h+24|0;Zi(c,au(h+96|0,2));if(cn(c)){break B}c=h+88|0;Zi(c,au(h+96|0,3));if(w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24)){break B}v[22656]=0;Q(190,g|0,12)|0;c=v[22656];v[22656]=0;if((c|0)==1){break t}v[22656]=0;U(1429,h+40|0,i|0,1);c=v[22656];v[22656]=0;if((c|0)==1){break s}c=h+40|0;TN(h+96|0,c);zB(c)}v[22656]=0;U(1430,h- -64|0,h+96|0,544501094);c=v[22656];v[22656]=0;if((c|0)==1){break r}v[22656]=0;l=g+156|0;f=Q(1431,h- -64|0,l|0)|0;c=v[22656];v[22656]=0;if((c|0)==1){break k}if(!f){break n}if((w[l|0]|w[l+1|0]<<8)==1){v[22656]=0;f=T(467,h- -64|0)|0;c=v[22656];v[22656]=0;if((c|0)==1){break k}if((f|0)==4){break q}}if((w[l|0]|w[l+1|0]<<8)!=65534){break o}v[22656]=0;f=Q(1432,h- -64|0,h+40|0)|0;c=v[22656];v[22656]=0;if((c|0)==1){break p}if(!f){break n}c=v[h+60>>2];v[h+16>>2]=v[h+56>>2];v[h+20>>2]=c;c=v[h+52>>2];v[h+8>>2]=v[h+48>>2];v[h+12>>2]=c;c=h+24|0;f=h+8|0;v[c>>2]=w[f|0]|w[f+1|0]<<8|(w[f+2|0]<<16|w[f+3|0]<<24);u[c+4>>1]=w[f+4|0]|w[f+5|0]<<8;u[c+6>>1]=w[f+6|0]|w[f+7|0]<<8;s=c,y=UC(w[f+8|0]|w[f+9|0]<<8|(w[f+10|0]<<16|w[f+11|0]<<24),w[f+12|0]|w[f+13|0]<<8|(w[f+14|0]<<16|w[f+15|0]<<24)),v[s+8>>2]=y;v[c+12>>2]=jb;u[g+172>>1]=v[c>>2];break o}c=P()|0;O()|0;break b}c=P()|0;O()|0;break c}c=P()|0;O()|0;break d}c=P()|0;O()|0;break e}c=P()|0;O()|0;break f}c=P()|0;O()|0;break g}c=P()|0;O()|0;break h}c=P()|0;O()|0;break h}c=P()|0;O()|0;break i}c=P()|0;O()|0;break i}c=P()|0;O()|0;break i}v[22656]=0;i=T(307,h- -64|0)|0;c=v[22656];v[22656]=0;C:{if((c|0)!=1){v[22656]=0;f=T(307,h- -64|0)|0;c=v[22656];v[22656]=0;if((c|0)==1){break C}if((i|0)!=2|(f|0)!=1){break o}t[g+177|0]=1;break o}c=P()|0;O()|0;break j}c=P()|0;O()|0;break j}c=P()|0;O()|0;break j}v[22656]=0;U(1430,h+40|0,h+96|0,1635017060);c=v[22656];v[22656]=0;D:{E:{F:{G:{H:{I:{if((c|0)!=1){c=h+40|0;Vc(n,c);xb(c);v[22656]=0;f=T(275,n|0)|0;c=v[22656];v[22656]=0;if((c|0)==1){break k}if(!f){v[22656]=0;U(1430,h+40|0,h+96|0,544039792);c=v[22656];v[22656]=0;if((c|0)==1){break I}c=h+40|0;Vc(n,c);xb(c)}v[22656]=0;U(1430,h+40|0,h+96|0,1952670054);c=v[22656];v[22656]=0;if((c|0)==1){break H}v[22656]=0;f=T(192,h+40|0)|0;c=v[22656];v[22656]=0;if((c|0)==1){break G}v[g+152>>2]=f;xb(h+40|0);if(v[g+152>>2]?(w[l|0]|w[l+1|0]<<8)==17:0){break D}if(!Dz(g)){break D}if(Jo(g)){if((Jo(g)>>>0)/(Nj(g)>>>0)>>>0<Dz(g)<<1>>>0){break F}}v[22656]=0;c=T(195,n|0)|0;f=v[22656];v[22656]=0;if((f|0)==1){break k}f=Dz(g);break E}c=P()|0;O()|0;break j}c=P()|0;O()|0;break j}c=P()|0;O()|0;break j}c=P()|0;O()|0;xb(h+40|0);break j}v[22656]=0;c=T(195,n|0)|0;f=v[22656];v[22656]=0;if((f|0)==1){break k}f=Jo(g)}v[g+152>>2]=(c>>>0)/(f>>>0)}v[22656]=0;f=Q(1433,g|0,h+96|0)|0;c=v[22656];v[22656]=0;if((c|0)==1){break k}u[g+174>>1]=f;v[22656]=0;R(1434,g|0,h+96|0);c=v[22656];v[22656]=0;if((c|0)==1){break k}v[22656]=0;U(1430,h+40|0,h+96|0,1886221175);c=v[22656];v[22656]=0;if((c|0)==1){break l}c=h+40|0;Vc(o,c);xb(c)}xb(h- -64|0);zB(h+96|0)}gb=h+128|0;break a}c=P()|0;O()|0;break j}c=P()|0;O()|0}xb(h- -64|0)}zB(h+96|0)}zB(m);xb(k)}xb(o)}xb(r)}xb(q)}xb(p)}xb(n)}xb(g);S(c|0);L()}v[22656]=0;f=T(1145,g|0)|0;c=v[22656];v[22656]=0;J:{K:{L:{M:{if((c|0)==1){break M}N:{O:{if(!f){break O}if(!Nj(g)){break O}if(Nj(g)>>>0>2){break O}if(!Sl(g)){v[22656]=0;f=$h(g);c=v[22656];v[22656]=0;if((c|0)==1){break M}if((f|0)!=85){break O}}if(Sl(g)>>>0<=31){v[22656]=0;f=$h(g);c=v[22656];v[22656]=0;if((c|0)==1){break M}if((f|0)==3){break O}}if(Sl(g)>>>0>64){break O}i=0;v[22656]=0;f=$h(g);c=v[22656];v[22656]=0;if((c|0)==1){break L}v[j+80>>2]=f;c=v[j+80>>2];f=36544;P:{while(1){h=f;if((c|0)==v[f>>2]){break P}f=f+4|0;if((f|0)!=36568){continue}break}h=36568}if((h|0)==36568){break N}v[22656]=0;Q(1140,a|0,b|0)|0;c=v[22656];v[22656]=0;if((c|0)==1){break M}v[22656]=0;f=Q(70,j+80|0,18726)|0;c=v[22656];v[22656]=0;Q:{R:{S:{T:{U:{V:{if((c|0)!=1){v[22656]=0;i=((b<<5)+a|0)+946304|0;Q(301,i|0,f|0)|0;c=v[22656];v[22656]=0;if((c|0)==1){break V}vb(f);v[22656]=0;f=B(b,104)+a|0;k=f+484380|0;R(424,k|0,0);c=v[22656];v[22656]=0;if((c|0)==1){break U}v[k>>2]=v[g+152>>2];v[f+484404>>2]=w[g+160|0]|w[g+161|0]<<8|(w[g+162|0]<<16|w[g+163|0]<<24);v[22656]=0;f=Kk(a);c=v[22656];v[22656]=0;if((c|0)==1){break U}v[22656]=0;Y(1147,g|0,k|0,f|0,i|0);c=v[22656];v[22656]=0;if((c|0)==1){break U}le(j+80|0,g+20|0);i=Rc(j+72|0,8,Nj(g)>>>0>1?2:1,0,0);v[22656]=0;f=$h(g);c=v[22656];v[22656]=0;if((c|0)==1){break K}if((f|0)!=17){break T}if(Nj(g)>>>0>2){break T}qc(k,268435456);d=(B(b,104)+a|0)+484414|0;u[d>>1]=x[d>>1]|1;c=Nj(g);u[d>>1]=x[d>>1]&65471|((c|0)==2)<<6;i=0;v[22656]=0;d=T(386,k|0)|0;c=v[22656];v[22656]=0;if((c|0)==1){break K}if(!d){break R}i=v[(B(b,104)+a|0)+484400>>2];f=v[k>>2];m=le(j+48|0,j+80|0);d=Jo(g);c=Nj(g);v[22656]=0;b=v[m+12>>2];v[j+8>>2]=v[m+8>>2];v[j+12>>2]=b;v[j+16>>2]=v[m+16>>2];b=v[m+4>>2];v[j>>2]=v[m>>2];v[j+4>>2]=b;ha(1148,i|0,f|0,j|0,d|0,c|0);b=v[22656];v[22656]=0;if((b|0)==1){break K}v[22656]=0;_h(k,a,0);b=v[22656];v[22656]=0;if((b|0)==1){break K}break S}a=P()|0;O()|0;break J}a=P()|0;O()|0;vb(f);break J}a=P()|0;O()|0;break J}v[22656]=0;f=$h(g);c=v[22656];v[22656]=0;if((c|0)==1){break K}if((f|0)==85){v[22656]=0;c=fa(753,a|0,b|0,j+80|0,0,1)|0;b=v[22656];v[22656]=0;if((b|0)==1){break Q}if(c){break S}i=0;v[22656]=0;a=v[22656];v[22656]=0;if((a|0)==1){break Q}break R}W:{if(AB(g)|!w[g+177|0]){break W}v[22656]=0;c=$h(g);b=v[22656];v[22656]=0;if((b|0)==1){break K}if((c|0)!=1){break W}if((Sl(g)|0)!=32){break W}if((Jo(g)|0)!=Nj(g)<<2){break W}Yi(i,32);Bf(i,12);v[22656]=0;W(329,i|0,k|0,j+80|0)|0;b=v[22656];v[22656]=0;if((b|0)!=1){break S}break K}X:{if(AB(g)){break X}v[22656]=0;c=$h(g);b=v[22656];v[22656]=0;if((b|0)==1){break K}if((c|0)!=1){break X}if((Sl(g)|0)!=24){break X}if((Jo(g)|0)!=Nj(g)<<2){break X}Yi(i,32);Bf(i,13);v[22656]=0;W(329,i|0,k|0,j+80|0)|0;b=v[22656];v[22656]=0;if((b|0)==1){break K}break S}v[22656]=0;c=$h(g);b=v[22656];v[22656]=0;if((b|0)==1){break K}Y:{if((c|0)!=6){v[22656]=0;c=$h(g);b=v[22656];v[22656]=0;if((b|0)==1){break K}if((c|0)!=7){break Y}}Yi(i,16);v[22656]=0;c=$h(g);b=v[22656];v[22656]=0;if((b|0)==1){break K}Bf(i,(c|0)==6?17:16);v[22656]=0;W(329,i|0,k|0,j+80|0)|0;b=v[22656];v[22656]=0;if((b|0)==1){break K}break S}c=(Sl(g)-1>>>3|0)-1|0;b=c<<3;f=b&31;Yi(i,(c>>>0<7?(b&63)>>>0>=32?4196360>>>f|0:((1<<f)-1&4196360)<<32-f|136321040>>>f:8)&255);if(Sl(g)>>>0<9){Bf(i,1)}v[22656]=0;c=$h(g);b=v[22656];v[22656]=0;if((b|0)==1){break K}if((c|0)==3){Bf(i,3)}if(d){XQ(i)}v[22656]=0;W(329,i|0,k|0,j+80|0)|0;b=v[22656];v[22656]=0;if((b|0)==1){break K}}if(e){b=j+24|0;le(b,g+100|0);Vc(e,b);xb(b)}b=v[a+480180>>2];v[22656]=0;U(1142,k|0,32,b|0);b=v[22656];v[22656]=0;i=1;if((b|0)==1){break K}v[22656]=0;_h(k,a,0);a=v[22656];v[22656]=0;if((a|0)==1){break K}}xb(j+80|0);break N}break K}i=0}hT(g);gb=j+288|0;return i|0}a=P()|0;O()|0;break J}a=P()|0;O()|0;break J}a=P()|0;O()|0;xb(j+80|0)}hT(g);S(a|0);L()}function GK(a,b,c,d,e,f,g){var h=0,i=0,j=0,k=0;h=gb-128|0;gb=h;v[h+124>>2]=c;a:{b:{if(g){He(h+112|0,f,32);v[22656]=0;W(716,h+96|0,f|0,32)|0;i=v[22656];v[22656]=0;if((i|0)!=1){break b}f=P()|0;O()|0;break a}Kb(h+112|0);Kb(h+96|0)}u[h+80>>1]=0;u[h+64>>1]=65535;c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{if(Ft(h+124|0,h+80|0,h- -64|0)){i=b+24|0;b=v[i>>2];v[22656]=0;b=me(b+484344|0,c&65535);j=v[22656];v[22656]=0;if((j|0)==1){break q}if(b){break r}}v[22656]=0;U(2101,a|0,h+112|0,h+96|0);a=v[22656];v[22656]=0;if((a|0)!=1){break m}f=P()|0;O()|0;break c}b=_b(v[i>>2]+484344|0,c);if(!(v[b+12>>2]>(d|0)&(d|0)>=0)){v[22656]=0;U(2101,a|0,h+112|0,h+96|0);a=v[22656];v[22656]=0;if((a|0)!=1){break m}break d}if(!(x[v[i>>2]+480188>>1]>e>>>0&(e|0)>=0)){v[22656]=0;U(2101,a|0,h+112|0,h+96|0);a=v[22656];v[22656]=0;if((a|0)==1){break d}break m}v[22656]=0;c=Yc(b,d,e&65535);b=v[22656];v[22656]=0;if((b|0)==1){break h}Se(h+112|0);Se(h+96|0);v[22656]=0;b=Rd(c);d=v[22656];v[22656]=0;s:{t:{u:{v:{w:{x:{y:{z:{A:{B:{C:{D:{if((d|0)!=1){E:{F:{if(!b){if(!_t(c)){break F}}b=v[i>>2];d=w[c+1|0];e=w[c|0];v[22656]=0;Y(2103,h- -64|0,b|0,e|0,d|0);d=v[22656];v[22656]=0;b=1;if((d|0)==1){break D}v[22656]=0;R(2039,h+80|0,h- -64|0);d=v[22656];v[22656]=0;if((d|0)!=1){break E}f=P()|0;O()|0;break A}b=0;v[22656]=0;Q(70,h+80|0,13839)|0;d=v[22656];v[22656]=0;if((d|0)==1){break C}}v[22656]=0;Q(1168,h+112|0,h+80|0)|0;d=v[22656];v[22656]=0;if((d|0)==1){break B}vb(h+80|0);if(b){vb(h- -64|0)}v[22656]=0;b=Rd(c);d=v[22656];v[22656]=0;if((d|0)==1){break e}G:{if(b){v[22656]=0;Q(70,h+80|0,7238)|0;b=v[22656];v[22656]=0;if((b|0)==1){break e}break G}if(_t(c)){v[22656]=0;Q(70,h+80|0,7548)|0;b=v[22656];v[22656]=0;if((b|0)!=1){break G}break e}v[22656]=0;Q(70,h+80|0,13839)|0;b=v[22656];v[22656]=0;if((b|0)==1){break e}}v[22656]=0;Q(1168,h+96|0,h+80|0)|0;b=v[22656];v[22656]=0;if((b|0)==1){break z}vb(h+80|0);j=f-1|0;if(j>>>0<5){break s}v[22656]=0;b=Q(70,h+80|0,14911)|0;d=v[22656];v[22656]=0;if((d|0)==1){break y}v[22656]=0;Q(1168,h+112|0,b|0)|0;d=v[22656];v[22656]=0;if((d|0)==1){break x}vb(b);v[22656]=0;b=Q(70,h+80|0,14911)|0;d=v[22656];v[22656]=0;if((d|0)==1){break w}v[22656]=0;Q(1168,h+96|0,b|0)|0;d=v[22656];v[22656]=0;if((d|0)==1){break v}vb(b);b=c+1|0;H:{if(w[c+1|0]){v[22656]=0;R(737,h+80|0,b|0);d=v[22656];v[22656]=0;if((d|0)!=1){break H}break f}v[22656]=0;Q(70,h+80|0,13844)|0;d=v[22656];v[22656]=0;if((d|0)==1){break f}}v[22656]=0;Q(1168,h+112|0,h+80|0)|0;d=v[22656];v[22656]=0;if((d|0)==1){break u}vb(h+80|0);I:{if(w[b|0]){v[22656]=0;Q(70,h+80|0,8055)|0;b=v[22656];v[22656]=0;if((b|0)!=1){break I}break g}v[22656]=0;Q(70,h+80|0,13844)|0;b=v[22656];v[22656]=0;if((b|0)==1){break g}}v[22656]=0;Q(1168,h+96|0,h+80|0)|0;b=v[22656];v[22656]=0;if((b|0)!=1){break t}f=P()|0;O()|0;vb(h+80|0);break c}f=P()|0;O()|0;break c}f=P()|0;O()|0;break c}f=P()|0;O()|0;break c}f=P()|0;O()|0;vb(h+80|0);if(!b){break c}}vb(h- -64|0);break c}f=P()|0;O()|0;vb(h+80|0);break c}f=P()|0;O()|0;break c}f=P()|0;O()|0;vb(b);break c}f=P()|0;O()|0;break c}f=P()|0;O()|0;vb(b);break c}f=P()|0;O()|0;vb(h+80|0);break c}vb(h+80|0);if(j>>>0<8){break s}v[22656]=0;b=Cg(c);d=v[22656];v[22656]=0;J:{K:{L:{M:{N:{O:{P:{Q:{R:{if((d|0)!=1){S:{if(b){v[22656]=0;b=Q(70,h+48|0,14911)|0;d=v[22656];v[22656]=0;if((d|0)==1){break R}v[22656]=0;e=Hq(c);d=v[22656];v[22656]=0;if((d|0)==1){break Q}d=0;v[22656]=0;v[h+16>>2]=e&255;R(735,h+32|0,h+16|0);k=v[22656];v[22656]=0;e=1;if((k|0)==1){break Q}v[22656]=0;U(2058,h+80|0,b|0,h+32|0);b=v[22656];v[22656]=0;if((b|0)!=1){break S}f=P()|0;O()|0;break M}if(w[c+2|0]){b=v[v[i>>2]+8>>2];d=w[c+2|0];v[22656]=0;b=xz(b,d);d=v[22656];v[22656]=0;if((d|0)==1){break K}v[22656]=0;b=W(716,h+48|0,1,b|0)|0;d=v[22656];v[22656]=0;if((d|0)==1){break K}e=0;v[22656]=0;R(737,h+32|0,c+4|0);k=v[22656];v[22656]=0;d=1;if((k|0)==1){break P}v[22656]=0;U(2058,h+80|0,b|0,h+32|0);k=v[22656];v[22656]=0;if((k|0)!=1){break S}f=P()|0;O()|0;vb(h+32|0);break i}e=0;v[22656]=0;Q(70,h+80|0,13843)|0;b=v[22656];v[22656]=0;d=0;if((b|0)==1){break O}}v[22656]=0;Q(1168,h+112|0,h+80|0)|0;b=v[22656];v[22656]=0;if((b|0)==1){break N}vb(h+80|0);if(d){vb(h+32|0);vb(h+48|0)}if(e){vb(h+32|0);vb(h+48|0)}v[22656]=0;b=Cg(c);d=v[22656];v[22656]=0;if((d|0)==1){break j}T:{if(b){v[22656]=0;Q(70,h+80|0,2580)|0;b=v[22656];v[22656]=0;if((b|0)==1){break j}break T}if(w[c+2|0]){v[22656]=0;Q(70,h+80|0,2576)|0;b=v[22656];v[22656]=0;if((b|0)!=1){break T}break j}v[22656]=0;Q(70,h+80|0,13843)|0;b=v[22656];v[22656]=0;if((b|0)==1){break j}}v[22656]=0;Q(1168,h+96|0,h+80|0)|0;b=v[22656];v[22656]=0;if((b|0)!=1){break J}f=P()|0;O()|0;vb(h+80|0);break c}f=P()|0;O()|0;break c}f=P()|0;O()|0;break c}f=P()|0;O()|0;break L}f=P()|0;O()|0;break i}f=P()|0;O()|0;break c}f=P()|0;O()|0;vb(h+80|0);if(d){vb(h+32|0);vb(h+48|0)}if(!e){break c}}vb(h+32|0)}vb(h+48|0);break c}f=P()|0;O()|0;break c}vb(h+80|0);if(j>>>0<12){break s}v[22656]=0;b=Q(70,h+80|0,14911)|0;d=v[22656];v[22656]=0;U:{V:{W:{X:{Y:{Z:{_:{$:{aa:{if((d|0)!=1){v[22656]=0;Q(1168,h+112|0,b|0)|0;d=v[22656];v[22656]=0;if((d|0)==1){break aa}vb(b);v[22656]=0;b=Q(70,h+80|0,14911)|0;d=v[22656];v[22656]=0;if((d|0)==1){break $}v[22656]=0;Q(1168,h+96|0,b|0)|0;d=v[22656];v[22656]=0;if((d|0)==1){break _}vb(b);v[22656]=0;b=Cg(c);d=v[22656];v[22656]=0;if((d|0)==1){break Z}ba:{if(b){b=0;v[22656]=0;d=Go(c);e=v[22656];v[22656]=0;if((e|0)!=1){v[22656]=0;v[h+28>>2]=d&4095;R(2105,h+80|0,h+28|0);d=v[22656];v[22656]=0;if((d|0)!=1){break ba}}f=P()|0;O()|0;break c}if(w[c+3|0]){b=v[v[i>>2]+8>>2];d=w[c+3|0];v[22656]=0;b=wz(b,d);d=v[22656];v[22656]=0;if((d|0)==1){break Y}v[22656]=0;d=W(716,h+16|0,1,b|0)|0;b=v[22656];v[22656]=0;if((b|0)==1){break Y}v[22656]=0;R(737,h|0,c+5|0);e=v[22656];v[22656]=0;b=1;if((e|0)==1){break X}v[22656]=0;U(2058,h+80|0,d|0,h|0);d=v[22656];v[22656]=0;if((d|0)!=1){break ba}f=P()|0;O()|0;vb(h);break k}b=0;v[22656]=0;Q(70,h+80|0,13839)|0;d=v[22656];v[22656]=0;if((d|0)==1){break V}}v[22656]=0;Q(1168,h+112|0,h+80|0)|0;d=v[22656];v[22656]=0;if((d|0)==1){break W}vb(h+80|0);if(b){vb(h);vb(h+16|0)}v[22656]=0;b=Cg(c);d=v[22656];v[22656]=0;if((d|0)==1){break l}ca:{if(b){v[22656]=0;Q(70,h+80|0,8341)|0;b=v[22656];v[22656]=0;if((b|0)==1){break l}break ca}if(w[c+3|0]){v[22656]=0;Q(70,h+80|0,8341)|0;b=v[22656];v[22656]=0;if((b|0)!=1){break ca}break l}v[22656]=0;Q(70,h+80|0,13839)|0;b=v[22656];v[22656]=0;if((b|0)==1){break l}}v[22656]=0;Q(1168,h+96|0,h+80|0)|0;b=v[22656];v[22656]=0;if((b|0)!=1){break U}f=P()|0;O()|0;vb(h+80|0);break c}f=P()|0;O()|0;break c}f=P()|0;O()|0;vb(b);break c}f=P()|0;O()|0;break c}f=P()|0;O()|0;vb(b);break c}f=P()|0;O()|0;break c}f=P()|0;O()|0;break c}f=P()|0;O()|0;break k}f=P()|0;O()|0;vb(h+80|0);if(!b){break c}vb(h);break k}f=P()|0;O()|0;break c}vb(h+80|0);if(!f){break n}}da:{ea:{if(Ab(h+112|0)>>>0>f>>>0){v[22656]=0;Y(151,h+80|0,h+112|0,0,f|0);b=v[22656];v[22656]=0;if((b|0)!=1){break ea}f=P()|0;O()|0;break c}if(g){b=Ab(h+112|0);v[22656]=0;b=W(716,h+80|0,f-b|0,32)|0;c=v[22656];v[22656]=0;if((c|0)==1){break p}v[22656]=0;Q(1168,h+112|0,b|0)|0;c=v[22656];v[22656]=0;if((c|0)==1){f=P()|0;O()|0;vb(b);break c}vb(b);if(Ab(h+96|0)>>>0>f>>>0){break o}break da}if(Ab(h+96|0)>>>0<=f>>>0){break n}break o}b=h+80|0;Eb(h+112|0,b);vb(b);if(Ab(h+96|0)>>>0>f>>>0){break o}if(!g){break n}}b=Ab(h+96|0);v[22656]=0;b=W(716,h+80|0,f-b|0,32)|0;c=v[22656];v[22656]=0;fa:{if((c|0)!=1){v[22656]=0;Q(1168,h+96|0,b|0)|0;c=v[22656];v[22656]=0;if((c|0)==1){break fa}vb(b);break n}f=P()|0;O()|0;break c}f=P()|0;O()|0;vb(b);break c}f=P()|0;O()|0;break c}f=P()|0;O()|0;break c}v[22656]=0;Y(151,h+80|0,h+96|0,0,f|0);b=v[22656];v[22656]=0;if((b|0)!=1){b=h+80|0;Eb(h+96|0,b);vb(b);break n}f=P()|0;O()|0;break c}v[22656]=0;U(2101,a|0,h+112|0,h+96|0);a=v[22656];v[22656]=0;if((a|0)==1){break h}}vb(h+96|0);vb(h+112|0);gb=h+128|0;return}f=P()|0;O()|0;break c}vb(h+16|0);break c}f=P()|0;O()|0;break c}vb(b);break c}f=P()|0;O()|0;break c}f=P()|0;O()|0;break c}f=P()|0;O()|0;break c}f=P()|0;O()|0;break c}f=P()|0;O()|0}vb(h+96|0)}vb(h+112|0);S(f|0);L()}function Zla(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,y=0,z=0,A=0,C=0,D=0;d=gb-1344|0;gb=d;vc(b);h=gb-32|0;gb=h;f=h+24|0;YU(f,d+232|0);e=yb(f);f=v[h+28>>2];j=v[h+24>>2];v[h+8>>2]=j;v[h+12>>2]=f;v[h>>2]=j;v[h+4>>2]=f;f=b;j=h+16|0;cc(j,b,h);j=yb(j);if((j|0)==(e|0)){Rb(f,yb(h+24|0))}gb=h+32|0;a:{b:{c:{if((e|0)!=(j|0)){break c}if(!$U(d+232|0)){break c}if(Pb(b,Qc(_U(d+232|0),jb))){break b}}b=0;break a}if(!c){b=1;break a}vc(b);b=le(d+232|0,b);v[22656]=0;R(817,d+216|0,b|0);f=v[22656];v[22656]=0;d:{e:{f:{g:{h:{i:{j:{if((f|0)!=1){xb(b);v[22656]=0;U(818,d+200|0,d+216|0,1196314451);b=v[22656];v[22656]=0;if((b|0)!=1){b=0;v[22656]=0;U(818,d+184|0,d+216|0,1280331091);f=v[22656];v[22656]=0;if((f|0)!=1){if(cd(d+200|0)){break d}if(cd(d+184|0)){break d}v[22656]=0;R(367,a|0,1);b=v[22656];v[22656]=0;k:{if((b|0)==1){break k}v[22656]=0;Bg(a);b=v[22656];v[22656]=0;if((b|0)==1){break k}v[a+480188>>2]=4;v[a+480208>>2]=16842752;b=d+184|0;C=d,D=Vb(b),v[C+24>>2]=D;C=d,D=Zb(b),v[C+144>>2]=D;if(!Gb(d+24|0,d+144|0)){break j}j=c&2;l:{m:{while(1){h=v[d+24>>2];if(!ei(a)){break j}b=x[a+480190>>1]+1|0;u[a+480190>>1]=b;v[22656]=0;b=B(b&65535,104)+a|0;e=b+484380|0;R(424,e|0,1);f=v[22656];v[22656]=0;n:{o:{if((f|0)!=1){v[22656]=0;f=Q(819,h|0,d+232|0)|0;m=v[22656];v[22656]=0;if((m|0)==1){break o}if(!f){break e}if(fv(d+232|0)){break n}break e}a=P()|0;O()|0;break i}a=P()|0;O()|0;break i}v[22656]=0;f=Q(70,d+56|0,d+232|0)|0;m=v[22656];v[22656]=0;if((m|0)!=1){m=x[a+480190>>1];v[22656]=0;Q(301,((m<<5)+a|0)+946304|0,f|0)|0;m=v[22656];v[22656]=0;if((m|0)==1){break m}vb(f);f=w[d+268|0]|w[d+269|0]<<8|(w[d+270|0]<<16|w[d+271|0]<<24);v[e>>2]=f;v[b+484388>>2]=f;v[b+484384>>2]=w[d+264|0]|w[d+265|0]<<8|(w[d+266|0]<<16|w[d+267|0]<<24);u[b+484410>>1]=255;b=b+484414|0;u[b>>1]=x[b>>1]|2;if(j){b=Rc(d+56|0,8,1,0,0);v[22656]=0;W(329,b|0,e|0,h|0)|0;b=v[22656];v[22656]=0;if((b|0)==1){break l}}b=d+24|0;Eh(b);if(Gb(b,d+144|0)){continue}break j}break}a=P()|0;O()|0;break i}a=P()|0;O()|0;vb(f);break i}a=P()|0;O()|0;break i}a=P()|0;O()|0;break i}a=P()|0;O()|0;break h}a=P()|0;O()|0;break g}a=P()|0;O()|0;xb(b);break f}b=d+200|0;C=d,D=Vb(b),v[C+176>>2]=D;C=d,D=Zb(b),v[C+168>>2]=D;n=a+484360|0;p:{q:{r:{s:{t:{u:{v:{w:{x:{y:{z:{if(!Gb(d+176|0,d+168|0)){break z}q=a+484344|0;e=1;s=c&1;j=d+1324|0;m=d+1328|0;o=d+1320|0;y=d+1318|0;z=a+484380|0;while(1){c=v[d+176>>2];if(!(e&1)){v[22656]=0;b=T(417,n|0)|0;f=v[22656];v[22656]=0;if((f|0)==1){break y}if(!b){break z}}cm(Sb(n));v[22656]=0;b=Q(820,c|0,d+232|0)|0;f=v[22656];v[22656]=0;if((f|0)==1){break x}if(!b|(w[y|0]|w[y+1|0]<<8)){break e}b=w[o|0]|w[o+1|0]<<8|(w[o+2|0]<<16|w[o+3|0]<<24);if(!b|b>>>0>4){break e}b=Sb(n);v[22656]=0;U(6,d+56|0,5,d+232|0);f=v[22656];v[22656]=0;if((f|0)==1){break p}v[22656]=0;R(418,b|0,d+56|0);b=v[22656];v[22656]=0;if((b|0)==1){break q}vb(d+56|0);A:{if(s){b=m;b=w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24);v[22656]=0;U(288,d+56|0,c|0,b|0);b=v[22656];v[22656]=0;if((b|0)!=1){break A}a=P()|0;O()|0;break i}v[22656]=0;T(215,d+120|0)|0;b=v[22656];v[22656]=0;if((b|0)==1){break r}Uw(d+56|0,d+120|0)}b=d+56|0;r=kc(d+144|0,b);xb(b);if(!s){xb(d+120|0)}Qb(d+56|0,0,64);k=1;B:{C:{while(1){v[22656]=0;b=(B(k,34)+d|0)+198|0;c=b+32|0;R(712,d+8|0,c|0);f=v[22656];v[22656]=0;if((f|0)==1){break w}D:{if(!w[v[d+8>>2]]){break D}f=w[b- -64|0];if(f>>>0>15){break C}b=w[b+65|0];if(b>>>0>64){break C}if(!fv(c)){break C}if(!x[a+480190>>1]){break D}h=b<<2;e=f<<4;c=1;f=0;b=1;while(1){v[22656]=0;R(713,d+24|0,d+8|0);g=v[22656];v[22656]=0;E:{F:{if((g|0)!=1){v[22656]=0;g=Q(821,d+24|0,((c<<5)+a|0)+946304|0)|0;l=v[22656];v[22656]=0;if((l|0)==1){break F}vb(d+24|0);if(g){break E}C=vd(d+56|0,k),D=b,u[C>>1]=D;c=B(c,104)+a|0;g=c+484410|0;l=x[g>>1];if((l|0)!=255){f=b;if(w[c+484417|0]!=(e&255)|(h|0)!=(l|0)){break E}}t[c+484417|0]=e;u[g>>1]=h;break D}a=P()|0;O()|0;break s}a=P()|0;O()|0;vb(d+24|0);break s}b=b+1|0;c=b&65535;if(c>>>0<=x[a+480190>>1]){continue}break}c=f&65535;if(!c){break D}if(!ei(a)){break D}b=x[a+480190>>1]+1|0;u[a+480190>>1]=b;C=vd(d+56|0,k),D=b,u[C>>1]=D;b=x[a+480190>>1];v[22656]=0;f=B(b,104);b=f+z|0;Pl(b);g=v[22656];v[22656]=0;if((g|0)==1){break v}g=B(c,104)+z|0;bp(b,g);f=a+f|0;u[f+484410>>1]=h;t[f+484417|0]=e;v[22656]=0;Q(747,b|0,g|0)|0;b=v[22656];v[22656]=0;if((b|0)==1){break v}f=a+946304|0;b=f+(x[a+480190>>1]<<5)|0;c=f+(c<<5)|0;f=v[c+4>>2];v[b>>2]=v[c>>2];v[b+4>>2]=f;f=v[c+28>>2];v[b+24>>2]=v[c+24>>2];v[b+28>>2]=f;f=v[c+20>>2];v[b+16>>2]=v[c+16>>2];v[b+20>>2]=f;f=v[c+12>>2];v[b+8>>2]=v[c+8>>2];v[b+12>>2]=f}k=k+1|0;if((k|0)!=32){continue}break}h=0;v[d+48>>2]=0;v[d+40>>2]=0;v[d+44>>2]=0;v[d+32>>2]=0;v[d+36>>2]=0;v[d+24>>2]=0;v[d+28>>2]=0;A=w[o|0]|w[o+1|0]<<8;c=64;l=65535;k=0;G:{while(1){H:{if(!k){v[22656]=0;b=Q(191,d+144|0,1)|0;f=v[22656];v[22656]=0;if((f|0)==1){break G}if(!b){break H}}c=c+1|0;if(c>>>0>=64){v[22656]=0;l=W(545,q|0,64,0)|0;b=v[22656];v[22656]=0;if((b|0)==1){break G}if((l|0)==65535){break B}c=0;b=Sb(n);v[22656]=0;R(710,b|0,l|0);b=v[22656];v[22656]=0;if((b|0)==1){break G}}b=_b(q,l&65535);v[22656]=0;b=Yc(b,c,0);f=v[22656];v[22656]=0;if((f|0)==1){break u}if(!A){continue}e=0;f=0;while(1){g=(d+24|0)+B(e,7)|0;e=w[g+6|0];I:{if(e){t[g+6|0]=e-1;e=w[g+4|0]|w[g+5|0]<<8;t[b+4|0]=e;t[b+5|0]=e>>>8;e=w[g|0]|w[g+1|0]<<8|(w[g+2|0]<<16|w[g+3|0]<<24);t[b|0]=e;t[b+1|0]=e>>>8;t[b+2|0]=e>>>16;t[b+3|0]=e>>>24;k=k-1|0;break I}v[22656]=0;e=Q(191,d+144|0,1)|0;i=v[22656];v[22656]=0;if((i|0)==1){break t}if(!e){break I}e=j;if(v[d+152>>2]==(w[e|0]|w[e+1|0]<<8|(w[e+2|0]<<16|w[e+3|0]<<24))){h=Sb(n);e=Sb(n);v[22656]=0;e=T(468,e|0)|0;i=v[22656];v[22656]=0;if((i|0)==1){break t}cf(h,e);h=c}v[22656]=0;e=T(374,r|0)|0;i=v[22656];v[22656]=0;J:{if((i|0)!=1){e=e<<24>>24;if((e|0)>=0){break J}i=e&127;t[g+6|0]=i;e=w[g+4|0]|w[g+5|0]<<8;t[b+4|0]=e;t[b+5|0]=e>>>8;e=w[g|0]|w[g+1|0]<<8|(w[g+2|0]<<16|w[g+3|0]<<24);t[b|0]=e;t[b+1|0]=e>>>8;t[b+2|0]=e>>>16;t[b+3|0]=e>>>24;k=i+k|0;break I}a=P()|0;O()|0;break s}if((e-1&255)>>>0<=35){t[b|0]=e+48}v[22656]=0;e=T(374,r|0)|0;i=v[22656];v[22656]=0;K:{L:{if((i|0)!=1){C=b,D=w[vd(d+56|0,e&31)|0],t[C+1|0]=D;if(!(e&128)){break L}t[b+3|0]=w[g+3|0];t[b+5|0]=w[g+5|0];break K}a=P()|0;O()|0;break s}v[22656]=0;R(403,d+8|0,r|0);e=v[22656];v[22656]=0;M:{if((e|0)!=1){e=d+8|0;p=qd(e);i=w[e|0];if(i>>>0>19){break K}t[b+3|0]=w[(i<<1)+33264|0];p=w[p|0];t[b+5|0]=p;if((i|0)!=18|p>>>0<32){break M}t[b+3|0]=17;break K}a=P()|0;O()|0;break s}e=w[e|0];if(819137>>>e&1){break K}t[b+5|0]=w[(e<<1)+33265|0]|p&15}e=w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24);t[g|0]=e;t[g+1|0]=e>>>8;t[g+2|0]=e>>>16;t[g+3|0]=e>>>24;e=w[b+4|0]|w[b+5|0]<<8;t[g+4|0]=e;t[g+5|0]=e>>>8}b=b+6|0;f=f+1|0;e=f&65535;if(A>>>0>e>>>0){continue}break}continue}break}if(!((h|0)!=0|c>>>0<63)){break B}b=l&65535;if((b|0)==65535){break B}b=_b(q,b);v[22656]=0;f=Be(d+8|0,14,h&255);h=v[22656];v[22656]=0;if((h|0)!=1){c=Fh(Ue(f,c));v[22656]=0;Q(431,b|0,c|0)|0;b=v[22656];v[22656]=0;if((b|0)!=1){break B}}a=P()|0;O()|0;break s}a=P()|0;O()|0;break s}xb(d+144|0);break e}xb(d+144|0);b=d+176|0;Eh(b);e=0;if(Gb(b,d+168|0)){continue}break}}v[22656]=0;Qi(n,0);b=v[22656];v[22656]=0;N:{O:{if((b|0)!=1){v[22656]=0;b=Q(2,d+232|0,3524)|0;c=v[22656];v[22656]=0;if((c|0)==1){break O}Eb(a+1298304|0,b);vb(b);v[22656]=0;c=Q(2,d+232|0,3826)|0;f=v[22656];v[22656]=0;b=1;if((f|0)==1){break N}Eb(a+1298316|0,c);vb(c);v[a+1298364>>2]=5;break d}a=P()|0;O()|0;break i}a=P()|0;O()|0;break i}a=P()|0;O()|0;break i}a=P()|0;O()|0;break i}a=P()|0;O()|0;break i}a=P()|0;O()|0;break s}a=P()|0;O()|0;break s}a=P()|0;O()|0;break s}a=P()|0;O()|0}xb(d+144|0);break i}a=P()|0;O()|0;break i}a=P()|0;O()|0;vb(d+56|0);break i}a=P()|0;O()|0}jd(d+184|0)}jd(d+200|0)}ke(d+216|0)}S(a|0);L()}b=0}jd(d+184|0);jd(d+200|0);ke(d+216|0)}gb=d+1344|0;return b|0}function Mla(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,y=0,z=0,A=0,C=0,D=0,E=0,F=0,G=0;d=gb-304|0;gb=d;vc(b);a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{if(!ev(b,d+208|0)){break j}if(!UU(d+208|0)){break j}if(!Pb(b,Qc(TU(d+208|0),jb))){break j}if(!c){n=1;break j}if(!Wc(b,w[d+208|4])){break j}Gd(a,268435456);Bg(a);v[a+480208>>2]=4;Ob(a+1074312|0,114,1);e=d+88|0;h=Tb(e,12454);Eb(a+1298304|0,h);vb(h);h=Tb(e,7552);Eb(a+1298316|0,h);vb(h);v[a+1298364>>2]=5;h=d+16|0;pf(h,d+208|6,48,3);Bc(e,h);Eb(a+1298268|0,e);vb(e);u[a+480188>>1]=w[d+262|0]+1;v[a+480228>>2]=w[d+265|0];v[a+480204>>2]=B(w[d+266|0],1e4);v[a+480196>>2]=w[d+267|0];if(w[d+262|0]){e=0;while(1){u[((e<<5)+a|0)+480284>>1]=B(w[(d+e|0)+268|0],17);e=e+1|0;if(e>>>0<w[d+262|0]){continue}break}}u[a+480190>>1]=w[d+300|0];e=w[d+302|0]|w[d+303|0]<<8;l=d+192|0;h=vh(l);k:{if(!e){break k}v[22656]=0;R(841,l|0,e|0);i=v[22656];v[22656]=0;if((i|0)!=1){v[22656]=0;mr(l,e);e=v[22656];v[22656]=0;if((e|0)!=1){break k}}a=P()|0;O()|0;ci(h);S(a|0);L()}e=w[d+302|0]|w[d+303|0]<<8;v[22656]=0;U(833,b|0,l|0,e|0);e=v[22656];v[22656]=0;if((e|0)==1){break i}s=mc(d+176|0);o=mc(d+160|0);e=w[d+301|0];v[22656]=0;W(564,b|0,s|0,e|0)|0;e=v[22656];v[22656]=0;if((e|0)==1){break f}h=w[d+300|0];e=0;v[22656]=0;W(564,b|0,o|0,h|0)|0;h=v[22656];v[22656]=0;if((h|0)==1){break f}if(w[d+300|0]){p=c&2;h=d+88|0;q=h|4;m=d+126|0;r=h|6;while(1){v[22656]=0;h=e;e=e+1|0;i=B(e,104)+a|0;g=i+484380|0;R(424,g|0,0);f=v[22656];v[22656]=0;l:{m:{if((f|0)!=1){f=Mb(o,h);if(!(w[f|0]|w[f+1|0]<<8|(w[f+2|0]<<16|w[f+3|0]<<24))){break l}f=Mb(o,h);f=w[f|0]|w[f+1|0]<<8|(w[f+2|0]<<16|w[f+3|0]<<24);v[22656]=0;f=Q(190,b|0,f|0)|0;k=v[22656];v[22656]=0;if((k|0)==1){break c}if(!f){break l}v[22656]=0;f=Q(834,b|0,d+88|0)|0;k=v[22656];v[22656]=0;if((k|0)==1){break c}if(!f){break l}v[22656]=0;Ke(d+72|0,2,r);f=v[22656];v[22656]=0;if((f|0)!=1){v[22656]=0;R(324,d+16|0,d+72|0);f=v[22656];v[22656]=0;if((f|0)!=1){break m}}e=P()|0;O()|0;break b}e=P()|0;O()|0;break b}v[22656]=0;Q(301,((e<<5)+a|0)+946304|0,d+16|0)|0;f=v[22656];v[22656]=0;n:{o:{p:{q:{r:{if((f|0)!=1){vb(d+16|0);v[22656]=0;Mk(d+72|0,2,m);f=v[22656];v[22656]=0;if((f|0)==1){break r}v[22656]=0;R(324,d+16|0,d+72|0);f=v[22656];v[22656]=0;if((f|0)==1){break r}v[22656]=0;Q(303,i+484423|0,d+16|0)|0;f=v[22656];v[22656]=0;if((f|0)==1){break q}vb(d+16|0);if(w[d+138|0]<=15){f=i+484414|0;u[f>>1]=x[f>>1]|32;u[i+484408>>1]=B(w[d+138|0],17)}t[d+16|0]=w[d+139|0];v[22656]=0;t[d+72|0]=64;f=ac(d+16|0,d+72|0);k=v[22656];v[22656]=0;if((k|0)==1){break p}u[i+484412>>1]=w[f|0];v[i+484404>>2]=w[d+141|0]|w[d+142|0]<<8;f=i+484384|0;v[f>>2]=w[d+147|0]|w[d+148|0]<<8|(w[d+149|0]<<16|w[d+150|0]<<24);k=i+484388|0;v[k>>2]=w[d+151|0]|w[d+152|0]<<8|(w[d+153|0]<<16|w[d+154|0]<<24);v[g>>2]=w[d+155|0]|w[d+156|0]<<8|(w[d+157|0]<<16|w[d+158|0]<<24);if(t[d+140|0]&1){break o}n=v[f>>2];f=v[k>>2];break n}e=P()|0;O()|0;vb(d+16|0);break b}e=P()|0;O()|0;break b}e=P()|0;O()|0;vb(d+16|0);break b}e=P()|0;O()|0;break b}n=v[f>>2]>>>1|0;v[f>>2]=n;f=v[k>>2]>>>1|0;v[k>>2]=f;v[g>>2]=v[g>>2]>>>1}s:{if(f>>>0<=n>>>0){break s}i=i+484414|0;u[i>>1]=x[i>>1]|2;if(!(w[d+140|0]&2)){break s}u[i>>1]=x[i>>1]|4}v[22656]=0;xk(g);i=v[22656];v[22656]=0;if((i|0)==1){break c}if(!p){break l}h=Mb(o,h);h=w[h|0]|w[h+1|0]<<8|(w[h+2|0]<<16|w[h+3|0]<<24);i=w[q|0];v[22656]=0;Q(190,b|0,h+i|0)|0;h=v[22656];v[22656]=0;if((h|0)==1){break c}h=Rc(d+16|0,t[d+140|0]&1?16:8,1,0,1);v[22656]=0;W(329,h|0,g|0,b|0)|0;h=v[22656];v[22656]=0;if((h|0)!=1){break l}e=P()|0;O()|0;break b}if(w[d+300|0]>e>>>0){continue}break}}n=1;t:{if(!(c&1)){break t}v[d+68>>2]=0;f=a+484360|0;cm(Sb(f));F=d,G=Vb(l),v[F+64>>2]=G;F=d,G=Zb(l),v[F+56>>2]=G;k=a+484344|0;if(Gb(d- -64|0,d+56|0)){c=d+88|0;r=c|5;p=c|4;while(1){h=v[d- -64>>2];c=h;u:{if(w[c+3|0]>=w[d+301|0]|w[c+2|0]>w[d+262|0]){break u}c=Mb(s,w[c+3|0]);c=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);v[22656]=0;c=Q(190,b|0,c|0)|0;e=v[22656];v[22656]=0;if((e|0)==1){break g}if(!c){break u}v[22656]=0;R(837,b|0,d+88|0);c=v[22656];v[22656]=0;if((c|0)==1){break h}if(!w[p|0]){break u}e=w[h|0]|w[h+1|0]<<8;c=e;t[d+16|0]=w[r|0];i=w[d+262|0];g=w[h+2|0];v[22656]=0;t[d+72|0]=i-g;i=ac(d+16|0,d+72|0);g=v[22656];v[22656]=0;if((g|0)==1){break d}q=w[i|0];i=w[h|0]|w[h+1|0]<<8;g=w[p|0];v[22656]=0;v[d+52>>2]=g+i;i=Lc(d+68|0,d+52|0);g=v[22656];v[22656]=0;if((g|0)==1){break e}v[d+68>>2]=v[i>>2];v[d+40>>2]=0;v[d+44>>2]=0;v[d+32>>2]=0;v[d+36>>2]=0;v[d+24>>2]=0;v[d+28>>2]=0;v[d+16>>2]=0;v[d+20>>2]=0;if(!w[p|0]){break u}y=c>>>6|0;e=e&63;A=0;while(1){v:{w:{x:{y:{z:{A:{B:{i=e>>>0>63;y=i+y|0;c=y&65535;if(tc(Sb(f))>>>0<=c>>>0){g=Sb(f);v[22656]=0;R(502,g|0,y+1&65535);g=v[22656];v[22656]=0;if((g|0)==1){break B}v[22656]=0;g=W(545,k|0,64,0)|0;m=v[22656];v[22656]=0;if((m|0)==1){break B}F=sc(Sb(f),c),G=g,u[F>>1]=G}m=x[sc(Sb(f),c)>>1];v[22656]=0;c=me(k,m);g=v[22656];v[22656]=0;if((g|0)==1){break z}if(!c){break u}c=_b(k,m);g=w[h+2|0];v[22656]=0;z=i?0:e;e=Yc(c,z,g);c=v[22656];v[22656]=0;if((c|0)==1){break w}i=0;if(q){break A}break x}e=P()|0;O()|0;break b}while(1){v[22656]=0;R(839,d+72|0,b|0);c=v[22656];v[22656]=0;if((c|0)==1){break y}c=d+72|0;g=qd(c);D=Ve(c);C=ej(c);E=fc(c);j=0;c=w[c|0];if((c-1&255)>>>0<=142){j=(B((c&240)>>>4|0,12)+(c&15)|0)+13|0;t[(d+16|0)+i|0]=j}t[e|0]=j;c=w[g|0];t[e+2|0]=1;t[e+1|0]=c;c=w[D|0];C:{if((c|0)!=255){t[e+4|0]=c;break C}t[e+2|0]=0}c=w[C|0];D:{if(c>>>0>22){break D}t[e+3|0]=w[c+33312|0];g=w[E|0];t[e+5|0]=g;c=e+5|0;E:{switch(w[C|0]-4|0){case 3:t[c|0]=g&3|64;break D;case 4:t[c|0]=g&3|48;break D;case 7:if(Nb(l)>>>0<=g>>>0){break D}j=c;c=Mb(l,g);g=w[c|0]|w[c+1|0]<<8;t[j|0]=g>>>6;c=_b(k,m);j=x[a+480188>>1];v[22656]=0;c=Yc(c,z,j-1&65535);j=v[22656];v[22656]=0;if((j|0)!=1){t[c+3|0]=14;t[c+5|0]=g&63;break D}e=P()|0;O()|0;break b;case 8:t[c|0]=v[d+52>>2]>>>6;c=_b(k,m);g=x[a+480188>>1];v[22656]=0;c=Yc(c,z,g-1&65535);g=v[22656];v[22656]=0;if((g|0)!=1){t[c+3|0]=14;t[c+5|0]=w[d+52|0]&63;break D}e=P()|0;O()|0;break b;case 10:t[c|0]=g&15|128;break D;case 12:v[22656]=0;t[d+15|0]=15;g=ac(c,d+15|0);j=v[22656];v[22656]=0;if((j|0)!=1){t[c|0]=w[g|0]|208;break D}e=P()|0;O()|0;break b;case 13:v[22656]=0;t[d+15|0]=15;g=ac(c,d+15|0);j=v[22656];v[22656]=0;if((j|0)!=1){t[c|0]=w[g|0]|192;break D}e=P()|0;O()|0;break b;case 14:v[22656]=0;t[d+15|0]=15;g=ac(c,d+15|0);j=v[22656];v[22656]=0;if((j|0)!=1){t[c|0]=w[g|0]|224;break D}e=P()|0;O()|0;break b;case 0:case 16:case 17:if(!(g&15)){break D}j=g&240;if(!j|(j|0)==240){break D}t[c|0]=g|15;break D;case 9:case 18:break E;default:break D}}if(j&255){break D}t[e|0]=w[(d+16|0)+i|0]}e=e+6|0;i=i+1|0;if((q|0)!=(i|0)){continue}break}break x}e=P()|0;O()|0;break b}e=P()|0;O()|0;break b}if(q>>>0>=w[r|0]){break v}c=w[r|0];v[22656]=0;Q(318,b|0,B(c-q|0,5)|0)|0;c=v[22656];v[22656]=0;if((c|0)!=1){break v}}e=P()|0;O()|0;break b}e=z+1|0;A=A+1|0;if(A>>>0<w[p|0]){continue}break}}c=d- -64|0;Qe(c);if(Gb(c,d+56|0)){continue}break}}F:{a=v[d+68>>2];b=a&63;if(!b){break F}c=Sb(f);v[22656]=0;a=a>>>6|0;c=Q(472,c|0,a&65535)|0;e=v[22656];v[22656]=0;if((e|0)!=1){if(!c){break F}a=_b(k,x[sc(Sb(f),a&65535)>>1]);v[22656]=0;da(840,a|0,b|0,0,1)|0;a=v[22656];v[22656]=0;if((a|0)!=1){break F}}e=P()|0;O()|0;break b}a=Sb(f);F=d,G=Vb(a),v[F+88>>2]=G;F=d,G=Zb(a),v[F+16>>2]=G;if(!Gb(d+88|0,d+16|0)){break t}i=65535;while(1){a=v[d+88>>2];if(x[a>>1]==65535){G:{if((i&65535)!=65535){break G}v[22656]=0;i=W(545,k|0,64,0)|0;b=v[22656];v[22656]=0;if((b|0)!=1){break G}e=P()|0;O()|0;break b}u[a>>1]=i}a=d+88|0;of(a);if(Gb(a,d+16|0)){continue}break}}di(o);di(s);ci(l)}gb=d+304|0;return n|0}e=P()|0;O()|0;break a}e=P()|0;O()|0;break b}e=P()|0;O()|0;break b}e=P()|0;O()|0;break b}e=P()|0;O()|0;break b}e=P()|0;O()|0;break b}e=P()|0;O()|0}di(o);di(s)}ci(l);S(e|0);L()}function j$(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,u=0,y=0,z=0,A=0,C=0,D=0,E=0,F=0,G=0,H=0;e=gb-1504|0;gb=e;vc(b);ss(a);a:{b:{c:{d:{e:{if(!$w(b,e+1480|0)){break e}if(!kG(e+1480|0)){break e}if(!c){g=1;break e}E=e+1498|0;c=E;if(!rs(b,w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24))){break e}c=E;s=e+1492|0;if(!rs(b,(w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24))+((w[s|0]|w[s+1|0]<<8)<<2)|0)){break e}_w(a);G=e,H=Zw(),v[G+104>>2]=H;d=e+104|0;Yw(lj(a)+32|0,d);qs(d);n=v[lj(a)+32>>2];c=e+1494|0;v[e+1476>>2]=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);G=e,H=lm(b),v[G+1216>>2]=H;v[e+1176>>2]=214748364;c=e+1216|0;G=e,H=B(v[Fb(c,e+1176|0)>>2],20),v[G+104>>2]=H;Nt(n,v[Fb(e+1476|0,d)>>2]);Qb(c,0,256);C=dd(e+1200|0);f:{if(w[s|0]|w[s+1|0]<<8){k=e+1176|4;l=e+1192|0;D=e+1194|0;q=e+1190|0;i=e+1188|0;while(1){c=E;c=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);v[22656]=0;c=Q(190,b|0,c+(F<<2)|0)|0;d=v[22656];v[22656]=0;g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{if((d|0)==1){break r}g=0;if(!c){break f}v[22656]=0;c=Q(191,b|0,4)|0;d=v[22656];v[22656]=0;if((d|0)==1){break r}if(!c){break f}v[22656]=0;d=T(192,b|0)|0;c=v[22656];v[22656]=0;if((c|0)==1){break q}v[22656]=0;c=Q(190,b|0,d|0)|0;f=v[22656];v[22656]=0;if((f|0)==1){break q}if(!c){break f}v[22656]=0;c=Q(193,b|0,e+1176|0)|0;f=v[22656];v[22656]=0;if((f|0)==1){break p}if(!c){break f}c=w[i|0]|w[i+1|0]<<8;v[22656]=0;c=W(194,b|0,C|0,c|0)|0;f=v[22656];v[22656]=0;if((f|0)==1){break p}if(!c){break f}c=w[i|0]|w[i+1|0]<<8?v[C>>2]:0;f=w[i|0]|w[i+1|0]<<8;v[22656]=0;j=T(195,b|0)|0;h=v[22656];v[22656]=0;if((h|0)==1){break o}d=d+20|0;if(j>>>0<=d+(f<<3)>>>0){break f}j=d+((w[i|0]|w[i+1|0]<<8)<<3)|0;if(!(t[q|0]&1)){f=0;if(!(w[i|0]|w[i+1|0]<<8)){break g}while(1){if(!c){break f}v[22656]=0;d=W(196,c|0,n|0,v[e+1476>>2])|0;h=v[22656];v[22656]=0;if((h|0)==1){break n}if(!d){break f}v[22656]=0;d=Q(190,b|0,j|0)|0;h=v[22656];v[22656]=0;if((h|0)==1){break n}if(!d){break f}d=c;h=d+4|0;h=wd(e+1168|0,lc(n,w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24)),w[h|0]|w[h+1|0]<<8|(w[h+2|0]<<16|w[h+3|0]<<24));v[22656]=0;m=v[h+4>>2];v[e+32>>2]=v[h>>2];v[e+36>>2]=m;U(197,e+104|0,b|0,e+32|0);h=v[22656];v[22656]=0;if((h|0)==1){break m}if((yb(e+104|0)|0)!=(w[d+4|0]|w[d+5|0]<<8|(w[d+6|0]<<16|w[d+7|0]<<24))){break f}c=c+8|0;f=f+1|0;if(f>>>0<(w[i|0]|w[i+1|0]<<8)>>>0){continue}break}break g}s:{if(w[q|0]&4){if(!c){break f}v[22656]=0;d=W(196,c|0,n|0,v[e+1476>>2])|0;f=v[22656];v[22656]=0;if((f|0)==1){break l}if(!d){break f}u=lc(n,w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24));r=(w[c+4|0]|w[c+5|0]<<8|(w[c+6|0]<<16|w[c+7|0]<<24))&-2;if(!r){break f}h=w[D|0]|w[D+1|0]<<8;d=w[l|0]|w[l+1|0]<<8;v[22656]=0;d=Q(190,b|0,d+j|0)|0;f=v[22656];v[22656]=0;if((f|0)==1){break k}if(!d){break f}d=w[k|0]|w[k+1|0]<<8|(w[k+2|0]<<16|w[k+3|0]<<24);f=w[l|0]|w[l+1|0]<<8;v[22656]=0;d=Q(191,b|0,d-f|0)|0;f=v[22656];v[22656]=0;if((f|0)==1){break k}if(!d){break f}d=w[k|0]|w[k+1|0]<<8|(w[k+2|0]<<16|w[k+3|0]<<24);f=w[l|0]|w[l+1|0]<<8;v[22656]=0;U(198,e+80|0,b|0,d-f|0);d=v[22656];v[22656]=0;if((d|0)==1){break b}v[22656]=0;p=Lp(e+104|0,e+80|0);d=v[22656];v[22656]=0;if((d|0)==1){break c}xb(e+80|0);m=0;y=0;j=0;t:{u:{v:{if(!(w[i|0]|w[i+1|0]<<8)){break v}while(1){w:{v[22656]=0;f=Q(200,p|0,h+1|0)|0;d=v[22656];v[22656]=0;if((d|0)==1){break w}d=h&15;o=x[(d<<1)+27376>>1];x:{y:{if(o>>>0<=f>>>0){v[22656]=0;d=w[d+27456|0];z=Q(200,p|0,d|0)|0;A=v[22656];v[22656]=0;if((A|0)==1){break w}d=z+(f-o<<d)|0;if((d|0)!=(h|0)){h=d&15;break x}v[22656]=0;d=Q(200,p|0,4)|0;f=v[22656];v[22656]=0;if((f|0)==1){break w}if((d|0)==15){v[22656]=0;d=Q(200,p|0,1)|0;f=v[22656];v[22656]=0;if((f|0)==1){break w}f=65535;if(!d){break y}break v}f=d+65520|0}if(f>>>0>65535){break x}}d=f&1?0-(f+1>>>1|0)|0:f>>>1|0;o=j+u|0;A=o;z:{if(w[q|0]&2){y=d+y|0;d=y;break z}d=w[q+1|0]&2?d:d^32768}f=d>>>8|0;z=(w[q|0]|w[q+1|0]<<8)&1024;t[A+1|0]=z?d:f;t[o|0]=z?f:d;j=j+2|0}if(j>>>0>=r>>>0){m=m+1|0;if(m>>>0>=(w[i|0]|w[i+1|0]<<8)>>>0){break v}v[22656]=0;d=(m<<3)+c|0;f=W(196,d|0,n|0,v[e+1476>>2])|0;j=v[22656];v[22656]=0;if((j|0)==1){break w}if(!f){break s}r=(w[d+4|0]|w[d+5|0]<<8|(w[d+6|0]<<16|w[d+7|0]<<24))&-2;if(!r){break s}u=lc(n,w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24));j=0}if((w[i|0]|w[i+1|0]<<8)>>>0>m>>>0){continue}break v}break}g=V(27364)|0;if((O()|0)!=(ea(27364)|0)){break t}Z(g|0)|0;v[22656]=0;X(20);c=v[22656];v[22656]=0;if((c|0)==1){break u}}xb(e+104|0);break g}g=P()|0;O()|0}xb(e+104|0);break a}if(!c){break f}v[22656]=0;d=W(196,c|0,n|0,v[e+1476>>2])|0;f=v[22656];v[22656]=0;if((f|0)==1){break j}if(!d){break f}y=lc(n,w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24));r=w[c+4|0]|w[c+5|0]<<8|(w[c+6|0]<<16|w[c+7|0]<<24);h=w[D|0]|w[D+1|0]<<8;if((w[l|0]|w[l+1|0]<<8)>>>0>256){break f}v[22656]=0;d=Q(190,b|0,j|0)|0;f=v[22656];v[22656]=0;A:{B:{if((f|0)!=1){if(!d){break f}d=wd(e+72|0,e+1216|0,w[l|0]|w[l+1|0]<<8);v[22656]=0;f=v[d+4>>2];v[e+40>>2]=v[d>>2];v[e+44>>2]=f;U(201,e+104|0,b|0,e+40|0);d=v[22656];v[22656]=0;if((d|0)==1){break B}if(yb(e+104|0)>>>0<(w[l|0]|w[l+1|0]<<8)>>>0){break f}d=w[k|0]|w[k+1|0]<<8|(w[k+2|0]<<16|w[k+3|0]<<24);f=w[l|0]|w[l+1|0]<<8;v[22656]=0;d=Q(191,b|0,d-f|0)|0;f=v[22656];v[22656]=0;if((f|0)!=1){break A}}g=P()|0;O()|0;break a}g=P()|0;O()|0;break a}if(!d){break f}d=w[k|0]|w[k+1|0]<<8|(w[k+2|0]<<16|w[k+3|0]<<24);f=w[l|0]|w[l+1|0]<<8;v[22656]=0;U(198,e+80|0,b|0,d-f|0);d=v[22656];v[22656]=0;if((d|0)==1){break h}v[22656]=0;p=Lp(e+104|0,e+80|0);d=v[22656];v[22656]=0;if((d|0)==1){break i}xb(e+80|0);u=0;j=0;m=0;C:{D:{E:{F:{if(!(w[i|0]|w[i+1|0]<<8)){break F}while(1){G:{v[22656]=0;f=Q(200,p|0,h+1|0)|0;d=v[22656];v[22656]=0;if((d|0)==1){break G}d=h&7;o=w[d+27408|0];H:{I:{if(o>>>0<=f>>>0){v[22656]=0;d=w[d+27416|0];z=Q(200,p|0,d|0)|0;A=v[22656];v[22656]=0;if((A|0)==1){break G}d=z+(f-o<<d)|0;if((d|0)!=(h|0)){h=d&7;break H}v[22656]=0;d=Q(200,p|0,3)|0;f=v[22656];v[22656]=0;if((f|0)==1){break G}if((d|0)==7){v[22656]=0;d=Q(200,p|0,1)|0;f=v[22656];v[22656]=0;if((f|0)==1){break G}f=255;if(!d){break I}break F}f=d+248|0}if(f>>>0>255){break H}}d=w[(e+1216|0)+f|0];f=d+u|0;o=d;d=(w[q|0]|w[q+1|0]<<8)&2;t[j+y|0]=d?f:o;u=d?f:u;j=j+1|0}if(j>>>0>=r>>>0){m=m+1|0;if(m>>>0>=(w[i|0]|w[i+1|0]<<8)>>>0){break F}v[22656]=0;d=(m<<3)+c|0;f=W(196,d|0,n|0,v[e+1476>>2])|0;j=v[22656];v[22656]=0;if((j|0)==1){break G}if(!f){break E}r=w[d+4|0]|w[d+5|0]<<8|(w[d+6|0]<<16|w[d+7|0]<<24);y=lc(n,w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24));j=0}if((w[i|0]|w[i+1|0]<<8)>>>0>m>>>0){continue}break F}break}g=V(27364)|0;if((O()|0)!=(ea(27364)|0)){break C}Z(g|0)|0;v[22656]=0;X(20);c=v[22656];v[22656]=0;if((c|0)==1){break D}}xb(e+104|0);break g}xb(e+104|0);break f}g=P()|0;O()|0}xb(e+104|0);break a}xb(e+104|0);break f}g=P()|0;O()|0;break a}g=P()|0;O()|0;break a}g=P()|0;O()|0;break a}g=P()|0;O()|0;break a}g=P()|0;O()|0;break a}g=P()|0;O()|0;break a}g=P()|0;O()|0;break a}g=P()|0;O()|0;break a}g=P()|0;O()|0;break a}g=P()|0;O()|0;xb(e+80|0);break a}g=P()|0;O()|0;break a}F=F+1|0;if(F>>>0<(w[s|0]|w[s+1|0]<<8)>>>0){continue}break}}v[22656]=0;Vd(e+56|0,n);b=v[22656];v[22656]=0;if((b|0)==1){break d}b=v[e+60>>2];v[e+24>>2]=v[e+56>>2];v[e+28>>2]=b;rh(e- -64|0,e+24|0);b=Ud(e+48|0);v[22656]=0;c=v[e+68>>2];v[e+16>>2]=v[e+64>>2];v[e+20>>2]=c;c=v[b+4>>2];v[e+8>>2]=v[b>>2];v[e+12>>2]=c;b=W(203,e+104|0,e+16|0,e+8|0)|0;c=v[22656];v[22656]=0;if((c|0)==1){break d}Vc(lj(a)+12|0,b);xb(b);g=1}ns(C)}gb=e+1504|0;return g|0}g=P()|0;O()|0;break a}g=P()|0;O()|0;xb(e+80|0);break a}g=P()|0;O()|0}ns(C);S(g|0);L()}function Poa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,z=0,A=0,C=0,D=0;g=gb-1344|0;gb=g;vc(b);j=gb-32|0;gb=j;h=j+24|0;l=g+768|0;tX(h,l);i=yb(h);h=v[j+28>>2];k=v[j+24>>2];v[j+8>>2]=k;v[j+12>>2]=h;v[j>>2]=k;v[j+4>>2]=h;k=j+16|0;h=b;cc(k,h,j);k=yb(k);if((k|0)==(i|0)){Rb(h,yb(j+24|0))}gb=j+32|0;h=(i|0)==(k|0);if(!h){sX(l)}a:{b:{c:{if(!h){break c}if(!wX(g+768|0)){break c}if(!Pb(b,Qc(vX(g+768|0),jb))){break c}if(!c){e=1;break c}n=wr(g+760|0);s=1;d:{while(1){h=(e<<5)+a|0;j=h+480280|0;We(j);i=(g+768|0)+(e<<4)|0;u[h+480284>>1]=((w[i+78|0]<<8&65280)>>>0)/255;l=g+496|0;Mk(l,1,i- -64|0);k=g+112|0;Bc(k,l);v[22656]=0;Q(399,h+480289|0,k|0)|0;h=v[22656];v[22656]=0;if((h|0)==1){break b}vb(g+112|0);e:{f:{switch(w[i+79|0]){case 0:f=e+1|0;break e;case 1:v[j>>2]=1024;f=d+1|0;break e;case 2:break f;default:break d}}v[j>>2]=1024;h=g+112|0;Bl(h,n,e);Uf(h,1)}s=e>>>0<31;d=d+1|0;e=e+1|0;if((e|0)!=32){continue}break}Gd(a,33554432);u[a+480188>>1]=f&255;e=g+112|0;f=Tb(e,3830);Eb(a+1298304|0,f);vb(f);e=Tb(e,8329);Eb(a+1298316|0,e);vb(e);v[a+1298364>>2]=5;g:{if(w[g+847|0]){break g}d=1;while(1){if(w[((d<<4)+g|0)+847|0]!=1){break g}e=1;d=d+1|0;if((d|0)!=16){continue}break}while(1){f=((e<<5)+a|0)+480280|0;v[f>>2]=v[f>>2]&-1025;e=e+1|0;if((e|0)!=16){continue}break}}e=g+496|0;Ke(e,1,g+768|0);f=g+112|0;Bc(f,e);Eb(a+1298268|0,f);vb(f);v[a+480208>>2]=v[a+480208>>2]&-17|(w[g+806|0]|w[g+807|0]<<8)<<4&16;v[a+480196>>2]=w[g+816|0];v[a+480204>>2]=B(w[g+817|0],1e4);v[a+480200>>2]=w[g+818|0]<<2;v[a+480228>>2]=w[g+819|0];f=w[g+804|0]|w[g+805|0]<<8;k=0;u[a+480190>>1]=0;u[a+480192>>1]=f;nw(b,e);Ur(Sb(a+484360|0),e,w[g+800|0]|w[g+801|0]<<8,65535,255);z=c&1;if(z){Ag(a+484344|0,w[g+802|0]|w[g+803|0]<<8)}if(w[g+802|0]|w[g+803|0]<<8){A=a+484344|0;while(1){f=Og(b);m=Og(b);e=g+48|0;Td(e,b,f-4|0);p=kc(g+112|0,e);xb(e);h:{if(!z){break h}v[22656]=0;e=W(331,A|0,k&65535,m|0)|0;f=v[22656];v[22656]=0;if((f|0)!=1){i:{if(!e){break h}o=0;l=bj(g+24|0);if(!m){break h}while(1){j:{v[22656]=0;f=T(374,p|0)|0;e=v[22656];v[22656]=0;k:{l:{if((e|0)!=1){if(f){break l}o=o+1|0;break k}break i}e=l;r=f&31;if(r>>>0<x[a+480188>>1]){e=_b(A,k);v[22656]=0;e=Yc(e,o,r);d=v[22656];v[22656]=0;if((d|0)==1){break i}}m:{if(!(f&32)){break m}v[22656]=0;R(403,g+48|0,p|0);d=v[22656];v[22656]=0;if((d|0)==1){break i}d=g+48|0;h=qd(d);d=w[d|0];t[e|0]=d;t[e+1|0]=w[h|0];h=255;n:{if((d|0)==160){break n}if((d|0)!=255){t[e|0]=(B(d>>>4|0,12)+(d&15)|0)+13;v[22656]=0;d=aD(e);h=v[22656];v[22656]=0;if((h|0)!=1){h=0;if(!d){break n}break m}break i}h=0}t[e|0]=h}f=f&192;o:{if(!f){break o}if((f|0)==192){v[22656]=0;R(532,g+48|0,p|0);f=v[22656];v[22656]=0;p:{q:{r:{if((f|0)!=1){f=g+48|0;i=f;j=qd(f);d=Ve(f);f=ej(f);q=w[i|0];if((q|0)!=12){break r}v[22656]=0;t[g|0]=64;h=ac(j,g);j=v[22656];v[22656]=0;if((j|0)==1){break i}t[e+4|0]=w[h|0];h=1;break q}break i}h=w[d|0];s:{if((h|0)==12){v[22656]=0;t[g|0]=64;f=ac(f,g);d=v[22656];v[22656]=0;if((d|0)!=1){t[e+4|0]=w[f|0];h=1;break s}break i}if((q|0)==10){t[e+4|0]=(w[j|0]<<6>>>0)/255;h=2;break q}if((h|0)!=10){break p}t[e+4|0]=(w[f|0]<<6>>>0)/255;h=2}d=i;f=j}t[e+2|0]=h;h=w[d|0]}t[e+3|0]=h;t[e+5|0]=w[f|0];break o}v[22656]=0;R(403,g+48|0,p|0);f=v[22656];v[22656]=0;if((f|0)==1){break i}f=g+48|0;d=qd(f);t[e+3|0]=w[f|0];t[e+5|0]=w[d|0]}if(w[e+3|0]){t:{h=0;f=e;j=e;i=e+3|0;u:{v:{w:{x:{y:{z:{A:{B:{C:{D:{E:{F:{G:{d=w[e+3|0];switch(d-14|0){case 2:case 3:case 4:case 5:break z;case 8:break C;case 6:case 7:break D;case 1:break E;case 0:break F;default:break G}}switch(d-31|0){case 0:break A;case 2:break B;default:break z}}h=w[f+5|0];if(!h){h=14;break x}if((h|0)==15){break w}if((h|0)==240){t[f+5|0]=239;break v}if(h>>>0>=16){t[f+5|0]=h|15;break v}t[f+5|0]=h|240;break v}t[f+5|0]=w[f+5|0]^128;break v}h=w[f+5|0];if(h>>>0>=16){t[f+5|0]=h>>>4|240;break v}t[f+5|0]=h|224;break v}t[f+5|0]=((w[f+5|0]^-1)&254)>>>1;break v}i=32;H:{I:{J:{K:{L:{M:{q=w[f+5|0];switch(q>>>4|0){case 0:break v;case 12:case 13:break y;case 3:break H;case 5:break I;case 14:break J;case 11:break K;case 10:break L;case 8:break M;default:break x}}i=64;break H}i=176;break H}i=224;break H}t[f+5|0]=119;break v}i=48}t[f+5|0]=q&15|i;break v}C=f,D=Xi(w[f+5|0]<<1),t[C+5|0]=D;d=w[f+3|0]}if(d>>>0<36){t[j+3|0]=w[d+28832|0];if(w[f+2|0]|(d|0)!=12){break u}t[f+2|0]=1;t[f+3|0]=0;t[f+4|0]=w[f+5|0];i=f+5|0}t[i|0]=0;break t}if(q){break v}}t[j+3|0]=w[h+28832|0];break t}t[f+5|0]=254}t[j+3|0]=w[d+28832|0]}}}f=g+48|0;Bl(f,n,r);if(!Cb(f)){break k}v[22656]=0;f=uX(e);d=v[22656];v[22656]=0;if((d|0)==1){break j}if(!f){break k}t[e+3|0]=0}if(m>>>0>o>>>0){continue}break h}break}}}e=P()|0;O()|0;xb(g+112|0);break a}xb(g+112|0);k=k+1|0;if(k>>>0<(w[g+802|0]|w[g+803|0]<<8)>>>0){continue}break}}if(!x[a+480192>>1]){break d}p=c&2;j=g- -64|0;f=1;h=0;while(1){h=h+1|0;o=h&65535;e=FO(a,o,0);d=gb-32|0;gb=d;c=d+24|0;l=g+112|0;bc(c,l,384);i=yb(c);c=v[d+28>>2];k=v[d+24>>2];v[d+8>>2]=k;v[d+12>>2]=c;v[d>>2]=k;v[d+4>>2]=c;k=d+16|0;c=b;cc(k,c,d);k=yb(k);if((k|0)==(i|0)){Rb(c,yb(d+24|0))}gb=d+32|0;c=(i|0)==(k|0);if(!c){Qb(l,0,384)}if(!(!c|!e)){l=f&65535;c=gb-32|0;gb=c;d=g+112|0;Ke(c,1,d);i=c+16|0;Bc(i,c);v[22656]=0;Q(301,e+492|0,i|0)|0;i=v[22656];v[22656]=0;N:{if((i|0)!=1){vb(c+16|0);O:{if(!(w[d+378|0]|w[d+379|0]<<8)){break O}v[c+16>>2]=120;v[c>>2]=116;if(!v[Fb(c+16|0,c)>>2]){break O}k=e+236|0;i=0;while(1){m=w[(d+i|0)+32|0];C=vd(k,i+12|0),D=l+m|0,u[C>>1]=D;v[c+16>>2]=120;v[c>>2]=116;i=i+1|0;if(i>>>0<y[Fb(c+16|0,c)>>2]){continue}break}}i=w[d+376|0]|w[d+377|0]<<8;t[e+33|0]=1;v[e>>2]=i;$C(d,e+48|0,0);$C(d,e+68|0,1);$C(d,e+88|0,2);d=w[e+100|0];if(d&1){t[e+100|0]=d|16}if(!(v[e>>2]|t[e+60|0]&1)){v[e>>2]=32767}gb=c+32|0;break N}a=P()|0;O()|0;vb(c+16|0);S(a|0);L()}e=0;P:{if(!(w[g+490|0]|w[g+491|0]<<8)){break P}while(1){Q:{aY(b,g+48|0);R:{if((w[g+108|0]|w[g+109|0]<<8|(w[g+110|0]<<16|w[g+111|0]<<24))!=808538953){break R}c=e+f|0;l=c&65535;if(l>>>0>3999){break R}u[a+480190>>1]=c;i=gb-32|0;gb=i;k=B(l,104)+a|0;m=k+484380|0;d=m;ud(d,0);c=g+48|0;ki(i,1,c);n=i+16|0;Bc(n,i);v[22656]=0;Q(303,d+43|0,n|0)|0;n=v[22656];v[22656]=0;S:{if((n|0)!=1){vb(i+16|0);v[d>>2]=w[c+16|0]|w[c+17|0]<<8|(w[c+18|0]<<16|w[c+19|0]<<24);v[d+4>>2]=w[c+20|0]|w[c+21|0]<<8|(w[c+22|0]<<16|w[c+23|0]<<24);v[d+8>>2]=w[c+24|0]|w[c+25|0]<<8|(w[c+26|0]<<16|w[c+27|0]<<24);v[d+24>>2]=w[c+28|0]|w[c+29|0]<<8|(w[c+30|0]<<16|w[c+31|0]<<24);u[d+30>>1]=w[c+32|0]<<2;u[d+28>>1]=w[c+33|0];if(t[c+48|0]&1){u[d+34>>1]=x[d+34>>1]|2}if(w[c+48|0]&2){u[d+34>>1]=x[d+34>>1]|4}if(w[c+48|0]&4){u[d+34>>1]=x[d+34>>1]|1;v[d>>2]=v[d>>2]>>>1;v[d+4>>2]=v[d+4>>2]>>>1;v[d+8>>2]=v[d+8>>2]>>>1}if(w[c+48|0]&8){u[d+34>>1]=x[d+34>>1]|32}gb=i+32|0;break S}a=P()|0;O()|0;vb(i+16|0);S(a|0);L()}c=gb-16|0;gb=c;d=c+8|0;_E(d,k+484423|0);i=g+24|0;Zr(i,d);gb=c+16|0;v[22656]=0;Q(301,((l<<5)+a|0)+946304|0,i|0)|0;c=v[22656];v[22656]=0;if((c|0)==1){break Q}vb(g+24|0);if(!(w[j|0]|w[j+1|0]<<8|(w[j+2|0]<<16|w[j+3|0]<<24))){break R}Td(g,b,w[j|0]|w[j+1|0]<<8|(w[j+2|0]<<16|w[j+3|0]<<24));c=kc(g+24|0,g);xb(g);T:{if(!p){break T}d=Rc(g,u[k+484414>>1]&1?16:8,1,0,0);v[22656]=0;W(329,d|0,m|0,c|0)|0;c=v[22656];v[22656]=0;if((c|0)!=1){break T}e=P()|0;O()|0;xb(g+24|0);break a}xb(g+24|0)}e=e+1|0;if(e>>>0<(w[g+490|0]|w[g+491|0]<<8)>>>0){continue}break P}break}e=P()|0;O()|0;vb(g+24|0);break a}f=(w[g+490|0]|w[g+491|0]<<8)+f|0}if(o>>>0<x[a+480192>>1]){continue}break}}e=!s}gb=g+1344|0;return e&1}e=P()|0;O()|0;vb(g+112|0)}S(e|0);L()}function gF(a,b,c,d,e,f,g,h,i){var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,w=0,x=0,z=0,A=0,B=0,C=0,D=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0;k=gb-336|0;gb=k;m=h;o=i&65535;p=d;n=e&65535;s=(e^i)&-2147483648;r=i>>>16&32767;z=e>>>16&32767;a:{b:{if(r-1>>>0<32766&z-1>>>0<=32765){break b}w=e&2147483647;l=w;j=d;if(!(!d&(l|0)==2147418112?!(b|c):l>>>0<2147418112)){I=d;s=e|32768;break a}w=i&2147483647;e=w;d=h;if(!(!d&(e|0)==2147418112?!(f|g):e>>>0<2147418112)){I=h;s=i|32768;b=f;c=g;break a}if(!(b|j|(l^2147418112|c))){if(!(d|f|(e^2147418112|g))){b=0;c=0;s=2147450880;break a}s=s|2147418112;b=0;c=0;break a}if(!(d|f|(e^2147418112|g))){b=0;c=0;break a}if(!(b|j|(c|l))){b=!(d|f|(e|g));I=b?0:I;s=b?2147450880:s;b=0;c=0;break a}if(!(d|f|(e|g))){s=s|2147418112;b=0;c=0;break a}if((l|0)==65535|l>>>0<65535){i=b;d=!(n|p);h=d<<6;j=E(d?b:p)+32|0;b=E(d?c:n);b=h+((b|0)==32?j:b)|0;Kf(k+320|0,i,c,p,n,b-15|0);t=16-b|0;p=v[k+328>>2];n=v[k+332>>2];c=v[k+324>>2];b=v[k+320>>2]}if(e>>>0>65535){break b}d=!(m|o);e=d<<6;h=E(d?f:m)+32|0;d=E(d?g:o);d=e+((d|0)==32?h:d)|0;Kf(k+304|0,f,g,m,o,d-15|0);t=(d+t|0)-16|0;m=v[k+312>>2];o=v[k+316>>2];f=v[k+304>>2];g=v[k+308>>2]}e=o|65536;D=e;w=m;d=m;j=e<<15|d>>>17;e=d<<15|g>>>17;d=0-e|0;h=j;i=1963258675-(j+((e|0)!=0)|0)|0;qf(k+288|0,e,j,0,0,d,i,0,0);j=v[k+296>>2];qf(k+272|0,0-j|0,0-(v[k+300>>2]+((j|0)!=0)|0)|0,0,0,d,i,0,0);d=v[k+280>>2];i=d<<1|v[k+276>>2]>>>31;d=v[k+284>>2]<<1|d>>>31;qf(k+256|0,i,d,0,0,e,h,0,0);j=d;d=v[k+264>>2];qf(k+240|0,i,j,0,0,0-d|0,0-(v[k+268>>2]+((d|0)!=0)|0)|0,0,0);i=v[k+248>>2];j=i<<1|v[k+244>>2]>>>31;d=v[k+252>>2]<<1|i>>>31;qf(k+224|0,j,d,0,0,e,h,0,0);i=d;d=v[k+232>>2];qf(k+208|0,j,i,0,0,0-d|0,0-(v[k+236>>2]+((d|0)!=0)|0)|0,0,0);d=v[k+216>>2];i=d<<1|v[k+212>>2]>>>31;d=v[k+220>>2]<<1|d>>>31;qf(k+192|0,i,d,0,0,e,h,0,0);j=d;d=v[k+200>>2];qf(k+176|0,i,j,0,0,0-d|0,0-(v[k+204>>2]+((d|0)!=0)|0)|0,0,0);d=e;i=v[k+184>>2];e=i<<1|v[k+180>>2]>>>31;l=e-1|0;i=(v[k+188>>2]<<1|i>>>31)-!e|0;qf(k+160|0,d,h,0,0,l,i,0,0);e=f;qf(k+144|0,e<<15,g<<15|e>>>17,0,0,l,i,0,0);h=v[k+172>>2];o=v[k+160>>2];e=v[k+152>>2];d=o+e|0;m=v[k+164>>2];j=m+v[k+156>>2]|0;j=d>>>0<e>>>0?j+1|0:j;e=d;d=j;m=(m|0)==(d|0)&o>>>0>e>>>0|d>>>0<m>>>0;j=m+v[k+168>>2]|0;h=j>>>0<m>>>0?h+1|0:h;o=!d&e>>>0>1|(d|0)!=0;m=o+j|0;j=h;h=m;qf(k+112|0,l,i,0,0,0-h|0,0-(((h|0)!=0)+(h>>>0<o>>>0?j+1|0:j)|0)|0,0,0);qf(k+128|0,1-e|0,0-((e>>>0>1)+d|0)|0,0,0,l,i,0,0);P=(z-r|0)+t|0;e=v[k+116>>2];A=e;d=v[k+112>>2];j=e<<1|d>>>31;m=d<<1;C=j;e=j;i=v[k+140>>2];F=i;h=v[k+136>>2];j=i<<1|h>>>31;l=h<<1|v[k+132>>2]>>>31;i=l+m|0;d=e+j|0;h=i;d=h>>>0<l>>>0?d+1|0:d;e=d;d=d-(h>>>0<13927)|0;i=h-13927|0;q=d;K=d;l=0;z=l;d=n|65536;L=d;M=p;B=(d&2147483647)<<1|p>>>31;u=kqa(q,l,B,0);d=jb;x=d;j=b;r=j<<1;d=c<<1|j>>>31;t=d;j=0;N=j;o=d;l=(e|0)==(q|0)&h>>>0>i>>>0|e>>>0>q>>>0;m=(e|0)==(C|0)&h>>>0<m>>>0|e>>>0<C>>>0;d=v[k+120>>2];h=v[k+124>>2]<<1|d>>>31;e=F>>>31|0;d=e+(d<<1|A>>>31)|0;j=h;j=d>>>0<e>>>0?j+1|0:j;e=d;d=m+d|0;j=d>>>0<e>>>0?j+1|0:j;e=d;d=l+d|0;l=d>>>0<e>>>0?j+1|0:j;e=d;d=d-1|0;G=l-!e|0;C=0;j=kqa(o,H,G,C);e=j+u|0;h=jb+x|0;h=e>>>0<j>>>0?h+1|0:h;j=e;A=(h|0)==(x|0)&j>>>0<u>>>0|h>>>0<x>>>0;m=j;j=0;H=j;q=d;S=0;d=p;Q=c>>>31|0;x=Q|d<<1;e=kqa(q,j,x,0);d=m+e|0;j=jb+h|0;j=d>>>0<e>>>0?j+1|0:j;p=d;n=j;e=(j|0)==(h|0)&d>>>0<m>>>0|j>>>0<h>>>0;d=e+A|0;l=0;l=d>>>0<e>>>0?1:l;e=kqa(B,J,G,C);d=e+d|0;j=jb+l|0;m=d;d=d>>>0<e>>>0?j+1|0:j;l=kqa(B,J,q,H);h=jb;u=kqa(x,R,G,C);e=u+l|0;j=jb+h|0;j=e>>>0<u>>>0?j+1|0:j;u=e;e=j;j=(h|0)==(j|0)&l>>>0>u>>>0|h>>>0>j>>>0;l=m+e|0;d=d+j|0;h=l;l=h>>>0<e>>>0?d+1|0:d;m=p;e=0;d=m+e|0;j=n+u|0;j=d>>>0<e>>>0?j+1|0:j;e=j;n=(j|0)==(n|0)&d>>>0<m>>>0|j>>>0<n>>>0;h=h+n|0;j=l;A=h;l=h>>>0<n>>>0?j+1|0:j;m=d;n=e;u=i;h=kqa(i,0,x,R);e=jb;i=kqa(K,z,o,N);d=i+h|0;j=jb+e|0;j=d>>>0<i>>>0?j+1|0:j;i=d;e=(e|0)==(j|0)&h>>>0>d>>>0|e>>>0>j>>>0;h=j;p=A;F=e;O=r&-2;e=kqa(q,H,O,0);d=e+d|0;j=jb+j|0;j=d>>>0<e>>>0?j+1|0:j;A=d;e=j;i=(j|0)==(h|0)&d>>>0<i>>>0|h>>>0>j>>>0;d=F+i|0;h=0;h=d>>>0<i>>>0?1:h;j=d;i=d+m|0;d=h+n|0;F=i;h=i;d=h>>>0<j>>>0?d+1|0:d;i=d;h=(d|0)==(n|0)&h>>>0<m>>>0|d>>>0<n>>>0;d=p+h|0;j=l;T=d;m=d>>>0<h>>>0?j+1|0:j;J=kqa(B,J,u,U);B=jb;h=kqa(G,C,O,V);d=h+J|0;j=jb+B|0;G=d;n=kqa(K,z,x,R);l=d+n|0;h=d>>>0<h>>>0?j+1|0:j;d=h+jb|0;d=l>>>0<n>>>0?d+1|0:d;x=l;n=kqa(o,N,q,H);j=l+n|0;l=jb+d|0;C=j;l=j>>>0<n>>>0?l+1|0:l;n=l;l=0;p=(d|0)==(n|0)&j>>>0<x>>>0|d>>>0>n>>>0;j=(d|0)==(h|0)&G>>>0>x>>>0|d>>>0<h>>>0;d=j+((h|0)==(B|0)&G>>>0<J>>>0|h>>>0<B>>>0)|0;h=0;d=p+d|0;h=F+n|0;j=(d|l)+i|0;q=h;d=h;j=d>>>0<n>>>0?j+1|0:j;p=j;h=(i|0)==(j|0)&d>>>0<F>>>0|i>>>0>j>>>0;d=h+T|0;j=m;B=d;i=d>>>0<h>>>0?j+1|0:j;H=kqa(K,z,O,V);z=jb;h=kqa(o,N,u,U);d=h+H|0;j=jb+z|0;j=d>>>0<h>>>0?j+1|0:j;l=j;j=0;h=(l|0)==(z|0)&d>>>0<H>>>0|l>>>0<z>>>0;d=l+A|0;j=(h|j)+e|0;j=d>>>0<l>>>0?j+1|0:j;h=d;d=j;j=(e|0)==(d|0)&h>>>0<A>>>0|d>>>0<e>>>0;l=d+C|0;m=0;n=m+h|0;e=n;l=m>>>0>e>>>0?l+1|0:l;e=(d|0)==(l|0)&e>>>0<h>>>0|d>>>0>l>>>0;d=j+e|0;j=0;j=d>>>0<e>>>0?1:j;e=d;d=q+d|0;j=j+p|0;j=d>>>0<e>>>0?j+1|0:j;e=j;j=(p|0)==(j|0)&d>>>0<q>>>0|j>>>0<p>>>0;h=j+B|0;l=i;l=h>>>0<j>>>0?l+1|0:l;i=l;c:{if((l|0)==131071|l>>>0<131071){j=M;l=L<<1|j>>>31;M=Q|j<<1;L=l|S;qf(k+80|0,d,e,h,i,f,g,w,D);l=b<<17;b=0;c=v[k+88>>2];n=b-c|0;j=v[k+80>>2];q=(j|0)!=0;o=v[k+84>>2];m=q|(o|0)!=0;p=n-m|0;n=(l-(v[k+92>>2]+(b>>>0<c>>>0)|0)|0)-(m>>>0>n>>>0)|0;m=0-j|0;o=0-(o+q|0)|0;b=P+16382|0;break c}d=(e&1)<<31|d>>>1;j=h<<31|e>>>1;e=j;h=(i&1)<<31|h>>>1;i=i>>>1|0;qf(k+96|0,d,j,h,i,f,g,w,D);n=0;m=v[k+104>>2];o=n-m|0;j=v[k+96>>2];l=(j|0)!=0;t=v[k+100>>2];r=l|(t|0)!=0;p=o-r|0;n=((b<<16)-(v[k+108>>2]+(m>>>0>n>>>0)|0)|0)-(o>>>0<r>>>0)|0;m=0-j|0;o=0-(l+t|0)|0;r=b;t=c;b=P+16383|0}if((b|0)>=32767){s=s|2147418112;b=0;c=0;break a}d:{if((b|0)>0){c=p;j=n<<1|c>>>31;p=c<<1|o>>>31;n=j;r=h;t=i&65535|b<<16;b=m;j=o<<1|b>>>31;b=b<<1;break d}if((b|0)<=-113){b=0;c=0;break a}pm(k- -64|0,d,e,h,i,1-b|0);Kf(k+48|0,r,t,M,L,b+112|0);d=v[k+64>>2];e=v[k+68>>2];r=v[k+72>>2];t=v[k+76>>2];qf(k+32|0,f,g,w,D,d,e,r,t);c=v[k+40>>2];i=c<<1;c=v[k+44>>2]<<1|c>>>31;n=v[k+36>>2];h=n;b=v[k+56>>2];n=h>>>31|i;i=b-n|0;l=v[k+60>>2]-((b>>>0<n>>>0)+c|0)|0;c=v[k+32>>2];h=h<<1|c>>>31;c=c<<1;m=v[k+52>>2];j=m;b=v[k+48>>2];j=(h|0)==(j|0)&c>>>0>b>>>0|h>>>0>j>>>0;p=i-j|0;n=l-(i>>>0<j>>>0)|0;i=b;b=i-c|0;j=m-((c>>>0>i>>>0)+h|0)|0}qf(k+16|0,f,g,w,D,3,0,0,0);qf(k,f,g,w,D,5,0,0,0);i=d;c=e;l=f;f=g;q=r;o=0;h=j+o|0;r=d&1;d=b+r|0;h=d>>>0<b>>>0?h+1|0:h;m=d;g=h;A=(h|0)==(f|0)&d>>>0>l>>>0|f>>>0<h>>>0;d=(h|0)==(o|0)&d>>>0<r>>>0|h>>>0<o>>>0;b=d+p|0;j=n;j=b>>>0<d>>>0?j+1|0:j;l=b;f=j;d=(l|0)==(w|0)&(j|0)==(D|0)?A:(D|0)==(j|0)&l>>>0>w>>>0|j>>>0>D>>>0;b=i+d|0;j=e;j=b>>>0<d>>>0?j+1|0:j;d=b;b=j;e=(j|0)==(c|0)&d>>>0<i>>>0|c>>>0>j>>>0;c=q+e|0;j=t;j=c>>>0<e>>>0?j+1|0:j;e=c;c=j;h=d;p=e;d=v[k+20>>2];i=(d|0)==(g|0)&y[k+16>>2]<m>>>0|d>>>0<g>>>0;d=v[k+28>>2];e=v[k+24>>2];i=j>>>0<2147418112&((e|0)==(l|0)&(d|0)==(f|0)?i:(d|0)==(f|0)&e>>>0<l>>>0|d>>>0<f>>>0);e=h+i|0;d=b;d=e>>>0<i>>>0?d+1|0:d;i=e;j=e;e=d;d=(d|0)==(b|0)&h>>>0>j>>>0|b>>>0>d>>>0;b=p+d|0;j=c;j=b>>>0<d>>>0?j+1|0:j;h=b;d=j;b=v[k+4>>2];g=(b|0)==(g|0)&y[k>>2]<m>>>0|b>>>0<g>>>0;b=v[k+12>>2];c=v[k+8>>2];c=d>>>0<2147418112&((c|0)==(l|0)&(b|0)==(f|0)?g:(b|0)==(f|0)&c>>>0<l>>>0|b>>>0<f>>>0);b=c+i|0;j=e;j=b>>>0<c>>>0?j+1|0:j;c=j;f=(e|0)==(j|0)&b>>>0<i>>>0|e>>>0>j>>>0;e=h+f|0;I=I|e;s=s|(e>>>0<f>>>0?d+1|0:d)}v[a>>2]=b;v[a+4>>2]=c;v[a+8>>2]=I;v[a+12>>2]=s;gb=k+336|0}function Tpa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;e=gb-272|0;gb=e;vc(b);a:{if(!vY(b,e+200|0)){break a}if(!wY(e+200|0)){break a}b:{if(!c){break b}Gd(a,131072);d=gb-16|0;gb=d;i=e+104|0;f=Tb(d,1061);Dc(i,f);vb(f);gb=d+16|0;v[22656]=0;U(463,e+152|0,i|0,e+200|4);d=v[22656];v[22656]=0;c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{if((d|0)!=1){d=e+152|0;Eb(a+1298304|0,d);vb(d);i=e+104|0;Hb(i);f=Tb(d,8333);Eb(a+1298316|0,f);vb(f);v[a+1298364>>2]=5;Lr(i,3,e+213|0);Bc(d,i);Eb(a+1298268|0,d);vb(d);f=e+80|0;_j(f,3,e+243|0);Bc(i,f);v[22656]=0;U(13,d|0,5,i|0);d=v[22656];v[22656]=0;m:{n:{o:{p:{q:{if((d|0)!=1){d=e+152|0;Eb(a+1298280|0,d);vb(d);vb(e+104|0);d=Dr(d);m=d,n=Md(w[e+263|0],1,31),v[m+12>>2]=n;m=d,n=Md(w[e+264|0],1,12)-1|0,v[m+16>>2]=n;v[d+20>>2]=w[e+265|0];i=a+1298368|0;xD(i);tY(i,d);h=e+112|0;j=e+40|4;i=hh(e+136|0);while(1){v[22656]=0;d=Q(191,b|0,8)|0;f=v[22656];v[22656]=0;if((f|0)==1){break q}if(!d){break m}v[22656]=0;R(464,b|0,e+40|0);d=v[22656];v[22656]=0;if((d|0)==1){break p}f=w[j|0]|w[j+1|0]<<8|(w[j+2|0]<<16|w[j+3|0]<<24);d=w[e+204|0];r:{if((d|0)==3){g=2;if((w[e+40|0]|w[e+41|0]<<8|(w[e+42|0]<<16|w[e+43|0]<<24))==1431389523){break r}d=w[e+204|0]}if((d&255)==4){g=4;if((w[e+40|0]|w[e+41|0]<<8|(w[e+42|0]<<16|w[e+43|0]<<24))==1431389523){break r}d=w[e+204|0]}g=0;if((d&255)>>>0>7){break r}f=(w[e+40|0]|w[e+41|0]<<8|(w[e+42|0]<<16|w[e+43|0]<<24))==1146113363?-1:f}d=v[e+44>>2];v[e+104>>2]=v[e+40>>2];v[e+108>>2]=d;v[22656]=0;U(288,e+80|0,b|0,f|0);d=v[22656];v[22656]=0;if((d|0)==1){break o}kc(h,e+80|0);v[22656]=0;R(465,i|0,e+104|0);d=v[22656];v[22656]=0;if((d|0)==1){break n}ed(e+104|0);xb(e+80|0);v[22656]=0;Q(318,b|0,g|0)|0;d=v[22656];v[22656]=0;if((d|0)!=1){continue}break}a=P()|0;O()|0;break d}a=P()|0;O()|0;vb(e+104|0);break c}a=P()|0;O()|0;break d}a=P()|0;O()|0;break d}a=P()|0;O()|0;break d}a=P()|0;O()|0;ed(e+104|0);xb(e+80|0);break d}v[22656]=0;b=T(215,e+104|0)|0;d=v[22656];v[22656]=0;s:{t:{u:{if((d|0)!=1){v[22656]=0;U(466,e+80|0,i|0,1431389523);d=v[22656];v[22656]=0;if((d|0)==1){break u}d=e+80|0;Vc(b,d);xb(d);u[e+78>>1]=0;u[e+76>>1]=65534;if(w[e+204|0]<3){break s}v[22656]=0;d=T(287,b|0)|0;f=v[22656];v[22656]=0;if((f|0)!=1){break t}break f}a=P()|0;O()|0;break d}a=P()|0;O()|0;break e}u[e+78>>1]=d;if(w[e+204|0]<4){break s}v[22656]=0;d=T(287,b|0)|0;f=v[22656];v[22656]=0;if((f|0)==1){break f}u[e+76>>1]=w[e+204|0]==4?d?d:-2:d}d=a+484360|0;f=Sb(d);v[22656]=0;g=T(467,b|0)|0;j=v[22656];v[22656]=0;if((j|0)==1){break f}v[22656]=0;fa(362,f|0,b|0,g>>>1|0,65535,65535)|0;f=v[22656];v[22656]=0;if((f|0)==1){break f}f=Sb(d);v[22656]=0;f=T(468,f|0)|0;g=v[22656];v[22656]=0;if((g|0)==1){break f}zg(e+78|0,f);f=Sb(d);v[22656]=0;f=T(468,f|0)|0;g=v[22656];v[22656]=0;if((g|0)==1){break f}zg(e+76|0,f);v[22656]=0;U(466,e+80|0,i|0,1414807888);f=v[22656];v[22656]=0;v:{w:{x:{y:{z:{A:{B:{C:{if((f|0)!=1){f=e+80|0;Vc(b,f);xb(f);v[22656]=0;f=T(275,b|0)|0;g=v[22656];v[22656]=0;if((g|0)==1){break f}if(!f|!(c&1)){break v}v[22656]=0;R(469,b|0,e+72|0);f=v[22656];v[22656]=0;if((f|0)==1){break C}m=a,n=Md(w[e+72|2],1,32)+1|0,u[m+480188>>1]=n;f=w[e+72|0]|w[e+73|0]<<8;v[22656]=0;f=Q(328,e|0,f|0)|0;g=v[22656];v[22656]=0;if((g|0)==1){break B}m=e,n=Vb(f),v[m+24>>2]=n;m=e,n=Zb(f),v[m+64>>2]=n;if(Gb(e+24|0,e- -64|0)){while(1){j=v[e+24>>2];v[22656]=0;g=w[e+204|0]<3?9:8;Q(318,b|0,g-4|0)|0;h=v[22656];v[22656]=0;if((h|0)==1){break A}v[22656]=0;h=T(192,b|0)|0;k=v[22656];v[22656]=0;if((k|0)==1){break z}pg(b,g);v[22656]=0;U(288,e+40|0,b|0,g+h|0);g=v[22656];v[22656]=0;if((g|0)==1){break y}h=j;g=e+80|0;j=e+40|0;Vc(h,kc(g,j));xb(g);xb(j);g=e+24|0;Eh(g);if(Gb(g,e- -64|0)){continue}break}}g=x[a+480188>>1];v[22656]=0;g=Q(470,e+80|0,g|0)|0;j=v[22656];v[22656]=0;if((j|0)==1){break x}h=am(Sb(d));v[22656]=0;j=a+484344|0;R(330,j|0,h|0);h=v[22656];v[22656]=0;if((h|0)==1){break h}h=Sb(d);m=e,n=Vb(h),v[m+40>>2]=n;m=e,n=Zb(h),v[m+24>>2]=n;if(Gb(e+40|0,e+24|0)){while(1){h=v[e+40>>2];k=x[h>>1];if(Je(f)>>>0>k>>>0){k=Lg(f,x[h>>1]);v[22656]=0;k=da(471,k|0,w[e+204|0],g|0,a|0)|0;l=v[22656];v[22656]=0;if((l|0)==1){break h}u[h>>1]=k}h=e+40|0;of(h);if(Gb(h,e+24|0)){continue}break}}h=Sb(d);v[22656]=0;h=Q(472,h|0,x[e+76>>1])|0;k=v[22656];v[22656]=0;if((k|0)==1){break h}if(!h){break w}if(!x[e+78>>1]){h=x[e+76>>1];k=Sb(d);v[22656]=0;k=T(468,k|0)|0;l=v[22656];v[22656]=0;if((l|0)==1){break h}if(h>>>0>=k>>>0){break w}}d=x[sc(Sb(d),x[e+76>>1])>>1];h=_b(j,d);v[22656]=0;k=Be(e+40|0,12,w[e+78|0]);l=v[22656];v[22656]=0;if((l|0)!=1){d=qp(Ue(k,v[_b(j,d)+12>>2]-1|0));v[22656]=0;Q(431,h|0,d|0)|0;d=v[22656];v[22656]=0;if((d|0)!=1){break w}}break h}a=P()|0;O()|0;break e}a=P()|0;O()|0;break e}a=P()|0;O()|0;break e}a=P()|0;O()|0;break g}a=P()|0;O()|0;break g}a=P()|0;O()|0;break g}a=P()|0;O()|0;break g}rD(g);jd(f)}v[22656]=0;U(466,e+80|0,i|0,1196641603);d=v[22656];v[22656]=0;if((d|0)==1){break l}d=e+80|0;Vc(b,d);xb(d);v[22656]=0;d=T(275,b|0)|0;f=v[22656];v[22656]=0;if((f|0)==1){break f}if(d){v[22656]=0;Q(318,b|0,1)|0;d=v[22656];v[22656]=0;if((d|0)==1){break f}v[22656]=0;d=T(467,b|0)|0;f=v[22656];v[22656]=0;if((f|0)==1){break f}v[22656]=0;fa(473,a+1298292|0,b|0,d|0,40,0)|0;d=v[22656];v[22656]=0;if((d|0)==1){break f}}v[22656]=0;U(466,e+80|0,i|0,1146113363);d=v[22656];v[22656]=0;if((d|0)==1){break i}v[22656]=0;U(466,e+40|0,i|0,1229999443);d=v[22656];v[22656]=0;if((d|0)!=1){d=e+40|0;Vc(b,d);xb(d);v[22656]=0;f=T(374,b|0)|0;g=v[22656];v[22656]=0;d=1;if((g|0)==1){break k}u[a+480190>>1]=f;D:{E:{if(x[a+480190>>1]){j=c&2;g=1;while(1){f=30;F:{G:{H:{if(w[e+204|0]>=2){v[22656]=0;f=T(374,b|0)|0;c=v[22656];v[22656]=0;if((c|0)==1){break H}}v[22656]=0;W(474,b|0,((d<<5)+a|0)+946304|0,f|0)|0;c=v[22656];v[22656]=0;if((c|0)==1){break H}v[22656]=0;R(475,b|0,e+24|0);c=v[22656];v[22656]=0;if((c|0)==1){break G}v[22656]=0;c=B(d,104)+a|0;f=c+484380|0;R(476,e+24|0,f|0);d=v[22656];v[22656]=0;if((d|0)==1){break G}d=w[e+204|0];if(d>>>0>=8){v[22656]=0;W(477,b|0,c+484423|0,8)|0;d=v[22656];v[22656]=0;if((d|0)==1){break G}d=w[e+204|0]}v[22656]=0;Q(318,b|0,((d&255)>>>0>1?6:2)|0)|0;d=v[22656];v[22656]=0;if((d|0)==1){break G}v[22656]=0;d=T(192,e+80|0)|0;h=v[22656];v[22656]=0;if((h|0)!=1){v[22656]=0;U(288,e|0,e+80|0,d|0);d=v[22656];v[22656]=0;if((d|0)!=1){break F}}a=P()|0;O()|0;break j}a=P()|0;O()|0;break j}a=P()|0;O()|0;break j}d=e+40|0;h=kc(d,e);xb(e);v[22656]=0;d=T(275,d|0)|0;k=v[22656];v[22656]=0;if((k|0)==1){break E}I:{if(!d|!j){break I}c=Rc(e,u[c+484414>>1]&1?16:8,1,0,(w[e+39|0]&12)==4?7:0);v[22656]=0;W(329,c|0,f|0,h|0)|0;c=v[22656];v[22656]=0;if((c|0)!=1){break I}break E}xb(e+40|0);g=g+1|0;d=g&65535;if(d>>>0<=x[a+480190>>1]){continue}break}}v[22656]=0;Bg(a);c=v[22656];v[22656]=0;if((c|0)!=1){break D}break k}a=P()|0;O()|0;xb(e+40|0);break j}v[a+480204>>2]=12e5;v[a+480208>>2]=24;v[a+480196>>2]=6;v[a+480200>>2]=256;v[a+480228>>2]=48;v[a+480232>>2]=48;v[22656]=0;W(409,a+1074312|0,114,1)|0;a=v[22656];v[22656]=0;if((a|0)==1){break k}xb(e+80|0);xb(b);ke(i);break b}a=P()|0;O()|0;break j}a=P()|0;O()|0;Hb(e+104|0);break c}a=P()|0;O()|0;break e}a=P()|0;O()|0}xb(e+80|0);break e}a=P()|0;O()|0;break e}a=P()|0;O()|0;rD(g)}jd(f);break e}a=P()|0;O()|0}xb(b)}ke(i)}S(a|0);L()}d=1}gb=e+272|0;return d|0}function Soa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,y=0;e=gb-272|0;gb=e;vc(b);f=gb-32|0;gb=f;d=f+24|0;l=e+112|0;yX(d,l);g=yb(d);d=v[f+28>>2];i=v[f+24>>2];v[f+8>>2]=i;v[f+12>>2]=d;v[f>>2]=i;v[f+4>>2]=d;i=f+16|0;d=b;cc(i,d,f);i=yb(i);if((i|0)==(g|0)){Rb(d,yb(f+24|0))}gb=f+32|0;d=(g|0)==(i|0);if(!d){xX(l)}a:{b:{c:{d:{if(!d){break d}if(!zX(e+112|0)){break d}if(!c){h=1;break d}Gd(a,v[((w[e+228|0]|w[e+229|0]<<8)<<2)+28624>>2]);v[a+480208>>2]=v[a+480208>>2]|16777216;d=e+48|0;f=Tb(d,10447);Eb(a+1298304|0,f);vb(f);f=Tb(d,7583);Eb(a+1298316|0,f);vb(f);f=gb-16|0;gb=f;h=e+8|0;g=Tb(f,1498);Dc(h,g);vb(g);gb=f+16|0;v[22656]=0;Y(349,d|0,h|0,e+191|0,e+188|0);d=v[22656];v[22656]=0;e:{f:{if((d|0)!=1){d=e+48|0;Eb(a+1298328|0,d);vb(d);f=e+8|0;Hb(f);Xc(a+1298352|0,((w[e+228|0]|w[e+229|0]<<8)<<2)+28672|0);Xc(a+1298340|0,v[((w[e+228|0]|w[e+229|0]<<8)<<2)+28720>>2]);v[a+1298364>>2]=5;Ke(f,2,e+112|4);Bc(d,f);Eb(a+1298268|0,d);vb(d);Ke(f,2,e+148|0);Bc(d,f);g:{if(xr(d,6892)){v[22656]=0;U(13,e+8|0,5,e+48|0);d=v[22656];v[22656]=0;if((d|0)==1){break g}d=e+8|0;Eb(a+1298280|0,d);vb(d)}vb(e+48|0);u[a+480188>>1]=32;d=0;h:{while(1){h=(d<<5)+a|0;g=h+480280|0;We(g);i:{f=d+e|0;if(w[f+193|0]<=15){v[e+48>>2]=w[f+193|0]<<4|8;v[e+8>>2]=256;s=h+480284|0,y=v[pd(e+48|0,e+8|0)>>2],u[s>>1]=y;break i}if(w[f+193|0]==16){u[h+480284>>1]=128;v[g>>2]=256;break i}if(w[f+193|0]!=255){break i}u[a+480188>>1]=d;break h}d=d+1|0;if((d|0)!=32){continue}break}d=x[a+480188>>1]}h=0;if(!(d&65535)){break d}v[e+48>>2]=w[e+225|0]<<2;v[e+8>>2]=256;s=a,y=v[Fb(e+48|0,e+8|0)>>2],v[s+480200>>2]=y;v[a+480196>>2]=w[e+226|0];v[a+480204>>2]=B(w[e+227|0],1e4);if(Wc(b,w[e+230|0]|w[e+231|0]<<8|(w[e+232|0]<<16|w[e+233|0]<<24))){kp(Sb(a+484360|0),b,w[e+234|0]+1|0,255,254)}if(!Wc(b,w[e+240|0]|w[e+241|0]<<8|(w[e+242|0]<<16|w[e+243|0]<<24))){break d}u[a+480190>>1]=w[e+248|0]+1;i=e+80|0;d=1;l=1;while(1){h=gb-32|0;gb=h;f=h+24|0;k=e+48|0;bc(f,k,62);g=yb(f);f=v[h+28>>2];j=v[h+24>>2];v[h+8>>2]=j;v[h+12>>2]=f;v[h>>2]=j;v[h+4>>2]=f;j=h+16|0;f=b;cc(j,f,h);j=yb(j);if((j|0)==(g|0)){Rb(f,yb(h+24|0))}gb=h+32|0;f=(g|0)==(j|0);if(!f){Qb(k,0,62)}if(f){f=B(d,104)+a|0;h=f+484380|0;ud(h,0);g=e+32|0;Ke(g,2,e+48|0);k=e+8|0;Bc(k,g);v[22656]=0;Q(301,((d<<5)+a|0)+946304|0,k|0)|0;d=v[22656];v[22656]=0;if((d|0)==1){break b}d=e+8|0;vb(d);g=e+32|0;Mk(g,2,i);Bc(d,g);v[22656]=0;Q(303,f+484423|0,d|0)|0;d=v[22656];v[22656]=0;if((d|0)==1){break c}vb(e+8|0);d=f+484404|0;v[d>>2]=w[e+106|0]|w[e+107|0]<<8;j:{if(!_l(a)){break j}g=v[d>>2];d=0;while(1){if((g|0)==x[(d<<1)+28768>>1]){t[f+484417|0]=d<<4;break j}d=d+1|0;if((d|0)!=16){continue}break}}u[f+484412>>1]=64;v[h>>2]=w[e+93|0]|w[e+94|0]<<8|(w[e+95|0]<<16|w[e+96|0]<<24);if(w[e+105|0]&2){d=f+484414|0;u[d>>1]=x[d>>1]|1;v[h>>2]=v[h>>2]>>>1}v[f+484384>>2]=w[e+97|0]|w[e+98|0]<<8|(w[e+99|0]<<16|w[e+100|0]<<24);v[f+484388>>2]=(w[e+101|0]|w[e+102|0]<<8|(w[e+103|0]<<16|w[e+104|0]<<24))-1;if(t[e+105|0]&1){d=f+484414|0;u[d>>1]=x[d>>1]|2}k:{if(!(!(w[e+105|0]&4)|w[e+108|0]==255)){t[e+8|0]=w[e+108|0];t[e+32|0]=64;s=f+484410|0,y=w[ac(e+8|0,e+32|0)|0]<<2,u[s>>1]=y;break k}d=f+484414|0;u[d>>1]=x[d>>1]|32768}l:{if(!(w[e+105|0]&8)){u[f+484408>>1]=128;break l}d=f+484414|0;u[d>>1]=x[d>>1]|32;m=f+484408|0;if(w[e+109|0]<=15){f=w[e+109|0];v[e+32>>2]=256;v[e+8>>2]=f<<4|8;f=v[pd(e+8|0,e+32|0)>>2]}else{f=128}u[m>>1]=f;u[d>>1]=x[d>>1]&65279|(w[e+109|0]==16)<<8}l=l+1|0;d=l&65535;if(d>>>0<=x[a+480190>>1]){continue}}break}m:{if(!(c&2)){break m}if(!Wc(b,w[e+244|0]|w[e+245|0]<<8|(w[e+246|0]<<16|w[e+247|0]<<24))|!x[a+480190>>1]){break m}d=1;while(1){f=B(d&65535,104)+a|0;Dg(Rc(e+48|0,u[f+484414>>1]&1?16:8,1,0,1),f+484380|0,b);d=d+1|0;if(x[a+480190>>1]>=(d&65535)>>>0){continue}break}}o=a+484344|0;Ag(o,w[e+239|0]+1|0);f=zq(a);d=gb-16|0;gb=d;v[d+12>>2]=0;hu(d+12|0,f);i=v[d+12>>2];gb=d+16|0;Wc(b,w[e+235|0]|w[e+236|0]<<8|(w[e+237|0]<<16|w[e+238|0]<<24));q=c&1;k=0;l=1;n:{while(1){o:{d=Og(b);if(d>>>0>=3){c=e+8|0;Td(c,b,d-2|0);j=kc(e+48|0,c);xb(c);p:{if(!q){break p}v[22656]=0;c=T(275,e+48|0)|0;d=v[22656];v[22656]=0;if((d|0)==1){break o}if(!c){break p}v[22656]=0;c=W(331,o|0,k&65535,64)|0;d=v[22656];v[22656]=0;if((d|0)==1){break o}n=0;if(!c){break p}while(1){c=_b(o,k);v[22656]=0;r=Tf(c,n);c=v[22656];v[22656]=0;if((c|0)==1){break f}q:while(1){v[22656]=0;c=T(374,j|0)|0;d=v[22656];v[22656]=0;if((d|0)==1){break n}r:{if(!c){break r}d=c&31;if(d>>>0>=x[a+480188>>1]){break r}f=B(d,6)+r|0;if(c&32){v[22656]=0;R(403,e+8|0,j|0);d=v[22656];v[22656]=0;if((d|0)==1){break f}d=e+8|0;h=qd(d);g=w[d|0];if(g){m=d;d=(g&127)-1|0;t[m|0]=d;t[f|0]=(B((d&240)>>>4|0,12)+(d&15)|0)+13;v[22656]=0;d=Dv(f);g=v[22656];v[22656]=0;if((g|0)==1){break f}l=d&l}t[f+1|0]=w[h|0]}if(!(c&64)){continue}t[f+2|0]=0;t[f+3|0]=0;h=f+5|0;while(1){v[22656]=0;c=Q(191,e+48|0,2)|0;d=v[22656];v[22656]=0;s:{t:{u:{v:{w:{x:{y:{z:{A:{B:{if((d|0)!=1){if(!c){continue q}p=w[h|0];c=w[f+3|0];v[22656]=0;R(403,e+8|0,j|0);d=v[22656];v[22656]=0;if((d|0)==1){break f}d=e+8|0;m=d;g=w[qd(d)|0];t[h|0]=g;d=w[(w[d|0]&31)+28800|0];t[f+3|0]=d;switch(d-2|0){case 4:case 5:break w;case 18:break x;case 13:break y;case 17:break z;case 11:break A;case 0:case 1:break B;default:break t}}break f}if(g>>>0<224){break u}d=223;if(v[a+480180>>2]!=1){break v}break u}v[22656]=0;t[e+32|0]=64;d=ac(h,e+32|0);g=v[22656];v[22656]=0;if((g|0)!=1){t[h|0]=w[d|0];v[22656]=0;d=yz(i,1);g=v[22656];v[22656]=0;if((g|0)==1){break f}if(!d){break u}t[f+2|0]=1;t[f+4|0]=w[h|0];t[f+3|0]=c;t[h|0]=p;d=c;break t}break f}C:{switch(((g&240)>>>4|0)-8|0){case 0:t[f+3|0]=2;t[h|0]=g&15|224;break s;case 1:t[f+3|0]=3;t[h|0]=g&15|224;break s;default:break C}}v[22656]=0;d=pq(i,19);g=v[22656];v[22656]=0;if((g|0)==1){break f}if(d){break u}v[22656]=0;$t(f);d=v[22656];v[22656]=0;if((d|0)!=1){break u}break f}v[22656]=0;d=pq(i,15);g=v[22656];v[22656]=0;if((g|0)==1){break f}if(d){break u}v[22656]=0;d=pq(i,19);g=v[22656];v[22656]=0;if((g|0)==1){break f}if(!d){break u}t[f+3|0]=19;t[h|0]=w[h|0]&15|144;break s}d=145;if((g|0)==1){break v}if((g&240)==128){v[22656]=0;d=pq(i,20);g=v[22656];v[22656]=0;if((g|0)==1){break f}if(d){break u}t[f+3|0]=19;break s}t[f+3|0]=0;break s}d=g&240;if(!d){break u}}t[h|0]=d}d=w[f+3|0]}if((d&255)!=20){break s}d=w[h|0];if(w[f+2|0]|(d&240)!=128){break s}t[f+2|0]=2;t[f+4|0]=(((d&15)<<6|8)>>>0)/15;t[f+3|0]=c;t[h|0]=p}if(w[m|0]&32){continue}break}continue}break}n=n+1|0;if((n|0)!=64){continue}break}}xb(e+48|0)}c=w[e+239|0]>k>>>0;k=k+1|0;if(c){continue}break e}break}break f}break f}d=P()|0;O()|0;vb(e+48|0);break a}d=P()|0;O()|0;Hb(e+8|0);break a}d=P()|0;O()|0;xb(e+48|0);break a}c=a;if(v[a+480180>>2]!=1){d=v[a+480208>>2]&-8454145}else{d=v[a+480208>>2]&-8454145|(x[a+480188>>1]==4?l&1?8454144:0:0)}v[c+480208>>2]=d;h=1;if(!(w[e+253|0]|w[e+254|0]<<8|(w[e+255|0]<<16|w[e+256|0]<<24))){break d}if(!Wc(b,w[e+249|0]|w[e+250|0]<<8|(w[e+251|0]<<16|w[e+252|0]<<24))){break d}uB(a+1298292|0,b,w[e+253|0]|w[e+254|0]<<8|(w[e+255|0]<<16|w[e+256|0]<<24),4)}gb=e+272|0;return h|0}d=P()|0;O()|0;vb(e+8|0);break a}d=P()|0;O()|0;vb(e+8|0)}S(d|0);L()}function XZ(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,y=0,z=0;g=gb-224|0;gb=g;vc(b);a:{if(!CE(b,g+176|0)){break a}if(!DE(g+176|0)){break a}if(!c){h=1;break a}Gd(a,2048);Bg(a);d=gb-16|0;gb=d;f=g+8|0;e=Tb(d,1075);Dc(f,e);vb(e);gb=d+16|0;v[22656]=0;l=g+176|3;U(316,g+80|0,f|0,l|0);d=v[22656];v[22656]=0;b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{if((d|0)!=1){d=g+80|0;Eb(a+1298304|0,d);vb(d);f=g+8|0;Hb(f);e=Tb(d,8337);Eb(a+1298316|0,e);vb(e);v[a+1298364>>2]=5;u[a+480188>>1]=w[g+216|0];u[a+480190>>1]=w[g+212|0];Ke(f,2,g+176|4);Bc(d,f);Eb(a+1298268|0,d);vb(d);if(w[l|0]<=8){u[a+480188>>1]=4;pg(b,1);xh(a,1)}d=w[l|0];n:{if(w[l|0]>=11){f=d>>>0>11?32:16;e=0;d=0;while(1){j=zE(b);o:{if((j|0)==100){v[((e<<5)+a|0)+480280>>2]=256;break o}v[g+80>>2]=(j<<1)+128;v[g+8>>2]=0;v[g+160>>2]=256;y=((e<<5)+a|0)+480284|0,z=v[dj(g+80|0,g+8|0,g+160|0)>>2],u[y>>1]=z}d=d+1|0;e=d&65535;if(f>>>0>e>>>0){continue}break}break n}if(d>>>0<9){break n}d=g+80|0;e=gb-32|0;gb=e;f=b;p:{if(!Pb(f,16)){f=gb-16|0;gb=f;j=d+16|0;while(1){Hf(d);d=d+1|0;if((j|0)!=(d|0)){continue}break}gb=f+16|0;break p}jw(e+24|0,d);d=v[e+28>>2];v[e+8>>2]=v[e+24>>2];v[e+12>>2]=d;kd(e+16|0,f,e+8|0)}gb=e+32|0;e=0;while(1){u[((e<<5)+a|0)+480284>>1]=t[(g+80|0)+e|0]&1?64:192;e=e+1|0;if((e|0)!=16){continue}break}}q:{if(w[l|0]>=13){e=g+80|0;mw(e,b);j=qd(e);f=a;d=w[e|0];if(d>>>0<=31){t[e|0]=125;d=125}v[f+480204>>2]=B(d,1e4);v[a+480196>>2]=w[j|0];break q}v[a+480196>>2]=6;v[a+480204>>2]=125e4}d=a+484360|0;Af(Sb(d),w[g+213|0]);n=mc(g+160|0);i=v[b+8>>2];r=w[l|0];r:{if(w[l|0]<14){break r}f=w[g+213|0];v[22656]=0;R(317,n|0,f|0);f=v[22656];v[22656]=0;if((f|0)!=1){break r}a=P()|0;O()|0;break e}s:{if(w[g+213|0]){e=0;while(1){y=sc(Sb(d),e),z=e,u[y>>1]=z;if(w[l|0]>=14){v[22656]=0;f=T(287,b|0)|0;j=v[22656];v[22656]=0;if((j|0)==1){break s}y=sc(n,e),z=f,u[y>>1]=z}f=x[a+480188>>1];v[22656]=0;Q(318,b|0,f<<1)|0;f=v[22656];v[22656]=0;if((f|0)==1){break s}e=e+1|0;if(e>>>0<w[g+213|0]){continue}break}}d=0;t:{u:{if(w[l|0]==10){j=v[b+8>>2];d=0;v:{if(!x[a+480190>>1]){break v}e=1;while(1){v[22656]=0;d=Q(319,b|0,g+80|0)|0;f=v[22656];v[22656]=0;if((f|0)==1){break u}w:{if(!d){break w}f=0;d=g+80|0;x:{if(w[d|0]>1|w[g+212|0]<(w[d+46|0]|w[d+47|0]<<8|(w[d+48|0]<<16|w[d+49|0]<<24))>>>0|((w[d+50|0]|w[d+51|0]<<8|(w[d+52|0]<<16|w[d+53|0]<<24))>>>0>1048576|w[d+56|0]>64)){break x}if((w[d+57|0]|w[d+58|0]<<8|(w[d+59|0]<<16|w[d+60|0]<<24))>>>0>(w[d+50|0]|w[d+51|0]<<8|(w[d+52|0]<<16|w[d+53|0]<<24))>>>0){break x}f=(w[d+61|0]|w[d+62|0]<<8|(w[d+63|0]<<16|w[d+64|0]<<24))>>>0<=(w[d+50|0]|w[d+51|0]<<8|(w[d+52|0]<<16|w[d+53|0]<<24))>>>0}if(f){break w}d=1;break v}e=e+1|0;if(x[a+480190>>1]>=(e&65535)>>>0){continue}break}d=0}v[22656]=0;Q(190,b|0,j|0)|0;f=v[22656];v[22656]=0;if((f|0)==1){break t}}f=x[a+480190>>1];v[22656]=0;v[g+80>>2]=0;q=W(320,g- -64|0,f|0,g+80|0)|0;f=v[22656];v[22656]=0;e=1;if((f|0)!=1){if(x[a+480190>>1]){o=d?59:65;j=g+80|1;f=1;while(1){y:{if(w[l|0]<=9){v[22656]=0;R(321,b|0,g+80|0);h=v[22656];v[22656]=0;z:{A:{B:{if((h|0)==1){break B}v[22656]=0;R(322,g+80|0,(B(e,104)+a|0)+484380|0);h=v[22656];v[22656]=0;if((h|0)==1){break B}v[22656]=0;Ke(g+48|0,2,j);h=v[22656];v[22656]=0;if((h|0)==1){break A}v[22656]=0;R(324,g+8|0,g+48|0);h=v[22656];v[22656]=0;if((h|0)==1){break A}v[22656]=0;Q(301,((e<<5)+a|0)+946304|0,g+8|0)|0;h=v[22656];v[22656]=0;if((h|0)==1){break z}break y}a=P()|0;O()|0;break f}a=P()|0;O()|0;break f}a=P()|0;O()|0;vb(g+8|0);break f}v[22656]=0;U(325,b|0,g+80|0,o|0);h=v[22656];v[22656]=0;if((h|0)==1){break g}v[22656]=0;U(326,g+80|0,(B(e,104)+a|0)+484380|0,d|0);h=v[22656];v[22656]=0;if((h|0)==1){break g}v[22656]=0;Ke(g+48|0,2,j);h=v[22656];v[22656]=0;if((h|0)==1){break h}v[22656]=0;R(324,g+8|0,g+48|0);h=v[22656];v[22656]=0;if((h|0)==1){break h}v[22656]=0;Q(301,((e<<5)+a|0)+946304|0,g+8|0)|0;h=v[22656];v[22656]=0;if((h|0)==1){break i}}vb(g+8|0);h=w[g+126|0]|w[g+127|0]<<8|(w[g+128|0]<<16|w[g+129|0]<<24);y=Mb(q,e-1|0),z=h,v[y>>2]=z;f=f+1|0;e=f&65535;if(e>>>0<=x[a+480190>>1]){continue}break}}j=mc(g+48|0);d=w[g+214|0]|w[g+215|0]<<8;v[22656]=0;h=W(327,b|0,j|0,d|0)|0;d=v[22656];v[22656]=0;if((d|0)==1){break m}if(!h){break b}d=0;if(!cd(j)){f=Vb(j);e=Zb(j);d=gb-32|0;gb=d;v[d+16>>2]=e;v[d+24>>2]=f;C:{if(!Gb(d+24|0,d+16|0)){break C}v[d>>2]=f;e=of(d);if(!Gb(e,d+16|0)){break C}while(1){if(uE(v[d+24>>2],v[e>>2])){f=v[d>>2];v[d+24>>2]=f}if(Gb(of(e),d+16|0)){continue}break}}gb=d+32|0;v[g+80>>2]=f;d=v[g+80>>2];d=w[d|0]|w[d+1|0]<<8}v[22656]=0;f=d;o=Q(328,g+32|0,d|0)|0;e=v[22656];v[22656]=0;if((e|0)!=1){D:{if(f){e=0;while(1){v[22656]=0;k=T(287,b|0)|0;m=v[22656];v[22656]=0;if((m|0)==1){break l}v[22656]=0;Q(318,b|0,1)|0;m=v[22656];v[22656]=0;if((m|0)==1){break l}if(k){m=w[l|0];v[22656]=0;U(288,g+8|0,b|0,B(k,3)+((m|0)==1?3:0)|0);k=v[22656];v[22656]=0;if((k|0)==1){break D}k=g+80|0;m=g+8|0;p=kc(k,m);Vc(Lg(o,e),p);xb(k);xb(m)}e=e+1|0;if((f|0)!=(e|0)){continue}break}}E:{if(!(c&2)){break E}f=1;m=Rc(g+80|0,8,1,0,1);if(!x[a+480190>>1]){break E}k=1;while(1){v[22656]=0;e=Q(191,b|0,1)|0;p=v[22656];v[22656]=0;F:{if((p|0)!=1){if(!e){break E}e=0;if(!x[a+480190>>1]){break F}p=v[b+8>>2];while(1){G:{H:{if(v[Mb(q,e)>>2]!=(f|0)){e=e+1|0;break H}v[22656]=0;Q(190,b|0,p|0)|0;s=v[22656];v[22656]=0;if((s|0)==1){break G}v[22656]=0;e=e+1|0;W(329,m|0,(B(e,104)+a|0)+484380|0,b|0)|0;s=v[22656];v[22656]=0;if((s|0)==1){break G}}if(x[a+480190>>1]>e>>>0){continue}break F}break}a=P()|0;O()|0;break k}a=P()|0;O()|0;break k}k=k+1|0;f=k&65535;if(f>>>0<=x[a+480190>>1]){continue}break}}if(!(c&1)){break c}f=w[g+213|0];c=0;v[22656]=0;k=a+484344|0;R(330,k|0,f|0);f=v[22656];v[22656]=0;I:{if((f|0)!=1){if(!w[g+213|0]){break c}r=i+((r>>>0>13)<<1)|0;while(1){J:{e=64;if(tc(n)>>>0>c>>>0){e=x[sc(n,c)>>1]}v[22656]=0;f=W(331,k|0,c&65535,e&65535)|0;e=v[22656];v[22656]=0;if((e|0)==1){break I}K:{if(f){f=x[a+480188>>1];e=w[l|0];v[22656]=0;Q(190,b|0,r+B(((e>>>0>13)<<1)+(f<<1)|0,c)|0)|0;f=v[22656];v[22656]=0;if((f|0)==1){break I}f=mc(g+80|0);e=x[a+480188>>1];v[22656]=0;e=W(327,b|0,f|0,e|0)|0;i=v[22656];v[22656]=0;if((i|0)==1){break K}L:{if(!e){break L}e=0;if(!x[a+480188>>1]){break L}while(1){M:{i=sc(f,e);if(!(w[i|0]|w[i+1|0]<<8)){break M}i=sc(f,e);if((w[i|0]|w[i+1|0]<<8)>>>0>(w[g+214|0]|w[g+215|0]<<8)>>>0){break M}i=sc(f,e);i=sc(j,(w[i|0]|w[i+1|0]<<8)-1|0);i=w[i|0]|w[i+1|0]<<8;if(!i|d>>>0<i>>>0){break M}m=_b(k,c);i=Lg(o,i-1&65535);v[22656]=0;U(332,m|0,e&65535,i|0);i=v[22656];v[22656]=0;if((i|0)!=1){break M}break J}e=e+1|0;if(e>>>0<x[a+480188>>1]){continue}break}}Qk(f)}c=c+1|0;if(c>>>0>=w[g+213|0]){break c}continue}}break}a=P()|0;O()|0;Qk(f);break k}a=P()|0;O()|0;break k}a=P()|0;O()|0;break k}a=P()|0;O()|0;break k}a=P()|0;O()|0;break j}a=P()|0;O()|0;break e}a=P()|0;O()|0;break e}a=P()|0;O()|0;break e}a=P()|0;O()|0;break e}a=P()|0;O()|0;Hb(g+8|0);break d}a=P()|0;O()|0;break j}a=P()|0;O()|0}jd(o)}Qk(j);break f}a=P()|0;O()|0;vb(g+8|0);break f}a=P()|0;O()|0;break f}a=P()|0;O()|0}Nc(q)}Ze(n)}S(a|0);L()}jd(o)}Qk(j);Nc(q);Ze(n)}gb=g+224|0;return h|0}function Z2(a,b,c,d,e,f,g,h,i,j,k){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;var l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,u=0,x=0,y=0,z=0,A=0,B=0,C=0;l=gb-560|0;gb=l;v[l+548>>2]=k;v[l+552>>2]=b;v[l+96>>2]=2479;b=l+96|0;r=ge(l+136|0,l+144|0,b);k=v[r>>2];v[l+132>>2]=k;v[l+128>>2]=k+400;u=Kb(b);m=Kb(l+80|0);n=Kb(l- -64|0);o=Kb(l+48|0);s=Kb(l+32|0);v[22656]=0;na(2489,c|0,d|0,l+120|0,l+116|0,l+112|0,u|0,m|0,n|0,o|0,l+28|0);b=v[22656];v[22656]=0;a:{b:{c:{d:{e:{if((b|0)!=1){v[j>>2]=v[i>>2];y=e&512;z=y>>>9|0;p=v[l+28>>2];e=0;f:{while(1){v[22656]=0;b=Q(2457,a|0,l+552|0)|0;c=v[22656];v[22656]=0;if((c|0)==1){break c}g:{if(!b){break g}h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{switch(t[(l+120|0)+q|0]){case 1:if((q|0)==3){break g}v[22656]=0;b=T(2459,a|0)|0;c=v[22656];v[22656]=0;if((c|0)==1){break c}v[22656]=0;b=W(2490,h|0,8192,b|0)|0;c=v[22656];v[22656]=0;if((c|0)==1){break c}if(b){v[22656]=0;R(2491,l+16|0,a|0);b=v[22656];v[22656]=0;if((b|0)!=1){b=v[l+16>>2];v[22656]=0;R(63,s|0,b|0);b=v[22656];v[22656]=0;if((b|0)!=1){break p}}a=P()|0;O()|0;break a}v[f>>2]=v[f>>2]|4;a=0;break f;case 4:break m;case 2:break n;case 3:break o;case 0:break q;default:break h}}if((q|0)==3){break g}}while(1){v[22656]=0;b=Q(2457,a|0,l+552|0)|0;c=v[22656];v[22656]=0;if((c|0)==1){break b}if(!b){break h}v[22656]=0;b=T(2459,a|0)|0;c=v[22656];v[22656]=0;if((c|0)==1){break b}v[22656]=0;b=W(2490,h|0,8192,b|0)|0;c=v[22656];v[22656]=0;if((c|0)==1){break b}if(!b){break h}v[22656]=0;R(2491,l+16|0,a|0);b=v[22656];v[22656]=0;if((b|0)!=1){b=v[l+16>>2];v[22656]=0;R(63,s|0,b|0);b=v[22656];v[22656]=0;if((b|0)!=1){continue}}break}a=P()|0;O()|0;break a}if((Ab(n)|0)==(0-Ab(o)|0)){break h}r:{if(Ab(n)){if(Ab(o)){break r}}if(Ab(n)){v[22656]=0;b=T(2459,a|0)|0;c=v[22656];v[22656]=0;if((c|0)==1){break c}if((b|0)!=v[Jb(n)>>2]){break l}v[22656]=0;T(2461,a|0)|0;b=v[22656];v[22656]=0;if((b|0)==1){break c}e=Ab(n)>>>0>1?n:e;break h}v[22656]=0;b=T(2459,a|0)|0;c=v[22656];v[22656]=0;if((c|0)==1){break c}if((b|0)!=v[Jb(o)>>2]){break h}v[22656]=0;T(2461,a|0)|0;b=v[22656];v[22656]=0;if((b|0)==1){break c}t[g|0]=1;e=Ab(o)>>>0>1?o:e;break h}v[22656]=0;b=T(2459,a|0)|0;c=v[22656];v[22656]=0;if((c|0)==1){break c}if((b|0)==v[Jb(n)>>2]){v[22656]=0;T(2461,a|0)|0;b=v[22656];v[22656]=0;if((b|0)==1){break c}e=Ab(n)>>>0>1?n:e;break h}v[22656]=0;b=T(2459,a|0)|0;c=v[22656];v[22656]=0;if((c|0)==1){break c}if((b|0)==v[Jb(o)>>2]){v[22656]=0;T(2461,a|0)|0;b=v[22656];v[22656]=0;if((b|0)==1){break c}t[g|0]=1;e=Ab(o)>>>0>1?o:e;break h}v[f>>2]=v[f>>2]|4;a=0;break f}if(!(q>>>0<2|e|((q|0)==2&w[l+123|0]!=0|z))){e=0;break h}B=l,C=zd(m),v[B+8>>2]=C;b=Fd(l+16|0,l+8|0);s:{if(!q|w[(l+q|0)+119|0]>1){break s}B=l,C=ui(m),v[B+8>>2]=C;t:{if(!Gb(b,l+8|0)){break t}while(1){c=v[v[b>>2]>>2];v[22656]=0;c=W(2490,h|0,8192,c|0)|0;d=v[22656];v[22656]=0;if((d|0)==1){break k}if(!c){break t}Qe(b);B=l,C=ui(m),v[B+8>>2]=C;if(Gb(b,l+8|0)){continue}break}}B=l,C=zd(m),v[B+8>>2]=C;c=rv(b,l+8|0);if(Ab(s)>>>0>=c>>>0){B=l,C=ui(s),v[B+8>>2]=C;b=gb-16|0;gb=b;v[b+8>>2]=v[l+8>>2];v[b+8>>2]=v[b+8>>2]+(0-c<<2);c=v[b+8>>2];gb=b+16|0;d=ui(s);x=zd(m);b=gb-32|0;gb=b;v[b+16>>2]=d;v[b+24>>2]=c;v[b+8>>2]=x;c=1;u:{if(!Gb(b+24|0,b+16|0)){break u}while(1){c=Sj(v[b+24>>2],v[b+8>>2]);if(!c){break u}d=b+24|0;Qe(d);Qe(b+8|0);if(Gb(d,b+16|0)){continue}break}}gb=b+32|0;if(c){break s}}B=l,C=zd(m),v[B>>2]=C;Fd(l+8|0,l);v[l+16>>2]=v[l+8>>2]}v[l+8>>2]=v[l+16>>2];B=l,C=ui(m),v[B>>2]=C;v:{w:{x:{if(!Gb(l+8|0,l)){break x}while(1){v[22656]=0;b=Q(2457,a|0,l+552|0)|0;c=v[22656];v[22656]=0;if((c|0)==1){break w}if(!b){break x}v[22656]=0;b=T(2459,a|0)|0;c=v[22656];v[22656]=0;if((c|0)==1){break w}if((b|0)!=v[v[l+8>>2]>>2]){break x}v[22656]=0;T(2461,a|0)|0;b=v[22656];v[22656]=0;if((b|0)==1){break v}b=l+8|0;Qe(b);B=l,C=ui(m),v[B>>2]=C;if(Gb(b,l)){continue}break}}if(!y){break h}B=l,C=ui(m),v[B>>2]=C;if(!Gb(l+8|0,l)){break h}v[f>>2]=v[f>>2]|4;a=0;break f}a=P()|0;O()|0;v[l+28>>2]=p;break a}a=P()|0;O()|0;v[l+28>>2]=p;break a}d=0;x=v[l+112>>2];b=k;y:{while(1){z:{v[22656]=0;c=Q(2457,a|0,l+552|0)|0;k=v[22656];v[22656]=0;if((k|0)==1){break z}if(!c){break y}v[22656]=0;c=T(2459,a|0)|0;k=v[22656];v[22656]=0;if((k|0)==1){break e}v[22656]=0;k=W(2490,h|0,2048,c|0)|0;A=v[22656];v[22656]=0;if((A|0)==1){break e}A:{if(k){k=v[j>>2];if((k|0)==v[l+548>>2]){v[22656]=0;U(2492,i|0,j|0,l+548|0);k=v[22656];v[22656]=0;if((k|0)==1){break e}k=v[j>>2]}v[j>>2]=k+4;v[k>>2]=c;d=d+1|0;break A}if(!Ab(u)|!d|(c|0)!=(x|0)){break y}if(v[l+128>>2]==(b|0)){v[22656]=0;U(2485,r|0,l+132|0,l+128|0);b=v[22656];v[22656]=0;if((b|0)==1){break e}b=v[l+132>>2]}c=b+4|0;v[l+132>>2]=c;v[b>>2]=d;b=c;d=0}v[22656]=0;T(2461,a|0)|0;c=v[22656];v[22656]=0;if((c|0)!=1){continue}}break}a=P()|0;O()|0;break a}if(!d|v[r>>2]==(b|0)){break j}if(v[l+128>>2]==(b|0)){v[22656]=0;U(2485,r|0,l+132|0,l+128|0);b=v[22656];v[22656]=0;if((b|0)==1){break d}b=v[l+132>>2]}k=b+4|0;v[l+132>>2]=k;v[b>>2]=d;break i}t[g|0]=1;break h}a=P()|0;O()|0;v[l+28>>2]=p;break a}k=b}B:{if((p|0)<=0){break B}v[22656]=0;b=Q(2458,a|0,l+552|0)|0;c=v[22656];v[22656]=0;if((c|0)==1){break d}C:{if(!b){v[22656]=0;b=T(2459,a|0)|0;c=v[22656];v[22656]=0;if((c|0)==1){break d}if((b|0)==v[l+116>>2]){break C}}v[f>>2]=v[f>>2]|4;a=0;break f}v[22656]=0;T(2461,a|0)|0;b=v[22656];v[22656]=0;if((b|0)==1){break d}while(1){if((p|0)<=0){p=0;break B}v[22656]=0;b=Q(2458,a|0,l+552|0)|0;c=v[22656];v[22656]=0;D:{if((c|0)==1){break D}E:{if(!b){v[22656]=0;b=T(2459,a|0)|0;c=v[22656];v[22656]=0;if((c|0)==1){break D}v[22656]=0;b=W(2490,h|0,2048,b|0)|0;c=v[22656];v[22656]=0;if((c|0)==1){break D}if(b){break E}}v[f>>2]=v[f>>2]|4;a=0;break f}if(v[j>>2]==v[l+548>>2]){v[22656]=0;U(2492,i|0,j|0,l+548|0);b=v[22656];v[22656]=0;if((b|0)==1){break D}}v[22656]=0;b=T(2459,a|0)|0;c=v[22656];v[22656]=0;if((c|0)==1){break D}c=v[j>>2];v[j>>2]=c+4;v[c>>2]=b;v[22656]=0;T(2461,a|0)|0;b=v[22656];v[22656]=0;p=p-1|0;if((b|0)!=1){continue}}break}a=P()|0;O()|0;break a}if(v[i>>2]!=v[j>>2]){break h}v[f>>2]=v[f>>2]|4;a=0;break f}q=q+1|0;if((q|0)!=4){continue}}break}v[l+28>>2]=p;F:{if(!e){break F}c=1;while(1){if(Ab(e)>>>0<=c>>>0){break F}v[22656]=0;b=Q(2458,a|0,l+552|0)|0;d=v[22656];v[22656]=0;G:{if((d|0)==1){break G}H:{if(!b){v[22656]=0;b=T(2459,a|0)|0;d=v[22656];v[22656]=0;if((d|0)==1){break G}if((b|0)==v[yk(e,c)>>2]){break H}}v[f>>2]=v[f>>2]|4;a=0;break f}v[22656]=0;T(2461,a|0)|0;b=v[22656];v[22656]=0;c=c+1|0;if((b|0)!=1){continue}}break}a=P()|0;O()|0;break a}a=1;if(v[r>>2]==(k|0)){break f}a=0;v[l+16>>2]=0;jf(u,v[r>>2],k,l+16|0);if(v[l+16>>2]){v[f>>2]=v[f>>2]|4;break f}a=1}Hc(s);Hc(o);Hc(n);Hc(m);vb(u);Ic(r);gb=l+560|0;return a|0}a=P()|0;O()|0;break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;break a}a=P()|0;O()|0}Hc(s);Hc(o);Hc(n);Hc(m);vb(u);Ic(r);S(a|0);L()}function zma(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,y=0,z=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,M=0,N=0,Q=0,T=0,V=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,ca=0,da=0,ea=0;d=gb-320|0;gb=d;a:{if(!Wc(b,1080)){break a}if(!ip(b,d+316|0)){break a}Gd(a,1);m=CV(d+296|0);if(!BV(d+316|0,m)){break a}h=x[m+10>>1];e=h;if(!e|e>>>0>127){break a}if(!c){j=1;break a}u[a+480188>>1]=h;C=w[m+14|0];T=w[m+13|0];g=w[m+12|0];M=1;if(!je(d+316|0,33192)){M=je(d+316|0,33197)}if(w[m+15|0]){Ob(a+1074312|0,5,1);h=x[a+480188>>1]}e=d+316|0;o=je(e,13819);f=1;if(!je(e,14596)){f=je(d+316|0,10894)}J=a+480188|0;G=(h&65535)==8&(T|0)!=0;Wc(b,0);YC(b,a+1298268|0,20);u[a+480190>>1]=31;n=(g|0)!=0;j=1;g=o;while(1){s=B(j,104)+a|0;e=s+484380|0;h=kC(b,d+160|0,e,((j<<5)+a|0)+946304|0,x[a+480188>>1]==4);p=v[e>>2];b:{if(f){t[s+484417|0]=0-(w[d+184|0]<<3);break b}n=p>>>0<65536&n}c:{d:{if(!Ib(w[d+182|0]|w[d+183|0]<<8)){break d}if(Ib(w[d+188|0]|w[d+189|0]<<8)){break d}ba=1;break c}if(Ib(w[d+182|0]|w[d+183|0]<<8)){break c}V=w[d+185|0]==64|V}e=g&1;g=0;e:{if(!e){break e}y=(Ib(w[d+182|0]|w[d+183|0]<<8)<<1)+y|0;if(w[d+184|0]){break e}if(!Ib(w[d+182|0]|w[d+183|0]<<8)){g=1;break e}g=w[d+185|0]==64}N=h+N|0;i=i+p|0;j=j+1|0;if((j|0)!=32){continue}break}f:{g:{h:{i:{j:{k:{X=v[m+4>>2];if(X>>>0>=N>>>0){p=d+160|0;zV(b,p);Wc(b,x[m+8>>1]);z=p|1;e=w[z|0];f=128;l=a+484360|0;Er(Sb(l),p|2,128);s=!e&g;h=s?y:0;e=w[p|0];l:{if(e>>>0>128){break l}f=e;if(e){break l}g=128;while(1){e=g-1|0;if(!x[sc(Sb(l),e)>>1]){f=1;g=e;if(e>>>0>1){continue}break l}break}f=g}Q=(C|0)!=0;D=yV(b,Sb(l),f&65535,i,J,h,0);if(!(!s|x[a+480188>>1]!=8)){v[m>>2]=8553;Q=1}m:{if(!G){break m}e=Sb(l);da=d,ea=Vb(e),v[da+144>>2]=ea;da=d,ea=Zb(e),v[da+128>>2]=ea;if(!Gb(d+144|0,d+128|0)){break m}while(1){g=d+144|0;e=v[g>>2];u[e>>1]=x[e>>1]>>>1;of(g);if(Gb(g,d+128|0)){continue}break}}cf(Sb(l),w[z|0]);p=f-1&65535;n:{if(p>>>0>=w[z|0]){j=x[J>>1];if(w[z|0]!=120|(j|0)!=4){break n}}cf(Sb(l),0);j=x[J>>1]}v[a+480260>>2]=56;v[a+480264>>2]=13696;v[a+480204>>2]=125e4;v[a+480196>>2]=6;e=Lb(256/((j&65535)>>>0)|0,32,128);v[a+480208>>2]=0;v[a+480228>>2]=e;xh(a,0);t[d+159|0]=0;E=1;j=1;if(!(n&1)){o:{if(!D){e=o;break o}s=d+144|5;e=o;n=0;y=0;while(1){g=0;f=0;while(1){i=bj(d+144|0);jv(b,i);C=Dv(i);h=0;p:{q:{r:{s:{t:{l=w[d+147|0];if((l-7&255)>>>0<3){break t}i=w[d+149|0];if((l|0)==14&i>>>0>1){break s}if(!((l|0)==15&(i&255)>>>0>31)){h=C?e:0;if((l|0)!=13){break t}f=f+1|0;if((f&65535)>>>0<2){break q}}h=0;break p}if((l|0)==8){break r}if((l|0)!=14){break q}i=w[d+149|0]}if((i&240)!=128){break q}t[d+128|0]=i<<4;da=d,ea=w[df(d+159|0,d+128|0)|0],t[da+159|0]=ea;break q}da=d,ea=w[df(d+159|0,s)|0],t[da+159|0]=ea;e=t[d+149|0];if((e|0)>=0){y=1;break p}n=(e|0)!=-92&(e&255)>>>0>143|n}}e=h;E=C&E;g=g+1|0;if((g|0)!=256){continue}break}q=q+1|0;if(D>>>0>(q&65535)>>>0){continue}break}q=0;if((y^-1|n)&1){break o}q=w[d+159|0]>47}j=e&1}Wc(b,x[m+8>>1]);g=x[a+480188>>1];H=a+484344|0;f=D+G|0;e=f&65535;Ag(H,e);Y=G?4:g;r=a+1074312|0;u:{if(!e){q=0;break u}C=q^1;s=c&1;y=Y&65535;Z=f&65535;n=0;q=0;v:{while(1){w:{if(G){f=(F&65534)>>>1|0;e=F&1;if(!e){if(!wh(H,f,64)){break u}}e=Yc(_b(H,f),0,e<<2);break w}if(!wh(H,F&65535,64)){break u}e=Yc(_b(H,F),0,0)}if(!e|!s){break u}f=x[a+480188>>1];t[d+128|0]=0;g=d+128|0;I=Pv(d+144|0,f,g);f=x[a+480188>>1];v[22656]=0;t[d+64|0]=0;K=W(780,g|0,f|0,d- -64|0)|0;f=v[22656];v[22656]=0;if((f|0)!=1){l=0;while(1){i=0;D=0;h=0;if(y){while(1){v[22656]=0;k=B(h,6)+e|0;R(781,b|0,k|0);f=v[22656];v[22656]=0;x:{y:{if((f|0)!=1){f=w[k+3|0];z:{A:{B:{if(!f){if(w[k+5|0]){break B}break A}if(!T){break B}C:{switch(f-14|0){case 0:t[k+3|0]=0;t[k+5|0]=0;break B;case 1:break C;default:break B}}if(w[k+5|0]<32){break B}t[k+5|0]=31}Of(k);f=1;D:{E:{F:{g=w[k+3|0];switch(g-14|0){case 2:break z;case 0:break E;case 3:break F;default:break D}}q=w[k+5|0]<100|q;D=1;break A}if(!j){break A}t[k+5|0]=0;break A}if(!(C|(g|0)!=9)){f=w[k+5|0];if((f|0)==164){t[k+3|0]=20;t[k+5|0]=145;break A}da=k,ea=Xi(f<<1),t[da+5|0]=ea;break A}if((g|0)!=19){break A}f=w[k+5|0];if(f>>>0>15){break A}f=f&1;g=!f;ca=!f;f=n&1;n=(f|0)==(g|0)?n:ca;_=((f|0)!=(g|0))+_|0}f=i}if(w[k|0]){break y}if(!w[k+1|0]|G){break x}if(!w[lc(I,h)|0]){break x}if(w[lc(I,h)|0]==w[k+1|0]){break x}g=lc(K,h);i=w[g|0]+1|0;t[g|0]=i;if((i&255)>>>0<4){break x}v[22656]=0;W(409,r|0,85,1)|0;g=v[22656];v[22656]=0;if((g|0)!=1){break x}}h=P()|0;O()|0;gc(K);break v}da=lc(K,h),ea=0,t[da|0]=ea}g=w[k+1|0];if(g){da=lc(I,h),ea=g,t[da|0]=ea}i=f;h=h+1|0;if((y|0)!=(h|0)){continue}break}}$=i&D|$;e=B(x[J>>1],6)+e|0;l=l+1|0;if((l|0)!=64){continue}break}gc(K);gc(I);F=F+1|0;if((Z|0)==(F|0)){break u}continue}break}h=P()|0;O()|0}gc(I);break f}G:{H:{I:{if((E^-1|ba)&1){break I}J:{if(je(d+316|0,13819)){break J}if(je(d+316|0,14601)){break J}if(!je(d+316|0,10889)){break I}}v[a+480208>>2]=v[a+480208>>2]|2162688;Ob(r,85,1);Ob(r,91,1);Ob(r,92,1);K:{if(w[d+159|0]>47){break K}Ob(r,84,1);if(w[z|0]==127){break K}Ob(r,83,1)}if(!E){break G}break H}if(E){break H}if(o^1|w[z|0]!=127|p>>>0>w[z|0]+1>>>0){break G}v[m>>2]=5485;break G}if((_|0)>6|Q){break G}v[a+480208>>2]=v[a+480208>>2]|8388608}if((o|Q)==1){Ob(r,89,1)}if(M){Ob(r,84,1)}if(c&2){Wc(b,x[m+8>>1]+(B(Y&65535,Z)<<8)|0);f=(o&E^1|V)&1;j=1;while(1){e=B(j,104)+a|0;i=e+484380|0;if(v[i>>2]){g=d+144|0;if(M){c=2}else{c=xV(b,11149)?10:0}g=Rc(g,8,1,0,c);c=v[b+8>>2]+Bv(g,v[i>>2])|0;if(!f){da=i,ea=v[Lc(i,e+484388|0)>>2],v[da>>2]=ea}Dg(g,i,b);Wc(b,c)}j=j+1|0;if((j|0)!=32){continue}break}}L:{if((o&q^-1|$)&1){break L}c=wV(d+104|0,0);b=v[c+20>>2];v[d+40>>2]=v[c+16>>2];v[d+44>>2]=b;b=v[c+12>>2];v[d+32>>2]=v[c+8>>2];v[d+36>>2]=b;b=v[c+4>>2];v[d+24>>2]=v[c>>2];v[d+28>>2]=b;b=d+144|0;vu(b,a,0,d+24|0);aa=A[v[b>>2]>>3];en(b);if(!(aa>=600)){break L}Ob(r,5,1);c=vV(d+80|0,aa);b=v[c+20>>2];v[d+16>>2]=v[c+16>>2];v[d+20>>2]=b;b=v[c+12>>2];v[d+8>>2]=v[c+8>>2];v[d+12>>2]=b;b=v[c+4>>2];v[d>>2]=v[c>>2];v[d+4>>2]=b;c=d+144|0;vu(c,a,0,d);b=w[v[c>>2]+26|0];en(c);if(b){Rf(r,5);break L}v[m>>2]=14153}o=d+316|0;f=o;b=f;e=fc(b);g=e;if((b|0)!=(e|0)){while(1){c=w[f|0];t[b|0]=c>>>0>32?c:32;b=b+1|0;f=f+1|0;if((g|0)!=(f|0)){continue}break}}Df(d+128|0,13906);v[22656]=0;c=W(782,d+48|0,o|0,e|0)|0;b=v[22656];v[22656]=0;if((b|0)==1){break k}v[22656]=0;U(13,d- -64|0,1,c|0);b=v[22656];v[22656]=0;if((b|0)==1){break j}v[22656]=0;U(167,d+144|0,d+128|0,d- -64|0);b=v[22656];v[22656]=0;if((b|0)==1){break i}b=d+144|0;Eb(a+1298304|0,b);vb(b);vb(d- -64|0);vb(c);Hb(d+128|0);b=Tb(b,9562);Eb(a+1298316|0,b);vb(b);b=v[m>>2];if(b){Xc(a+1298328|0,b)}v[a+1298364>>2]=2}j=N>>>0<=X>>>0;break a}h=P()|0;O()|0;break g}h=P()|0;O()|0;break h}h=P()|0;O()|0;vb(d- -64|0)}vb(c)}Hb(d+128|0)}S(h|0);L()}gb=d+320|0;return j|0}function vla(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;d=gb-272|0;gb=d;vc(b);f=gb-32|0;gb=f;e=f+24|0;j=d+120|0;zU(e,j);k=yb(e);e=v[f+28>>2];h=v[f+24>>2];v[f+8>>2]=h;v[f+12>>2]=e;v[f>>2]=h;v[f+4>>2]=e;h=f+16|0;e=b;cc(h,e,f);h=yb(h);if((h|0)==(k|0)){Rb(e,yb(f+24|0))}gb=f+32|0;e=(h|0)==(k|0);if(!e){yU(j)}a:{b:{c:{d:{e:{if(!e){break e}if(!JU(d+120|0)){break e}if(!c){i=1;break e}Gd(a,4194304);e=d+32|0;f=Tb(e,14112);Eb(a+1298304|0,f);vb(f);f=Tb(e,7407);Eb(a+1298316|0,f);vb(f);v[a+1298364>>2]=5;n=a,o=Md(w[d+198|0]|w[d+199|0]<<8,w[d+200|0]|w[d+201|0]<<8,127),u[n+480188>>1]=o;f=w[d+189|0];v[a+480228>>2]=(f|0)==255?48:f;v[a+480196>>2]=w[d+187|0];v[a+480204>>2]=B(w[d+188|0],1e4);f=d+96|0;pf(f,d+120|4,59,3);Bc(e,f);Eb(a+1298268|0,e);vb(e);f:{if((w[d+202|0]|w[d+203|0]<<8|(w[d+204|0]<<16|w[d+205|0]<<24))>>>0<5){break f}if(!Wc(b,(w[d+202|0]|w[d+203|0]<<8|(w[d+204|0]<<16|w[d+205|0]<<24))-4|0)){break f}if(!Gh(b,11471)){break f}kp(Sb(a+484360|0),b,w[d+192|0]|w[d+193|0]<<8,65535,65535)}g:{if((w[d+206|0]|w[d+207|0]<<8|(w[d+208|0]<<16|w[d+209|0]<<24))>>>0<5){break g}if(!Wc(b,(w[d+206|0]|w[d+207|0]<<8|(w[d+208|0]<<16|w[d+209|0]<<24))-4|0)){break g}if(!Gh(b,11108)){break g}while(1){e=(i<<5)+a|0;We(e+480280|0);n=e+480284|0,o=((((Ae(b)^-1)&15)<<8|8)>>>0)/15|0,u[n>>1]=o;i=i+1|0;if((i|0)!=32){continue}break}}h:{if((w[d+214|0]|w[d+215|0]<<8|(w[d+216|0]<<16|w[d+217|0]<<24))>>>0<5){break h}if(!Wc(b,(w[d+214|0]|w[d+215|0]<<8|(w[d+216|0]<<16|w[d+217|0]<<24))-4|0)){break h}if(!Gh(b,11384)){break h}f=d+32|0;Td(f,b,(w[d+196|0]|w[d+197|0]<<8)<<6);e=kc(d+96|0,f);xb(f);i:{if(!(w[d+196|0]|w[d+197|0]<<8)){break i}k=c&2;j=a+480190|0;h=d+45|0;while(1){v[22656]=0;f=Q(867,e|0,d+32|0)|0;i=v[22656];v[22656]=0;if((i|0)==1){break d}if(!f){break i}f=w[d+77|0]|w[d+78|0]<<8;u[d+30>>1]=f;j:{if((f-1&65535)>>>0>3998){break j}if(Jd((B(f,104)+a|0)+484380|0)){break j}v[22656]=0;f=Le(j,d+30|0);i=v[22656];v[22656]=0;if((i|0)==1){break c}u[a+480190>>1]=x[f>>1];v[22656]=0;R(868,d+32|0,(B(x[d+30>>1],104)+a|0)+484380|0);f=v[22656];v[22656]=0;if((f|0)==1){break c}pf(d,h,24,1);v[22656]=0;R(324,d+16|0,d|0);f=v[22656];v[22656]=0;k:{if((f|0)!=1){v[22656]=0;Q(301,((x[d+30>>1]<<5)+a|0)+946304|0,d+16|0)|0;f=v[22656];v[22656]=0;if((f|0)==1){break k}vb(d+16|0);if(!k){break j}f=w[d+69|0]|w[d+70|0]<<8|(w[d+71|0]<<16|w[d+72|0]<<24);v[22656]=0;Q(190,b|0,f|0)|0;f=v[22656];v[22656]=0;if((f|0)==1){break c}i=1;g=d+16|0;f=d+79|0;l=Rc(g,w[f|0]&4?16:8,1,0,0);l:{m:{if(w[f|0]&8){break m}i=2;if(w[f|0]&16){break m}if(w[f|0]&127){break l}}Bf(l,i)}v[22656]=0;W(329,g|0,(B(x[d+30>>1],104)+a|0)+484380|0,b|0)|0;f=v[22656];v[22656]=0;if((f|0)!=1){break j}b=P()|0;O()|0;break b}b=P()|0;O()|0;break b}b=P()|0;O()|0;vb(d+16|0);break b}m=m+1|0;if((m&65535)>>>0<(w[d+196|0]|w[d+197|0]<<8)>>>0){continue}break}}xb(e)}i=1;if(!(c&1)){break e}n:{if((w[d+210|0]|w[d+211|0]<<8|(w[d+212|0]<<16|w[d+213|0]<<24))>>>0<5){break n}if(!Wc(b,(w[d+210|0]|w[d+211|0]<<8|(w[d+212|0]<<16|w[d+213|0]<<24))-4|0)){break n}if(!Gh(b,10974)){break n}h=a+484344|0;Ag(h,w[d+194|0]|w[d+195|0]<<8);if(!(w[d+194|0]|w[d+195|0]<<8)){break n}k=d+16|2;m=0;while(1){if(!BC(b,d+16|0)){break n}if((w[d+16|0]|w[d+17|0]<<8)>>>0>3){c=d+96|0;Td(c,b,((w[d+16|0]|w[d+17|0]<<8)+15&131056)-4|0);f=kc(d+32|0,c);xb(c);c=w[k|0];v[22656]=0;c=W(331,h|0,m&65535,c|0)|0;e=v[22656];v[22656]=0;o:{if((e|0)!=1){p:{j=0;if(!c){break o}while(1){v[22656]=0;c=Q(191,d+32|0,1)|0;e=v[22656];v[22656]=0;q:{r:{s:{if((e|0)!=1){if(!c|w[k|0]<=j>>>0){break r}v[22656]=0;e=T(374,f|0)|0;c=v[22656];v[22656]=0;if((c|0)==1){break p}if(e){break s}j=j+1|0;continue}break p}c=_b(h,m);u[d+96>>1]=e&31;g=x[a+480188>>1];v[22656]=0;u[d>>1]=g-1;g=Pc(d+96|0,d);l=v[22656];v[22656]=0;if((l|0)==1){break p}g=x[g>>1];v[22656]=0;c=Yc(c,j,g);g=v[22656];v[22656]=0;if((g|0)==1){break p}if(e&128){v[22656]=0;R(403,d+96|0,f|0);g=v[22656];v[22656]=0;if((g|0)==1){break p}g=d+96|0;l=qd(g);t[c|0]=w[g|0]+36;t[c+1|0]=w[l|0]}if(!(e&64)){break q}t[c+2|0]=1;v[22656]=0;g=T(374,f|0)|0;l=v[22656];v[22656]=0;t:{if((l|0)!=1){t[d+96|0]=g;v[22656]=0;t[d|0]=64;g=ac(d+96|0,d);l=v[22656];v[22656]=0;if((l|0)==1){break t}t[c+4|0]=w[g|0];break q}break p}break p}if(w[k|0]==64){break o}c=_b(h,m);v[22656]=0;e=Be(d+96|0,14,0);f=v[22656];v[22656]=0;if((f|0)!=1){e=Fh(Ue(e,w[k|0]-1|0));v[22656]=0;Q(431,c|0,e|0)|0;c=v[22656];v[22656]=0;if((c|0)!=1){break o}}break p}if(!(e&32)){continue}v[22656]=0;R(403,d+96|0,f|0);e=v[22656];v[22656]=0;u:{v:{w:{x:{y:{z:{A:{B:{C:{D:{E:{F:{G:{H:{I:{J:{K:{L:{M:{N:{O:{P:{Q:{R:{S:{T:{U:{V:{W:{X:{Y:{Z:{if((e|0)!=1){g=d+96|0;e=w[qd(g)|0];t[c+5|0]=e;switch(w[g|0]-1|0){case 71:break v;case 70:break w;case 69:break x;case 60:break y;case 59:break z;case 52:break A;case 51:break B;case 50:break C;case 49:break D;case 42:break E;case 41:break F;case 40:break G;case 39:break H;case 30:break I;case 29:break J;case 22:break K;case 21:break L;case 20:break M;case 19:break N;case 16:break O;case 15:break P;case 14:break Q;case 13:break R;case 12:break S;case 11:break T;case 10:break U;case 9:break V;case 3:break W;case 2:break X;case 1:break Y;case 0:break Z;default:break u}}break p}t[c+3|0]=11;t[c+5|0]=e<<4|15;continue}t[c+3|0]=11;t[c+5|0]=e<<4;continue}t[c+3|0]=11;t[c+5|0]=e|240;continue}t[c+3|0]=11;t[c+5|0]=e&15;continue}t[c+3|0]=2;t[c+5|0]=e|240;continue}t[c+3|0]=2;continue}t[c+3|0]=3;t[c+5|0]=e|240;continue}t[c+3|0]=3;continue}t[c+3|0]=4;continue}t[c+3|0]=20;t[c+5|0]=e|16;continue}t[c+3|0]=6;t[c+5|0]=e<<4;continue}t[c+3|0]=6;t[c+5|0]=e&15;continue}t[c+3|0]=5;continue}t[c+3|0]=20;t[c+5|0]=e|48;continue}t[c+3|0]=7;t[c+5|0]=e<<4;continue}t[c+3|0]=7;t[c+5|0]=e&15;continue}t[c+3|0]=8;continue}t[c+3|0]=20;t[c+5|0]=e|64;continue}t[c+3|0]=10;v[22656]=0;e=T(374,f|0)|0;g=v[22656];v[22656]=0;if((g|0)!=1){t[c+5|0]=e;v[22656]=0;Q(318,d+32|0,1)|0;c=v[22656];v[22656]=0;if((c|0)!=1){continue}}break p}t[c+3|0]=15;t[c+5|0]=e&15;continue}t[c+3|0]=20;t[c+5|0]=e|192;continue}t[c+3|0]=20;t[c+5|0]=e|208;continue}t[c+3|0]=12;continue}t[c+3|0]=14;continue}t[c+3|0]=20;t[c+5|0]=e|176;continue}t[c+3|0]=20;t[c+5|0]=e|224;continue}t[c+3|0]=16;continue}t[c+3|0]=17;continue}t[c+3|0]=1;continue}t[c+3|0]=20;t[c+5|0]=e&15|32;continue}t[c+3|0]=20;t[c+5|0]=e&15|128;continue}t[c+3|0]=0;continue}}}b=P()|0;O()|0;xb(d+32|0);break a}xb(d+32|0)}m=m+1|0;if(m>>>0<(w[d+194|0]|w[d+195|0]<<8)>>>0){continue}break}}if(!(w[d+218|0]|w[d+219|0]<<8|(w[d+220|0]<<16|w[d+221|0]<<24))){break e}Wc(b,w[d+218|0]|w[d+219|0]<<8|(w[d+220|0]<<16|w[d+221|0]<<24));uB(a+1298292|0,b,Og(b),4)}gb=d+272|0;return i|0}b=P()|0;O()|0;break b}b=P()|0;O()|0}xb(e)}S(b|0);L()}function tu(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;h=gb-32|0;gb=h;v[h+28>>2]=c;a:{if((c|0)<=0){break a}k=v[b+104>>2];j=v[b+656>>2];if(!(!j|v[a+480180>>2]!=16777216)){o=v[j+44>>2]!=0}b:{if(!(!j|(c|0)>128)){i=x[vd(j+236|0,c-1|0)>>1];c:{if((i-1&65535)>>>0<=3998){k=(B(i,104)+a|0)+484380|0;break c}i=h+16|0;Db(i,a+1074312|0,43);if(!Cb(i)){break c}if(!tk(b)){break a}}m=w[ic(j+108|0,v[h+28>>2]-1|0)|0];v[h+28>>2]=m;break b}m=c}if(m>>>0>=121){d:{if(!(v[a+480180>>2]&16777248?(m|0)!=255:0)){Do(a,b);if(d){break d}c=h+16|0;Db(c,a+1074312|0,100);if(!Cb(c)|!(w[a+480208|0]&4)|!w[b+789|0]){break d}v[b+88>>2]=v[b+88>>2]&-6145;break d}if(!x[a+480192>>1]){break d}v[b+88>>2]=v[b+88>>2]|4096}e:{if(v[h+28>>2]!=254){break e}f:{c=v[b+88>>2];if(!(c&512)){break f}c=v[b+88>>2];if(v[a+480180>>2]!=2){break f}v[b+88>>2]=c|2048;break e}v[b+88>>2]=c|2101248;g:{if(v[a+480180>>2]&16777248){if(!x[a+480192>>1]){break g}c=h+16|0;Db(c,a+1074312|0,50);if(Cb(c)){break g}}v[b+688>>2]=0}c=h+16|0;Db(c,a+1074312|0,50);if(Cb(c)){v[b+8>>2]=0;v[b+12>>2]=0}v[b+696>>2]=0}c=h+16|0;Db(c,a+1074312|0,20);if(!Cb(c)){break a}t[b+797|0]=0;t[b+802|0]=0;break a}h:{i:{j:{if(o){if(d){n=w[b+797|0];if(n){break j}}v[b+708>>2]=0}if(d){break i}if(!(!(v[a+480180>>2]&1048588)|!k)){u[b+770>>1]=t[k+36|0];u[b+772>>1]=t[k+37|0]}if(k){d=h+16|0;Db(d,a+1074312|0,24);m=0;p=1;if(!Cb(d)){break h}v[b+704>>2]=v[k+24>>2];break h}m=0;break h}i=v[j+44>>2];u[h>>1]=n;u[h+14>>1]=m;v[h+16>>2]=0;i=(v[h+16>>2]+B(u[i+36>>1]+1|0,u[h+14>>1]-u[h>>1]|0)|0)-v[b+852>>2]|0;v[b+708>>2]=i;v[b+852>>2]=0-i}p=(k|0)!=0;m=1;if(Mi(b)){break h}i=h+16|0;m=a+1074312|0;Db(i,m,54);if(Cb(i)){v[b+700>>2]=0;break a}i=h+16|0;Db(i,m,39);m=(Cb(i)^-1)&d}k:{if(_l(a)){v[h+28>>2]=v[h+28>>2]+u[b+770>>1];Zd(h+28|0,12,131);break k}fV(h+28|0)}i=h+16|0;l=a+1074312|0;Db(i,l,34);d=b;l:{if(Cb(i)){i=on(c);break l}i=v[h+28>>2]}t[d+797|0]=i;t[b+851|0]=w[b+851|0]&219|32;if(!(v[a+480180>>2]&16777250?0:m)){t[b+803|0]=0}n=_g(a,v[h+28>>2],u[b+772>>1],v[b+704>>2]);t[b+831|0]=0;d=h+16|0;Db(d,l,48);if(Cb(d)){EP(a,b,j,k)}d=h+16|0;Db(d,l,115);if(!(!Cb(d)|!j|!w[j+26|0])){if(!x[b+784>>1]){u[b+784>>1]=x[b+692>>1]+1}pO(b+692|0,c,j)}m:{if(e^1|m){break m}v[b+776>>2]=0;v[b+780>>2]=0;if(!j){break m}c=h+16|0;Db(c,l,29);if(Cb(c)){t[b+798|0]=w[j+16|0]}if(!(w[j+60|0]&8)){Ij(b+724|0)}if(!(w[j+80|0]&8)){Ij(b+732|0)}if(!(w[j+100|0]&8)){Ij(b+740|0)}if(w[j+20|0]){d=ru(Co(a));c=w[j+20|0];i=h+16|0;Db(i,l,28);d=((B(c,d)<<16>>16)/64<<16)+65536>>16;c=b;n:{if(Cb(i)){i=v[b+752>>2];break n}i=(v[b+688>>2]+1|0)/2|0}u[c+776>>1]=(B(i,d)|0)/199}o:{if(!w[j+19|0]){break o}q=b,r=(B(ru(Co(a)),w[j+19|0])<<16>>16)/32|0,u[q+778>>1]=r;c=h+16|0;Db(c,l,28);if(Cb(c)|x[b+784>>1]){break o}u[b+784>>1]=x[b+692>>1]+1}i=w[j+23|0];if(i){d=ru(Co(a));c=w[b+837|0];t[b+796|0]=c+1;u[b+780>>1]=(B(c,(B(i,d+1|0)<<16>>16)/128<<16>>16)+1|0)/128}i=w[j+24|0];if(!i){break m}d=ru(Co(a));c=w[b+838|0];t[b+795|0]=c+1;u[b+782>>1]=(B(c,(B(i,d+1|0)<<16>>16)/128<<16>>16)+1|0)/128}if(!p){break a}c=0;p:{q:{if(!n){break q}if(!(v[b+700>>2]?m:0)){v[b+700>>2]=n}r:{s:{if(!o){if(!m){d=h+16|0;Db(d,l,69);if(Cb(d)){break s}Db(h,l,46);if(Cb(h)|v[a+480180>>2]==1){break s}}v[b+708>>2]=n;t[b+851|0]=w[b+851|0]&247}if(!m){break s}if(v[b+76>>2]|v[a+480180>>2]&2){break r}}v[b+104>>2]=k;d=v[k>>2];v[b+84>>2]=d;v[b+76>>2]=d;v[b+80>>2]=0;v[b>>2]=0;v[b+4>>2]=0;t:{u:{if(!(v[a+480208>>2]&2097152)){d=h+16|0;Db(d,l,96);if(!Cb(d)){break u}}if(w[b+789|0]){break u}v[h+16>>2]=v[b+76>>2]-1;q=b,r=v[Fb(b+660|0,h+16|0)>>2],v[q+4>>2]=r;break t}v[b+660>>2]=0}d=x[k+34>>1];n=d&1023;i=n|v[b+88>>2]&-525056;v[b+88>>2]=i;v:{w:{if(d&8){v[b+80>>2]=v[k+12>>2];o=v[k+16>>2];v[b+88>>2]=(n&16?i|4:i&-524295)|2;v[b+84>>2]=o;if(y[b+76>>2]>o>>>0){break w}break v}if(!(n&2)){break v}v[b+80>>2]=v[k+4>>2];o=v[k+8>>2];v[b+84>>2]=o;if(y[b+76>>2]<=o>>>0){break v}}v[b+76>>2]=o}d=h+16|0;Db(d,l,83);if(!(!Cb(d)|v[b+80>>2])){d=v[k>>2];v[b+84>>2]=d;v[b+76>>2]=d}i=v[b+88>>2];x:{if(!(i&128)){break x}d=v[b+76>>2];if(!d){break x}v[b+88>>2]=i|128;v[b+4>>2]=d-1}y:{if(w[b+822|0]>3){break y}i=h+16|0;Db(i,l,21);d=b;z:{if(!(Cb(i)|!(v[a+480180>>2]&16777248))){i=16;if(!(v[a+480208>>2]&4)){break z}}i=32;if(v[a+480180>>2]==16){break z}if(v[a+480180>>2]&67633152){break y}i=0}t[d+819|0]=i}d=h+16|0;Db(d,l,21);if(Cb(d)|w[b+825|0]>3){break r}t[b+820|0]=0}d=v[b>>2];if(y[b+76>>2]<=y[b+4>>2]){i=d;d=v[b+80>>2];v[b>>2]=i;v[b+4>>2]=d}if(!m){break q}c=1;if(!(v[a+480180>>2]&17301536)|(v[b+696>>2]?0:w[b+89|0]&16)){break q}d=1;if(!(w[a+480208|0]&8)){break p}d=1;if(!w[b+789|0]){break p}}if(!(v[b+696>>2]|(!(v[a+480180>>2]&17301536)|!(w[b+89|0]&16)))){Nm(b);d=h+16|0;Db(d,l,21);if(!Cb(d)){t[b+818|0]=0;v[b+756>>2]=0}v[b+696>>2]=65536;v[b+88>>2]=v[b+88>>2]&-4097}if(!(!c|!(w[a+480208|0]&8))){d=1;if(!w[b+789|0]){break p}}if(!(w[b+789|0]?0:v[a+480180>>2]&1048580)){v[b+696>>2]=65536;v[b+88>>2]=v[b+88>>2]&-4097}d=c}c=h+16|0;Db(c,l,40);A:{B:{if(Cb(c)){if(d){if(!(!(w[a+480208|0]&8)|!w[b+789|0])){v[b+88>>2]=v[b+88>>2]&-4196353;k=1;break A}v[b+88>>2]=v[b+88>>2]&-4194305;k=1;break A}c=v[b+88>>2]&-4196353;break B}c=v[b+88>>2]&-4196353;v[b+88>>2]=c;k=1;if(d){break A}}u[b+842>>1]=65535;v[b+88>>2]=c&-6326273|2097152;c=h+16|0;Db(c,l,23);C:{if(Cb(c)){break C}Db(h,l,22);if(Cb(h)){break C}c=h+16|0;Db(c,l,52);if(Cb(c)){break C}Db(h,l,71);if(Cb(h)){break C}t[b+839|0]=0;t[b+808|0]=0}if(e){t[b+818|0]=0;v[b+756>>2]=0}v[b+20>>2]=0;v[b+24>>2]=0;c=v[a+480208>>2]&8192;D:{if(j){E:{F:{if(!aF(j)){if(yw(j)){break F}c=!(c>>>13|0);if(c){break E}break D}q=b,r=bF(j),t[q+838|0]=r;if(!yw(j)){break E}}q=b,r=cF(j),t[q+837|0]=r}c=1;d=w[j+25|0];if((d|0)==255){break D}t[b+845|0]=d;break D}v[b+776>>2]=0;v[b+780>>2]=0;c=!c}G:{if(w[b+837|0]>=127){d=h+16|0;Db(d,l,36);if(!Cb(d)){break G}}if(!c){break G}if((Jq(a,b,1,256)|0)<0|!(w[b+89|0]&2)){break G}c=a+1298260|0;if(!Dd(c)|(g|0)==65535){break G}Qq(v[c>>2],g,w[b+837|0]>>>1|0,1)}k=0;if(!(w[b+89|0]&2)){break A}d=a+1298260|0;if(!Dd(d)|(g|0)==65535){break A}c=h+16|0;Db(c,l,111);if(Cb(c)){vk(v[d>>2],g);break A}c=h+16|0;Db(c,l,110);if(!Cb(c)){break A}$A(v[d>>2],g,0,1,0)}c=v[b+88>>2];if(f){c=c&-1025;v[b+88>>2]=c}H:{I:{if(w[a+24618|0]&16?c&1024:0){break I}a=v[b+104>>2];if(!(f?1:!a|!(w[a+35|0]&4))){break I}a=v[b+656>>2];if(!a|!(w[a+15|0]&2)){break H}}if(f){break H}v[b+700>>2]=0}if(k){break a}u[b+136>>1]=0;v[b+132>>2]=4194304;v[b+112>>2]=0;v[b+116>>2]=0}gb=h+32|0}function g3(a,b,c,d,e,f,g,h,i,j,k){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;var l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,u=0,x=0,y=0,z=0,A=0,B=0;l=gb-560|0;gb=l;v[l+548>>2]=k;v[l+552>>2]=b;v[l+104>>2]=2479;b=l+104|0;q=ge(l+136|0,l+144|0,b);k=v[q>>2];v[l+132>>2]=k;v[l+128>>2]=k+400;u=Kb(b);m=Kb(l+88|0);n=Kb(l+72|0);p=Kb(l+56|0);s=Kb(l+40|0);v[22656]=0;na(2482,c|0,d|0,l+120|0,l+119|0,l+118|0,u|0,m|0,n|0,p|0,l+36|0);b=v[22656];v[22656]=0;a:{b:{c:{d:{e:{if((b|0)!=1){v[j>>2]=v[i>>2];y=e&512;z=y>>>9|0;r=v[l+36>>2];e=0;f:{while(1){v[22656]=0;b=Q(2430,a|0,l+552|0)|0;c=v[22656];v[22656]=0;if((c|0)==1){break c}g:{if(!b){break g}h:{i:{j:{k:{l:{m:{n:{o:{p:{switch(t[(l+120|0)+e|0]){case 1:if((e|0)==3){break g}v[22656]=0;b=T(2432,a|0)|0;c=v[22656];v[22656]=0;if((c|0)==1){break c}if(nh(h,8192,b)){v[22656]=0;R(2483,l+24|0,a|0);b=v[22656];v[22656]=0;if((b|0)!=1){b=t[l+24|0];v[22656]=0;R(61,s|0,b|0);b=v[22656];v[22656]=0;if((b|0)!=1){break o}}a=P()|0;O()|0;break a}v[f>>2]=v[f>>2]|4;a=0;break f;case 4:break l;case 2:break m;case 3:break n;case 0:break p;default:break h}}if((e|0)==3){break g}}while(1){v[22656]=0;b=Q(2430,a|0,l+552|0)|0;c=v[22656];v[22656]=0;if((c|0)==1){break b}if(!b){break h}v[22656]=0;b=T(2432,a|0)|0;c=v[22656];v[22656]=0;if((c|0)==1){break b}if(!nh(h,8192,b)){break h}v[22656]=0;R(2483,l+24|0,a|0);b=v[22656];v[22656]=0;if((b|0)!=1){b=t[l+24|0];v[22656]=0;R(61,s|0,b|0);b=v[22656];v[22656]=0;if((b|0)!=1){continue}}break}a=P()|0;O()|0;break a}if((Ab(n)|0)==(0-Ab(p)|0)){break h}q:{if(Ab(n)){if(Ab(p)){break q}}if(Ab(n)){v[22656]=0;b=T(2432,a|0)|0;c=v[22656];v[22656]=0;if((c|0)==1){break c}if(w[pc(n,0)|0]!=(b&255)){break k}v[22656]=0;T(2434,a|0)|0;b=v[22656];v[22656]=0;if((b|0)==1){break c}o=Ab(n)>>>0>1?n:o;break h}v[22656]=0;b=T(2432,a|0)|0;c=v[22656];v[22656]=0;if((c|0)==1){break c}if(w[pc(p,0)|0]!=(b&255)){break h}v[22656]=0;T(2434,a|0)|0;b=v[22656];v[22656]=0;if((b|0)==1){break c}t[g|0]=1;o=Ab(p)>>>0>1?p:o;break h}v[22656]=0;b=T(2432,a|0)|0;c=v[22656];v[22656]=0;if((c|0)==1){break c}if(w[pc(n,0)|0]==(b&255)){v[22656]=0;T(2434,a|0)|0;b=v[22656];v[22656]=0;if((b|0)==1){break c}o=Ab(n)>>>0>1?n:o;break h}v[22656]=0;b=T(2432,a|0)|0;c=v[22656];v[22656]=0;if((c|0)==1){break c}if(w[pc(p,0)|0]==(b&255)){v[22656]=0;T(2434,a|0)|0;b=v[22656];v[22656]=0;if((b|0)==1){break c}t[g|0]=1;o=Ab(p)>>>0>1?p:o;break h}v[f>>2]=v[f>>2]|4;a=0;break f}if(!(e>>>0<2|o|((e|0)==2&w[l+123|0]!=0|z))){o=0;break h}A=l,B=zd(m),v[A+16>>2]=B;b=Fd(l+24|0,l+16|0);r:{if(!e|w[(e+l|0)+119|0]>1){break r}A=l,B=gf(m),v[A+16>>2]=B;s:{if(!Gb(b,l+16|0)){break s}while(1){if(!nh(h,8192,t[v[b>>2]])){break s}Pe(b);A=l,B=gf(m),v[A+16>>2]=B;if(Gb(b,l+16|0)){continue}break}}A=l,B=zd(m),v[A+16>>2]=B;b=ck(b,l+16|0);if(Ab(s)>>>0>=b>>>0){A=l,B=gf(s),v[A+16>>2]=B;c=we(l+16|0,0-b|0);d=gf(s);x=zd(m);b=gb-32|0;gb=b;v[b+16>>2]=d;v[b+24>>2]=c;v[b+8>>2]=x;c=1;t:{if(!Gb(b+24|0,b+16|0)){break t}while(1){c=w[v[b+24>>2]]==w[v[b+8>>2]];if(!c){break t}d=b+24|0;Pe(d);Pe(b+8|0);if(Gb(d,b+16|0)){continue}break}}gb=b+32|0;if(c){break r}}A=l,B=zd(m),v[A+8>>2]=B;Fd(l+16|0,l+8|0);v[l+24>>2]=v[l+16>>2]}v[l+16>>2]=v[l+24>>2];A=l,B=gf(m),v[A+8>>2]=B;u:{v:{w:{if(!Gb(l+16|0,l+8|0)){break w}while(1){v[22656]=0;b=Q(2430,a|0,l+552|0)|0;c=v[22656];v[22656]=0;if((c|0)==1){break v}if(!b){break w}v[22656]=0;b=T(2432,a|0)|0;c=v[22656];v[22656]=0;if((c|0)==1){break v}if(w[v[l+16>>2]]!=(b&255)){break w}v[22656]=0;T(2434,a|0)|0;b=v[22656];v[22656]=0;if((b|0)==1){break u}b=l+16|0;Pe(b);A=l,B=gf(m),v[A+8>>2]=B;if(Gb(b,l+8|0)){continue}break}}if(!y){break h}A=l,B=gf(m),v[A+8>>2]=B;if(!Gb(l+16|0,l+8|0)){break h}v[f>>2]=v[f>>2]|4;a=0;break f}a=P()|0;O()|0;v[l+36>>2]=r;break a}a=P()|0;O()|0;v[l+36>>2]=r;break a}d=0;x=w[l+118|0];b=k;x:{while(1){y:{v[22656]=0;c=Q(2430,a|0,l+552|0)|0;k=v[22656];v[22656]=0;if((k|0)==1){break y}if(!c){break x}v[22656]=0;c=T(2432,a|0)|0;k=v[22656];v[22656]=0;if((k|0)==1){break e}z:{if(nh(h,2048,c)){k=v[j>>2];if((k|0)==v[l+548>>2]){v[22656]=0;U(2484,i|0,j|0,l+548|0);k=v[22656];v[22656]=0;if((k|0)==1){break e}k=v[j>>2]}v[j>>2]=k+1;t[k|0]=c;d=d+1|0;break z}if(!Ab(u)|!d|(x|0)!=(c&255)){break x}if(v[l+128>>2]==(b|0)){v[22656]=0;U(2485,q|0,l+132|0,l+128|0);b=v[22656];v[22656]=0;if((b|0)==1){break e}b=v[l+132>>2]}c=b+4|0;v[l+132>>2]=c;v[b>>2]=d;b=c;d=0}v[22656]=0;T(2434,a|0)|0;c=v[22656];v[22656]=0;if((c|0)!=1){continue}}break}a=P()|0;O()|0;break a}if(!d|v[q>>2]==(b|0)){break j}if(v[l+128>>2]==(b|0)){v[22656]=0;U(2485,q|0,l+132|0,l+128|0);b=v[22656];v[22656]=0;if((b|0)==1){break d}b=v[l+132>>2]}k=b+4|0;v[l+132>>2]=k;v[b>>2]=d;break i}t[g|0]=1;break h}k=b}A:{if((r|0)<=0){break A}v[22656]=0;b=Q(2431,a|0,l+552|0)|0;c=v[22656];v[22656]=0;if((c|0)==1){break d}B:{if(!b){v[22656]=0;b=T(2432,a|0)|0;c=v[22656];v[22656]=0;if((c|0)==1){break d}if(w[l+119|0]==(b&255)){break B}}v[f>>2]=v[f>>2]|4;a=0;break f}v[22656]=0;T(2434,a|0)|0;b=v[22656];v[22656]=0;if((b|0)==1){break d}while(1){if((r|0)<=0){r=0;break A}v[22656]=0;b=Q(2431,a|0,l+552|0)|0;c=v[22656];v[22656]=0;C:{if((c|0)==1){break C}D:{if(!b){v[22656]=0;b=T(2432,a|0)|0;c=v[22656];v[22656]=0;if((c|0)==1){break C}if(nh(h,2048,b)){break D}}v[f>>2]=v[f>>2]|4;a=0;break f}if(v[j>>2]==v[l+548>>2]){v[22656]=0;U(2484,i|0,j|0,l+548|0);b=v[22656];v[22656]=0;if((b|0)==1){break C}}v[22656]=0;b=T(2432,a|0)|0;c=v[22656];v[22656]=0;if((c|0)==1){break C}c=v[j>>2];v[j>>2]=c+1;t[c|0]=b;v[22656]=0;T(2434,a|0)|0;b=v[22656];v[22656]=0;r=r-1|0;if((b|0)!=1){continue}}break}a=P()|0;O()|0;break a}if(v[i>>2]!=v[j>>2]){break h}v[f>>2]=v[f>>2]|4;a=0;break f}e=e+1|0;if((e|0)!=4){continue}}break}v[l+36>>2]=r;E:{if(!o){break E}c=1;while(1){if(Ab(o)>>>0<=c>>>0){break E}v[22656]=0;b=Q(2431,a|0,l+552|0)|0;d=v[22656];v[22656]=0;F:{if((d|0)==1){break F}G:{if(!b){v[22656]=0;b=T(2432,a|0)|0;d=v[22656];v[22656]=0;if((d|0)==1){break F}if(w[pc(o,c)|0]==(b&255)){break G}}v[f>>2]=v[f>>2]|4;a=0;break f}v[22656]=0;T(2434,a|0)|0;b=v[22656];v[22656]=0;c=c+1|0;if((b|0)!=1){continue}}break}a=P()|0;O()|0;break a}a=1;if(v[q>>2]==(k|0)){break f}a=0;v[l+24>>2]=0;jf(u,v[q>>2],k,l+24|0);if(v[l+24>>2]){v[f>>2]=v[f>>2]|4;break f}a=1}vb(s);vb(p);vb(n);vb(m);vb(u);Ic(q);gb=l+560|0;return a|0}a=P()|0;O()|0;break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;break a}a=P()|0;O()|0}vb(s);vb(p);vb(n);vb(m);vb(u);Ic(q);S(a|0);L()}function bha(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;e=gb-224|0;gb=e;vc(c);if(!(!Ar(c,e+208|0)|v[e+208>>2]!=1297239878|v[e+216>>2]!=1179011393&(w[e+216|0]|w[e+217|0]<<8|(w[e+218|0]<<16|w[e+219|0]<<24))!=1128679745)){g=gb-32|0;gb=g;h=e+192|0;f=hh(h);a:{b:{c:{d:{e:{while(1){v[22656]=0;i=Q(191,c|0,8)|0;j=v[22656];v[22656]=0;if((j|0)==1){break c}if(!i){break d}v[22656]=0;R(1163,g|0,c|0);i=v[22656];v[22656]=0;if((i|0)!=1){v[22656]=0;R(1164,f|0,g|0);i=v[22656];v[22656]=0;if((i|0)==1){break e}ed(g);continue}break}a=P()|0;O()|0;break b}a=P()|0;O()|0;ed(g);break b}gb=g+32|0;break a}a=P()|0;O()|0}ke(f);S(a|0);L()}v[22656]=0;U(1149,e+168|0,h|0,1129270605);c=v[22656];v[22656]=0;f:{g:{h:{i:{j:{k:{l:{m:{if((c|0)!=1){v[22656]=0;c=Q(1150,e+168|0,e+144|0)|0;g=v[22656];v[22656]=0;n:{if((g|0)!=1){g=0;if(!c){break f}h=e+144|2;if(!Xb(w[h|0]|w[h+1|0]<<8|(w[h+2|0]<<16|w[h+3|0]<<24))){break f}if(!Ib(w[e+144|0]|w[e+145|0]<<8)){break f}if(Ib(w[e+144|0]|w[e+145|0]<<8)>>>0>2){break f}f=e+144|6;if(!Ib(w[f|0]|w[f+1|0]<<8)){break f}if(Ib(w[f|0]|w[f+1|0]<<8)>>>0>64){break f}v[e+140>>2]=1162760014;c=1;if((w[e+216|0]|w[e+217|0]<<8|(w[e+218|0]<<16|w[e+219|0]<<24))==1128679745){v[22656]=0;c=Q(798,e+168|0,e+140|0)|0;i=v[22656];v[22656]=0;if((i|0)==1){break n}if(!c){break f}c=v[e+140>>2]!=1936684916}v[22656]=0;U(1149,e+120|0,e+192|0,1397968452);g=v[22656];v[22656]=0;o:{p:{if((g|0)!=1){v[22656]=0;g=Q(1151,e+120|0,e+112|0)|0;i=v[22656];v[22656]=0;if((i|0)==1){break o}if(g){break p}break g}g=P()|0;O()|0;break i}i=((Ib(w[f|0]|w[f+1|0]<<8)-1|0)/8|0)-1|0;j=i<<3;f=j&31;f=Rc(e+104|0,(i>>>0<7?(j&63)>>>0>=32?4196360>>>f|0:((1<<f)-1&4196360)<<32-f|136321040>>>f:8)&255,(Ib(w[e+144|0]|w[e+145|0]<<8)|0)==2?2:1,c,0);q:{c=v[e+140>>2];if((c|0)<=875981925){if((c|0)<=842230885){if((c|0)==544694642){break q}if((c|0)==842222662){break l}break k}if((c|0)==842230886){break l}if((c|0)!=875973702){break k}break l}if((c|0)<=1463897172){if((c|0)==875981926){break l}if((c|0)!=1463897153){break k}break m}if((c|0)!=1463897173){if((c|0)==2002873441){break m}if((c|0)!=2002873461){break k}}Bf(f,16);Yi(f,16);break k}Bf(f,1);break k}g=P()|0;O()|0;break j}g=P()|0;O()|0;break i}g=P()|0;O()|0;break i}g=P()|0;O()|0;break h}Bf(f,17);Yi(f,16);break k}Bf(f,3)}if(d){XQ(f)}c=Xb(w[e+112|0]|w[e+113|0]<<8|(w[e+114|0]<<16|w[e+115|0]<<24));v[22656]=0;c=Q(191,e+120|0,c|0)|0;d=v[22656];v[22656]=0;r:{if((d|0)==1){break r}if(c){c=Xb(w[e+112|0]|w[e+113|0]<<8|(w[e+114|0]<<16|w[e+115|0]<<24));v[22656]=0;Q(318,e+120|0,c|0)|0;c=v[22656];v[22656]=0;if((c|0)==1){break r}}v[22656]=0;Q(1140,a|0,b|0)|0;c=v[22656];v[22656]=0;s:{t:{u:{v:{w:{x:{y:{z:{A:{B:{if((c|0)==1){break B}v[22656]=0;i=(B(b,104)+a|0)+484380|0;R(424,i|0,0);c=v[22656];v[22656]=0;if((c|0)==1){break B}l=i,m=Xb(w[h|0]|w[h+1|0]<<8|(w[h+2|0]<<16|w[h+3|0]<<24)),v[l>>2]=m;h=e+144|0;c=w[h+13|0]|(w[h+11|0]<<16|w[h+10|0]<<24|w[h+12|0]<<8);d=0;h=w[h+9|0];if((h|0)!=30){h=30-h|0;while(1){d=c;c=c>>>1|0;h=h-1|0;if(h&255){continue}break}}v[(B(b,104)+a|0)+484404>>2]=(d&1)+c;v[22656]=0;W(329,f|0,i|0,e+120|0)|0;c=v[22656];v[22656]=0;if((c|0)==1){break B}v[22656]=0;U(1149,e+80|0,e+192|0,1296126539);c=v[22656];v[22656]=0;if((c|0)==1){break A}v[22656]=0;c=T(275,e+80|0)|0;d=v[22656];v[22656]=0;if((d|0)==1){break z}if(!c){break t}v[22656]=0;U(1149,e+32|0,e+192|0,1229869908);c=v[22656];v[22656]=0;if((c|0)==1){break y}v[22656]=0;c=Q(1152,e+32|0,e+56|0)|0;d=v[22656];v[22656]=0;if((d|0)==1){break x}xb(e+32|0);if(!c){break t}v[22656]=0;f=T(416,e+80|0)|0;c=v[22656];v[22656]=0;if((c|0)==1){break w}d=dd(e+32|0);v[22656]=0;R(1153,d|0,f|0);c=v[22656];v[22656]=0;if((c|0)!=1){C:{if(!f){break C}h=e+8|6;c=0;while(1){v[22656]=0;j=Q(1154,e+80|0,e+8|0)|0;k=v[22656];v[22656]=0;if((k|0)==1){break v}if(!j){break C}v[22656]=0;R(1155,d|0,e+8|0);j=v[22656];v[22656]=0;if((j|0)==1){break v}j=w[h|0];k=w[h|0];v[22656]=0;Q(318,e+80|0,j+((k^-1)&1)|0)|0;j=v[22656];v[22656]=0;if((j|0)==1){break v}c=c+1|0;if((f|0)!=(c|0)){continue}break}}c=e- -64|0;if(Ib(w[c|0]|w[c+1|0]<<8)){f=(B(b,104)+a|0)+484414|0;u[f>>1]=x[f>>1]|8;c=Ib(w[c|0]|w[c+1|0]<<8);u[f>>1]=x[f>>1]&65519|((c|0)==2)<<4}if(Ib(w[e+70|0]|w[e+71|0]<<8)){c=(B(b,104)+a|0)+484414|0;u[c>>1]=x[c>>1]|2;f=Ib(w[e+70|0]|w[e+71|0]<<8);u[c>>1]=x[c>>1]&65531|((f|0)==2)<<2}l=e,m=Vb(d),v[l+8>>2]=m;l=e,m=Zb(d),v[l+24>>2]=m;if(Gb(e+8|0,e+24|0)){c=B(b,104)+a|0;f=c+484388|0;h=c+484384|0;j=c+484396|0;k=c+484392|0;while(1){c=v[e+8>>2];if((Ib(w[c|0]|w[c+1|0]<<8)|0)==(Ib(w[e+66|0]|w[e+67|0]<<8)|0)){l=k,m=Xb(w[c+2|0]|w[c+3|0]<<8|(w[c+4|0]<<16|w[c+5|0]<<24)),v[l>>2]=m}if((Ib(w[c|0]|w[c+1|0]<<8)|0)==(Ib(w[e+68|0]|w[e+69|0]<<8)|0)){l=j,m=Xb(w[c+2|0]|w[c+3|0]<<8|(w[c+4|0]<<16|w[c+5|0]<<24)),v[l>>2]=m}if((Ib(w[c|0]|w[c+1|0]<<8)|0)==(Ib(w[e+72|0]|w[e+73|0]<<8)|0)){l=h,m=Xb(w[c+2|0]|w[c+3|0]<<8|(w[c+4|0]<<16|w[c+5|0]<<24)),v[l>>2]=m}if((Ib(w[c|0]|w[c+1|0]<<8)|0)==(Ib(w[e+74|0]|w[e+75|0]<<8)|0)){l=f,m=Xb(w[c+2|0]|w[c+3|0]<<8|(w[c+4|0]<<16|w[c+5|0]<<24)),v[l>>2]=m}c=e+8|0;v[c>>2]=v[c>>2]+7;if(Gb(c,e+24|0)){continue}break}}v[22656]=0;xk(i);c=v[22656];v[22656]=0;if((c|0)!=1){break u}}break v}g=P()|0;O()|0;break j}g=P()|0;O()|0;break j}g=P()|0;O()|0;break s}g=P()|0;O()|0;break s}g=P()|0;O()|0;xb(e+32|0);break s}g=P()|0;O()|0;break s}g=P()|0;O()|0;TQ(d);break s}TQ(d)}v[22656]=0;U(1149,e+32|0,e+192|0,1312902469);c=v[22656];v[22656]=0;D:{E:{if((c|0)!=1){v[22656]=0;c=T(275,e+32|0)|0;d=v[22656];v[22656]=0;if((d|0)==1){break E}F:{G:{H:{I:{if(c){v[22656]=0;c=T(195,e+32|0)|0;d=v[22656];v[22656]=0;if((d|0)==1){break E}v[22656]=0;W(474,e+32|0,((b<<5)+a|0)+946304|0,c|0)|0;b=v[22656];v[22656]=0;if((b|0)!=1){break I}break E}v[22656]=0;c=Q(70,e+8|0,18726)|0;d=v[22656];v[22656]=0;if((d|0)==1){break H}v[22656]=0;Q(301,((b<<5)+a|0)+946304|0,c|0)|0;b=v[22656];v[22656]=0;if((b|0)==1){break G}vb(c)}b=v[a+480180>>2];v[22656]=0;U(1142,i|0,32,b|0);b=v[22656];v[22656]=0;if((b|0)==1){break F}v[22656]=0;_h(i,a,0);a=v[22656];v[22656]=0;if((a|0)==1){break E}xb(e+32|0);xb(e+80|0);break g}g=P()|0;O()|0;break D}g=P()|0;O()|0;vb(c);break D}g=P()|0;O()|0;break D}g=P()|0;O()|0;break s}g=P()|0;O()|0}xb(e+32|0)}xb(e+80|0);break j}g=P()|0;O()|0}xb(e+120|0)}xb(e+168|0)}ke(e+192|0);S(g|0);L()}xb(e+120|0)}xb(e+168|0);ke(e+192|0)}gb=e+224|0;return g|0}function Zfa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;g=gb-208|0;gb=g;u[a+480212>>1]=0;v[a+480240>>2]=65536;v[a+480244>>2]=65536;ZO(a+900380|0);v[22656]=0;qA(a+946304|0);d=v[22656];v[22656]=0;a:{b:{c:{d:{e:{if((d|0)==1){break e}d=g+48|0;Qb(d,0,160);d=aP(d);v[22656]=0;e=a+906300|0;U(1297,e|0,e+4e4|0,d|0);e=v[22656];v[22656]=0;f:{g:{h:{i:{if((e|0)!=1){Bq(d);v[22656]=0;d=T(275,b|0)|0;e=v[22656];v[22656]=0;if((e|0)==1){break e}if(!d){break f}i=dd(g+48|0);e=0;if(c&16){break h}v[22656]=0;h=(c|0)!=0;e=W(1298,i|0,b|0,h|0)|0;d=v[22656];v[22656]=0;if((d|0)==1){break g}d=4;j:{if(e){break j}v[22656]=0;e=W(1299,i|0,b|0,h|0)|0;d=v[22656];v[22656]=0;if((d|0)==1){break g}d=5;if(e){break j}v[22656]=0;e=W(1300,i|0,b|0,h|0)|0;d=v[22656];v[22656]=0;if((d|0)==1){break g}d=6;if(e){break j}e=0;v[22656]=0;h=W(1301,i|0,b|0,h|0)|0;d=v[22656];v[22656]=0;if((d|0)==1){break g}d=3;if(!h){break h}}if(c){break i}f=1;break b}a=P()|0;O()|0;Bq(d);break c}if(!cd(i)){Hw(b,v[i>>2]+12|0)}e=d}if(c&32){break b}d=37824;k:{l:{while(1){j=v[d+8>>2];h=(j>>1)+a|0;f=v[d+4>>2];f=j&1?v[v[h>>2]+f>>2]:f;v[22656]=0;f=W(f|0,h|0,b|0,c|0)|0;h=v[22656];v[22656]=0;if((h|0)!=1){if(f){break k}d=d+12|0;if((d|0)==38328){break l}continue}break}break g}v[a+480180>>2]=0;v[a+480184>>2]=0}if(!c){break b}if(!(v[a+480184>>2]|!e)){v[a+480184>>2]=e}v[22656]=0;R(1124,a+1298224|0,1);d=v[22656];v[22656]=0;if((d|0)!=1){kA(i);break d}}a=P()|0;O()|0;kA(i);break c}v[22656]=0;R(367,a|0,0);d=v[22656];v[22656]=0;if((d|0)==1){break e}v[22656]=0;R(1124,a+1298224|0,1);d=v[22656];v[22656]=0;if((d|0)==1){break e}v[a+1074304>>2]=19923028;break d}a=P()|0;O()|0;break c}d=0;m:{n:{while(1){e=(d<<5)+a|0;zg(e+480286|0,64);f=e+480284|0;if(x[f>>1]>=257){u[f>>1]=128}e=e+480288|0;if(w[e|0]>=251){t[e|0]=0}v[22656]=0;$m((B(d,872)+a|0)+1074992|0,7,a,d&65535,134217728);e=v[22656];v[22656]=0;if((e|0)==1){break n}d=d+1|0;if((d|0)!=127){continue}break}if(x[a+480190>>1]){i=a+1298260|0;f=1;while(1){e=B(f&65535,104)+a|0;d=e+484380|0;o:{if(Jd(d)){v[22656]=0;_h(d,a,0);d=v[22656];v[22656]=0;if((d|0)!=1){break o}break m}h=e+484414|0;j=x[h>>1];if(j&16384){break o}v[d>>2]=0;v[d+4>>2]=0;v[d+16>>2]=0;v[d+8>>2]=0;v[d+12>>2]=0;u[h>>1]=j&65505}d=e+484412|0;if(x[d>>1]>=65){u[d>>1]=64}p:{if(!(w[e+484415|0]&2)){break p}if(!wk(i)){break p}v[22656]=0;_(1303,a|0);d=v[22656];v[22656]=0;if((d|0)==1){break m}}f=f+1|0;if(x[a+480190>>1]>=(f&65535)>>>0){continue}break}}d=0;e=0;while(1){q:{f=v[(((d&65535)<<2)+a|0)+900380>>2];if(!f){break q}e=v[a+480180>>2];v[22656]=0;CS(f,e);f=v[22656];v[22656]=0;e=d;if((f|0)!=1){break q}a=P()|0;O()|0;break c}d=d+1|0;if(x[a+480192>>1]>=(d&65535)>>>0){continue}break}u[a+480192>>1]=e;d=a+480204|0;r:{if(y[a+480204>>2]<1e4){v[d>>2]=125e4;break r}qc(d,65535e4)}if(!v[a+480196>>2]){v[a+480196>>2]=6}d=a+480220|0;e=v[a+480216>>2];if(e>>>0>y[a+480220>>2]){v[d>>2]=e}e=a+480216|0;qc(e,65536);qc(d,65536);qc(a+480200|0,256);s:{d=a+480248|0;if(!cd(d)){e=v[e>>2];v[22656]=0;U(1305,d|0,e|0,16777216);d=v[22656];v[22656]=0;if((d|0)==1){break s}}v[a+1074416>>2]=v[a+480196>>2];v[a+1074420>>2]=v[a+480204>>2];e=v[a+480220>>2];d=a+1074408|0;v[d>>2]=v[a+480216>>2];v[d+4>>2]=e;v[a+1074456>>2]=v[a+480200>>2];yA(a+1074376|0);d=a+1074446|0;u[d>>1]=0;u[d+2>>1]=0;u[d+4>>1]=0;u[d+6>>1]=65535;v[a+1074392>>2]=-2;d=a+1074384|0;v[d>>2]=0;v[d+4>>2]=0;v[a+1074380>>2]=0;d=a+1074424|0;v[d>>2]=0;v[d+4>>2]=0;v[a+1074432>>2]=0;d=a+1074396|0;v[d>>2]=0;v[d+4>>2]=0;if(_l(a)){v[22656]=0;Q(410,a+1074312|0,7)|0;d=v[22656];v[22656]=0;if((d|0)==1){break s}}u[a+480276>>1]=0;v[22656]=0;_(1306,a|0);d=v[22656];v[22656]=0;if((d|0)==1){break s}d=a+484360|0;l=g,m=Vb(d),v[l+48>>2]=m;l=g,m=Zb(d),v[l+32>>2]=m;t:{if(Gb(g+48|0,g+32|0)){while(1){d=v[g+48>>2];v[22656]=0;_(1307,d|0);e=v[22656];v[22656]=0;if((e|0)==1){break t}e=x[d+28>>1];if(tc(d)>>>0<=e>>>0){cf(d,0)}d=g+48|0;nS(d);if(Gb(d,g+32|0)){continue}break}}u:{v:{w:{x:{y:{z:{A:{B:{C:{k=v[a+480180>>2];if(k){hu(a+8|0,zq(a));if(v[a+1074308>>2]){v[22656]=0;_(1308,a|0);d=v[22656];v[22656]=0;if((d|0)==1){break s}}f=dd(g+48|0);if((c&12)==12){d=0;while(1){j=B(d,160)+a|0;i=j+906300|0;e=i;c=e+16|0;h=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);c=e+20|0;D:{if(!(h|(w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24)))){break D}v[22656]=0;Q(1309,i|0,a|0)|0;c=v[22656];v[22656]=0;E:{if((c|0)!=1){c=v[i>>2];if(!c){break E}e=v[j+906448>>2];i=v[v[c>>2]+56>>2];v[22656]=0;R(i|0,c|0,e|0);c=v[22656];v[22656]=0;if((c|0)!=1){break D}}a=P()|0;O()|0;break u}e=Vb(f);h=Zb(f);c=gb-32|0;gb=c;v[c+16>>2]=h;v[c+24>>2]=e;v[c+8>>2]=i;if(Gb(c+24|0,c+16|0)){while(1){e=v[v[c+24>>2]>>2];h=v[c+8>>2];if((w[e+4|0]|w[e+5|0]<<8|(w[e+6|0]<<16|w[e+7|0]<<24))==(w[h+20|0]|w[h+21|0]<<8|(w[h+22|0]<<16|w[h+23|0]<<24))){h=w[e|0]|w[e+1|0]<<8|(w[e+2|0]<<16|w[e+3|0]<<24);e=v[c+8>>2];e=(h|0)==(w[e+16|0]|w[e+17|0]<<8|(w[e+18|0]<<16|w[e+19|0]<<24))}else{e=0}if(!e){e=c+24|0;Qe(e);if(Gb(e,c+16|0)){continue}}break}e=v[c+24>>2]}gb=c+32|0;v[g+32>>2]=e;l=g,m=Zb(f),v[l+16>>2]=m;if(Gb(g+32|0,g+16|0)){break D}v[22656]=0;v[g+32>>2]=j+906316;R(1310,f|0,g+32|0);c=v[22656];v[22656]=0;if((c|0)==1){break C}v[22656]=0;c=Q(2,g+16|0,14796)|0;e=v[22656];v[22656]=0;if((e|0)==1){break B}v[22656]=0;R(1311,g|0,i|0);e=v[22656];v[22656]=0;if((e|0)==1){break A}v[22656]=0;U(3,g+32|0,c|0,g|0);e=v[22656];v[22656]=0;if((e|0)==1){break z}v[22656]=0;U(560,a|0,2,g+32|0);e=v[22656];v[22656]=0;if((e|0)==1){break y}vb(g+32|0);vb(g);vb(c)}d=d+1|0;if((d|0)!=250){continue}break}}c=w[a+1074368|0];v[22656]=0;R(1312,a|0,c|0);a=v[22656];v[22656]=0;if((a|0)==1){break v}Hl(f)}f=(k|0)!=0;break a}a=P()|0;O()|0;break u}a=P()|0;O()|0;break u}a=P()|0;O()|0;break w}a=P()|0;O()|0;break x}a=P()|0;O()|0;vb(g+32|0)}vb(g)}vb(c);break u}a=P()|0;O()|0}Hl(f);break c}a=P()|0;O()|0;break c}a=P()|0;O()|0;break c}a=P()|0;O()|0;break c}a=P()|0;O()|0}xb(b);S(a|0);L()}kA(i)}xb(b);gb=g+208|0;return f|0}function Fo(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,z=0,A=0,C=0,D=0,E=0,F=0;j=gb-16|0;gb=j;g=x[a+480192>>1]>=c>>>0?v[((c<<2)+a|0)+900380>>2]:g;s=v[b+752>>2];h=w[b+802|0];a:{if(!h){i=j+8|0;Db(i,a+1074312|0,11);if(Cb(i)){break a}}b:{c:{if(!g){break c}if(!ve(h)){break c}d:{i=g+236|0;h=h-1|0;if(x[vd(i,h)>>1]){break d}k=j+8|0;Db(k,a+1074312|0,43);if(!Cb(k)){break d}if(Kj(g)){break d}v[b+656>>2]=g;break a}if(w[ic(g+108|0,h)|0]>120){break a}h=x[vd(i,h)>>1];k=(h-1&65535)>>>0<3999?(B(h,104)+a|0)+484380|0:0;break b}k=(B(c,104)+a|0)+484380|0;if(!x[a+480192>>1]){break b}if(h>>>0>250){break a}h=j+8|0;Db(h,a+1074312|0,43);if(Cb(h)){if(g){k=0;if(Kj(g)){break b}}t[b+803|0]=0;v[b+656>>2]=0;break a}k=0}h=v[b+104>>2];o=(h|0)!=0&(h|0)!=(k|0);i=v[b+656>>2];q=!g|v[a+480180>>2]!=16777216?q:v[g+44>>2]!=0;p=d^1;h=(g|0)!=(i|0);if((p|h|o)==1){u[b+774>>1]=0}r=!o;if(!(r?1:!(d&q)|v[b+656>>2]!=(g|0))){break a}e:{if(p|r){break e}l=j+8|0;m=a+1074312|0;Db(l,m,32);if(!(!Cb(l)|!(w[a+480208|0]&8))){k=v[b+8>>2]|v[b+12>>2]?v[b+104>>2]:k}f:{if(!(g?!(v[a+480180>>2]&1048580)|h:1)|v[a+480180>>2]==268435456){break f}if(v[a+480180>>2]==1){if(Mi(b)){break f}}l=j+8|0;Db(l,m,79);if(!Cb(l)){break e}if(!Mi(b)){break e}}n=1}g:{if(!v[b+16>>2]|(!o|(h|!x[a+480192>>1]))){break g}l=j+8|0;Db(l,a+1074312|0,87);if(!Cb(l)){break g}n=Rd(b+788|0)^1|n}h:{i:{j:{k:{l:{if(Mi(b)|!(v[a+480180>>2]&16777248)){break l}if(g){if(Kj(g)){break l}}l=1;break k}if(!(h|o)){break j}l=(g|0)!=(i|0)}if(!d){break i}h=j+8|0;Db(h,a+1074312|0,61);if(!Cb(h)){break i}i=v[b+656>>2];if(!i){m=0;i=0;h=v[b+104>>2];if(!h){break i}break h}h=v[b+104>>2];m=0;break h}l=0}v[b+656>>2]=g;m=l;h=k;i=g}m:{if(!e){break m}l=b;n:{o:{p:{if(v[a+480180>>2]&3){if(h){if(Jd(h)){break p}}if(!tk(b)){break m}}if(!h){break o}}if(u[h+34>>1]<0){break m}g=x[h+30>>1];break n}g=0;if(!i|!w[i+34|0]){break n}g=b;k=v[b+656>>2];q:{if(k){g=v[k+4>>2]<<2;break q}g=v[g+688>>2]}}v[l+688>>2]=g}if(n){if(!((h|0)!=0&o)){break a}c=j+8|0;Db(c,a+1074312|0,85);if(Cb(c)){u[b+772>>1]=t[h+37|0]}if(v[a+480180>>2]!=2){break a}if(!Jd(h)){break a}v[b+704>>2]=v[h+24>>2];break a}t[b+803|0]=0;r:{if(!i){break r}g=j+8|0;Db(g,a+1074312|0,29);if(z=0,A=(D=Cb(g),E=1,F=h,F?D:E),C=w[i+34|0]|m,C?z:A){break r}t[b+798|0]=w[i+16|0]}g=i;n=64;k=b;v[b+752>>2]=64;l=h;if(h){n=x[l+32>>1];v[k+752>>2]=n}if(g){v[k+752>>2]=B(v[g+4>>2],n)>>>6}s:{if(!(v[a+480180>>2]&1048580?e:1)){break s}e=j+8|0;Db(e,a+1074312|0,48);if(Cb(e)){break s}EP(a,b,i,h)}t:{u:{v:{if(!f){break v}f=j+8|0;e=a+1074312|0;Db(f,e,19);w:{x:{y:{z:{A:{B:{C:{D:{E:{if(Cb(f)){if(v[b+76>>2]){if(!(!c|p)){g=(w[a+480208|0]&8)>>>3|0;if(g){break C}break D}g=0;if(c){break D}break C}g=v[b+88>>2];if(!v[b+696>>2]|m){break E}c=g&2048;break B}g=1;F:{if(!d|!(v[a+480180>>2]&17301536)|(!v[b+76>>2]|w[a+480208|0]&8)){break F}g=0;if(!(w[b+89|0]&16)){break F}g=!v[b+696>>2]}if(!(v[a+480180>>2]&17301536)|(!i|m)){break A}if(!g){break z}g=v[b+88>>2];c=g&6144;break B}v[b+88>>2]=g|2097152;if(!i){break w}break x}if(d){break C}if(!(w[b+89|0]&24)){g=0;break C}g=(w[a+480208|0]&4)>>>2|0}if(!v[b+696>>2]|m){break A}if(!g){break z}g=v[b+88>>2];c=g&2048}v[b+88>>2]=g|2097152;if(!i){break w}if(c){break x}if(!(w[i+60|0]&8)){Ij(b+724|0)}if(!(w[i+80|0]&8)){Ij(b+732|0)}if(w[i+100|0]&8){break w}Ij(b+740|0);break w}if(g){break y}}if(i){if(t[i+60|0]&1){break v}c=j+8|0;Db(c,e,32);if(Cb(c)){Ij(b+724|0);break v}Nm(b);break v}g=0;if(!h){break u}break t}v[b+88>>2]=v[b+88>>2]|2097152;if(!i){break w}}Nm(b)}c=j+8|0;Db(c,e,21);if(Cb(c)){break v}t[b+818|0]=0;v[b+756>>2]=0}g=0;if(h){break t}if(!i){break u}g=1;if(Kj(i)){break t}}v[b+752>>2]=0;v[b+104>>2]=0;break a}c=b;G:{H:{I:{J:{K:{if(!(!d|!h|v[b+104>>2]!=(h|0))){if(v[b+76>>2]?v[a+480180>>2]&16777250:0){break a}if(v[a+480180>>2]!=4){break K}d=j+8|0;Db(d,a+1074312|0,40);if(!Cb(d)|w[b+789|0]){break K}d=v[b+88>>2];break J}v[b+88>>2]=v[b+88>>2]&-6145;e=j+8|0;f=a+1074312|0;Db(e,f,18);c=b;L:{if(z=Cb(e),A=1,C=v[a+480180>>2]&16777248,C?z:A){e=-640;if(!(v[b+104>>2]!=(h|0)|m)){break L}}e=-768}v[c+88>>2]=e&v[b+88>>2];M:{if(!i){break M}t[b+730|0]=w[i+60|0];t[b+738|0]=w[i+80|0];t[b+746|0]=w[i+100|0];N:{if((w[i+100|0]&17)!=17){break N}c=j+8|0;Db(c,f,36);if(Cb(c)|w[b+837|0]){break N}t[b+837|0]=127}if(yw(i)){z=b,A=cF(i),t[z+837|0]=A}if(!aF(i)){break M}z=b,A=bF(i),t[z+838|0]=A}if(g){break I}if(!d){break G}break H}d=v[b+88>>2]&-6145}v[c+88>>2]=d&-640;if(!g){break H}}v[b+76>>2]=0;v[b+104>>2]=0;break a}if(v[b+76>>2]){break G}c=j+8|0;d=a+1074312|0;Db(c,d,54);if(!Cb(c)){Db(j,d,39);if(!Cb(j)){break G}}v[b+8>>2]=0;v[b+12>>2]=0}O:{if(w[b+788|0]!=255){break O}c=j+8|0;Db(c,a+1074312|0,100);if(!Cb(c)|(!(v[a+480208>>2]&4)|r)){break O}c=v[b+104>>2];if(c){v[b+88>>2]=v[b+88>>2]|x[c+34>>1]&1023}v[b+752>>2]=s;v[b+688>>2]=x[h+30>>1];if(!(w[h+34|0]&32)){break a}Uo(b,x[h+28>>1],a);break a}v[b+104>>2]=h;v[b+76>>2]=v[h>>2];v[b+80>>2]=v[h+4>>2];v[b+84>>2]=v[h+8>>2];c=j+8|0;d=a+1074312|0;Db(c,d,83);if(!(!Cb(c)|v[b+80>>2])){v[b+84>>2]=v[h>>2]}v[b+88>>2]=v[b+88>>2]|x[h+34>>1]&1023;c=j+8|0;Db(c,d,21);if(Cb(c)){t[b+818|0]=0;v[b+756>>2]=0}c=b;P:{Q:{if(q){v[b+704>>2]=v[h+24>>2];t[b+851|0]=w[b+851|0]|32;e=0;break Q}if(!(v[a+480180>>2]&5?o|p:1)){break P}v[b+704>>2]=v[h+24>>2];e=t[h+37|0]}u[c+772>>1]=e}c=b;if(_l(a)){e=t[h+36|0]}else{e=0}u[c+770>>1]=e;c=j+8|0;Db(c,d,69);if(!(Cb(c)|v[a+480180>>2]==1)){v[b+708>>2]=0}v[b+852>>2]=0;g=v[b+88>>2];if(g&8){v[b+80>>2]=v[h+12>>2];v[b+84>>2]=v[h+16>>2];g=g>>>2&4|g|2;v[b+88>>2]=g}R:{if(!(g&2)){g=v[b+76>>2];break R}g=v[b+76>>2];c=v[b+84>>2];if(g>>>0<=c>>>0){break R}v[b+76>>2]=c;g=c}if(!(v[a+480180>>2]&16777248)|y[b+4>>2]<g>>>0){break a}v[b>>2]=0;v[b+4>>2]=0}gb=j+16|0}function Oba(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=C(0),f=C(0),g=C(0),h=C(0),i=C(0),j=C(0),k=0,l=0,m=0,n=C(0),o=0,p=0,q=0,r=0,s=0,u=0,x=0,y=C(0),A=C(0),B=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=C(0),R=0,S=0,T=0,U=0,V=0,W=C(0),X=0,Y=0,Z=0,_=C(0);a:{if(!w[a+5046|0]){break a}g=z[a+4268>>2];eM(a);if(g==z[a+4268>>2]){break a}Yy(a)}b:{if(!w[a+5045|0]){break b}p=a+44|0;if(!mi(p)){break b}q=Nd(p,0);x=Nd(p,1);l=od(p,0);m=od(p,1);c:{if(!(w[a+4264|0]&2|(!w[a+5044|0]|!d))){z[l>>2]=z[a+5036>>2];z[m>>2]=z[a+5040>>2];t[a+5044|0]=0;x=x+4|0;q=q+4|0;m=m+4|0;l=l+4|0;k=d-1|0;break c}k=d}r=k;d:{if(!r){break d}V=a+4960|0;F=a+4648|0;G=a+4672|0;R=a+4936|0;H=a+4696|0;I=a+4720|0;J=a+4744|0;K=a+4768|0;S=a+4840|0;E=a+4504|0;L=a+4528|0;T=a+4912|0;M=a+4552|0;N=a+4576|0;O=a+4600|0;P=a+4624|0;U=a+4816|0;s=a+4888|0;u=a+4864|0;while(1){g=z[q>>2];g=C(g+C(C(z[a+5008>>2]-g)*z[a+4276>>2]));z[a+5008>>2]=g;Z=Cc(u,v[a+4880>>2]),_=g,z[Z>>2]=_;g=z[x>>2];g=C(g+C(C(z[a+5012>>2]-g)*z[a+4276>>2]));z[a+5012>>2]=g;Z=Cc(s,v[a+4904>>2]),_=g,z[Z>>2]=_;g=C(C(C(C(C(Sh(u,v[a+4356>>2])*C(.6800000071525574))-C(Sh(u,v[a+4360>>2])*C(.5)))-C(Sh(u,v[a+4364>>2])*C(.6200000047683716)))-C(Sh(u,v[a+4368>>2])*C(.5)))-C(Sh(u,v[a+4372>>2])*C(.6200000047683716)));if(t[a+4264|0]&1){f=g;g=C(z[Cc(U,v[a+4836>>2])>>2]+C(f*C(.6180340051651001)));Z=Cc(U,v[a+4832>>2]),_=C(f-C(g*C(.6180340051651001))),z[Z>>2]=_}y=z[a+4280>>2];Z=a,_=C(Sh(u,v[a+4352>>2])+z[a+5020>>2]),z[Z+5020>>2]=_;f=C(Sh(s,v[a+4376>>2])+z[a+5024>>2]);z[a+5024>>2]=f;e=z[a+5020>>2];h=C(C(C(z[a+4980>>2]-z[Cc(P,v[a+4644>>2])>>2])*z[a+4444>>2])+z[Cc(P,v[a+4644>>2])>>2]);z[a+4980>>2]=h;Q=C(h*z[a+4440>>2]);j=C(f*C(.7070000171661377));i=C(e*C(-.7070000171661377));e=C(j+i);h=z[a+4272>>2];f=C(Q+C(e*h));Z=Cc(P,v[a+4640>>2]),_=C(e-C(h*f)),z[Z>>2]=_;e=C(C(C(z[a+4976>>2]-z[Cc(O,v[a+4620>>2])>>2])*z[a+4436>>2])+z[Cc(O,v[a+4620>>2])>>2]);z[a+4976>>2]=e;h=z[a+4272>>2];e=C(C(e*z[a+4432>>2])+C(f*h));Z=Cc(O,v[a+4616>>2]),_=C(f-C(h*e)),z[Z>>2]=_;A=C(C(f*C(-.15000000596046448))+C(e*C(-.20000000298023224)));if(t[a+4264|0]&1){f=C(C(C(z[a+4972>>2]-z[Cc(N,v[a+4596>>2])>>2])*z[a+4428>>2])+z[Cc(N,v[a+4596>>2])>>2]);z[a+4972>>2]=f;h=z[a+4272>>2];f=C(C(f*z[a+4424>>2])+C(e*h));Z=Cc(N,v[a+4592>>2]),_=C(e-C(h*f)),z[Z>>2]=_;e=C(C(C(z[a+4968>>2]-z[Cc(M,v[a+4572>>2])>>2])*z[a+4420>>2])+z[Cc(M,v[a+4572>>2])>>2]);z[a+4968>>2]=e;h=z[a+4272>>2];e=C(C(e*z[a+4416>>2])+C(f*h));Z=Cc(M,v[a+4568>>2]),_=C(f-C(h*e)),z[Z>>2]=_;A=C(C(A+C(f*C(.3499999940395355)))+C(e*C(-.3799999952316284)))}Z=Cc(T,v[a+4928>>2]),_=e,z[Z>>2]=_;f=C(z[Cc(T,v[a+4932>>2])>>2]*z[a+4496>>2]);z[a+5028>>2]=f+C(C(z[a+5028>>2]-f)*z[a+4500>>2]);f=C(C(C(z[a+4964>>2]-z[Cc(L,v[a+4548>>2])>>2])*z[a+4412>>2])+z[Cc(L,v[a+4548>>2])>>2]);z[a+4964>>2]=f;e=z[a+5028>>2];n=z[a+4272>>2];h=C(C(e*n)+C(f*z[a+4408>>2]));Z=Cc(L,v[a+4544>>2]),_=C(e-C(n*h)),z[Z>>2]=_;f=C(C(C(z[a+4960>>2]-z[Cc(E,v[a+4524>>2])>>2])*z[a+4404>>2])+z[Cc(E,v[a+4524>>2])>>2]);z[a+4960>>2]=f;e=C(f*z[a+4400>>2]);f=z[a+4272>>2];n=C(e+C(h*f));Z=Cc(E,v[a+4520>>2]),_=C(h-C(f*n)),z[Z>>2]=_;z[a+5020>>2]=n;f=C(C(C(C(C(Sh(s,v[a+4380>>2])*C(.7070000171661377))-C(Sh(s,v[a+4384>>2])*C(.6000000238418579)))-C(Sh(s,v[a+4388>>2])*C(.5)))-C(Sh(s,v[a+4392>>2])*C(.6000000238418579)))-C(Sh(s,v[a+4396>>2])*C(.5)));if(t[a+4264|0]&1){e=f;f=C(z[Cc(S,v[a+4860>>2])>>2]+C(f*C(.6180340051651001)));Z=Cc(S,v[a+4856>>2]),_=C(e-C(f*C(.6180340051651001))),z[Z>>2]=_}W=z[a+4280>>2];e=C(C(C(z[a+5004>>2]-z[Cc(K,v[a+4788>>2])>>2])*z[a+4492>>2])+z[Cc(K,v[a+4788>>2])>>2]);z[a+5004>>2]=e;Q=C(e*z[a+4488>>2]);e=C(i-j);i=z[a+4272>>2];j=C(Q+C(e*i));Z=Cc(K,v[a+4784>>2]),_=C(e-C(i*j)),z[Z>>2]=_;e=C(C(C(z[a+5e3>>2]-z[Cc(J,v[a+4764>>2])>>2])*z[a+4484>>2])+z[Cc(J,v[a+4764>>2])>>2]);z[a+5e3>>2]=e;i=z[a+4272>>2];e=C(C(e*z[a+4480>>2])+C(j*i));Z=Cc(J,v[a+4760>>2]),_=C(j-C(i*e)),z[Z>>2]=_;j=C(C(C(h*C(.3799999952316284))+C(j*C(-.15000000596046448)))+C(e*C(-.20000000298023224)));if(t[a+4264|0]&1){h=C(C(C(z[a+4996>>2]-z[Cc(I,v[a+4740>>2])>>2])*z[a+4476>>2])+z[Cc(I,v[a+4740>>2])>>2]);z[a+4996>>2]=h;i=z[a+4272>>2];h=C(C(h*z[a+4472>>2])+C(e*i));Z=Cc(I,v[a+4736>>2]),_=C(e-C(i*h)),z[Z>>2]=_;e=C(C(C(z[a+4992>>2]-z[Cc(H,v[a+4716>>2])>>2])*z[a+4468>>2])+z[Cc(H,v[a+4716>>2])>>2]);z[a+4992>>2]=e;i=z[a+4272>>2];e=C(C(e*z[a+4464>>2])+C(h*i));Z=Cc(H,v[a+4712>>2]),_=C(h-C(i*e)),z[Z>>2]=_;j=C(C(j+C(h*C(.3499999940395355)))+C(e*C(-.3799999952316284)))}X=x+4|0;Y=q+4|0;h=C(g*y);A=C(A-C(n*C(.3799999952316284)));n=C(f*W);Z=Cc(R,v[a+4952>>2]),_=e,z[Z>>2]=_;g=C(z[Cc(R,v[a+4956>>2])>>2]*z[a+4496>>2]);z[a+5032>>2]=g+C(C(z[a+5032>>2]-g)*z[a+4500>>2]);g=C(C(C(z[a+4988>>2]-z[Cc(G,v[a+4692>>2])>>2])*z[a+4460>>2])+z[Cc(G,v[a+4692>>2])>>2]);z[a+4988>>2]=g;f=z[a+5032>>2];e=z[a+4272>>2];g=C(C(f*e)+C(g*z[a+4456>>2]));Z=Cc(G,v[a+4688>>2]),_=C(f-C(e*g)),z[Z>>2]=_;e=z[a+4284>>2];f=C(C(C(z[a+4984>>2]-z[Cc(F,v[a+4668>>2])>>2])*z[a+4452>>2])+z[Cc(F,v[a+4668>>2])>>2]);z[a+4984>>2]=f;y=z[a+4272>>2];f=C(C(f*z[a+4448>>2])+C(g*y));Z=Cc(F,v[a+4664>>2]),_=C(g-C(y*f)),z[Z>>2]=_;z[a+5024>>2]=f;g=C(g*C(.3799999952316284));y=z[a+4288>>2];k=E;while(1){o=k;B=v[o+16>>2];D=B-1|0;v[o+16>>2]=D;if((B|0)<=0){v[o+16>>2]=D+v[o+12>>2]}D=v[o+20>>2];B=D-1|0;v[o+20>>2]=B;if((D|0)<=0){v[o+20>>2]=B+v[o+12>>2]}k=k+24|0;if((V|0)!=(k|0)){continue}break}g=C(h+C(C(A+g)*e));f=C(n+C(C(j+C(f*C(-.3799999952316284)))*y));e:{f:{if(w[a+4264|0]&2){q=Y;k=X;break f}z[l>>2]=C(g+z[a+5036>>2])*C(.5);z[m>>2]=C(f+z[a+5040>>2])*C(.5);z[a+5040>>2]=f;z[a+5036>>2]=g;if((r|0)==1){break e}r=r-1|0;q=q+8|0;m=m+4|0;l=l+4|0;k=x+8|0}x=k;z[l>>2]=g;z[m>>2]=f;m=m+4|0;l=l+4|0;r=r-1|0;if(r){continue}break d}break}t[a+5044|0]=1}Ei(a,b,c,od(p,0),od(p,1),d)}}function uoa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,z=0,A=0,C=0,D=0,E=0,F=0;f=gb-208|0;gb=f;a:{b:{c:{d:{e:{f:{g:{if(Gh(b,11139)){if(d){t[d|0]=1}j=a+1074312|0;Av(j);m=a+480216|0;n=a+480220|0;o=a+480224|0;k=a+1074368|0;p=a+480200|0;h:{if(!Pb(b,7)){break h}s=a+480228|0;z=a+480232|0;A=a+484360|0;l=a+480268|0;C=a+1298280|0;D=a+480248|0;while(1){d=sg(b);e=Og(b);if((d|0)==(w[18702]|w[18703]<<8|(w[18704]<<16|w[18705]<<24))){pg(b,6);break h}if(!(d&1616928864)|d&-2139062144){break h}if(!Pb(b,e)){break h}h=f+24|0;Td(h,b,e);g=kc(f+184|0,h);xb(h);i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{t:{u:{v:{w:{x:{y:{z:{A:{B:{if((d|0)<=1347243309){if((d|0)<=1146367533){if((d|0)<=1130917458){if((d|0)==1127099950){break z}if((d|0)!=1129797166){break i}v[22656]=0;v[f+24>>2]=0;U(608,g|0,e|0,f+24|0);d=v[22656];v[22656]=0;if((d|0)==1){break w}v[a+1074304>>2]=v[f+24>>2];break i}if((d|0)==1130917459){break r}if((d|0)!=1145525806){break i}v[22656]=0;U(608,g|0,e|0,p|0);d=v[22656];v[22656]=0;if((d|0)==1){break b}break i}if((d|0)<=1213486400){if((d|0)==1146367534){break B}if((d|0)!=1196316499|e>>>0<3){break i}v[22656]=0;R(609,f+8|0,f+184|0);d=v[22656];v[22656]=0;if((d|0)==1){break p}v[22656]=0;R(610,f+168|0,f+8|0);d=v[22656];v[22656]=0;if((d|0)==1){break o}v[22656]=0;e=W(100,f+24|0,f+168|0,8)|0;d=v[22656];v[22656]=0;if((d|0)==1){break n}vb(f+168|0);gc(f+8|0);v[22656]=0;d=T(195,f+184|0)|0;g=v[22656];v[22656]=0;if((g|0)==1){break l}v[22656]=0;U(611,f+24|0,D|0,d|0);d=v[22656];v[22656]=0;if((d|0)==1){break l}vf(e);break i}if((d|0)==1213486401){break s}if((d|0)==1280530262){break v}if((d|0)!=1297303086){break i}Av(j);d=0;break k}if((d|0)<=1380994349){if((d|0)<=1380340803){if((d|0)==1347243310){break x}if((d|0)!=1347244882){break i}v[22656]=0;U(612,g|0,e|0,l|0);d=v[22656];v[22656]=0;if((d|0)==1){break b}if(vp(w[l|0])){break i}t[l|0]=5;break i}if((d|0)==1380340804){break A}if((d|0)==1380986414){break t}if((d|0)!=1380991534){break i}v[22656]=0;U(608,g|0,e|0,m|0);d=v[22656];v[22656]=0;if((d|0)==1){break b}break i}if((d|0)<=1397768493){if((d|0)==1380994350){break j}if((d|0)!=1397052739|e>>>0<3){break i}v[22656]=0;d=T(287,g|0)|0;e=v[22656];v[22656]=0;if((e|0)==1){break c}if(!d|d>>>0>x[a+480190>>1]){break i}d=(B(d,104)+a|0)+484448|0;e=lX(d);if((d|0)==(e|0)){break i}while(1){v[22656]=0;h=T(192,g|0)|0;i=v[22656];v[22656]=0;if((i|0)==1){break q}v[d>>2]=h;d=d+4|0;if((e|0)!=(d|0)){continue}break}break i}if((d|0)==1397768494){break u}if((d|0)==1414344238){break y}if((d|0)!=1448301654){break i}v[22656]=0;U(608,g|0,e|0,z|0);d=v[22656];v[22656]=0;if((d|0)==1){break b}break i}v[22656]=0;U(608,g|0,e|0,f+24|0);d=v[22656];v[22656]=0;if((d|0)==1){break g}v[a+480204>>2]=B(v[f+24>>2],1e4)+(y[a+480204>>2]%1e4|0);break i}v[22656]=0;U(608,g|0,e|0,f+24|0);d=v[22656];v[22656]=0;if((d|0)!=1){d=v[a+480204>>2];v[a+480204>>2]=d-((d>>>0)%1e4|0)+y[f+24>>2]%1e4;break i}d=P()|0;O()|0;break a}if(c){break i}v[22656]=0;u[f+24>>1]=0;U(613,g|0,e|0,f+24|0);d=v[22656];v[22656]=0;if((d|0)!=1){E=a,F=Md(x[f+24>>1],x[a+480188>>1],127),u[E+480188>>1]=F;break i}d=P()|0;O()|0;break a}v[22656]=0;U(614,g|0,e|0,o|0);d=v[22656];v[22656]=0;if((d|0)==1){break b}break i}v[22656]=0;U(615,g|0,e|0,k|0);d=v[22656];v[22656]=0;if((d|0)==1){break b}break i}d=P()|0;O()|0;break a}v[22656]=0;v[f+24>>2]=0;U(608,g|0,e|0,f+24|0);d=v[22656];v[22656]=0;if((d|0)==1){break f}d=v[f+24>>2];if(!d){break i}v[a+1074308>>2]=d;break i}v[22656]=0;U(608,g|0,e|0,s|0);d=v[22656];v[22656]=0;if((d|0)!=1){break i}break b}if(v[a+480180>>2]==4){break i}v[22656]=0;U(613,g|0,e|0,f+24|0);d=v[22656];v[22656]=0;if((d|0)!=1){cf(Sb(A),x[f+24>>1]);break i}d=P()|0;O()|0;break a}e=Kb(f+24|0);v[22656]=0;d=T(195,f+184|0)|0;h=v[22656];v[22656]=0;C:{if((h|0)==1){break C}v[22656]=0;W(616,g|0,e|0,d|0)|0;d=v[22656];v[22656]=0;if((d|0)==1){break C}v[22656]=0;U(13,f+168|0,0,e|0);d=v[22656];v[22656]=0;if((d|0)==1){break C}d=f+168|0;Eb(C,d);vb(d);vb(e);break i}d=P()|0;O()|0;vb(e);break a}if(e&1|e>>>0>126){break i}u[f+24>>1]=(e>>>1|0)- -64;v[22656]=0;u[f+168>>1]=127;d=Pc(f+24|0,f+168|0);e=v[22656];v[22656]=0;if((e|0)==1){break e}q=x[d>>1];if(q>>>0<65){break i}e=64;while(1){v[22656]=0;R(403,f+24|0,g|0);d=v[22656];v[22656]=0;if((d|0)==1){break d}h=f+24|0;d=qd(h);D:{if(w[h|0]==255){break D}i=w[d|0];d=(e<<5)+a|0;r=d+480284|0;u[r>>1]=128;u[d+480286>>1]=i;i=d+480280|0;v[i>>2]=0;v[i>>2]=(w[h|0]&128)<<3;d=w[h|0]&127;t[h|0]=d;if(d>>>0<65){u[r>>1]=d<<2;d=w[h|0]}if((d&255)!=100){break D}v[i>>2]=v[i>>2]|256}e=e+1|0;if((q|0)!=(e|0)){continue}break}break i}d=P()|0;O()|0;break a}d=P()|0;O()|0;break a}d=P()|0;O()|0;break m}d=P()|0;O()|0;vb(f+168|0)}gc(f+8|0);break a}d=P()|0;O()|0;vf(e);break a}E:{F:{G:while(1){v[22656]=0;e=Q(191,f+184|0,1)|0;h=v[22656];v[22656]=0;if((h|0)==1){break F}if(!(e&d>>>0<117)){break i}v[22656]=0;h=T(374,g|0)|0;e=v[22656];v[22656]=0;if((e|0)==1){break E}e=0;while(1){H:{if(!(!(h>>>e&1)|d>>>0>116)){v[22656]=0;W(409,j|0,d|0,1)|0;i=v[22656];v[22656]=0;if((i|0)==1){break H}}d=d+1|0;e=e+1|0;if((e|0)!=8){continue}continue G}break}break}d=P()|0;O()|0;break a}d=P()|0;O()|0;break a}d=P()|0;O()|0;break a}v[22656]=0;U(608,g|0,e|0,n|0);d=v[22656];v[22656]=0;if((d|0)==1){break b}}xb(f+184|0);if(Pb(b,7)){continue}break}}Gp(a+480204|0,B(v[v[a+8>>2]+20>>2],1e4),B(v[v[a+8>>2]+24>>2],1e4));if(w[a+480224|0]>=3){t[o|0]=0}if(w[k|0]>=6){t[k|0]=0}qc(p,256);qc(m,65536);qc(n,65536)}gb=f+208|0;return}d=P()|0;O()|0;break a}d=P()|0;O()|0;break a}d=P()|0;O()|0;break a}d=P()|0;O()|0;break a}d=P()|0;O()|0;break a}d=P()|0;O()|0}xb(f+184|0);S(d|0);L()}function kP(a,b,c,d,e){var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=C(0),q=0,r=0,s=0,y=0,A=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=C(0),M=C(0),N=0,O=0,P=C(0),Q=0;j=gb-48|0;gb=j;h=x[a+480192>>1]?v[(B(b,872)+a|0)+1075648>>2]:h;r=a+1074312|0;f=B(b,872)+a|0;s=f+1075791|0;D=f+1075680|0;E=f+1075768|0;y=f+1075744|0;A=f+1075740|0;F=f+1075712|0;G=f+1075684|0;H=f+1075676|0;I=f+1075656|0;J=f+1075778|0;K=f+1075080|0;m=e&127;L=C(m>>>0);q=f+1075842|0;M=C(w[q|0]);g=255;l=1;while(1){e=w[d+o|0];if(e){f=e-48|0;a:{b:{c:{if((f&255)>>>0<10){break c}if((e-65&255)>>>0<=5){f=e-55|0;break c}d:{e:{f:{switch(e-97|0){case 2:g:{e=Lm(a,b,3,0);if((e-1&255)>>>0>249){break g}e=v[(B(e,160)+a|0)+906140>>2];if(!e){break g}e=jx(e,50368,50400);if(!e){break g}f=kb[v[v[e>>2]+188>>2]](e,b)|0;e=(f|0)!=255;f=e?f:0;if(e|!h){break c}break d}if(h){break d}f=0;break c;case 13:f=0;if(!ve(w[s|0])){break e}f=w[s|0]-1|0;break e;case 21:e=j+8|0;Db(e,r,28);h:{if(!Cb(e)){Db(j,r,1);e=0;if(!Cb(j)){break h}}e=u[E>>1]}f=B(v[y>>2],v[A>>2]);e=B(v[a+1074456>>2],e+v[D>>2]|0);f=Lb((Ac(lqa(kqa(f,f>>31,e,e>>31),jb,1048576,0),jb)|0)/2|0,1,127);break e;case 23:v[j+8>>2]=v[G>>2]/2;v[j>>2]=127;f=v[pd(j+8|0,j)>>2];break e;case 24:v[j+8>>2]=v[H>>2]/2;v[j>>2]=127;f=v[pd(j+8|0,j)>>2];break e;case 0:f=0;if(!h){break e}e=x[h+28>>1];if(!e){break e}f=e-1>>>7&127;break e;case 1:f=0;if(!h){break e}e=x[h+28>>1];if(!e){break e}f=e-1&127;break e;case 14:f=v[I>>2]>>>8|0;break e;case 7:e=b;if(e>>>0>=x[a+480188>>1]){e=w[J|0]-1|0}f=e&127;break e;case 12:f=w[K|0]>>>7|0;break e;case 15:f=0;if(!h){break e}e=w[h+30|0];if(!e){break e}f=e-1&127;break e;case 25:i:{if(!c|t[q|0]<0){break i}j:{if(i>>>0<3){break j}e=(j+16|0)+i|0;if(w[e-3|0]!=240){break j}if(w[e-2|0]>239){break i}}e=q;p=Dq(a,M,L);k:{if(p<C(4294967296)&p>=C(0)){f=~~p>>>0;break k}f=0}t[e|0]=f;g=128;break e}g=(g&255)==255?m:g;f=m;break e;case 18:e=i;l:{if(!e){e=0;break l}while(1){e=e-1|0;if(w[e+(j+16|0)|0]==240){break l}if(e){continue}break}}if(w[(j+16|0)+e|0]!=240|i-e>>>0<5){break a}f=0;e=e+5|0;if((i|0)!=(e|0)){while(1){f=w[(j+16|0)+e|0]+f|0;e=e+1|0;if((i|0)!=(e|0)){continue}break}}f=0-f&127;break e;case 20:break f;default:break a}}e=B(v[y>>2],v[A>>2]);n=e;f=e>>31;e=B(v[a+1074456>>2],v[F>>2]);f=Lb((Ac(lqa(kqa(n,f,e,e>>31),jb,67108864,0),jb)|0)/2|0,1,127)}e=((l^-1)&1)+i|0;t[e+(j+16|0)|0]=f;i=e+1|0;l=1;break b}e=h;n=a;f=0;k=b;m:{if(k>>>0>=256){break m}if(w[e+31|0]==17){e=x[(n+B(k,872)|0)+1075778>>1];f=(e?e-1|0:k)&15;break m}if(!Kj(e)){break m}f=w[e+31|0]-1&15}}e=(j+16|0)+i|0;n:{if(l&1){t[e|0]=f;break n}t[e|0]=w[e|0]<<4|f;i=i+1|0}l=(l^-1)&1}}o=o+1|0;if((o|0)!=31){continue}}break}e=((l^-1)&1)+i|0;if(g<<24>>24>=0){t[q|0]=g}o:{if(!e){break o}f=0;l=0;while(1){k=(j+16|0)+l|0;d=t[k|0];p:{q:{r:{if((d|0)==-16){if(e-l>>>0>=4){o=4;if((w[(j+l|0)+17|0]&254)==240){break q}}o=l;s:{while(1){o=o+1|0;if(o>>>0>=e>>>0){break s}if(w[(j+16|0)+o|0]!=247){continue}break}d=o-l|0;o=d+1|0;if(o>>>0>=d>>>0){break q}}t[(j+16|0)+e|0]=247;e=e+1|0;o=e-l|0;break r}if((d|0)>=0){if(f&255){l=l-1|0;t[l+(j+16|0)|0]=f;break p}l=l+1|0;f=0;break p}N=j,O=US(d&255),v[N+8>>2]=O;v[j>>2]=e-l;o=v[Fb(j+8|0,j)>>2]}if(!o){break o}d=w[k|0];f=d>>>0<240?d:f}d=a;h=b;q=c;m=gb-32|0;gb=m;i=o;v[m+28>>2]=i;g=w[k|0];n=g-250|0;if(!(n>>>0>5|!(1<<n&37))){if(x[d+480188>>1]){g=0;while(1){n=(d+B(g,872)|0)+1075829|0;t[n|0]=127;t[n+1|0]=0;g=g+1|0;if(g>>>0<x[d+480188>>1]){continue}break}}g=w[k|0]}t:{u:{if((g&255)!=240){break u}n=w[k+1|0];if((n&254)!=240){break u}g=i>>>0<4;i=0;if(g){break t}r=(d+B(h,872)|0)+1074992|0;g=t[k+3|0];v:{w:{x:{y:{z:{A:{k=w[k+2|0];switch(k|0){case 3:break x;case 2:break y;case 1:break z;case 0:break A;default:break w}}if((n|0)==241|(g|0)<0){break w}k=d+B(h,872)|0;i=k+1075829|0;n=i;if(q){g=ch(Dq(d,C(w[i|0]),C((g&255)>>>0)))}t[n|0]=g;t[k+1075788|0]=0;i=4;g=k+1075080|0;q=Jq(d,r,!(v[g>>2]&32768),256);if((q|0)<0|!(w[g+1|0]&2)){break t}d=d+1298260|0;if(!Dd(d)){break t}Qq(v[d>>2],h,q>>>2&255,1);break t}if((n|0)==241|(g|0)<0){break w}i=d+B(h,872)|0;h=i+1075830|0;B:{if(!q){break B}p=Dq(d,C(w[h|0]),C((g&255)>>>0));if(p<C(4294967296)&p>=C(0)){g=~~p>>>0;break B}g=0}t[h|0]=g;t[i+1075787|0]=0;Jq(d,r,!(v[i+1075080>>2]&32768),256);i=4;break t}if((n|0)==241){break v}i=4;if((g&255)>>>0>31){break t}h=d+B(h,872)|0;t[h+1075837|0]=(g&240)>>>4;Jq(d,r,!(v[h+1075080>>2]&32768),256);break t}if((n|0)==241){break v}i=4;h=Lm(d,h,3,0);if((g|0)<0|(h-1&255)>>>0>249){break t}h=(d+B(h,160)|0)+906284|0;p=C(C(((g^127)&255)>>>0)/C(127));if(!q){z[h>>2]=p;break t}N=h,P=Dq(d,z[h>>2],p),z[N>>2]=P;break t}if(k&128){break v}if((n|0)!=241){break t}}i=4;h=Lm(d,h,3,0);if((h-1&255)>>>0>249){break t}h=v[(d+B(h,160)|0)+906140>>2];if(!h|(g|0)<0){break t}k=(n|0)==241?k+128|0:k&127;p=C(C((g&255)>>>0)/C(127));if(!q){kb[v[v[h>>2]+44>>2]](h,k,p);break t}O=h,Q=k,P=Dq(d,C(kb[v[v[h>>2]+48>>2]](h,k)),p),N=v[v[h>>2]+44>>2],kb[N](O|0,Q|0,C(P));break t}C:{if(h>>>0<x[d+480188>>1]){g=h+1|0;break C}g=x[(d+B(h,872)|0)+1075778>>1];if(!g){break t}}if(w[(d+B(h,872)|0)+1075083|0]&4|x[d+480188>>1]<(g&65535)>>>0){break t}g=Lm(d,h,3,0);if((g-1&255)>>>0>249){break t}d=v[(d+B(g,160)|0)+906140>>2];if(!d){break t}g=w[k|0];if((g|0)==240){bc(m+16|0,zb(k),i);g=v[v[d>>2]+72>>2];h=v[m+20>>2];v[m>>2]=v[m+16>>2];v[m+4>>2]=h;kb[g|0](d,m)|0;break t}N=m,Q=US(g),v[N+12>>2]=Q;i=m+12|0;g=v[Fb(i,m+28|0)>>2];v[m+12>>2]=0;hc(i,k,g);kb[v[v[d>>2]+68>>2]](d,v[m+12>>2])|0;i=v[m+28>>2]}gb=m+32|0;l=(i?i:o)+l|0}if(e>>>0>l>>>0){continue}break}}gb=j+48|0}function f6(a,b,c,d,e,f){a=a|0;b=+b;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,k=0,l=0,m=0,n=0,p=0,q=0,r=0,s=0,u=0,x=0,y=0,z=0,A=0,C=0,E=0,F=0,G=0,H=0;m=gb-560|0;gb=m;v[m+44>>2]=0;o(+b);g=j(1)|0;j(0)|0;a:{if((g|0)<0){A=1;C=2388;b=-b;o(+b);g=j(1)|0;j(0)|0;break a}if(e&2048){A=1;C=2391;break a}A=e&1;C=A?2394:2389;F=!A}b:{if((g&2146435072)==2146435072){i=A+3|0;cg(a,32,c,i,e&-65537);tf(a,C,A);d=f&32;tf(a,b!=b?d?7248:11113:d?8325:11422,3);break b}y=m+16|0;c:{d:{e:{b=XI(b,m+44|0);b=b+b;if(b!=0){g=v[m+44>>2];v[m+44>>2]=g-1;s=f|32;if((s|0)!=97){break e}break c}s=f|32;if((s|0)==97){break c}l=v[m+44>>2];n=(d|0)<0?6:d;break d}l=g-29|0;v[m+44>>2]=l;b=b*268435456;n=(d|0)<0?6:d}q=(l|0)<0?m+48|0:m+336|0;h=q;while(1){d=h;if(b<4294967296&b>=0){g=~~b>>>0}else{g=0}v[d>>2]=g;h=h+4|0;b=(b-+(g>>>0))*1e9;if(b!=0){continue}break}f:{if((l|0)<=0){d=l;g=h;k=q;break f}k=q;d=l;while(1){p=d>>>0<29?d:29;g=h-4|0;g:{if(k>>>0>g>>>0){break g}d=p;i=0;while(1){u=g;G=i;x=v[g>>2];r=d&31;if((d&63)>>>0>=32){i=x<<r;x=0}else{i=(1<<r)-1&x>>>32-r;x=x<<r}r=G+x|0;i=i+H|0;i=r>>>0<x>>>0?i+1|0:i;i=nqa(r,i,1e9,0);x=u;u=kqa(i,jb,1e9,0);v[x>>2]=r-u;g=g-4|0;if(k>>>0<=g>>>0){continue}break}if(!i){break g}k=k-4|0;v[k>>2]=i}while(1){g=h;if(k>>>0<g>>>0){h=g-4|0;if(!v[h>>2]){continue}}break}d=v[m+44>>2]-p|0;v[m+44>>2]=d;h=g;if((d|0)>0){continue}break}}h=(n+25|0)/9|0;if((d|0)<0){p=h+1|0;E=(s|0)==102;while(1){d=0-d|0;i=d>>>0<9?d:9;h:{if(g>>>0>k>>>0){u=1e9>>>i|0;r=-1<<i^-1;d=0;h=k;while(1){x=d;d=v[h>>2];v[h>>2]=x+(d>>>i|0);d=B(u,d&r);h=h+4|0;if(h>>>0<g>>>0){continue}break}h=v[k>>2];if(!d){break h}v[g>>2]=d;g=g+4|0;break h}h=v[k>>2]}d=i+v[m+44>>2]|0;v[m+44>>2]=d;k=(!h<<2)+k|0;h=E?q:k;g=(p|0)<g-h>>2?h+(p<<2)|0:g;if((d|0)<0){continue}break}}h=0;i:{if(g>>>0<=k>>>0){break i}h=B(q-k>>2,9);d=10;i=v[k>>2];if(i>>>0<10){break i}while(1){h=h+1|0;d=B(d,10);if(i>>>0>=d>>>0){continue}break}}d=(n-((s|0)==102?0:h)|0)-((s|0)==103&(n|0)!=0)|0;if((d|0)<(B(g-q>>2,9)-9|0)){i=((l|0)<0?4:292)+m|0;l=d+9216|0;p=(l|0)/9|0;i=(i+(p<<2)|0)-4048|0;d=10;l=l-B(p,9)|0;if((l|0)<=7){while(1){d=B(d,10);l=l+1|0;if((l|0)!=8){continue}break}}p=v[i>>2];u=(p>>>0)/(d>>>0)|0;l=p-B(d,u)|0;r=i+4|0;j:{if(!l&(r|0)==(g|0)){break j}b=(g|0)==(r|0)?1:1.5;r=d>>>1|0;z=l>>>0<r>>>0?.5:(r|0)==(l|0)?b:1.5;b=u&1?9007199254740994:9007199254740992;if(!(w[C|0]!=45|F)){z=-z;b=-b}l=p-l|0;v[i>>2]=l;if(b+z==b){break j}d=d+l|0;v[i>>2]=d;if(d>>>0>=1e9){while(1){v[i>>2]=0;i=i-4|0;if(i>>>0<k>>>0){k=k-4|0;v[k>>2]=0}d=v[i>>2]+1|0;v[i>>2]=d;if(d>>>0>999999999){continue}break}}h=B(q-k>>2,9);d=10;l=v[k>>2];if(l>>>0<10){break j}while(1){h=h+1|0;d=B(d,10);if(l>>>0>=d>>>0){continue}break}}d=i+4|0;g=d>>>0<g>>>0?d:g}while(1){l=g;d=g>>>0<=k>>>0;if(!d){g=l-4|0;if(!v[g>>2]){continue}}break}k:{if((s|0)!=103){s=e&8;break k}g=n?n:1;i=(g|0)>(h|0)&(h|0)>-5;n=(i?h^-1:-1)+g|0;f=(i?-1:-2)+f|0;s=e&8;if(s){break k}i=-9;l:{if(d){break l}p=v[l-4>>2];i=-9;if(!p){break l}d=10;g=0;i=0;if((p>>>0)%10|0){break l}while(1){i=g;g=g+1|0;d=B(d,10);if(!((p>>>0)%(d>>>0)|0)){continue}break}i=i^-1}d=B(l-q>>2,9)-9|0;if((f&-33)==70){s=0;d=d+i|0;d=(d|0)>0?d:0;n=(d|0)>(n|0)?n:d;break k}s=0;d=i+(d+h|0)|0;d=(d|0)>0?d:0;n=(d|0)>(n|0)?n:d}p=(n|s)!=0;d=a;x=c;u=f&-33;if((u|0)==70){f=(h|0)>0?h:0}else{g=h>>31;g=ao(g+h^g,0,y);if((y-g|0)<=1){while(1){g=g-1|0;t[g|0]=48;if((y-g|0)<2){continue}break}}E=g-2|0;t[E|0]=f;t[g-1|0]=(h|0)<0?45:43;f=y-E|0}i=(f+(p+(n+A|0)|0)|0)+1|0;cg(d,32,x,i,e);tf(a,C,A);cg(a,48,c,i,e^65536);m:{n:{o:{if((u|0)==70){f=m+16|0;d=f|8;f=f|9;k=k>>>0>q>>>0?q:k;h=k;while(1){g=ao(v[h>>2],0,f);p:{if((h|0)!=(k|0)){if(m+16>>>0>=g>>>0){break p}while(1){g=g-1|0;t[g|0]=48;if(m+16>>>0<g>>>0){continue}break}break p}if((f|0)!=(g|0)){break p}t[m+24|0]=48;g=d}tf(a,g,f-g|0);h=h+4|0;if(q>>>0>=h>>>0){continue}break}g=0;if(!p){break n}tf(a,13845,1);if((n|0)<=0|h>>>0>=l>>>0){break o}while(1){g=ao(v[h>>2],0,f);if(g>>>0>m+16>>>0){while(1){g=g-1|0;t[g|0]=48;if(m+16>>>0<g>>>0){continue}break}}tf(a,g,(n|0)<9?n:9);g=n-9|0;h=h+4|0;if(l>>>0<=h>>>0){break n}d=(n|0)>9;n=g;if(d){continue}break}break n}q:{if((n|0)<0){break q}q=k>>>0<l>>>0?l:k+4|0;d=m+16|0;f=d|9;d=d|8;h=k;while(1){g=ao(v[h>>2],0,f);if((f|0)==(g|0)){t[m+24|0]=48;g=d}r:{if((h|0)!=(k|0)){if(m+16>>>0>=g>>>0){break r}while(1){g=g-1|0;t[g|0]=48;if(m+16>>>0<g>>>0){continue}break}break r}tf(a,g,1);g=g+1|0;if(!(n|s)){break r}tf(a,13845,1)}l=g;g=f-g|0;tf(a,l,(g|0)<(n|0)?g:n);n=n-g|0;h=h+4|0;if(q>>>0<=h>>>0){break q}if((n|0)>=0){continue}break}}cg(a,48,n+18|0,18,0);tf(a,E,y-E|0);break m}g=n}cg(a,48,g+9|0,9,0)}break b}n=(f<<26>>31&9)+C|0;s:{if(d>>>0>11){break s}g=12-d|0;z=8;while(1){z=z*16;g=g-1|0;if(g){continue}break}if(w[n|0]==45){b=-(z+(-b-z));break s}b=b+z-z}h=v[m+44>>2];g=h>>31;g=ao(g^g+h,0,y);if((y|0)==(g|0)){t[m+15|0]=48;g=m+15|0}q=A|2;l=f&32;h=v[m+44>>2];k=g-2|0;t[k|0]=f+15;t[g-1|0]=(h|0)<0?45:43;i=e&8;h=m+16|0;while(1){f=h;u=l;if(D(b)<2147483648){g=~~b}else{g=-2147483648}t[h|0]=u|w[g+74096|0];b=(b-+(g|0))*16;h=f+1|0;if(!(!(i?1:(d|0)>0|b!=0)|(h-(m+16|0)|0)!=1)){t[f+1|0]=46;h=f+2|0}if(b!=0){continue}break}f=m+16|0;d=!d|((h-m|0)-18|0)>=(d|0)?(y-(f+k|0)|0)+h|0:((d+y|0)-k|0)+2|0;i=d+q|0;cg(a,32,c,i,e);tf(a,n,q);cg(a,48,c,i,e^65536);g=f;f=h-f|0;tf(a,g,f);g=d;d=y-k|0;cg(a,48,g-(d+f|0)|0,0,0);tf(a,k,d)}cg(a,32,c,i,e^8192);gb=m+560|0;return((c|0)>(i|0)?c:i)|0}function gla(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;e=gb-336|0;gb=e;Wc(b,60);j=15;a:{if(!Gh(b,11407)){Wc(b,124);j=31;if(!Gh(b,12505)){break a}}Gd(a,536870912);u[a+480190>>1]=j;vc(b);b:{if(x[a+480190>>1]){while(1){d=Kr(b);v[(e+208|0)+(f<<2)>>2]=d;if(d>>>0>131072){break b}f=f+1|0;if(f>>>0<x[a+480190>>1]){continue}break}}v[a+480260>>2]=56;v[a+480264>>2]=13696;v[a+480196>>2]=6;f=0;u[a+480192>>1]=0;u[a+480188>>1]=4;v[a+480228>>2]=64;xh(a,1);Rb(b,4);h=Mr(b);if(h>>>0<178){break a}d=a;p=1776930/+(h>>>0)*1e4;c:{if(p<4294967296&p>=0){h=~~p>>>0;break c}h=0}v[d+480204>>2]=h;Rb(b,14);d:{e:{f:{if(x[a+480190>>1]){i=e+62|0;k=1;j=0;m=1;while(1){f=e+40|0;uV(b,f);d=v[((k<<2)+e|0)+204>>2];n=gb-16|0;gb=n;g=(B(k,104)+a|0)+484380|0;ud(g,1);v[g>>2]=d;t[g+37|0]=w[f+24|0]<<4;t[n+15|0]=w[f+25|0];t[n+14|0]=64;q=g,r=w[ac(n+15|0,n+14|0)|0]<<2,u[q+30>>1]=r;d=f+26|0;l=Ib(w[d|0]|w[d+1|0]<<8);d=f+28|0;d=Ib(w[d|0]|w[d+1|0]<<8);h=v[g>>2];g:{if(!h){break g}v[g+4>>2]=l;d=(d<<1)+l|0;v[g+8>>2]=d;if(h>>>0<=l>>>0){l=h-1|0;v[g+4>>2]=l}if(d>>>0>h>>>0){v[g+8>>2]=h;d=h}if(!(!(d>>>0<l>>>0|d>>>0<4)&d-l>>>0>3)){v[g+4>>2]=0;v[g+8>>2]=0;break g}if(d>>>0<=l>>>0){break g}u[g+34>>1]=x[g+34>>1]|2}gb=n+16|0;while(1){if((w[f|0]-1&255)>>>0<=30){t[f|0]=32;j=j+1|0}f=f+1|0;if((i|0)!=(f|0)){continue}break}if(j>>>0>127){break b}d=e+176|0;Rk(d,3,e+40|0);h=e+192|0;Bc(h,d);v[22656]=0;Q(301,((k<<5)+a|0)+946304|0,h|0)|0;d=v[22656];v[22656]=0;if((d|0)==1){break f}vb(e+192|0);m=m+1|0;k=m&65535;if(k>>>0<=x[a+480190>>1]){continue}break}}d=Tb(e+40|0,11292);v[22656]=0;f=a+946336|0;h=Q(884,f|0,d|0)|0;g=v[22656];v[22656]=0;j=1;h:{i:{j:{k:{if((g|0)!=1){if(!h){v[22656]=0;h=Q(70,e+192|0,11303)|0;j=v[22656];v[22656]=0;if((j|0)==1){break k}v[22656]=0;j=Q(884,f|0,h|0)|0;f=v[22656];v[22656]=0;if((f|0)==1){break j}vb(h)}vb(d);f=0;d=e+40|0;h=nV(b,d);if(!h){cC(d)}if(!h){break a}if(!oU(e+40|0)){break a}if(c){break h}break d}a=P()|0;O()|0;break i}a=P()|0;O()|0;break i}a=P()|0;O()|0;vb(h)}vb(d);break e}u[e+38>>1]=0;if(w[e+40|0]){while(1){u[e+192>>1]=w[(e+f|0)+42|0]+1;q=e,r=x[Le(e+38|0,e+192|0)>>1],u[q+38>>1]=r;f=f+1|0;if(f>>>0<w[e+40|0]){continue}break}}d=e+40|1;h=w[d|0];f=w[e+40|0];g=a+484360|0;cf(Sb(g),f>>>0>h>>>0?w[d|0]:0);Er(Sb(g),e+40|2,w[e+40|0]);if(x[a+480190>>1]==31){Rb(b,4)}k=0;v[e+32>>2]=0;v[e+28>>2]=0;v[e+24>>2]=0;t[e+23|0]=0;l=c&1;if(l){Ag(a+484344|0,x[e+38>>1])}if(x[e+38>>1]){h=a+484344|0;while(1){l:{m:{if(l){m=0;if(wh(h,k&65535,64)){break m}}Rb(b,1024);break l}while(1){n=Yc(_b(h,k),m,0);f=0;while(1){g=e+192|0;wn(g,b);d=n+B(f,6)|0;n:{o:{p:{q:{if(w[ic(g,0)|0]!=255){break q}t[(e+32|0)+f|0]=0;t[(e+24|0)+f|0]=0;g=ic(e+192|0,1);i=w[g|0];if((i|0)==252&j){t[g|0]=254;break o}switch(i-252|0){case 1:break n;case 2:break o;case 0:break p;default:break q}}g=v[e+192>>2];v[e+16>>2]=g;v[e+8>>2]=g;gr(e+8|0,d);g=w[d|0];r:{if(!g){break r}t[(e+24|0)+f|0]=0;t[(e+32|0)+f|0]=g;if(g>>>0>48){break r}t[e+176|0]=8;q=e,r=w[df(e+23|0,e+176|0)|0],t[q+23|0]=r}s:{t:{u:{v:{w:{x:{switch(w[d+3|0]){case 1:t[d+3|0]=1;break n;case 2:g=w[d+5|0];if(g&240){t[d+3|0]=3;t[d+5|0]=g>>>4;break n}g=g&15;if(g){t[d+3|0]=2;t[d+5|0]=g;break n}t[d+5|0]=0;break t;case 3:if(w[(e+24|0)+f|0]){break u}t[d+3|0]=19;t[d+5|0]=0;break n;case 4:if(w[(e+24|0)+f|0]){break u}t[d+3|0]=19;t[d+5|0]=1;break n;case 5:if(!w[d+1|0]){break u}t[d+3|0]=13;t[e+176|0]=63;t[e+15|0]=w[d+5|0]+(x[(B(w[d+1|0],104)+a|0)+484410>>1]>>>2|0);q=d,r=w[ac(e+176|0,e+15|0)|0],t[q+5|0]=r;if(!w[(e+24|0)+f|0]){break w}t[d+2|0]=1;t[d+4|0]=w[d+5|0];t[d+5|0]=0;break t;case 6:g=w[d+1|0];if(!g){break u}t[d+3|0]=13;g=x[(B(g,104)+a|0)+484410>>1]>>>2|0;i=w[d+5|0];g=g>>>0<i>>>0?0:g-i|0;t[d+5|0]=g;if(!w[(e+24|0)+f|0]){break w}t[d+4|0]=g;t[d+2|0]=1;t[d+5|0]=0;break t;case 8:i=w[(e+32|0)+f|0];g=w[d+5|0];o=i+(g>>>4|0)|0;t[(e+28|0)+f|0]=o;t[d+3|0]=2;g=g&15;t[(e+24|0)+f|0]=g;q=d,r=nU(g,i,o&255),t[q+5|0]=r;break w;case 9:t[e+176|0]=8;q=e,r=w[df(e+23|0,e+176|0)|0],t[q+23|0]=r;break t;case 0:break v;case 7:break x;default:break t}}g=w[(e+32|0)+f|0];i=w[d+5|0];o=g-(i>>>4|0)|0;t[(e+28|0)+f|0]=o;t[d+3|0]=3;i=i&15;t[(e+24|0)+f|0]=i;q=d,r=nU(i,o&255,g),t[q+5|0]=r}if(!w[d+3|0]){break s}break n}if(!w[d+5|0]){break s}break t}t[d+5|0]=0}t[d+3|0]=0}i=w[(e+24|0)+f|0];if(!i){break n}o=(e+28|0)+f|0;g=w[o|0];if(g){t[(e+32|0)+f|0]=g;t[d|0]=g;t[d+5|0]=i;t[o|0]=0}t[d+3|0]=4;break n}t[d+3|0]=14;t[e+23|0]=9;break n}t[d+3|0]=13}f=f+1|0;if((f|0)!=4){continue}break}m=m+1|0;if((m|0)!=64){continue}break}}k=k+1|0;if(k>>>0<x[e+38>>1]){continue}break}}y:{z:{A:{B:{if(c&2){j=x[a+480190>>1];if(!j){break A}f=1;while(1){c=(B(f&65535,104)+a|0)+484380|0;if(v[c>>2]){Dg(Rc(e+192|0,8,1,0,0),c,b);j=x[a+480190>>1]}f=f+1|0;if((f&65535)>>>0<=(j&65535)>>>0){continue}break}break B}j=x[a+480190>>1]}if((j&65535)!=15){break A}b=gb-16|0;gb=b;c=e+176|0;d=Tb(b,1514);Dc(c,d);vb(d);gb=b+16|0;v[22656]=0;U(463,e+192|0,c|0,e+23|0);b=v[22656];v[22656]=0;f=1;if((b|0)!=1){break z}a=P()|0;O()|0;Hb(e+176|0);break e}f=0;v[22656]=0;Q(2,e+192|0,9566)|0;b=v[22656];v[22656]=0;if((b|0)==1){break y}}b=e+192|0;Eb(a+1298304|0,b);vb(b);if(f){Hb(e+176|0)}Xc(a+1298316|0,x[a+480190>>1]==15?2374:12319);v[a+1298364>>2]=2;break d}a=P()|0;O()|0;break e}a=P()|0;O()|0;vb(e+192|0)}S(a|0);L()}f=1;break a}f=0}gb=e+336|0;return f|0}function Xga(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;d=gb-144|0;gb=d;vc(c);a:{b:{c:{d:{e:{f:{g:{if(!(!Ar(c,d+128|0)|v[d+128>>2]!=1297239878|!(v[d+136>>2]==1482052408|(w[d+136|0]|w[d+137|0]<<8|(w[d+138|0]<<16|w[d+139|0]<<24))==1448293937)&(w[d+136|0]|w[d+137|0]<<8|(w[d+138|0]<<16|w[d+139|0]<<24))!=1146437965)){e=gb-32|0;gb=e;i=hh(d+112|0);h:{i:{j:{k:{l:{while(1){v[22656]=0;h=Q(191,c|0,8)|0;g=v[22656];v[22656]=0;if((g|0)==1){break j}if(!h){break k}v[22656]=0;R(1170,e|0,c|0);h=v[22656];v[22656]=0;if((h|0)!=1){v[22656]=0;R(1171,i|0,e|0);h=v[22656];v[22656]=0;if((h|0)==1){break l}ed(e);continue}break}a=P()|0;O()|0;break i}a=P()|0;O()|0;ed(e);break i}gb=e+32|0;break h}a=P()|0;O()|0}ke(i);S(a|0);L()}v[22656]=0;i=T(215,d+88|0)|0;c=v[22656];v[22656]=0;m:{n:{o:{p:{q:{r:{s:{t:{u:{v:{w:{x:{y:{z:{A:{B:{if((c|0)!=1){h=Rc(d+84|0,8,1,1,0);if((w[d+136|0]|w[d+137|0]<<8|(w[d+138|0]<<16|w[d+139|0]<<24))!=1146437965){break z}v[22656]=0;U(1156,d- -64|0,d+112|0,1296581714);c=v[22656];v[22656]=0;if((c|0)==1){break B}v[22656]=0;U(1156,d+40|0,d+112|0,1296318804);c=v[22656];v[22656]=0;if((c|0)==1){break c}c=d+40|0;Vc(i,c);xb(c);v[22656]=0;c=T(1157,d- -64|0)|0;e=v[22656];v[22656]=0;if((e|0)==1){break c}if(!c){break n}v[22656]=0;c=T(275,i|0)|0;e=v[22656];v[22656]=0;if((e|0)==1){break c}if(!c){break n}v[22656]=0;c=T(426,d- -64|0)|0;e=v[22656];v[22656]=0;if((e|0)==1){break c}v[22656]=0;f=T(416,d- -64|0)|0;e=v[22656];v[22656]=0;C:{if((e|0)==1){break C}v[22656]=0;Q(318,d- -64|0,2)|0;e=v[22656];v[22656]=0;if((e|0)==1){break C}v[22656]=0;k=T(426,d- -64|0)|0;e=v[22656];v[22656]=0;if((e|0)!=1){break A}}break c}e=P()|0;O()|0;break a}e=P()|0;O()|0;break b}v[22656]=0;R(829,d+40|0,d- -64|0);e=v[22656];v[22656]=0;if((e|0)==1){break c}if(!Ib(w[d+40|0]|w[d+41|0]<<8)){break n}j=d+40|0;e=fc(j);j=Ve(j);k=(k>>>0)/(Ib(w[d+40|0]|w[d+41|0]<<8)>>>0)|0;if((Ib(w[e|0]|w[e+1|0]<<8)|0)!=(Ib(w[j|0]|w[j+1|0]<<8)+1|0)){break n}if((Ib(w[e|0]|w[e+1|0]<<8)|0)==2){Bp(h,2)}D:{if((f|0)!=16){if((f|0)!=8){break n}if(!Ib(w[d+46|0]|w[d+47|0]<<8)){Bf(h,1);break D}if((Ib(w[d+46|0]|w[d+47|0]<<8)|0)==2){Bf(h,17);break D}if((Ib(w[d+46|0]|w[d+47|0]<<8)|0)!=3){break n}Bf(h,16);break D}if(Ib(w[d+46|0]|w[d+47|0]<<8)){break n}Yi(h,16)}xb(d- -64|0);j=0;f=0;break y}v[22656]=0;U(1156,d- -64|0,d+112|0,1447576658);c=v[22656];v[22656]=0;if((c|0)==1){break x}v[22656]=0;U(1156,d+40|0,d+112|0,1128808782);c=v[22656];v[22656]=0;if((c|0)==1){break w}v[22656]=0;U(1156,d+16|0,d+112|0,1112491097);c=v[22656];v[22656]=0;if((c|0)==1){break g}c=d+16|0;Vc(i,c);xb(c);v[22656]=0;g=T(275,i|0)|0;c=v[22656];v[22656]=0;if((c|0)==1){break g}e=0;c=0;E:{if(!g){break E}v[22656]=0;g=T(275,d- -64|0)|0;c=v[22656];v[22656]=0;if((c|0)==1){break g}c=0;if(!g){break E}v[22656]=0;g=Q(1158,d- -64|0,d+16|0)|0;c=v[22656];v[22656]=0;if((c|0)==1){break g}c=0;if(!g){break E}c=w[d+136|0]|w[d+137|0]<<8|(w[d+138|0]<<16|w[d+139|0]<<24);v[22656]=0;f=T(426,d+40|0)|0;k=v[22656];v[22656]=0;if((k|0)==1){break g}g=(c|0)!=1482052408;if(g){Rc(d+12|0,16,1,0,0);v[d+84>>2]=v[d+12>>2]}if((f|0)==6){Bp(h,3)}c=d+16|0;l=Xb(w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24));c=c|4;m=Xb(w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24));k=Ib(w[d+28|0]|w[d+29|0]<<8);j=Xb(w[d+32|0]|w[d+33|0]<<8|(w[d+34|0]<<16|w[d+35|0]<<24));v[22656]=0;n=T(195,i|0)|0;c=v[22656];v[22656]=0;o=1;if((c|0)==1){break g}c=B((f|0)==6?2:1,g?2:1);f=(l>>>0)/(c>>>0)|0;l=(m>>>0)/(c>>>0)|0;c=(n>>>0)/(c>>>0)|0}xb(d+40|0);xb(d- -64|0);if(!o){break m}}v[22656]=0;Q(1140,a|0,b|0)|0;e=v[22656];v[22656]=0;if((e|0)==1){break q}v[22656]=0;g=B(b,104)+a|0;e=g+484380|0;R(424,e|0,0);m=v[22656];v[22656]=0;if((m|0)==1){break p}v[e>>2]=c;l=f+l|0;v[g+484388>>2]=l;v[g+484384>>2]=f;if(!(c>>>0<l>>>0|l>>>0<=f+4>>>0)){c=(B(b,104)+a|0)+484414|0;u[c>>1]=x[c>>1]|2}c=B(b,104)+a|0;v[c+484404>>2]=k?k:22050;f=c+484410|0;c=j>>>8|0;u[f>>1]=c&65535?(j&16776960)>>>0>65536?256:c:256;c=v[a+480180>>2];v[22656]=0;U(1142,e|0,32,c|0);c=v[22656];v[22656]=0;if((c|0)==1){break v}v[22656]=0;U(1156,d- -64|0,d+112|0,1312902469);c=v[22656];v[22656]=0;if((c|0)==1){break u}v[22656]=0;c=T(275,d- -64|0)|0;f=v[22656];v[22656]=0;if((f|0)==1){break e}if(!c){break t}v[22656]=0;c=T(195,d- -64|0)|0;f=v[22656];v[22656]=0;if((f|0)==1){break e}v[22656]=0;W(503,d- -64|0,((b<<5)+a|0)+946304|0,c|0)|0;b=v[22656];v[22656]=0;if((b|0)!=1){break s}break e}e=P()|0;O()|0;break b}e=P()|0;O()|0;break f}e=P()|0;O()|0;break b}e=P()|0;O()|0;break b}v[22656]=0;c=Q(70,d+40|0,18726)|0;f=v[22656];v[22656]=0;if((f|0)==1){break r}v[22656]=0;Q(301,((b<<5)+a|0)+946304|0,c|0)|0;b=v[22656];v[22656]=0;if((b|0)==1){break o}vb(c)}v[22656]=0;W(329,h|0,e|0,i|0)|0;b=v[22656];v[22656]=0;if((b|0)==1){break e}v[22656]=0;_h(e,a,0);a=v[22656];v[22656]=0;if((a|0)==1){break e}xb(d- -64|0);e=1;break m}e=P()|0;O()|0;break d}e=P()|0;O()|0;break b}e=P()|0;O()|0;break b}e=P()|0;O()|0;vb(c);break d}xb(d- -64|0);e=0}xb(i);ke(d+112|0)}gb=d+144|0;return e|0}e=P()|0;O()|0;xb(d+40|0)}xb(d- -64|0);break b}e=P()|0;O()|0}xb(d- -64|0);break b}e=P()|0;O()|0;xb(d- -64|0)}xb(i)}ke(d+112|0);S(e|0);L()}function IK(a,b,c,d,e,f){var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;g=gb-48|0;gb=g;v[g+44>>2]=c;u[g+32>>1]=0;u[g+16>>1]=65535;a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{if(Ft(g+44|0,g+32|0,g+16|0)){if(me(v[b+24>>2]+484344|0,c&65535)){break j}}c=a;a=Kb(g+32|0);b=Kb(g+16|0);Aj(c,a,b);vb(b);vb(a);break i}c=_b(v[b+24>>2]+484344|0,c);if(!(v[c+12>>2]>(d|0)&(d|0)>=0)){c=a;a=Kb(g+32|0);b=Kb(g+16|0);Aj(c,a,b);vb(b);vb(a);break i}if(!(x[v[b+24>>2]+480188>>1]>e>>>0&(e|0)>=0)){c=a;a=Kb(g+32|0);b=Kb(g+16|0);Aj(c,a,b);vb(b);vb(a);break i}if(f>>>0>=6){c=a;a=Kb(g+32|0);b=Kb(g+16|0);Aj(c,a,b);vb(b);vb(a);break i}e=Yc(c,d,e&65535);k:{switch(f-1|0){default:l:{m:{n:{if(!Rd(e)){if(!_t(e)){break n}}c=g+16|0;KO(c,v[b+24>>2],w[e|0],w[e+1|0]);v[22656]=0;R(2039,g+32|0,c|0);c=v[22656];v[22656]=0;b=1;if((c|0)!=1){break m}c=P()|0;O()|0;break b}b=0;v[22656]=0;Q(70,g+32|0,13839)|0;c=v[22656];v[22656]=0;if((c|0)==1){break l}}v[22656]=0;c=Rd(e);d=v[22656];v[22656]=0;if((d|0)==1){break c}o:{if(c){v[22656]=0;Q(70,g|0,7238)|0;c=v[22656];v[22656]=0;if((c|0)==1){break c}break o}if(_t(e)){v[22656]=0;Q(70,g|0,7548)|0;c=v[22656];v[22656]=0;if((c|0)!=1){break o}break c}v[22656]=0;Q(70,g|0,13839)|0;c=v[22656];v[22656]=0;if((c|0)==1){break c}}c=a;a=g+32|0;Aj(c,a,g);vb(g);vb(a);if(!b){break i}vb(g+16|0);break i}c=P()|0;O()|0;break a;case 0:b=e+1|0;p:{if(w[e+1|0]){lv(g+32|0,b);break p}Tb(g+32|0,13844)}q:{if(w[b|0]){v[22656]=0;Q(70,g+16|0,8055)|0;b=v[22656];v[22656]=0;if((b|0)!=1){break q}break d}v[22656]=0;Q(70,g+16|0,13844)|0;b=v[22656];v[22656]=0;if((b|0)==1){break d}}c=a;a=g+32|0;b=g+16|0;Aj(c,a,b);vb(b);vb(a);break i;case 1:r:{if(Cg(e)){Tb(g+32|0,14911);break r}if(w[e+2|0]){He(g+32|0,1,xz(v[v[b+24>>2]+8>>2],w[e+2|0]));break r}Tb(g+32|0,14911)}v[22656]=0;b=Cg(e);c=v[22656];v[22656]=0;if((c|0)==1){break e}s:{if(b){v[22656]=0;Q(70,g+16|0,14911)|0;b=v[22656];v[22656]=0;if((b|0)==1){break e}break s}if(w[e+2|0]){v[22656]=0;Q(70,g+16|0,2597)|0;b=v[22656];v[22656]=0;if((b|0)!=1){break s}break e}v[22656]=0;Q(70,g+16|0,14911)|0;b=v[22656];v[22656]=0;if((b|0)==1){break e}}c=a;a=g+32|0;b=g+16|0;Aj(c,a,b);vb(b);vb(a);break i;case 3:t:{if(Cg(e)){q=g,r=Hq(e)&255,v[q>>2]=r;pC(g+32|0,g);break t}if(w[e+2|0]){lv(g+32|0,e+4|0);break t}Tb(g+32|0,13844)}v[22656]=0;b=Cg(e);c=v[22656];v[22656]=0;if((c|0)==1){break f}u:{if(b){v[22656]=0;Q(70,g+16|0,2581)|0;b=v[22656];v[22656]=0;if((b|0)==1){break f}break u}if(w[e+2|0]){v[22656]=0;Q(70,g+16|0,2581)|0;b=v[22656];v[22656]=0;if((b|0)!=1){break u}break f}v[22656]=0;Q(70,g+16|0,13844)|0;b=v[22656];v[22656]=0;if((b|0)==1){break f}}c=a;a=g+32|0;b=g+16|0;Aj(c,a,b);vb(b);vb(a);break i;case 2:v:{if(Cg(e)){q=g,r=(Go(e)&3840)!=0,t[q|0]=r;i=gb-32|0;gb=i;t[i+24|0]=44;v[i+16>>2]=-1;v[i+20>>2]=0;v[i+8>>2]=1058;v[i+12>>2]=1;n=g+32|0;c=g;b=gb+-64|0;gb=b;d=b;k=i+8|0;l=v[k>>2]&2?16:10;j=gb-32|0;gb=j;f=He(j+16|0,1,0);w:{x:{y:{while(1){h=Jb(f);m=Jb(f);o=Ab(f);p=w[c|0];v[22656]=0;ha(91,j+8|0,h|0,m+o|0,p|0,l|0);h=v[22656];v[22656]=0;if((h|0)==1){break x}if(!v[j+12>>2]){break y}h=Ab(f);v[22656]=0;v[j+4>>2]=h;h=xf(j+4|0);m=v[22656];v[22656]=0;if((m|0)!=1){v[22656]=0;U(75,f|0,h|0,0);h=v[22656];v[22656]=0;if((h|0)!=1){continue}}break}break x}c=v[j+8>>2];l=Jb(f);v[22656]=0;R(76,f|0,c-l|0);c=v[22656];v[22656]=0;if((c|0)!=1){v[22656]=0;R(77,d|0,f|0);c=v[22656];v[22656]=0;if((c|0)==1){break x}vb(f);gb=j+32|0;break w}}a=P()|0;O()|0;vb(f);S(a|0);L()}c=b+16|0;Ml(c,b,k);v[22656]=0;U(89,b+32|0,c|0,k|0);c=v[22656];v[22656]=0;z:{A:{B:{C:{D:{if((c|0)!=1){v[22656]=0;U(90,b+48|0,b+32|0,k|0);c=v[22656];v[22656]=0;if((c|0)==1){break D}v[22656]=0;R(72,n|0,b+48|0);c=v[22656];v[22656]=0;if((c|0)==1){break C}vb(b+48|0);vb(b+32|0);vb(b+16|0);vb(b);gb=b- -64|0;break z}a=P()|0;O()|0;break A}a=P()|0;O()|0;break B}a=P()|0;O()|0;vb(b+48|0)}vb(b+32|0)}vb(b+16|0);vb(b);S(a|0);L()}gb=i+32|0;break v}if(w[e+3|0]){He(g+32|0,1,wz(v[v[b+24>>2]+8>>2],w[e+3|0]));break v}Tb(g+32|0,13845)}v[22656]=0;b=Cg(e);c=v[22656];v[22656]=0;if((c|0)==1){break g}E:{if(b){v[22656]=0;Q(70,g+16|0,9551)|0;b=v[22656];v[22656]=0;if((b|0)==1){break g}break E}if(w[e+3|0]){v[22656]=0;Q(70,g+16|0,9551)|0;b=v[22656];v[22656]=0;if((b|0)!=1){break E}break g}v[22656]=0;Q(70,g+16|0,13845)|0;b=v[22656];v[22656]=0;if((b|0)==1){break g}}c=a;a=g+32|0;b=g+16|0;Aj(c,a,b);vb(b);vb(a);break i;case 4:break k}}F:{if(Cg(e)){q=g,r=Go(e)&255,v[q>>2]=r;pC(g+32|0,g);break F}if(w[e+3|0]){lv(g+32|0,e+5|0);break F}Tb(g+32|0,13844)}v[22656]=0;b=Cg(e);c=v[22656];v[22656]=0;if((c|0)==1){break h}G:{if(b){v[22656]=0;Q(70,g+16|0,8342)|0;b=v[22656];v[22656]=0;if((b|0)==1){break h}break G}if(w[e+3|0]){v[22656]=0;Q(70,g+16|0,8342)|0;b=v[22656];v[22656]=0;if((b|0)!=1){break G}break h}v[22656]=0;Q(70,g+16|0,13844)|0;b=v[22656];v[22656]=0;if((b|0)==1){break h}}c=a;a=g+32|0;b=g+16|0;Aj(c,a,b);vb(b);vb(a)}gb=g+48|0;return}c=P()|0;O()|0;vb(g+32|0);break a}c=P()|0;O()|0;vb(g+32|0);break a}c=P()|0;O()|0;vb(g+32|0);break a}c=P()|0;O()|0;vb(g+32|0);break a}c=P()|0;O()|0;vb(g+32|0);break a}c=P()|0;O()|0;vb(g+32|0);if(!b){break a}}vb(g+16|0)}S(c|0);L()}function xma(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,y=0,z=0,A=0;d=gb-1824|0;gb=d;vc(b);g=gb-32|0;gb=g;e=g+24|0;k=d+1224|0;kV(e,k);i=yb(e);e=v[g+28>>2];j=v[g+24>>2];v[g+8>>2]=j;v[g+12>>2]=e;v[g>>2]=j;v[g+4>>2]=e;j=g+16|0;e=b;cc(j,e,g);j=yb(j);if((j|0)==(i|0)){Rb(e,yb(g+24|0))}gb=g+32|0;e=(i|0)==(j|0);if(!e){jV(k)}a:{if(!e){break a}if(!tV(d+1224|0)){break a}if(!jC(b,16,0)){break a}v[d+1216>>2]=v[d+1240>>2];e=v[d+1228>>2];v[d+1200>>2]=v[d+1224>>2];v[d+1204>>2]=e;e=d+1232|0;h=v[e+4>>2];v[d+1208>>2]=v[e>>2];v[d+1212>>2]=h;Gd(a,1);e=a+1074312|0;Rf(e,83);Ob(e,84,1);Ob(e,85,1);u[a+480188>>1]=4;v[d+1196>>2]=0;u[a+480190>>1]=15;Wc(b,20);j=a+480188|0;h=1;g=1;while(1){i=B(h,104)+a|0;k=i+484380|0;e=((h<<5)+a|0)+946304|0;kC(b,d+16|0,k,e,1);m=v[k>>2];b:{if(!w[ic(e,0)|0]){break b}c:{if(sd(e,13847,3)){if(sd(e,13851,3)){break c}}if(w[ic(e,5)|0]==58){break b}}g=0}if(Ib(w[d+44|0]|w[d+45|0]<<8)>>>0>=2){z=i+484384|0,A=Ib(w[d+42|0]|w[d+43|0]<<8),v[z>>2]=A;z=i+484388|0,A=Ib(w[d+42|0]|w[d+43|0]<<8)+(Ib(w[d+44|0]|w[d+45|0]<<8)<<1)|0,v[z>>2]=A;xk(k)}d:{if(Ib(w[d+38|0]|w[d+39|0]<<8)>>>0<=4999){if(Ib(w[d+42|0]|w[d+43|0]<<8)>>>0<1e4){break d}}v[d+1064>>2]=5;z=d,A=v[cp(d+1196|0,d+1064|0)>>2],v[z+1196>>2]=A}f=f+m|0;h=h+1|0;if((h|0)!=16){continue}break}r=d+1064|0;e=r;zV(b,e);p=a+484360|0;Er(Sb(p),e|2,128);h=0;m=yV(b,Sb(p),w[e|0],f,j,0,1);e=e|1;if(!(w[e|0]|w[r|0])&m>>>0<2){break a}if(nf(b)+65536>>>0<(m<<10)+f>>>0){break a}if(!c){h=1;break a}if(!w[e|0]){t[e|0]=120}if(!sd(d+1200|0,12129,6)){t[e|0]=120}v[a+480204>>2]=125e4;e:{if(w[e|0]==120){break e}f=a;s=1773447.5/(+(240-w[e|0]|0)*122)*1e4;f:{if(s<4294967296&s>=0){e=~~s>>>0;break f}e=0}v[f+480204>>2]=e;if(v[d+1196>>2]>=2){v[d+16>>2]=g?4:5;z=d,A=v[cp(d+1196|0,d+16|0)>>2],v[z+1196>>2]=A;break e}v[d+16>>2]=g?1:2;z=d,A=v[cp(d+1196|0,d+16|0)>>2],v[z+1196>>2]=A}v[a+480260>>2]=452;v[a+480264>>2]=3424;v[a+480228>>2]=64;v[a+480208>>2]=v[a+480208>>2]|2097152;e=d+1048|0;_j(e,3,d+1200|0);f=d+16|0;Bc(f,e);Eb(a+1298268|0,f);vb(f);k=0;xh(a,0);y=v[b+8>>2];u[d+1046>>1]=0;g:{h:{if(!m){break h}while(1){f=Sb(p);z=d,A=iC(Vb(f),Zb(f),d+1046|0),v[z+16>>2]=A;z=d,A=Zb(f),v[z+1048>>2]=A;f=d+16|0;e=Gb(f,d+1048|0);sV(b,f);if(e){k=hC(d+16|0,0)+k|0;if(k>>>0>512){break g}}j=0;f=0;o=0;while(1){r=rV(d+16|0,j);h=0;while(1){e=f;l=Fe(r,h);q=w[ic(l,2)|0]&15;i=w[ic(l,3)|0];f=0;i:{if(!(e&255)|(w[l|0]|w[l+1|0]<<8|(w[l+2|0]<<16|w[l+3|0]<<24))){break i}f=e+1|0;if((f&255)>>>0<33){break i}v[d+1196>>2]=6}j:{k:{l:{switch(q-1|0){case 0:case 1:e=v[d+1196>>2];if((e|0)==1&i>>>0>=32){break k}l=(q|0)!=1;if(!(l|!i|i>>>0>2)){v[d+1048>>2]=2;z=d,A=v[cp(d+1196|0,d+1048|0)>>2],v[z+1196>>2]=A;break j}if(l|(i|0)!=55&(i|0)!=71){break j}if((e|0)<=2){break k}break j;case 10:v[d+1196>>2]=6;break j;case 11:case 12:case 13:v[d+1048>>2]=2;z=d,A=v[cp(d+1196|0,d+1048|0)>>2],v[z+1196>>2]=A;if((q|0)!=13){break j}o=((i|j)!=0)+o|0;f=1;break j;case 14:break l;default:break j}}v[d+1048>>2]=3;z=d,A=v[cp(d+1196|0,d+1048|0)>>2],v[z+1196>>2]=A;break j}v[d+1196>>2]=g}h=h+1|0;if((h|0)!=4){continue}break}j=j+1|0;if((j|0)!=64){continue}break}if((o-1&255)>>>0<2){v[d+1196>>2]=6}n=(o&255)+n|0;f=x[d+1046>>1]+1|0;u[d+1046>>1]=f;if(m>>>0>(f&65535)>>>0){continue}break}if(v[d+1196>>2]!=6|m+32>>>0>=n>>>0){break h}v[d+1196>>2]=5}Wc(b,y);o=c&1;if(o){Ag(a+484344|0,m)}if(m){l=a+484344|0;j=0;while(1){sV(b,d+16|0);m:{if(!o){break m}if(!wh(l,j&65535,64)){break m}v[d+1048>>2]=0;n=0;while(1){q=Yc(_b(l,j),n,0);p=rV(d+16|0,n);i=0;while(1){f=Fe(p,i);f=w[f|0]|w[f+1|0]<<8|(w[f+2|0]<<16|w[f+3|0]<<24);v[d+8>>2]=f;v[d+12>>2]=f;e=q+B(i,6)|0;gr(d+8|0,e);n:{o:{p:{q:{r:{s:{t:{f=w[e+5|0];if(f){h=e+3|0;g=(d+1048|0)+i|0;k=w[e+3|0];if((k|0)!=14){break t}t[g|0]=0;break r}t[(d+1048|0)+i|0]=0;k=w[e+3|0];if(!k){break n}h=e+3|0;break s}g=w[g|0];if(!g){break s}u:{if(g>>>0>=16){t[e+2|0]=3;g=g>>>4|0;break u}t[e+2|0]=4}t[e+4|0]=g}v:{w:{switch(k-12|0){case 1:g=v[d+1196>>2];if((g|0)==6){break v}k=10;t[h|0]=10;break p;case 0:f=f&127;t[e+5|0]=f;k=12;break q;case 2:break r;case 3:break w;default:break q}}k=15;f=f&15;t[e+5|0]=f;break q}t[e+5|0]=0;break o}if(f>>>0<=1&v[d+1196>>2]>3){break o}k=10;t[h|0]=10;t[(d+1048|0)+i|0]=f}g=v[d+1196>>2]}if((g|0)>1){break o}x:{y:{z:{switch(k|0){case 0:if(f>>>0>2){break y}break;case 2:break x;case 1:break y;default:break z}}t[h|0]=0;break n}t[h|0]=1;break n}g=f&15;if(g){t[h|0]=2;t[e+5|0]=g;break n}if(f>>>0<16){break n}t[h|0]=3;t[e+5|0]=f>>>4;break n}Of(e)}i=i+1|0;if((i|0)!=4){continue}break}n=n+1|0;if((n|0)!=64){continue}break}}j=j+1|0;if((m|0)!=(j|0)){continue}break}}h=18726;f=v[d+1196>>2];if(f>>>0<7){h=v[(f<<2)+33208>>2]}f=d+16|0;e=Tb(f,5437);Eb(a+1298304|0,e);vb(e);f=Tb(f,8043);Eb(a+1298316|0,f);vb(f);Xc(a+1298328|0,h);v[a+1298364>>2]=2;h=1;if(!(c&2)){break a}i=1;while(1){c=B(i,104)+a|0;f=c+484384|0;Rb(b,v[f>>2]);e=v[f>>2];v[f>>2]=0;f=c+484380|0;v[f>>2]=v[f>>2]-e;c=c+484388|0;v[c>>2]=v[c>>2]-e;c=d+16|0;Rc(c,8,1,1,0);Dg(c,f,b);i=i+1|0;if((i|0)!=16){continue}break}break a}h=0}gb=d+1824|0;return h|0}function dy(a,b,c,d,e,f,g){var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,x=0,y=0,z=0,C=0,D=0;h=gb-80|0;gb=h;v[h+76>>2]=b;z=h+55|0;x=h+56|0;b=0;a:{b:{c:while(1){d:{if((p|0)<0){break d}if((2147483647-p|0)<(b|0)){v[115137]=61;p=-1;break d}p=b+p|0}e:{f:{k=v[h+76>>2];b=k;i=w[b|0];if(i){while(1){g:{i=i&255;h:{if(!i){i=b;break h}if((i|0)!=37){break g}i=b;while(1){if(w[b+1|0]!=37){break h}j=b+2|0;v[h+76>>2]=j;i=i+1|0;m=w[b+2|0];b=j;if((m|0)==37){continue}break}}b=i-k|0;if(a){tf(a,k,b)}if(b){continue c}q=-1;i=1;j=h;r=!Qh(t[v[h+76>>2]+1|0]);b=v[h+76>>2];if(!(r|w[b+2|0]!=36)){q=t[b+1|0]-48|0;y=1;i=3}b=i+b|0;v[j+76>>2]=b;s=0;l=t[b|0];j=l-32|0;i:{if(j>>>0>31){i=b;break i}i=b;j=1<<j;if(!(j&75913)){break i}while(1){i=b+1|0;v[h+76>>2]=i;s=j|s;l=t[b+1|0];j=l-32|0;if(j>>>0>=32){break i}b=i;j=1<<j;if(j&75913){continue}break}}j:{if((l|0)==42){j=h;k:{l:{if(!Qh(t[i+1|0])){break l}b=v[h+76>>2];if(w[b+2|0]!=36){break l}v[((t[b+1|0]<<2)+e|0)-192>>2]=10;o=v[((t[b+1|0]<<3)+d|0)-384>>2];y=1;b=b+3|0;break k}if(y){break b}y=0;o=0;if(a){b=v[c>>2];v[c>>2]=b+4;o=v[b>>2]}b=v[h+76>>2]+1|0}v[j+76>>2]=b;if((o|0)>=0){break j}o=0-o|0;s=s|8192;break j}o=UI(h+76|0);if((o|0)<0){break b}b=v[h+76>>2]}m=-1;m:{if(w[b|0]!=46){break m}if(w[b+1|0]==42){n:{if(!Qh(t[b+2|0])){break n}b=v[h+76>>2];if(w[b+3|0]!=36){break n}v[((t[b+2|0]<<2)+e|0)-192>>2]=10;m=v[((t[b+2|0]<<3)+d|0)-384>>2];b=b+4|0;v[h+76>>2]=b;break m}if(y){break b}if(a){b=v[c>>2];v[c>>2]=b+4;m=v[b>>2]}else{m=0}b=v[h+76>>2]+2|0;v[h+76>>2]=b;break m}v[h+76>>2]=b+1;m=UI(h+76|0);b=v[h+76>>2]}i=0;while(1){r=i;n=-1;if(t[b|0]-65>>>0>57){break a}l=b+1|0;v[h+76>>2]=l;i=t[b|0];b=l;i=w[(i+B(r,58)|0)+73567|0];if(i-1>>>0<8){continue}break}o:{p:{if((i|0)!=19){if(!i){break a}if((q|0)>=0){v[(q<<2)+e>>2]=i;b=(q<<3)+d|0;i=v[b+4>>2];v[h+64>>2]=v[b>>2];v[h+68>>2]=i;break p}if(!a){break e}TI(h- -64|0,i,c,g);l=v[h+76>>2];break o}if((q|0)>=0){break a}}b=0;if(!a){continue c}}j=s&-65537;i=s&8192?j:s;n=0;q=2378;s=x;q:{r:{s:{t:{u:{v:{w:{x:{y:{z:{A:{B:{C:{D:{E:{F:{b=t[l-1|0];b=r?(b&15)==3?b&-33:b:b;switch(b-88|0){case 11:break q;case 9:case 13:case 14:case 15:break r;case 27:break w;case 12:case 17:break z;case 23:break A;case 0:case 32:break B;case 24:break C;case 22:break D;case 29:break E;case 1:case 2:case 3:case 4:case 5:case 6:case 7:case 8:case 10:case 16:case 18:case 19:case 20:case 21:case 25:case 26:case 28:case 30:case 31:break f;default:break F}}G:{switch(b-65|0){case 0:case 4:case 5:case 6:break r;case 2:break u;case 1:case 3:break f;default:break G}}if((b|0)==83){break v}break f}l=v[h+64>>2];k=v[h+68>>2];q=2378;break y}b=0;H:{switch(r&255){case 0:v[v[h+64>>2]>>2]=p;continue c;case 1:v[v[h+64>>2]>>2]=p;continue c;case 2:i=v[h+64>>2];v[i>>2]=p;v[i+4>>2]=p>>31;continue c;case 3:u[v[h+64>>2]>>1]=p;continue c;case 4:t[v[h+64>>2]]=p;continue c;case 6:v[v[h+64>>2]>>2]=p;continue c;case 7:break H;default:continue c}}i=v[h+64>>2];v[i>>2]=p;v[i+4>>2]=p>>31;continue c}m=m>>>0>8?m:8;i=i|8;b=120}j=x;C=b&32;r=v[h+68>>2];k=r;l=v[h+64>>2];if(k|l){while(1){j=j-1|0;t[j|0]=C|w[(l&15)+74096|0];D=!k&l>>>0>15|(k|0)!=0;r=k;k=k>>>4|0;l=(r&15)<<28|l>>>4;if(D){continue}break}}k=j;if(!(i&8)|!(v[h+64>>2]|v[h+68>>2])){break x}q=(b>>>4|0)+2378|0;n=2;break x}b=x;j=v[h+68>>2];k=j;l=v[h+64>>2];if(j|l){while(1){b=b-1|0;t[b|0]=l&7|48;r=!k&l>>>0>7|(k|0)!=0;j=k;k=j>>>3|0;l=(j&7)<<29|l>>>3;if(r){continue}break}}k=b;if(!(i&8)){break x}b=x-k|0;m=(b|0)<(m|0)?m:b+1|0;break x}b=v[h+68>>2];k=b;l=v[h+64>>2];if((b|0)<0){k=0-(k+((l|0)!=0)|0)|0;l=0-l|0;v[h+64>>2]=l;v[h+68>>2]=k;n=1;q=2378;break y}if(i&2048){n=1;q=2379;break y}n=i&1;q=n?2380:2378}k=ao(l,k,x)}i=(m|0)>=0?i&-65537:i;b=v[h+68>>2];j=b;l=v[h+64>>2];if(!((l|0)!=0|(b|0)!=0|m)){m=0;k=x;break f}b=!(j|l)+(x-k|0)|0;m=(b|0)<(m|0)?m:b;break f}b=v[h+64>>2];k=b?b:14146;b=it(k,0,m);s=b?b:k+m|0;i=j;m=b?b-k|0:m;break f}if(m){b=v[h+64>>2];break t}b=0;cg(a,32,o,0,i);break s}v[h+12>>2]=0;v[h+8>>2]=v[h+64>>2];b=h+8|0;v[h+64>>2]=b;m=-1}j=b;b=0;I:{while(1){k=v[j>>2];if(!k){break I}k=YI(h+4|0,k);l=(k|0)<0;if(!(l|k>>>0>m-b>>>0)){j=j+4|0;b=b+k|0;if(m>>>0>b>>>0){continue}break I}break}n=-1;if(l){break a}}cg(a,32,o,b,i);if(!b){b=0;break s}j=0;l=v[h+64>>2];while(1){k=v[l>>2];if(!k){break s}k=YI(h+4|0,k);j=k+j|0;if((j|0)>(b|0)){break s}tf(a,h+4|0,k);l=l+4|0;if(b>>>0>j>>>0){continue}break}}cg(a,32,o,b,i^8192);b=(b|0)<(o|0)?o:b;continue c}b=kb[f|0](a,A[h+64>>3],o,m,i,b)|0;continue c}t[h+55|0]=v[h+64>>2];m=1;k=z;i=j;break f}j=b+1|0;v[h+76>>2]=j;i=w[b+1|0];b=j;continue}}n=p;if(a){break a}if(!y){break e}b=1;while(1){a=v[(b<<2)+e>>2];if(a){TI((b<<3)+d|0,a,c,g);n=1;b=b+1|0;if((b|0)!=10){continue}break a}break}n=1;if(b>>>0>9){break a}while(1){n=1;b=b+1|0;if((b|0)==10){break a}n=-1;if(!v[(b<<2)+e>>2]){continue}break}break a}l=s-k|0;m=(l|0)>(m|0)?l:m;j=m+n|0;b=(j|0)>(o|0)?j:o;cg(a,32,b,j,i);tf(a,q,n);cg(a,48,b,j,i^65536);cg(a,48,m,l,0);tf(a,k,l);cg(a,32,b,j,i^8192);continue}break}n=0;break a}n=-1}gb=h+80|0;return n}function pL(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0;e=gb-448|0;gb=e;a:{if(rk(b)){break a}f=w[vl(b)|0];if((f|0)==33){d=1}else{if((f|0)!=63){break a}d=0}Kl(e+184|0,b,v[b+4>>2]-1|0);f=v[e+188>>2];v[b>>2]=v[e+184>>2];v[b+4>>2]=f}f=e+184|0;Ld(f);g=v[e+184>>2];Ld(e+416|0);h=ul(g,v[e+420>>2],b);Ld(f);f=v[b>>2];g=v[b+4>>2];b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{if((h|0)==v[e+188>>2]){v[e+440>>2]=f;v[e+444>>2]=g;a=uc(e+432|0,18726);f=v[e+444>>2];v[e+16>>2]=v[e+440>>2];v[e+20>>2]=f;f=v[a+4>>2];v[e+8>>2]=v[a>>2];v[e+12>>2]=f;if(Gc(e+16|0,e+8|0)){a=ba(8)|0;v[22656]=0;c=Q(2057,e+416|0,c|0)|0;b=v[22656];v[22656]=0;if((b|0)!=1){v[22656]=0;U(2037,e+184|0,14728,c|0);b=v[22656];v[22656]=0;if((b|0)==1){break i}rc(a,e+184|0);v[22656]=0;U(186,a|0,54952,1936);a=v[22656];v[22656]=0;if((a|0)!=1){break b}b=P()|0;O()|0;vb(e+184|0);vb(c);break c}b=P()|0;O()|0;break d}if(!d){break k}a=ba(8)|0;v[22656]=0;f=Q(2057,e+384|0,b|0)|0;b=v[22656];v[22656]=0;l:{m:{n:{o:{p:{q:{r:{s:{if((b|0)!=1){v[22656]=0;U(2037,e+400|0,14764,f|0);b=v[22656];v[22656]=0;if((b|0)==1){break s}v[22656]=0;R(2054,e+416|0,e+400|0);b=v[22656];v[22656]=0;d=1;if((b|0)==1){break r}v[22656]=0;c=Q(2057,e+368|0,c|0)|0;b=v[22656];v[22656]=0;if((b|0)==1){break q}v[22656]=0;U(2058,e+184|0,e+416|0,c|0);b=v[22656];v[22656]=0;if((b|0)==1){break p}rc(a,e+184|0);v[22656]=0;U(186,a|0,54952,1936);b=v[22656];v[22656]=0;if((b|0)!=1){break b}b=P()|0;O()|0;vb(e+184|0);d=0;break o}b=P()|0;O()|0;break l}b=P()|0;O()|0;vb(f);break l}b=P()|0;O()|0;break m}b=P()|0;O()|0;break n}b=P()|0;O()|0}vb(c)}vb(e+416|0)}vb(e+400|0);vb(f);if(!d){break c}}ca(a|0);break c}v[e+360>>2]=f;v[e+364>>2]=g;d=uc(e+352|0,18726);f=v[e+364>>2];v[e+176>>2]=v[e+360>>2];v[e+180>>2]=f;f=v[d+4>>2];v[e+168>>2]=v[d>>2];v[e+172>>2]=f;if(Gc(e+176|0,e+168|0)){a=ba(8)|0;v[22656]=0;c=Q(2057,e+416|0,c|0)|0;b=v[22656];v[22656]=0;if((b|0)!=1){v[22656]=0;U(2037,e+184|0,14728,c|0);b=v[22656];v[22656]=0;if((b|0)==1){break h}rc(a,e+184|0);v[22656]=0;U(186,a|0,54952,1936);a=v[22656];v[22656]=0;if((a|0)!=1){break b}b=P()|0;O()|0;vb(e+184|0);vb(c);break c}b=P()|0;O()|0;break e}d=v[b+4>>2];v[e+344>>2]=v[b>>2];v[e+348>>2]=d;d=uc(e+336|0,9597);f=v[e+348>>2];v[e+160>>2]=v[e+344>>2];v[e+164>>2]=f;f=v[d+4>>2];v[e+152>>2]=v[d>>2];v[e+156>>2]=f;if(Gc(e+160|0,e+152|0)){b=v[c+4>>2];d=v[c>>2];v[e+328>>2]=d;v[e+332>>2]=b;f=uc(e+320|0,2693);g=v[e+332>>2];v[e+64>>2]=v[e+328>>2];v[e+68>>2]=g;g=v[f+4>>2];v[e+56>>2]=v[f>>2];v[e+60>>2]=g;if(Gc(e- -64|0,e+56|0)){v[a+52>>2]=0;break k}v[e+312>>2]=d;v[e+316>>2]=b;f=uc(e+304|0,8575);g=v[e+316>>2];v[e+48>>2]=v[e+312>>2];v[e+52>>2]=g;g=v[f+4>>2];v[e+40>>2]=v[f>>2];v[e+44>>2]=g;if(Gc(e+48|0,e+40|0)){v[a+52>>2]=1;break k}v[e+296>>2]=d;v[e+300>>2]=b;b=uc(e+288|0,6363);d=v[e+300>>2];v[e+32>>2]=v[e+296>>2];v[e+36>>2]=d;d=v[b+4>>2];v[e+24>>2]=v[b>>2];v[e+28>>2]=d;if(Gc(e+32|0,e+24|0)){v[a+52>>2]=2;break k}a=ba(8)|0;v[22656]=0;c=Q(2057,e+416|0,c|0)|0;b=v[22656];v[22656]=0;if((b|0)!=1){v[22656]=0;U(2037,e+184|0,11823,c|0);b=v[22656];v[22656]=0;if((b|0)==1){break g}rc(a,e+184|0);v[22656]=0;U(186,a|0,54952,1936);a=v[22656];v[22656]=0;if((a|0)!=1){break b}b=P()|0;O()|0;vb(e+184|0);vb(c);break c}b=P()|0;O()|0;break f}d=v[b+4>>2];v[e+280>>2]=v[b>>2];v[e+284>>2]=d;b=uc(e+272|0,8812);d=v[e+284>>2];v[e+144>>2]=v[e+280>>2];v[e+148>>2]=d;d=v[b+4>>2];v[e+136>>2]=v[b>>2];v[e+140>>2]=d;if(!Gc(e+144|0,e+136|0)){break k}d=v[c+4>>2];c=v[c>>2];v[e+264>>2]=c;v[e+268>>2]=d;b=uc(e+256|0,12689);f=v[e+268>>2];v[e+128>>2]=v[e+264>>2];v[e+132>>2]=f;f=v[b+4>>2];v[e+120>>2]=v[b>>2];v[e+124>>2]=f;b=0;t:{if(Gc(e+128|0,e+120|0)){break t}v[e+248>>2]=c;v[e+252>>2]=d;b=uc(e+240|0,12694);f=v[e+252>>2];v[e+112>>2]=v[e+248>>2];v[e+116>>2]=f;f=v[b+4>>2];v[e+104>>2]=v[b>>2];v[e+108>>2]=f;b=1;if(Gc(e+112|0,e+104|0)){break t}v[e+232>>2]=c;v[e+236>>2]=d;b=uc(e+224|0,9902);f=v[e+236>>2];v[e+96>>2]=v[e+232>>2];v[e+100>>2]=f;f=v[b+4>>2];v[e+88>>2]=v[b>>2];v[e+92>>2]=f;b=2;if(Gc(e+96|0,e+88|0)){break t}v[e+216>>2]=c;v[e+220>>2]=d;b=uc(e+208|0,6427);c=v[e+220>>2];v[e+80>>2]=v[e+216>>2];v[e+84>>2]=c;c=v[b+4>>2];v[e+72>>2]=v[b>>2];v[e+76>>2]=c;b=3;if(Gc(e+80|0,e+72|0)){break t}a=ba(8)|0;v[22656]=0;c=Q(70,e+184|0,8848)|0;b=v[22656];v[22656]=0;if((b|0)==1){break j}rc(a,c);v[22656]=0;U(186,a|0,54952,1936);a=v[22656];v[22656]=0;if((a|0)!=1){break b}b=P()|0;O()|0;vb(c);break c}v[a+56>>2]=b;b=a+24|0;if(!v[v[b>>2]+24668>>2]){break k}c=v[b>>2];d=c+24664|0;f=v[d+4>>2];v[e+200>>2]=v[d>>2];v[e+204>>2]=f;d=c+24656|0;f=v[d+4>>2];v[e+192>>2]=v[d>>2];v[e+196>>2]=f;d=v[c+24652>>2];v[e+184>>2]=v[c+24648>>2];v[e+188>>2]=d;i=e,j=FK(v[a+56>>2]),v[i+204>>2]=j;if(!Qy(e+184|0,v[b>>2]+24648|0)){break k}_z(v[b>>2],e+184|0)}gb=e+448|0;return}b=P()|0;O()|0;ca(a|0);break c}b=P()|0;O()|0;vb(c);break d}b=P()|0;O()|0;vb(c);break e}b=P()|0;O()|0;vb(c)}ca(a|0);break c}ca(a|0);break c}ca(a|0)}S(b|0)}L()}function tJ(a,b,c,d,e,f){var g=0,h=C(0),i=C(0),j=0,k=C(0),l=C(0),m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=C(0),v=0,w=0,x=0,y=0,A=C(0),D=0,E=0,F=0,G=C(0),H=C(0),I=C(0),J=C(0),K=C(0),L=C(0),M=C(0),N=C(0),O=0,P=0,Q=0,R=0;if((d|0)>0){while(1){D=B(v,2304)+b|0;p=c;x=0;s=gb-128|0;while(1){m=D+(x<<2)|0;o=0;n=s;j=n;while(1){h=z[B(15-o|0,72)+m>>2];w=B(o,72)+m|0;i=z[w+1152>>2];l=C(h+i);k=z[w>>2];t=z[B(31-o|0,72)+m>>2];A=C(k+t);z[j>>2]=l+A;w=B(o,12);h=C(C(h-i)*z[w+68304>>2]);i=C(C(k-t)*z[w+68308>>2]);z[j+64>>2]=h+i;k=C(A-l);l=z[w+68312>>2];z[j+32>>2]=k*l;z[j+96>>2]=C(i-h)*l;j=j+4|0;o=o+1|0;if((o|0)!=8){continue}break}o=0;while(1){l=z[n+8>>2];k=z[n+20>>2];i=C(l+k);t=z[n+4>>2];A=z[n+24>>2];G=C(t+A);h=C(i+G);H=z[n+12>>2];I=z[n+16>>2];J=C(H+I);K=z[n>>2];L=z[n+28>>2];M=C(K+L);N=C(J+M);z[n>>2]=h+N;z[n+16>>2]=C(N-h)*C(.7071067690849304);h=C(M-J);i=C(C(h+C(G-i))*C(.7071067690849304));z[n+24>>2]=C(h-i)*C(1.3065630197525024);z[n+8>>2]=C(h+i)*C(.5411961078643799);h=C(K-L);l=C(l-k);k=C(t-A);t=C(C(l+k)*C(.7071067690849304));i=C(h+t);k=C(k+h);l=C(C(C(H-I)+l)-C(k*C(.1989123672246933)));k=C(k+C(l*C(.3826834261417389)));z[n+28>>2]=C(i-k)*C(2.562915563583374);z[n+4>>2]=C(i+k)*C(.509795606136322);h=C(h-t);i=C(l-C(k*C(.1989123672246933)));z[n+20>>2]=C(h+i)*C(.8999761939048767);z[n+12>>2]=C(h-i)*C(.601344883441925);n=n+32|0;o=o+1|0;if((o|0)!=4){continue}break}o=0;l=z[s+32>>2];h=z[s+96>>2];k=z[s+64>>2];while(1){z[m>>2]=z[s+(o<<2)>>2];n=m;o=o+1|0;m=s+(o<<2)|0;i=z[m+96>>2];z[n+72>>2]=C(h+k)+i;k=l;l=z[m+32>>2];z[n+144>>2]=k+l;k=z[m- -64>>2];z[n+216>>2]=i+C(h+k);m=n+288|0;h=i;if((o|0)!=7){continue}break}z[n+288>>2]=z[s+28>>2];h=z[s+124>>2];z[n+360>>2]=z[s+92>>2]+h;i=z[s+60>>2];z[n+504>>2]=h;z[n+432>>2]=i;x=x+1|0;if((p|0)!=(x|0)){continue}break}v=v+1|0;if((v|0)!=(d|0)){continue}break}}F=hc(f,a,3840);P=d<<5;v=0;while(1){m=gb-32|0;gb=m;o=(v<<8)+F|0;x=(v<<2)+b|0;z[o+4080>>2]=z[x+1152>>2];n=d;f=n-1|0;w=x+B(f,2304)|0;z[o+4084>>2]=z[w+1152>>2];z[o+4088>>2]=z[x>>2];z[o+4092>>2]=z[w>>2];z[o+4336>>2]=z[x+1156>>2];z[o+4340>>2]=z[w+1156>>2];z[o+4344>>2]=z[x+4>>2];z[o+4348>>2]=z[w+4>>2];D=(B(v,P)<<1)+e|0;E=D+(f<<1)|0;st(E,n,o+244|0);f=n<<6;st(f+E|0,n,o+500|0);st(D,n,o+240|0);st(f+D|0,n,o+496|0);O=o+3840|0;p=68400;f=14;while(1){s=f;q=f<<4;j=q+O|0;g=B(31-f|0,72);l=z[g+x>>2];z[j>>2]=l;z[j+4>>2]=z[g+w>>2];g=g|4;z[j+8>>2]=z[g+x>>2];z[j+12>>2]=z[g+w>>2];g=B(f,72);r=g+76|0;z[j+256>>2]=z[r+x>>2];z[j+260>>2]=z[r+w>>2];g=g+72|0;z[j-248>>2]=z[g+x>>2];z[j-244>>2]=z[g+w>>2];h=z[p>>2];i=z[p+4>>2];q=o+q|0;t=z[q>>2];k=C(C(l*h)-C(i*t));z[m+16>>2]=k;l=C(C(i*l)+C(h*t));z[m>>2]=l;r=f<<2;f=1;while(1){g=f<<2;t=z[g+j>>2];A=z[g+q>>2];z[g+(m+16|0)>>2]=C(h*t)-C(i*A);z[g+m>>2]=C(i*t)+C(h*A);f=f+1|0;if((f|0)!=4){continue}break}j=(r<<2)+O|0;q=j-3584|0;r=j-256|0;h=z[p+12>>2];i=z[p+8>>2];f=0;while(1){g=f<<2;t=z[g+q>>2];A=z[g+r>>2];z[g+(m+16|0)>>2]=C(C(h*t)-C(i*A))+k;z[g+m>>2]=l+C(C(h*A)+C(i*t));f=f+1|0;if((f|0)!=4){g=f<<2;k=z[g+(m+16|0)>>2];l=z[g+m>>2];continue}break}q=j-3328|0;r=j-512|0;h=z[p+20>>2];i=z[p+16>>2];f=0;while(1){g=f<<2;y=g+m|0;l=z[g+r>>2];k=z[g+q>>2];z[y>>2]=z[y>>2]+C(C(h*l)+C(i*k));g=g+(m+16|0)|0;z[g>>2]=C(C(i*l)-C(h*k))+z[g>>2];f=f+1|0;if((f|0)!=4){continue}break}q=j-3072|0;r=j-768|0;h=z[p+28>>2];i=z[p+24>>2];f=0;while(1){g=f<<2;y=g+m|0;l=z[g+r>>2];k=z[g+q>>2];z[y>>2]=z[y>>2]+C(C(h*l)+C(i*k));g=g+(m+16|0)|0;z[g>>2]=C(C(h*k)-C(i*l))+z[g>>2];f=f+1|0;if((f|0)!=4){continue}break}q=j-2816|0;r=j-1024|0;h=z[p+36>>2];i=z[p+32>>2];f=0;while(1){g=f<<2;y=g+m|0;l=z[g+r>>2];k=z[g+q>>2];z[y>>2]=z[y>>2]+C(C(h*l)+C(i*k));g=g+(m+16|0)|0;z[g>>2]=C(C(i*l)-C(h*k))+z[g>>2];f=f+1|0;if((f|0)!=4){continue}break}q=j-2560|0;r=j-1280|0;h=z[p+44>>2];i=z[p+40>>2];f=0;while(1){g=f<<2;y=g+m|0;l=z[g+r>>2];k=z[g+q>>2];z[y>>2]=z[y>>2]+C(C(h*l)+C(i*k));g=g+(m+16|0)|0;z[g>>2]=C(C(h*k)-C(i*l))+z[g>>2];f=f+1|0;if((f|0)!=4){continue}break}q=j-2304|0;r=j-1536|0;h=z[p+52>>2];i=z[p+48>>2];f=0;while(1){g=f<<2;y=g+m|0;l=z[g+r>>2];k=z[g+q>>2];z[y>>2]=z[y>>2]+C(C(h*l)+C(i*k));g=g+(m+16|0)|0;z[g>>2]=C(C(i*l)-C(h*k))+z[g>>2];f=f+1|0;if((f|0)!=4){continue}break}g=j-2048|0;q=j-1792|0;h=z[p+60>>2];i=z[p+56>>2];f=0;while(1){j=f<<2;r=j+m|0;l=z[j+q>>2];k=z[g+j>>2];z[r>>2]=z[r>>2]+C(C(h*l)+C(i*k));j=j+(m+16|0)|0;z[j>>2]=C(C(h*k)-C(i*l))+z[j>>2];f=f+1|0;if((f|0)!=4){continue}break}f=B(n,15-s|0)<<1;Q=f+E|0,R=zj(z[m+20>>2]),u[Q>>1]=R;j=B(n,s+17|0)<<1;Q=j+E|0,R=zj(z[m+4>>2]),u[Q>>1]=R;Q=f+D|0,R=zj(z[m+16>>2]),u[Q>>1]=R;Q=j+D|0,R=zj(z[m>>2]),u[Q>>1]=R;f=B(n,47-s|0)<<1;Q=f+E|0,R=zj(z[m+28>>2]),u[Q>>1]=R;j=B(n,s+49|0)<<1;Q=j+E|0,R=zj(z[m+12>>2]),u[Q>>1]=R;Q=f+D|0,R=zj(z[m+24>>2]),u[Q>>1]=R;Q=j+D|0,R=zj(z[m+8>>2]),u[Q>>1]=R;f=s-1|0;p=p- -64|0;if(s){continue}break}gb=m+32|0;v=v+2|0;if((v|0)<(c|0)){continue}break}b=c<<6;a:{if((d|0)==1){v=0;while(1){z[(v<<2)+a>>2]=z[(b+v<<2)+F>>2];c=v>>>0<958;v=v+2|0;if(c){continue}break}break a}hc(a,(b<<2)+F|0,3840)}}function oka(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,y=0,z=0,A=0;g=gb-208|0;gb=g;vc(b);a:{b:{c:{d:{e:{if(!dD(b,g+160|0)){break e}if(!oT(g+160|0)){break e}if(!c){i=1;break e}if(!Pb(b,Qc(nT(g+160|0),jb))){break e}Gd(a,128);e=g+144|0;Ke(e,2,g+175|0);d=g+72|0;Bc(d,e);Eb(a+1298268|0,d);vb(d);j=Tb(d,5600);Eb(a+1298304|0,j);vb(j);j=Tb(d,3148);Eb(a+1298316|0,j);vb(j);e=Tb(e,14645);v[22656]=0;U(946,d|0,e|0,v[(w[g+174|0]<<2)+33180>>2]);d=v[22656];v[22656]=0;i=1;if((d|0)==1){break b}d=g+72|0;Eb(a+1298328|0,d);vb(d);vb(e);v[a+480208>>2]=12;v[a+1298364>>2]=5;tB(a+1298292|0,b,w[g+207|0]<<5,32,0);z=a,A=Ae(b),u[z+480190>>1]=A;if(x[a+480190>>1]){k=1;while(1){f:{if(w[g+174|0]>=52){d=g+72|0;if(!lY(b,d)){qD(d)}break f}e=gb-48|0;gb=e;v[e+44>>2]=64;v[e+24>>2]=66;d=b;j=v[Fb(e+44|0,e+24|0)>>2];if(!Pb(d,j)){j=nf(d)}f=e+24|0;h=g+72|0;Lv(f,h);m=wd(e+32|0,v[f>>2],j);o=v[m+4>>2];v[e+8>>2]=v[m>>2];v[e+12>>2]=o;cc(e+16|0,d,e+8|0);Lv(f,h);Qb(v[e+24>>2]+j|0,0,66-j|0);Rb(d,v[e+44>>2]);gb=e+48|0;d=w[g+134|0]|w[g+135|0]<<8;t[g+136|0]=d;t[g+137|0]=d>>>8;t[g+134|0]=171;t[g+135|0]=32}j=gb-32|0;gb=j;e=(B(i,104)+a|0)+484380|0;ud(e,0);Ku(e);h=g+72|0;d=h;Mk(j,2,d+32|0);f=j+16|0;Bc(f,j);v[22656]=0;Q(303,e+43|0,f|0)|0;f=v[22656];v[22656]=0;g:{if((f|0)!=1){vb(j+16|0);h:{if((w[d+56|0]|w[d+57|0]<<8|(w[d+58|0]<<16|w[d+59|0]<<24))>>>0<=(w[d+52|0]|w[d+53|0]<<8|(w[d+54|0]<<16|w[d+55|0]<<24))>>>0){break h}v[e>>2]=(w[d+56|0]|w[d+57|0]<<8|(w[d+58|0]<<16|w[d+59|0]<<24))-(w[d+52|0]|w[d+53|0]<<8|(w[d+54|0]<<16|w[d+55|0]<<24));v[e+12>>2]=w[d+44|0]|w[d+45|0]<<8|(w[d+46|0]<<16|w[d+47|0]<<24);v[j+16>>2]=w[d+48|0]|w[d+49|0]<<8|(w[d+50|0]<<16|w[d+51|0]<<24);z=e,A=v[Fb(j+16|0,e)>>2],v[z+16>>2]=A;u[e+30>>1]=w[d+60|0];v[e+24>>2]=w[d+62|0]|w[d+63|0]<<8;f=d- -64|0;if(w[f|0]|w[f+1|0]<<8){Qo(e,+((w[f|0]|w[f+1|0]<<8)<<16>>16)/393216)}if(w[d+61|0]&8){u[e+34>>1]=x[e+34>>1]|8}if(w[d+61|0]&16){u[e+34>>1]=x[e+34>>1]|16}if(!(w[d+61|0]&4)){break h}u[e+34>>1]=x[e+34>>1]|1;v[e+12>>2]=v[e+12>>2]>>>1;v[e+16>>2]=v[e+16>>2]>>>1}gb=j+32|0;break g}a=P()|0;O()|0;vb(j+16|0);S(a|0);L()}d=g+56|0;Ke(d,2,h);e=g+144|0;Bc(e,d);v[22656]=0;Q(301,((i<<5)+a|0)+946304|0,e|0)|0;d=v[22656];v[22656]=0;if((d|0)==1){break c}vb(g+144|0);k=k+1|0;i=k&65535;if(i>>>0<=x[a+480190>>1]){continue}break}}kp(Sb(a+484360|0),b,256,255,254);i=0;d=Ae(b);if(d>>>0>=127){break e}u[a+480188>>1]=d+1;d=Ae(b);r=d+1|0;if(x[a+480188>>1]){while(1){e=(i<<5)+a|0;We(e+480280|0);h=e+480284|0;i:{if(w[g+174|0]>=51){e=(Ae(b)<<4|8)&248;break i}e=i&1?192:64}u[h>>1]=e;i=i+1|0;if(i>>>0<x[a+480188>>1]){continue}break}}m=a+484344|0;Ag(m,r);i=0;k=0;while(1){e=k&65535;if(!wh(m,e,64)){break e}k=k+1|0;if(d>>>0>e>>>0){continue}break}if(x[a+480188>>1]){while(1){j=bj(g+72|0);o=0;while(1){if(Pb(b,5)){k=0;i=Yc(_b(m,o),0,p&65535);while(1){l=w[g+174|0];f=gb-16|0;gb=f;q=1;s=64-k|0;e=b;h=Ae(e);if((h|0)==252){q=Ae(e);h=Ae(e)}d=j;t[d|0]=(h-1&255)>>>0<60?h+36|0:0;h=f+8|0;wn(h,e);e=qd(h);n=Ve(h);y=ej(h);t[d+1|0]=w[h|0];t[f+7|0]=w[e|0]&15;t[f+6|0]=w[e|0]>>>4;t[f+5|0]=w[n|0];t[f+4|0]=w[y|0];lT(f+7|0,f+5|0,l);lT(f+6|0,f+4|0,l);h=w[f+7|0];l=(h|0)!=10;e=w[f+6|0];j:{if(!(l|(e|0)!=10)){h=w[f+5|0];e=w[f+4|0];t[d+3|0]=10;h=h|e<<8;t[d+5|0]=h>>>6;if(h>>>0<16384){break j}t[d+2|0]=15;t[d+4|0]=e>>>6;break j}k:{l:{m:{n:{if(!l){l=w[f+5|0];n=l<<2;z=f,A=Bn(n),t[z+5|0]=A;if(l>>>0<64){break n}if(Fj(e)>>>0>=vz(10)>>>0){break n}t[d+5|0]=n;t[d+2|0]=15;t[d+3|0]=10;t[d+4|0]=l>>>6;break j}if((e|0)==10){e=w[f+4|0];l=e<<2;z=f,A=Bn(l),t[z+4|0]=A;if(e>>>0<64){break k}if(Fj(h)>>>0>=vz(10)>>>0){break k}t[d+5|0]=l;t[d+2|0]=15;t[d+3|0]=10;t[d+4|0]=e>>>6;break j}if((e|0)!=(h|0)){break n}e=0;t[f+6|0]=0;break m}if((e|0)==13){break l}}if((h|0)==13|e){break k}}fi(f+7|0,f+6|0);fi(f+5|0,f+4|0)}e=f+6|0;h=f+4|0;l=f+7|0;n=f+5|0;tz(e,h,l,n);vo(f,l,n,e,h);t[d+2|0]=w[f+7|0];t[d+4|0]=w[f+5|0];t[d+3|0]=w[f+6|0];t[d+5|0]=w[f+4|0]}gb=f+16|0;e=k+q|0;k=e>>>0>64?s:q;if(k){while(1){d=v[g+72>>2];t[i|0]=d;t[i+1|0]=d>>>8;t[i+2|0]=d>>>16;t[i+3|0]=d>>>24;d=x[g+76>>1];t[i+4|0]=d;t[i+5|0]=d>>>8;i=B(x[a+480188>>1],6)+i|0;k=k-1|0;if(k){continue}break}d=e>>>0<64;k=d?e:64;if(d){continue}}break}o=o+1|0;if((r|0)!=(o|0)){continue}}break}p=p+1|0;if(x[a+480188>>1]>(p&65535)>>>0){continue}break}}e=x[a+480188>>1];d=g+8|0;j=CB(d);t[d+16|0]=0;u[d+14>>1]=0;u[d+12>>1]=e;v[22656]=0;U(948,j|0,e|0,0);e=v[22656];v[22656]=0;if((e|0)==1){a=P()|0;O()|0;Ye(j);S(a|0);L()}v[22656]=0;U(947,g+32|0,m|0,d|0);e=v[22656];v[22656]=0;i=1;if((e|0)==1){break d}Ye(g+32|0);Ye(d);if(!(c&2)|!x[a+480190>>1]){break e}k=1;while(1){c=B(k&65535,104)+a|0;Dg(Rc(g+72|0,u[c+484414>>1]&1?16:8,1,0,0),c+484380|0,b);k=k+1|0;if(x[a+480190>>1]>=(k&65535)>>>0){continue}break}}gb=g+208|0;return i|0}i=P()|0;O()|0;Ye(d);break a}i=P()|0;O()|0;vb(g+144|0);break a}i=P()|0;O()|0;vb(e)}S(i|0);L()}function ola(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,y=0,z=0,A=0,C=0,D=0;e=gb-752|0;gb=e;vc(b);f=gb-32|0;gb=f;d=f+24|0;j=e+144|0;vU(d,j);h=yb(d);d=v[f+28>>2];g=v[f+24>>2];v[f+8>>2]=g;v[f+12>>2]=d;v[f>>2]=g;v[f+4>>2]=d;g=f+16|0;d=b;cc(g,d,f);g=yb(g);if((g|0)==(h|0)){Rb(d,yb(f+24|0))}gb=f+32|0;d=(g|0)==(h|0);if(!d){tU(j)}a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{if(!d){break m}if(!xU(e+144|0)){break m}if(!Pb(b,Qc(wU(e+144|0),jb))){break m}if(!c){o=1;break m}Gd(a,262144);f=e+104|0;Nk(f,2,e+144|0);d=e+24|0;Bc(d,f);Eb(a+1298268|0,d);vb(d);h=Tb(d,5450);Eb(a+1298304|0,h);vb(h);d=Tb(d,7395);Eb(a+1298316|0,d);vb(d);d=gb-16|0;gb=d;g=f;f=Tb(d,1302);Dc(g,f);vb(f);gb=d+16|0;t[e+8|0]=w[e+174|0];d=w[e+173|0];v[22656]=0;t[e+127|0]=d;R(874,e+128|0,e+127|0);d=v[22656];v[22656]=0;if((d|0)==1){break c}v[22656]=0;Y(372,e+24|0,e+104|0,e+8|0,e+128|0);d=v[22656];v[22656]=0;if((d|0)==1){break d}d=e+24|0;Eb(a+1298328|0,d);vb(d);vb(e+128|0);f=e+104|0;Hb(f);v[a+480208>>2]=12;v[a+1298364>>2]=5;u[a+480188>>1]=w[e+182|0]|w[e+183|0]<<8;u[e+24>>1]=w[e+178|0]|w[e+179|0]<<8;u[e+104>>1]=3999;C=a,D=x[Pc(d,f)>>1],u[C+480190>>1]=D;JX(Sb(a+484360|0),e+240|0,w[e+176|0]|w[e+177|0]<<8);if(x[a+480188>>1]){d=0;while(1){f=(d<<5)+a|0;We(f+480280|0);u[f+480284>>1]=(w[(d+e|0)+208|0]<<4|4)&244;d=d+1|0;if(d>>>0<x[a+480188>>1]){continue}break}}d=e+24|0;Td(d,b,B(w[e+178|0]|w[e+179|0]<<8,80));l=kc(e+104|0,d);xb(d);if(x[a+480190>>1]){h=c&2;j=e+72|0;d=0;while(1){v[22656]=0;R(875,l|0,e+24|0);f=v[22656];v[22656]=0;if((f|0)==1){break l}v[22656]=0;Nk(e+8|0,2,j);f=v[22656];v[22656]=0;n:{o:{p:{if((f|0)==1){break p}v[22656]=0;R(324,e+128|0,e+8|0);f=v[22656];v[22656]=0;if((f|0)==1){break p}v[22656]=0;d=d+1|0;Q(301,((d<<5)+a|0)+946304|0,e+128|0)|0;f=v[22656];v[22656]=0;if((f|0)==1){break o}f=e+128|0;vb(f);v[22656]=0;g=f;f=(B(d,104)+a|0)+484380|0;U(876,g|0,e+24|0,f|0);g=v[22656];v[22656]=0;q:{if((g|0)==1){break q}if(!h|!v[f>>2]){break n}g=w[e+42|0]|w[e+43|0]<<8|(w[e+44|0]<<16|w[e+45|0]<<24);v[22656]=0;g=Q(190,b|0,g|0)|0;i=v[22656];v[22656]=0;if((i|0)==1){break q}if(!g){break n}v[22656]=0;W(329,e+128|0,f|0,b|0)|0;f=v[22656];v[22656]=0;if((f|0)!=1){break n}}a=P()|0;O()|0;break e}a=P()|0;O()|0;break e}a=P()|0;O()|0;vb(e+128|0);break e}if(x[a+480190>>1]>d>>>0){continue}break}}o=1;r:{if(!(c&1)){break r}c=w[e+180|0]|w[e+181|0]<<8;j=0;v[22656]=0;m=a+484344|0;R(330,m|0,c|0);c=v[22656];v[22656]=0;if((c|0)==1){break k}if(!(w[e+180|0]|w[e+181|0]<<8)){break r}c=e+24|0;p=c|4;q=c|2;r=c|5;s=c|3;y=c|1;while(1){v[22656]=0;c=W(331,m|0,j&65535,64)|0;d=v[22656];v[22656]=0;if((d|0)==1){break j}s:{if(!c){break s}c=(j<<1)+e|0;d=c+496|0;if(!(w[d|0]|w[d+1|0]<<8)){break s}c=w[c+496|0]|w[c+497|0]<<8;v[22656]=0;c=Q(190,b|0,c<<4)|0;d=v[22656];v[22656]=0;if((d|0)==1){break j}if(!c){break s}n=0;c=_b(m,j);v[22656]=0;c=Yc(c,0,0);d=v[22656];v[22656]=0;if((d|0)==1){break f}while(1){v[22656]=0;d=Q(191,b|0,1)|0;f=v[22656];v[22656]=0;t:{u:{v:{if((f|0)!=1){if(!d){break s}v[22656]=0;g=T(374,b|0)|0;d=v[22656];v[22656]=0;if((d|0)==1){break v}if(g){break u}n=n+1|0;c=B(x[a+480188>>1],6)+c|0;break t}a=P()|0;O()|0;break e}a=P()|0;O()|0;break e}u[e+28>>1]=0;v[e+24>>2]=0;d=g&31;f=B(d,6)+c|0;z=bj(e+24|0);h=d>>>0<x[a+480188>>1];w:{if(!(g&32)){break w}v[22656]=0;R(403,e+128|0,b|0);d=v[22656];v[22656]=0;if((d|0)==1){break i}d=e+128|0;i=qd(d);k=h?f:e+24|0;d=w[d|0];t[k|0]=d;t[(h?f+1|0:y)|0]=w[i|0];x:{if(d){if((d|0)==254){break x}if(d>>>0<121){break w}}d=0}t[k|0]=d}y:{if(!(g&64)){break y}v[22656]=0;R(403,e+128|0,b|0);d=v[22656];v[22656]=0;if((d|0)==1){break h}d=e+128|0;A=qd(d);i=h?f+3|0:s;d=w[d|0];t[i|0]=d;k=h?f+5|0:r;t[k|0]=w[A|0];z:{A:{B:{if(d>>>0<=15){v[22656]=0;Of(h?f:z);d=v[22656];v[22656]=0;if((d|0)!=1){break B}a=P()|0;O()|0;break e}if(d>>>0>23){break z}d=w[d+33319|0];t[i|0]=d;break A}d=w[i|0]}if((d|0)!=23){if((d|0)!=9){break y}t[i|0]=20;t[e+8|0]=w[k|0]>>>3;v[22656]=0;t[e+127|0]=1;d=df(e+8|0,e+127|0);i=v[22656];v[22656]=0;if((i|0)!=1){t[k|0]=w[d|0]-1&15|128;break y}a=P()|0;O()|0;break e}v[22656]=0;t[e+8|0]=64;d=ac(k,e+8|0);i=v[22656];v[22656]=0;if((i|0)!=1){t[k|0]=w[d|0]<<1;break y}a=P()|0;O()|0;break e}t[i|0]=0}if(!(g&128)){break t}t[(h?f+2|0:q)|0]=1;v[22656]=0;d=T(374,b|0)|0;g=v[22656];v[22656]=0;if((g|0)==1){break g}t[(h?f+4|0:p)|0]=d}if(n>>>0<64){continue}break}}j=j+1|0;if(j>>>0<(w[e+180|0]|w[e+181|0]<<8)>>>0){continue}break}}xb(l)}gb=e+752|0;return o|0}a=P()|0;O()|0;break e}a=P()|0;O()|0;break e}a=P()|0;O()|0;break e}a=P()|0;O()|0;break e}a=P()|0;O()|0;break e}a=P()|0;O()|0;break e}a=P()|0;O()|0}xb(l);break a}a=P()|0;O()|0;vb(e+128|0);break b}a=P()|0;O()|0}Hb(e+104|0)}S(a|0);L()}function Sla(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;f=gb-112|0;gb=f;vc(b);a:{b:{c:{d:{e:{if(!XU(b,11403)){break e}i=mc(f+96|0);j=mc(f+80|0);v[22656]=0;v[f+72>>2]=0;v[f+76>>2]=0;R(367,a|0,32768);d=v[22656];v[22656]=0;if((d|0)==1){break b}v[22656]=0;d=Q(2,f+40|0,5302)|0;h=v[22656];v[22656]=0;if((h|0)==1){break c}Eb(a+1298304|0,d);vb(d);v[22656]=0;d=Q(2,f+40|0,3152)|0;h=v[22656];v[22656]=0;if((h|0)==1){break d}Eb(a+1298316|0,d);vb(d);v[a+1298364>>2]=2;k=a+484360|0;h=f- -64|4;while(1){v[22656]=0;d=Q(191,b|0,8)|0;e=v[22656];v[22656]=0;f:{g:{h:{i:{j:{k:{l:{m:{if((e|0)!=1){n:{o:{p:{q:{r:{s:{if(!d){break s}v[22656]=0;d=Q(827,b|0,f- -64|0)|0;e=v[22656];v[22656]=0;if((e|0)==1){break r}if(!d){break s}d=h;d=Xb(w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24));v[22656]=0;U(288,f+16|0,b|0,d|0);d=v[22656];v[22656]=0;if((d|0)==1){break q}d=f+40|0;g=f+16|0;e=kc(d,g);xb(g);v[22656]=0;d=T(275,d|0)|0;g=v[22656];v[22656]=0;if((g|0)==1){break o}if(d){break p}xb(f+40|0)}if(x[a+480188>>1]){break n}d=0;break g}a=P()|0;O()|0;break a}a=P()|0;O()|0;break a}t:{u:{v:{w:{d=f- -64|0;d=Xb(w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24));if((d|0)<=1396788559){if((d|0)<=1346522947){if((d|0)==1129140036){break w}if((d|0)!=1346458708){break t}d=Sb(k);v[22656]=0;g=T(195,f+40|0)|0;l=v[22656];v[22656]=0;if((l|0)==1){break o}v[22656]=0;fa(522,d|0,e|0,g|0,255,254)|0;d=v[22656];v[22656]=0;if((d|0)!=1){break f}break o}if((d|0)==1346522948){break u}if((d|0)!=1347175758){break t}v[22656]=0;d=T(195,f+40|0)|0;g=v[22656];v[22656]=0;if((g|0)==1){break o}if(d>>>0<2){break f}v[22656]=0;m=T(416,e|0)|0;d=v[22656];v[22656]=0;if((d|0)!=1){break f}break o}if((d|0)<=1397507405){if((d|0)==1396788560){break v}if((d|0)!=1396854596){break t}if(Je(j)>>>0>3998){break f}v[22656]=0;d=T(195,f+40|0)|0;g=v[22656];v[22656]=0;if((g|0)==1){break o}if(!d){break f}v[22656]=0;R(828,j|0,e|0);d=v[22656];v[22656]=0;if((d|0)==1){break o}break f}if((d|0)==1397507406){break f}if((d|0)!=1397769541){break t}v[22656]=0;d=T(195,f+40|0)|0;g=v[22656];v[22656]=0;if((g|0)==1){break o}if(d>>>0<2){break f}v[22656]=0;d=T(416,e|0)|0;e=v[22656];v[22656]=0;if((e|0)==1){break o}n=a,o=Md(d,1,255),v[n+480196>>2]=o;break f}if(x[a+480188>>1]){break f}v[22656]=0;d=T(195,f+40|0)|0;g=v[22656];v[22656]=0;if((g|0)==1){break o}if(d>>>0<8){break f}d=0;v[22656]=0;R(829,f+16|0,e|0);e=v[22656];v[22656]=0;if((e|0)==1){break o}while(1){e=vd(f+16|0,d);g=Ib(w[e|0]|w[e+1|0]<<8);e=x[a+480188>>1];if(g){g=f+72|0;n=ic(g,e),o=1,t[n|0]=o;n=ic(g,x[a+480188>>1]+1|0),o=255,t[n|0]=o;e=x[a+480188>>1];v[22656]=0;We(((e<<5)+a|0)+480280|0);e=v[22656];v[22656]=0;if((e|0)==1){break o}g=x[a+480188>>1];e=g+1|0;u[a+480188>>1]=e;u[((g<<5)+a|0)+480284>>1]=d-1>>>0<2?192:64}v[22656]=0;We((((e&65535)<<5)+a|0)+480280|0);e=v[22656];v[22656]=0;if((e|0)==1){break o}e=x[a+480188>>1];u[a+480188>>1]=e+1;u[((e<<5)+a|0)+480284>>1]=d-1>>>0<2?192:64;d=d+1|0;if((d|0)!=4){continue}break}break i}if(x[a+480190>>1]){break f}v[22656]=0;R(830,e|0,a|0);d=v[22656];v[22656]=0;if((d|0)!=1){break f}break o}if(Je(i)>>>0>255){break f}v[22656]=0;R(828,i|0,e|0);d=v[22656];v[22656]=0;if((d|0)!=1){break f}break o}d=f- -64|0;if(!(Xb(w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24))&-2139062144)){break f}d=0;break h}a=P()|0;O()|0;xb(f+40|0);break a}v[a+480200>>2]=256;v[a+480204>>2]=125e4;v[a+480260>>2]=452;v[a+480264>>2]=3424;v[a+480228>>2]=48;v[a+480232>>2]=48;b=Sb(k);v[22656]=0;R(502,b|0,m&65535);b=v[22656];v[22656]=0;if((b|0)==1){break b}x:{if(!(c&1)){break x}d=0;b=Je(i);v[22656]=0;R(330,a+484344|0,b&65535);b=v[22656];v[22656]=0;if((b|0)==1){break b}if(!Je(i)){break x}b=0;while(1){h=Lg(i,d);v[22656]=0;d=v[f+76>>2];e=v[f+72>>2];v[f+8>>2]=e;v[f+12>>2]=d;v[f>>2]=e;v[f+4>>2]=d;Y(831,h|0,b&65535,a|0,f|0);d=v[22656];v[22656]=0;if((d|0)==1){break m}b=b+1|0;d=b&65535;if(Je(i)>>>0>d>>>0){continue}break}}e=1;if(x[a+480190>>1]<2){break j}h=c&2;b=0;while(1){if(!h|Je(j)>>>0<=b>>>0){break j}v[22656]=0;c=(B(e,104)+a|0)+484380|0;Lu(c);d=v[22656];v[22656]=0;if((d|0)==1){break l}if(v[c>>2]){d=Lg(j,b);v[22656]=0;d=T(195,d|0)|0;k=v[22656];v[22656]=0;if((k|0)==1){break l}qc(c,d);d=Rc(f+40|0,8,1,1,0);k=Lg(j,b);v[22656]=0;W(329,d|0,c|0,k|0)|0;c=v[22656];v[22656]=0;if((c|0)==1){break k}b=b+1|0}d=1;e=e+1|0;if(e>>>0<x[a+480190>>1]){continue}break}break g}a=P()|0;O()|0;break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;break a}d=1;break g}if(c){break f}d=1}xb(f+40|0)}jd(j);jd(i);break e}xb(f+40|0);continue}}gb=f+112|0;return d|0}a=P()|0;O()|0;break a}a=P()|0;O()|0;break a}a=P()|0;O()|0}jd(j);jd(i);S(a|0);L()}function tma(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;d=gb-240|0;gb=d;vc(b);a:{b:{c:{d:{e:{f:{g:{h:{if(!Ar(b,d+224|0)){break h}if(!qV(d+224|0)){break h}j=Jh(d+200|0);k=Kb(d+184|0);nD(d+120|0);v[22656]=0;e=Q(783,b|0,d+112|0)|0;f=v[22656];v[22656]=0;if((f|0)==1){break d}i:{if(!e){break i}e=d+112|4;h=Xb(Xb(w[e|0]|w[e+1|0]<<8|(w[e+2|0]<<16|w[e+3|0]<<24))-4|0);t[e|0]=h;t[e+1|0]=h>>>8;t[e+2|0]=h>>>16;t[e+3|0]=h>>>24;h=0;while(1){f=Xb(Xb(w[e|0]|w[e+1|0]<<8|(w[e+2|0]<<16|w[e+3|0]<<24))-8|0);t[e|0]=f;t[e+1|0]=f>>>8;t[e+2|0]=f>>>16;t[e+3|0]=f>>>24;j:{if(c){break j}f=d+112|0;if((Xb(w[f|0]|w[f+1|0]<<8|(w[f+2|0]<<16|w[f+3|0]<<24))|0)!=1347699796){break j}h=1;break i}f=Xb(w[e|0]|w[e+1|0]<<8|(w[e+2|0]<<16|w[e+3|0]<<24));v[22656]=0;U(288,d+88|0,b|0,f|0);f=v[22656];v[22656]=0;k:{l:{m:{n:{o:{if((f|0)!=1){g=d+8|0;i=d+88|0;f=kc(g,i);xb(i);v[22656]=0;g=T(275,g|0)|0;i=v[22656];v[22656]=0;if((i|0)==1){break n}if(g){break o}xb(d+8|0);break k}a=P()|0;O()|0;break a}g=d+112|0;g=Xb(w[g|0]|w[g+1|0]<<8|(w[g+2|0]<<16|w[g+3|0]<<24));if((g|0)<=1347699795){if((g|0)==1129139796){break m}if((g|0)!=1229866575){break l}v[22656]=0;l=Q(784,f|0,d+120|0)|0;f=v[22656];v[22656]=0;if((f|0)==1){break n}break l}if((g|0)!=1347699796){if((g|0)!=1447383635){break l}v[22656]=0;Q(318,d+8|0,4)|0;g=v[22656];v[22656]=0;if((g|0)==1){break n}v[22656]=0;g=T(785,f|0)|0;i=v[22656];v[22656]=0;if((i|0)==1){break n}if(!g){break l}if(Xb(w[e|0]|w[e+1|0]<<8|(w[e+2|0]<<16|w[e+3|0]<<24))>>>0<7){break l}g=Xb(w[e|0]|w[e+1|0]<<8|(w[e+2|0]<<16|w[e+3|0]<<24));v[22656]=0;U(786,f|0,k|0,g-6|0);f=v[22656];v[22656]=0;if((f|0)==1){break n}break l}v[22656]=0;h=W(787,a|0,f|0,c|0)|0;f=v[22656];v[22656]=0;if((f|0)!=1){break l}}a=P()|0;O()|0;xb(d+8|0);break a}Hw(j,f)}xb(d+8|0);v[22656]=0;f=Q(783,b|0,d+112|0)|0;g=v[22656];v[22656]=0;if((g|0)==1){break e}if(f){continue}}break}if(gd(k)){v[22656]=0;b=Q(2,d+8|0,12081)|0;c=v[22656];v[22656]=0;if((c|0)==1){break c}Eb(k,b);vb(b)}p:{if(!(h&l&1)){break p}b=d+162|0;b=Ib(w[b|0]|w[b+1|0]<<8);v[22656]=0;c=b&256;W(409,a+1074312|0,5,!c|0)|0;b=v[22656];v[22656]=0;q:{r:{if((b|0)!=1){b=d+158|0;if(Ib(w[b|0]|w[b+1|0]<<8)){u[d+8>>1]=64;b=Ib(w[b|0]|w[b+1|0]<<8);v[22656]=0;u[d+88>>1]=b;b=Pc(d+8|0,d+88|0);e=v[22656];v[22656]=0;if((e|0)==1){break r}v[a+480228>>2]=x[b>>1]}b=d+160|0;if(!(!Ib(w[b|0]|w[b+1|0]<<8)|!c)){m=a,n=B(Ib(w[b|0]|w[b+1|0]<<8),1e4),v[m+480204>>2]=n}if(w[d+120|0]){v[22656]=0;Ke(d+88|0,2,d+120|0);b=v[22656];v[22656]=0;if((b|0)==1){break q}v[22656]=0;R(324,d+8|0,d+88|0);b=v[22656];v[22656]=0;if((b|0)==1){break q}b=d+8|0;Eb(a+1298268|0,b);vb(b)}v[d+8>>2]=1;v[d+88>>2]=12;c=d+166|0;if(!fr(c,d+8|0,d+88|0)){break p}v[d+80>>2]=31;v[d+84>>2]=1;e=d+164|0;if(!fr(e,d+84|0,d+80|0)){break p}v[d+72>>2]=23;v[d+76>>2]=0;f=d+170|0;if(!fr(f,d+76|0,d+72|0)){break p}v[d+64>>2]=59;v[d+68>>2]=0;g=d+172|0;if(!fr(g,d+68|0,d- -64|0)){break p}v[d+56>>2]=59;v[d+60>>2]=0;i=d+174|0;if(!fr(i,d+60|0,d+56|0)){break p}b=Dr(d+8|0);l=d+168|0;m=b,n=Ib(w[l|0]|w[l+1|0]<<8),v[m+20>>2]=n;m=b,n=Ib(w[c|0]|w[c+1|0]<<8)-1|0,v[m+16>>2]=n;m=b,n=Ib(w[e|0]|w[e+1|0]<<8),v[m+12>>2]=n;m=b,n=Ib(w[f|0]|w[f+1|0]<<8),v[m+8>>2]=n;m=b,n=Ib(w[g|0]|w[g+1|0]<<8),v[m+4>>2]=n;m=b,n=Ib(w[i|0]|w[i+1|0]<<8),v[m>>2]=n;v[22656]=0;R(601,a+1298368|0,b|0);b=v[22656];v[22656]=0;if((b|0)!=1){break p}a=P()|0;O()|0;break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;break a}if(h&1){v[22656]=0;b=T(275,j|0)|0;c=v[22656];v[22656]=0;if((c|0)==1){break d}if(b){b=Kb(d+8|0);v[22656]=0;W(413,j|0,b|0,32)|0;c=v[22656];v[22656]=0;if((c|0)==1){break b}if(xr(b,11063)){v[22656]=0;U(13,d+88|0,2,b|0);c=v[22656];v[22656]=0;if((c|0)==1){break b}c=d+88|0;Eb(a+1298280|0,c);vb(c)}v[22656]=0;c=T(788,j|0)|0;e=v[22656];v[22656]=0;if((e|0)==1){break b}if(!c){v[22656]=0;c=T(467,j|0)|0;e=v[22656];v[22656]=0;if((e|0)==1){break b}v[22656]=0;fa(473,a+1298292|0,j|0,c|0,40,0)|0;c=v[22656];v[22656]=0;if((c|0)==1){break b}}vb(b)}v[22656]=0;b=Q(2,d+88|0,14633)|0;c=v[22656];v[22656]=0;if((c|0)==1){break g}v[22656]=0;U(652,d+8|0,b|0,k|0);c=v[22656];v[22656]=0;if((c|0)==1){break f}c=d+8|0;Eb(a+1298328|0,c);vb(c);vb(b)}v[a+480208>>2]=v[a+480208>>2]|2097152;v[22656]=0;a=a+1074312|0;W(409,a|0,84,1)|0;b=v[22656];v[22656]=0;if((b|0)==1){break d}v[22656]=0;W(409,a|0,83,1)|0;b=v[22656];v[22656]=0;if((b|0)==1){break d}v[22656]=0;Q(410,a|0,85)|0;a=v[22656];v[22656]=0;if((a|0)==1){break d}}vb(k);xb(j)}gb=d+240|0;return h&1}a=P()|0;O()|0;break a}a=P()|0;O()|0;vb(b);break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;vb(b)}vb(k);xb(j);S(a|0);L()}function Ed(a,b,c,d,e,f,g,h,i){var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0;l=gb-96|0;gb=l;j=i&65535;k=j;w=h;t=h<<15|g>>>17;o=(e^i)&-2147483648;m=e&65535;n=m;p=d;D=m;m=0;A=(j&131071)<<15|h>>>17;B=i>>>16&32767;M=e>>>16&32767;a:{b:{if(B-1>>>0<32766&M-1>>>0<=32765){break b}C=e&2147483647;q=C;j=d;if(!(!j&(q|0)==2147418112?!(b|c):q>>>0<2147418112)){z=d;o=e|32768;break a}C=i&2147483647;e=C;d=h;if(!(!h&(e|0)==2147418112?!(f|g):e>>>0<2147418112)){z=h;o=i|32768;b=f;c=g;break a}if(!(b|j|(q^2147418112|c))){if(!(d|f|(e|g))){o=2147450880;b=0;c=0;break a}o=o|2147418112;b=0;c=0;break a}if(!(d|f|(e^2147418112|g))){d=b|j;e=c|q;b=0;c=0;if(!(d|e)){o=2147450880;break a}o=o|2147418112;break a}if(!(b|j|(c|q))){b=0;c=0;break a}if(!(d|f|(e|g))){b=0;c=0;break a}if((q|0)==65535|q>>>0<65535){i=b;d=!(n|p);h=d<<6;j=E(d?b:p)+32|0;b=E(d?c:n);b=h+((b|0)==32?j:b)|0;Kf(l+80|0,i,c,p,n,b-15|0);x=16-b|0;p=v[l+88>>2];D=v[l+92>>2];c=v[l+84>>2];b=v[l+80>>2]}if(e>>>0>65535){break b}d=!(k|w);e=d<<6;h=E(d?f:w)+32|0;d=E(d?g:k);d=e+((d|0)==32?h:d)|0;Kf(l- -64|0,f,g,w,k,d-15|0);x=(x-d|0)+16|0;f=v[l+76>>2];d=f;i=v[l+72>>2];e=i;e=e<<15;h=v[l+68>>2];g=h;f=v[l+64>>2];t=h>>>17|e;A=(d&131071)<<15|i>>>17}h=f;u=h<<15&-32768;e=0;r=c;i=0;q=kqa(u,e,c,i);c=jb;F=c;d=c;s=(g&131071)<<15|h>>>17;c=b;f=kqa(s,0,b,0);b=f+q|0;j=jb+d|0;k=b;b=b>>>0<f>>>0?j+1|0:j;h=0;g=kqa(c,G,u,e);f=h+g|0;d=k;j=d+jb|0;j=f>>>0<g>>>0?j+1|0:j;g=j;I=(d|0)==(j|0)&h>>>0>f>>>0|d>>>0>j>>>0;n=p;N=kqa(u,e,n,0);J=jb;j=kqa(r,i,s,y);d=j+N|0;h=jb+J|0;O=d;w=kqa(t,0,c,G);p=d+w|0;d=d>>>0<j>>>0?h+1|0:h;j=d+jb|0;C=p;j=p>>>0<w>>>0?j+1|0:j;w=j;p=j;j=(b|0)==(F|0)&k>>>0<q>>>0|b>>>0<F>>>0;k=b;b=b+C|0;h=j+p|0;F=b;h=b>>>0<k>>>0?h+1|0:h;p=h;j=u;H=D|65536;u=m;P=kqa(j,e,H,m);K=jb;m=kqa(n,Q,s,y);e=m+P|0;j=jb+K|0;j=e>>>0<m>>>0?j+1|0:j;R=e;k=kqa(r,i,t,S);e=e+k|0;m=j;j=j+jb|0;j=e>>>0<k>>>0?j+1|0:j;L=e;A=A&2147483647|-2147483648;e=kqa(A,0,c,G);c=L+e|0;q=j;j=j+jb|0;G=c;e=c>>>0<e>>>0?j+1|0:j;j=I;c=0;b=c+b|0;h=h+G|0;h=b>>>0<c>>>0?h+1|0:h;I=b;c=b;b=j+b|0;D=h;j=h;j=b>>>0<c>>>0?j+1|0:j;c=j;x=((B+M|0)+x|0)-16383|0;B=kqa(n,Q,t,S);h=jb;s=kqa(s,y,H,u);k=s+B|0;j=jb+h|0;j=k>>>0<s>>>0?j+1|0:j;s=k;k=j;y=(h|0)==(j|0)&s>>>0<B>>>0|h>>>0>j>>>0;i=kqa(A,T,r,i);h=i+s|0;j=jb+j|0;j=h>>>0<i>>>0?j+1|0:j;i=h;h=j;r=(k|0)==(j|0)&i>>>0<s>>>0|j>>>0<k>>>0;k=y+r|0;j=0;j=k>>>0<r>>>0?1:j;r=kqa(A,T,H,u);k=r+k|0;j=jb+j|0;y=k;k=k>>>0<r>>>0?j+1|0:j;s=i;r=h;B=y;i=(d|0)==(w|0)&C>>>0<O>>>0|d>>>0>w>>>0;d=i+((d|0)==(J|0)&N>>>0>O>>>0|d>>>0<J>>>0)|0;j=0;j=d>>>0<i>>>0?1:j;i=d;d=s+d|0;h=h+j|0;h=d>>>0<i>>>0?h+1|0:h;y=d;i=h;h=(h|0)==(r|0)&d>>>0<s>>>0|h>>>0<r>>>0;d=B+h|0;j=k;r=d;k=d>>>0<h>>>0?j+1|0:j;n=kqa(A,T,n,Q);h=jb;t=kqa(t,S,H,u);d=t+n|0;j=jb+h|0;j=d>>>0<t>>>0?j+1|0:j;t=d;u=d;d=j;j=(h|0)==(j|0)&n>>>0>u>>>0|h>>>0>j>>>0;n=d+r|0;h=j+k|0;h=n>>>0<d>>>0?h+1|0:h;k=h;u=n;n=0;d=n+y|0;j=i+t|0;j=d>>>0<n>>>0?j+1|0:j;h=j;n=(i|0)==(j|0)&d>>>0<y>>>0|i>>>0>j>>>0;i=u+n|0;j=k;t=i;i=i>>>0<n>>>0?j+1|0:j;n=d;k=h;h=(m|0)==(K|0)&P>>>0>R>>>0|m>>>0<K>>>0;m=(m|0)==(q|0)&R>>>0>L>>>0|m>>>0>q>>>0;h=h+m|0;h=h+((e|0)==(q|0)&G>>>0<L>>>0|e>>>0<q>>>0)|0;j=h;d=e+d|0;h=j+k|0;h=d>>>0<e>>>0?h+1|0:h;e=d;j=d;d=h;m=(h|0)==(k|0)&j>>>0<n>>>0|h>>>0<k>>>0;h=m+t|0;j=i;j=h>>>0<m>>>0?j+1|0:j;i=j;k=e;m=d;n=h;e=(p|0)==(D|0)&F>>>0>I>>>0|p>>>0>D>>>0;d=e+((p|0)==(w|0)&C>>>0>F>>>0|p>>>0<w>>>0)|0;j=0;j=d>>>0<e>>>0?1:j;e=d;d=k+d|0;h=j+m|0;h=d>>>0<e>>>0?h+1|0:h;j=d;e=h;m=(h|0)==(m|0)&j>>>0<k>>>0|h>>>0<m>>>0;h=n+m|0;j=i;j=h>>>0<m>>>0?j+1|0:j;i=j;c:{if(j&65536){x=x+1|0;break c}p=g>>>31|0;m=0;j=i<<1|h>>>31;h=h<<1|e>>>31;i=j;j=e<<1|d>>>31;d=d<<1|c>>>31;e=j;j=g<<1|f>>>31;f=f<<1;g=j;j=c<<1|b>>>31;b=b<<1|p;c=j|m}if((x|0)>=32767){o=o|2147418112;b=0;c=0;break a}d:{if((x|0)<=0){j=1-x|0;if(j>>>0>=128){b=0;c=0;break a}m=x+127|0;Kf(l+48|0,f,g,b,c,m);Kf(l+32|0,d,e,h,i,m);pm(l+16|0,f,g,b,c,j);pm(l,d,e,h,i,j);f=(v[l+48>>2]|v[l+56>>2])!=0|(v[l+52>>2]|v[l+60>>2])!=0|(v[l+32>>2]|v[l+16>>2]);g=v[l+36>>2]|v[l+20>>2];b=v[l+40>>2]|v[l+24>>2];c=v[l+44>>2]|v[l+28>>2];d=v[l>>2];e=v[l+4>>2];i=v[l+12>>2];h=v[l+8>>2];break d}i=i&65535|x<<16}z=h|z;o=i|o;if(!(!b&(c|0)==-2147483648?!(f|g):(c|0)>0|(c|0)>=0)){h=e;b=d+1|0;h=b?h:h+1|0;c=h;e=(e|0)==(h|0)&d>>>0>b>>>0|e>>>0>h>>>0;d=e+z|0;h=o;z=d;o=d>>>0<e>>>0?h+1|0:h;break a}if(b|f|(c^-2147483648|g)){b=d;c=e;break a}h=o;c=d&1;b=c+d|0;j=e;j=b>>>0<c>>>0?j+1|0:j;c=j;e=(e|0)==(j|0)&d>>>0>b>>>0|e>>>0>j>>>0;d=e+z|0;z=d;o=d>>>0<e>>>0?h+1|0:h}v[a>>2]=b;v[a+4>>2]=c;v[a+8>>2]=z;v[a+12>>2]=o;gb=l+96|0}function DZ(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;g=gb-128|0;gb=g;vc(b);a:{if(!Tr(b,9028)){break a}if(!fw(b,g+112|0)){break a}if(!fE(g+112|0)){break a}if(!Pb(b,Qc(eE(g+112|0),jb))){break a}if(!Rb(b,w[g+121|0]|w[g+122|0]<<8)){break a}b:{if(!c){break b}Gd(a,4096);v[a+480208>>2]=12;d=1;h=g+112|0;u[a+480188>>1]=(w[h|2]&31)+1;i=h|3;u[a+480190>>1]=w[i|0];xh(a,1);j=g+32|0;e=Tb(j,5623);Eb(a+1298304|0,e);vb(e);e=Tb(j,4107);Eb(a+1298316|0,e);vb(e);e=gb-16|0;gb=e;f=g+8|0;k=Tb(e,1356);Dc(f,k);vb(k);gb=e+16|0;v[22656]=0;Y(349,j|0,f|0,h|1,h|0);h=v[22656];v[22656]=0;c:{d:{e:{f:{g:{h:{i:{j:{if((h|0)!=1){h=g+32|0;Eb(a+1298328|0,h);vb(h);Hb(g+8|0);v[a+1298364>>2]=5;e=w[i|0];h=gb-16|0;gb=h;j=g+96|0;v[j>>2]=0;v[j+4>>2]=0;v[h+12>>2]=0;ff(j+8|0,h+12|0,h+8|0);if(e){Yr(j,e);$E(j,e,0)}gb=h+16|0;k:{if(x[a+480190>>1]){h=1;while(1){v[22656]=0;R(350,b|0,g+32|0);e=v[22656];v[22656]=0;if((e|0)==1){break k}v[22656]=0;R(351,g+32|0,(B(d,104)+a|0)+484380|0);e=v[22656];v[22656]=0;if((e|0)==1){break k}e=w[g+48|0];i=g+8|0;Ce(i,j,d-1|0);Uf(i,(e&3)!=0);h=h+1|0;d=h&65535;if(d>>>0<=x[a+480190>>1]){continue}break}}v[22656]=0;W(352,b|0,a+1298268|0,-1)|0;h=v[22656];v[22656]=0;d=1;l:{m:{if((h|0)!=1){if(x[a+480190>>1]){while(1){v[22656]=0;W(353,b|0,(((d&65535)<<5)+a|0)+946304|0,-1)|0;h=v[22656];v[22656]=0;if((h|0)==1){break m}d=d+1|0;if(x[a+480190>>1]>=(d&65535)>>>0){continue}break}}if(x[a+480188>>1]){d=0;while(1){v[22656]=0;h=(d<<5)+a|0;We(h+480280|0);e=v[22656];v[22656]=0;if((e|0)==1){break e}v[22656]=0;U(355,b|0,h+480289|0,-1);h=v[22656];v[22656]=0;if((h|0)==1){break e}d=d+1|0;if(d>>>0<x[a+480188>>1]){continue}break}}h=g+112|4;e=w[h|0]|w[h+1|0]<<8;d=0;v[22656]=0;i=a+484344|0;R(330,i|0,e|0);e=v[22656];v[22656]=0;if((e|0)!=1){break l}}b=P()|0;O()|0;break d}b=P()|0;O()|0;break d}if(w[h|0]|w[h+1|0]<<8){while(1){v[22656]=0;U(356,b|0,g+32|0,-1);e=v[22656];v[22656]=0;n:{o:{if((e|0)==1){break o}v[22656]=0;e=W(331,i|0,d&65535,64)|0;f=v[22656];v[22656]=0;if((f|0)==1){break o}if(!e){break n}e=_b(i,d);v[22656]=0;R(357,e|0,g+32|0);e=v[22656];v[22656]=0;if((e|0)!=1){break n}}b=P()|0;O()|0;break d}d=d+1|0;if(d>>>0<(w[h|0]|w[h+1|0]<<8)>>>0){continue}break}}v[22656]=0;f=T(287,b|0)|0;d=v[22656];v[22656]=0;if((d|0)==1){break f}p:{if(!f){break p}v[22656]=0;d=Q(191,b|0,f|0)|0;e=v[22656];v[22656]=0;if((e|0)==1){break f}if(!d){break p}e=mc(g+32|0);v[22656]=0;W(358,b|0,e|0,f|0)|0;d=v[22656];v[22656]=0;if((d|0)==1){break h}d=Kb(g+8|0);v[22656]=0;R(60,d|0,f|0);f=v[22656];v[22656]=0;if((f|0)==1){break i}m=g,n=Vb(e),v[m+56>>2]=n;m=g,n=Zb(e),v[m+88>>2]=n;if(Gb(g+56|0,g+88|0)){while(1){q:{f=w[v[g+56>>2]];if(f&128){m=g,n=gf(d),v[m+72>>2]=n;Fd(g+80|0,g+72|0);v[22656]=0;da(359,d|0,v[g+80>>2],f&127,32)|0;f=v[22656];v[22656]=0;if((f|0)!=1){break q}break i}v[22656]=0;R(61,d|0,f<<24>>24);f=v[22656];v[22656]=0;if((f|0)!=1){break q}break i}f=g+56|0;Pe(f);if(Gb(f,g+88|0)){continue}break}}v[22656]=0;Y(360,g+56|0,5,6,d|0);f=v[22656];v[22656]=0;if((f|0)==1){break i}f=g+56|0;Eb(d,f);vb(f);f=zb(Jb(d));k=Ab(d);v[22656]=0;fa(361,a+1298292|0,f|0,k|0,76,0)|0;f=v[22656];v[22656]=0;if((f|0)==1){break i}vb(d);gc(e)}e=Sb(a+484360|0);d=g+112|6;f=w[d|0]|w[d+1|0]<<8;d=0;v[22656]=0;fa(362,e|0,b|0,f|0,65535,65535)|0;e=v[22656];v[22656]=0;if((e|0)==1){break f}r:{s:{t:{u:{if(!(w[h|0]|w[h+1|0]<<8)){break u}e=c&1;while(1){v[22656]=0;f=Q(191,b|0,4)|0;k=v[22656];v[22656]=0;v:{if((k|0)!=1){if(f){break v}break u}b=P()|0;O()|0;break d}v[22656]=0;f=T(192,b|0)|0;k=v[22656];v[22656]=0;if((k|0)==1){break s}v[22656]=0;U(288,g+8|0,b|0,f|0);f=v[22656];v[22656]=0;if((f|0)==1){break r}f=g+8|0;k=kc(g+32|0,f);xb(f);w:{if(!e){break w}v[22656]=0;f=me(i,d&65535);l=v[22656];v[22656]=0;if((l|0)==1){break t}if(!f){break w}f=_b(i,d);v[22656]=0;U(364,f|0,0,k|0);f=v[22656];v[22656]=0;if((f|0)==1){break t}}xb(g+32|0);d=d+1|0;if(d>>>0<(w[h|0]|w[h+1|0]<<8)>>>0){continue}break}}if(!(!(c&2)|!x[a+480190>>1])){d=1;c=1;while(1){h=B(d,104)+a|0;e=x[h+484414>>1];i=g+32|0;Ce(i,j,d-1|0);d=Rc(g+8|0,e&1?16:8,1,0,Cb(i)?6:0);v[22656]=0;W(329,d|0,h+484380|0,b|0)|0;d=v[22656];v[22656]=0;if((d|0)==1){break j}c=c+1|0;d=c&65535;if(d>>>0<=x[a+480190>>1]){continue}break}}Ye(j);break b}b=P()|0;O()|0;xb(g+32|0);break d}b=P()|0;O()|0;break d}b=P()|0;O()|0;break d}b=P()|0;O()|0;break d}b=P()|0;O()|0;Hb(g+8|0);break c}b=P()|0;O()|0;break d}b=P()|0;O()|0;vb(d);break g}b=P()|0;O()|0}gc(e);break d}b=P()|0;O()|0;break d}b=P()|0;O()|0}Ye(j)}S(b|0);L()}d=1}gb=g+128|0;return d|0}function dZ(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;g=gb-3056|0;gb=g;vc(b);h=gb-32|0;gb=h;e=h+24|0;f=g+1096|0;KD(e,f);l=yb(e);e=v[h+28>>2];j=v[h+24>>2];v[h+8>>2]=j;v[h+12>>2]=e;v[h>>2]=j;v[h+4>>2]=e;j=h+16|0;e=b;cc(j,e,h);j=yb(j);if((j|0)==(l|0)){Rb(e,yb(h+24|0))}gb=h+32|0;e=(j|0)==(l|0);if(!e){JD(f)}a:{if(!e){break a}if(!ND(g+1096|0)){break a}if(!c){d=1;break a}if(!Pb(b,Qc(1024,0))){break a}MD(b,g+576|0);MD(b,g- -64|0);while(1){e=i<<2;h=e+(g+576|0)|0;if((w[h|0]|w[h+1|0]<<8|(w[h+2|0]<<16|w[h+3|0]<<24))>>>0>16777215){break a}e=e+(g- -64|0)|0;f=w[e+1|0]<<8;j=w[e+2|0]<<16|w[e+3|0]<<24;if((w[e|0]|f|j)>>>0<3|(j|(f|w[e|0]))>>>0>4096){break a}if(!rs(b,((w[h|0]|w[h+1|0]<<8|(w[h+2|0]<<16|w[h+3|0]<<24))+(w[e|0]|w[e+1|0]<<8|(w[e+2|0]<<16|w[e+3|0]<<24))|0)+2978|0)){break a}i=i+1|0;if((i|0)!=128){continue}break}Gd(a,2);Bg(a);d=g+40|0;e=Tb(d,11144);Eb(a+1298304|0,e);vb(e);e=Tb(d,11962);Eb(a+1298316|0,e);vb(e);d=Tb(d,12607);Eb(a+1298328|0,d);vb(d);v[a+1298364>>2]=5;d=w[g+1096|0];v[a+480204>>2]=143e4;v[a+480196>>2]=d;l=a+484360|0;cf(Sb(l),w[g+1097|0]);v[a+480188>>2]=4194317;Ob(a+1074312|0,95,1);v[a+480208>>2]=v[a+480208>>2]|16777216;d=0;while(1){u[((d<<5)+a|0)+480284>>1]=d&1?192:64;d=d+1|0;if((d|0)!=4){continue}break}d=0;b:{c:{d:{e:{while(1){e=d+1|0;i=B(e,104)+a|0;h=i+484380|0;ud(h,2);f=g+16|0;ki(f,1,(B(d,13)+g|0)+1098|0);j=g+40|0;Bc(j,f);v[22656]=0;Q(301,((e<<5)+a|0)+946304|0,j|0)|0;f=v[22656];v[22656]=0;if((f|0)==1){break e}vb(g+40|0);f=h;d=(g+1096|0)+(d<<4)|0;h=d+422|0;v[f>>2]=w[h|0]|w[h+1|0]<<8|(w[h+2|0]<<16|w[h+3|0]<<24);if((w[d+430|0]|w[d+431|0]<<8|(w[d+432|0]<<16|w[d+433|0]<<24))>>>0<=(w[d+422|0]|w[d+423|0]<<8|(w[d+424|0]<<16|w[d+425|0]<<24))>>>0){v[i+484384>>2]=w[d+426|0]|w[d+427|0]<<8|(w[d+428|0]<<16|w[d+429|0]<<24);d=w[d+430|0]|w[d+431|0]<<8|(w[d+432|0]<<16|w[d+433|0]<<24);u[i+484414>>1]=2;v[i+484388>>2]=d}v[i+484404>>2]=8287;d=e;if((d|0)!=32){continue}break}i=0;while(1){d=i+33|0;h=(B(d,104)+a|0)+484380|0;ud(h,2);e=g+16|0;ki(e,1,(B(i,13)+g|0)+2026|0);f=g+40|0;Bc(f,e);v[22656]=0;Q(301,((d<<5)+a|0)+946304|0,f|0)|0;d=v[22656];v[22656]=0;if((d|0)==1){break d}d=g+40|0;vb(d);v[g+48>>2]=0;v[g+40>>2]=0;v[g+44>>2]=0;e=(g+1096|0)+B(i,11)|0;f=w[e+1347|0];p=ic(d,0),q=f,t[p|0]=q;f=w[e+1352|0];p=ic(d,1),q=f,t[p|0]=q;f=w[e+1348|0];p=ic(d,2),q=f,t[p|0]=q;f=w[e+1353|0];p=ic(d,3),q=f,t[p|0]=q;f=w[e+1349|0];p=ic(d,4),q=f,t[p|0]=q;f=w[e+1354|0];p=ic(d,5),q=f,t[p|0]=q;f=w[e+1350|0];p=ic(d,6),q=f,t[p|0]=q;f=w[e+1355|0];p=ic(d,7),q=f,t[p|0]=q;f=w[e+1351|0];p=ic(d,8),q=f,t[p|0]=q;f=w[e+1356|0];p=ic(d,9),q=f,t[p|0]=q;e=w[e+1346|0];p=ic(d,10),q=e,t[p|0]=q;v[g+8>>2]=v[g+48>>2];d=v[g+44>>2];v[g>>2]=v[g+40>>2];v[g+4>>2]=d;So(h,1,g);i=i+1|0;if((i|0)!=32){continue}break}Ur(Sb(l),g+2794|0,256,255,65535);j=a+484344|0;Ag(j,128);o=c&1;i=0;f:{while(1){h=i<<2;d=h+(g+576|0)|0;Wc(b,(w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24))+2978|0);e=g+16|0;d=h+(g- -64|0)|0;Td(e,b,w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24));h=kc(g+40|0,e);xb(e);g:{if(!o){break g}v[22656]=0;d=W(331,j|0,i&65535,64)|0;e=v[22656];v[22656]=0;if((e|0)==1){break c}if(!d){break g}d=0;l=_b(j,i);while(1){v[22656]=0;e=Q(191,g+40|0,1)|0;f=v[22656];v[22656]=0;h:{i:{if((f|0)!=1){if(!e){break g}v[22656]=0;e=T(374,h|0)|0;f=v[22656];v[22656]=0;if((f|0)==1){break c}if(e>>>0>12){break i}v[22656]=0;f=Yc(l,d,e);k=v[22656];v[22656]=0;if((k|0)==1){break c}v[22656]=0;R(403,g+16|0,h|0);k=v[22656];v[22656]=0;if((k|0)==1){break c}k=g+16|0;m=qd(k);n=w[k|0];e=e>>>0>3;t[f|0]=((n&15)+(e?13:37)|0)+B(n>>>4&7,12);t[f+1|0]=((w[m|0]>>>4|0)+(e?33:1)|0)+(w[k|0]>>>3&16);LD(f,w[m|0],e);break h}break c}f=e-32|0;if((f&255)>>>0<=12){v[22656]=0;f=Yc(l,d,f&65535);k=v[22656];v[22656]=0;if((k|0)==1){break c}v[22656]=0;k=T(374,h|0)|0;m=v[22656];v[22656]=0;if((m|0)==1){break c}LD(f,k,e>>>0>35);break h}if((e|0)!=64){if((e|0)!=96){break f}if(!d){break g}v[22656]=0;d=Yc(l,d-1|0,0);e=v[22656];v[22656]=0;if((e|0)==1){break c}t[d+3|0]=14;break g}v[22656]=0;e=T(374,h|0)|0;f=v[22656];v[22656]=0;if((f|0)==1){break c}d=d+e|0}if(d>>>0<64){continue}break}}xb(g+40|0);i=i+1|0;if((i|0)!=128){continue}break}d=1;if(!(c&2)){break a}i=1;while(1){Dg(Rc(g+40|0,8,1,0,1),(B(i,104)+a|0)+484380|0,b);i=i+1|0;if((i|0)!=33){continue}break}break a}xb(g+40|0);d=0;break a}d=P()|0;O()|0;vb(g+40|0);break b}d=P()|0;O()|0;vb(g+40|0);break b}d=P()|0;O()|0;xb(g+40|0)}S(d|0);L()}gb=g+3056|0;return d|0}function Apa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;d=gb-336|0;gb=d;vc(b);a:{if(!Ar(b,d+320|0)){break a}if(!bY(d+320|0)){break a}if(v[d+320>>2]==1179472708){Rb(b,4)}if(!Ih(b,d+312|0)|v[d+312>>2]!=1196314451){break a}if(!c){e=1;break a}l=d+312|4;f=l;ZD(b,d+120|0,w[f|0]|w[f+1|0]<<8|(w[f+2|0]<<16|w[f+3|0]<<24));if((w[d+156|0]|w[d+157|0]<<8)>>>0>128|(w[d+162|0]|w[d+163|0]<<8)>>>0>16|((w[d+160|0]|w[d+161|0]<<8)>>>0>256|(w[d+154|0]|w[d+155|0]<<8)>>>0>128)){break a}Gd(a,8192);e=d+32|0;f=Tb(e,3596);Eb(a+1298304|0,f);vb(f);f=Tb(e,7411);Eb(a+1298316|0,f);vb(f);v[a+1298364>>2]=5;f=d+96|0;Nk(f,2,d+120|0);Bc(e,f);Eb(a+1298268|0,e);vb(e);u[d+32>>1]=w[d+162|0]|w[d+163|0]<<8;u[d+96>>1]=1;q=a,r=x[Le(e,f)>>1],u[q+480188>>1]=r;v[a+480196>>2]=w[d+166|0];v[a+480204>>2]=B(w[d+167|0],1e4);t[d+32|0]=w[d+164|0];t[d+96|0]=64;e=w[ac(e,f)|0];v[a+480200>>2]=e<<2;if(!e){v[a+480200>>2]=256}e=a;b:{if(w[d+165|0]==128){v[d+32>>2]=256/x[a+480188>>1];v[d+96>>2]=128;f=v[Fb(d+32|0,d+96|0)>>2];break b}f=w[d+165|0]&127}v[e+480228>>2]=f;e=0;while(1){f=(e<<5)+a|0;We(f+480280|0);h=d+e|0;if(w[h+168|0]<=128){u[f+480284>>1]=w[h+168|0]<<1}e=e+1|0;if((e|0)!=16){continue}break}k=a+484360|0;g=Sb(k);i=d+184|0;e=gb-16|0;gb=e;v[e+12>>2]=w[d+156|0]|w[d+157|0]<<8;f=e+12|0;qc(f,128);qc(f,65535);j=x[e+12>>1];Af(g,j);if(j){h=0;while(1){f=w[h+i|0];c:{if((f|0)==255){f=65535;break c}if((f|0)!=254){break c}f=65534}q=fj(g,h),r=f,u[q>>1]=r;h=h+1|0;if((j|0)!=(h|0)){continue}break}}gb=e+16|0;if((w[d+154|0]|w[d+155|0]<<8)>>>0<(w[d+156|0]|w[d+157|0]<<8)>>>0){cf(Sb(k),w[d+154|0]|w[d+155|0]<<8)}e=1;if(!Ih(b,d+312|0)){break a}n=c&2;k=a+484344|0;o=c&1;p=d+68|0;j=0;while(1){e=d+32|0;c=l;Td(e,b,w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24));h=kc(d+96|0,e);xb(e);d:{e:{f:{if(!(!o|v[d+312>>2]!=1414807888)){v[22656]=0;m=j&65535;c=W(331,k|0,m|0,64)|0;e=v[22656];v[22656]=0;if((e|0)==1){break f}if(!c){break d}v[22656]=0;Q(318,d+96|0,2)|0;c=v[22656];v[22656]=0;if((c|0)==1){break f}gi(d+32|0);f=0;g:{while(1){v[22656]=0;c=Q(191,d+96|0,1)|0;e=v[22656];v[22656]=0;h:{i:{if((e|0)!=1){if(!(c&f>>>0<64)){break g}v[22656]=0;e=T(374,h|0)|0;c=v[22656];v[22656]=0;if((c|0)==1){break i}if(e){break h}f=f+1|0;continue}b=P()|0;O()|0;break e}b=P()|0;O()|0;break e}c=d+32|0;j:{k:{l:{g=e&15;m:{if(g>>>0<x[a+480188>>1]){c=_b(k,m);v[22656]=0;c=Yc(c,f,g);g=v[22656];v[22656]=0;if((g|0)==1){break m}}n:{if(!(e&128)){break n}v[22656]=0;g=T(374,h|0)|0;i=v[22656];v[22656]=0;if((i|0)==1){break l}if(!g){break n}t[c|0]=g>>>0<109?g+12|0:g}if(!(e&64)){break j}v[22656]=0;g=T(374,h|0)|0;i=v[22656];v[22656]=0;if((i|0)!=1){break k}}b=P()|0;O()|0;break e}b=P()|0;O()|0;break e}t[c+1|0]=g}o:{p:{q:{r:{s:{t:{u:{v:{if(e&32){t[c+2|0]=1;v[22656]=0;g=T(374,h|0)|0;i=v[22656];v[22656]=0;if((i|0)==1){break v}t[d+16|0]=g;v[22656]=0;t[d|0]=64;g=ac(d+16|0,d);i=v[22656];v[22656]=0;if((i|0)==1){break u}t[c+4|0]=w[g|0]}if(!(e&16)){continue}v[22656]=0;R(403,d+16|0,h|0);e=v[22656];v[22656]=0;if((e|0)==1){break t}e=d+16|0;g=e;i=qd(e);e=w[e|0];switch(e-17|0){case 2:break r;case 0:case 1:break s;default:break q}}b=P()|0;O()|0;break e}b=P()|0;O()|0;break e}b=P()|0;O()|0;break e}e=e&15;break p}t[g|0]=33;t[i|0]=145;e=w[g|0];break o}if(e>>>0<17){break o}e=(e&240)==32?9:-1}t[g|0]=e}t[c+3|0]=e;t[c+5|0]=w[i|0];v[22656]=0;Of(c);c=v[22656];v[22656]=0;if((c|0)!=1){continue}break}b=P()|0;O()|0;break e}j=j+1|0;break d}if(v[d+312>>2]!=1414745673){break d}if(!ei(a)){break d}c=x[a+480190>>1]+1|0;u[a+480190>>1]=c;v[22656]=0;R(495,h|0,d+32|0);e=v[22656];v[22656]=0;w:{x:{y:{if((e|0)==1){break y}v[22656]=0;g=(B(c&65535,104)+a|0)+484380|0;R(496,d+32|0,g|0);c=v[22656];v[22656]=0;if((c|0)==1){break y}v[22656]=0;Nk(d,2,p);c=v[22656];v[22656]=0;if((c|0)==1){break x}v[22656]=0;R(324,d+16|0,d|0);c=v[22656];v[22656]=0;if((c|0)==1){break x}c=x[a+480190>>1];v[22656]=0;Q(301,((c<<5)+a|0)+946304|0,d+16|0)|0;c=v[22656];v[22656]=0;if((c|0)==1){break w}vb(d+16|0);if(!n){break d}i=d+16|0;c=Rc(i,8,1,0,1);e=2;f=d+45|0;z:{if(!(w[f|0]&64)){e=0;if(!(w[f|0]&2)){break z}}Bf(c,e)}if(w[f|0]&4){Yi(c,16)}v[22656]=0;W(329,i|0,g|0,h|0)|0;c=v[22656];v[22656]=0;if((c|0)!=1){break d}b=P()|0;O()|0;break e}b=P()|0;O()|0;break e}b=P()|0;O()|0;break e}b=P()|0;O()|0;vb(d+16|0);break e}b=P()|0;O()|0}xb(d+96|0);S(b|0);L()}xb(d+96|0);e=1;if(Ih(b,d+312|0)){continue}break}}gb=d+336|0;return e|0}function Uoa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,z=0,A=0;d=gb-320|0;gb=d;vc(b);g=gb-32|0;gb=g;f=g+24|0;AX(f,d+96|0);i=yb(f);f=v[g+28>>2];h=v[g+24>>2];v[g+8>>2]=h;v[g+12>>2]=f;v[g>>2]=h;v[g+4>>2]=f;h=g+16|0;f=b;cc(h,f,g);h=yb(h);if((h|0)==(i|0)){Rb(f,yb(g+24|0))}gb=g+32|0;a:{b:{c:{d:{if((i|0)!=(h|0)){break d}if(!EX(d+96|0)){break d}if(!Pb(b,Qc(DX(d+96|0),jb))){break d}if(!c){e=1;break d}Gd(a,2);Bg(a);v[a+480204>>2]=455e3;v[a+480188>>2]=524296;Ob(a+1074312|0,110,1);v[a+480208>>2]=v[a+480208>>2]|16777216;e=d- -64|0;Ke(e,2,d+127|0);f=d+80|0;Bc(f,e);Eb(a+1298268|0,f);vb(f);e=0;e:{f:{g:{h:{i:{while(1){g=d+80|0;f=(d+96|0)+B(e,19)|0;cD(g,f+63|0);i=d- -64|0;Bc(i,g);v[22656]=0;Q(399,((e<<5)+a|0)+480289|0,i|0)|0;g=v[22656];v[22656]=0;if((g|0)==1){break h}g=d- -64|0;vb(g);e=e+1|0;h=B(e,104)+a|0;j=h+484380|0;ud(j,2);v[d+72>>2]=0;v[d+64>>2]=0;v[d+68>>2]=0;i=w[f+78|0]|w[f+79|0]<<8|(w[f+80|0]<<16|w[f+81|0]<<24);t[g+7|0]=i;t[g+8|0]=i>>>8;t[g+9|0]=i>>>16;t[g+10|0]=i>>>24;i=w[f+75|0]|w[f+76|0]<<8|(w[f+77|0]<<16|w[f+78|0]<<24);f=w[f+71|0]|w[f+72|0]<<8|(w[f+73|0]<<16|w[f+74|0]<<24);t[g|0]=f;t[g+1|0]=f>>>8;t[g+2|0]=f>>>16;t[g+3|0]=f>>>24;t[g+4|0]=i;t[g+5|0]=i>>>8;t[g+6|0]=i>>>16;t[g+7|0]=i>>>24;v[d+8>>2]=v[d+72>>2];f=v[d+68>>2];v[d>>2]=v[d+64>>2];v[d+4>>2]=f;So(j,1,d);v[h+484404>>2]=8215;f=d+48|0;Bc(f,d+80|0);v[22656]=0;Q(301,((e<<5)+a|0)+946304|0,f|0)|0;f=v[22656];v[22656]=0;if((f|0)==1){break i}vb(d+48|0);if((e|0)!=8){continue}break}o=w[d+312|0];m=o+1|0;j=a+484360|0;kp(Sb(j),b,m,65535,65535);f=mc(d+80|0);v[22656]=0;W(358,b|0,f|0,m|0)|0;e=v[22656];v[22656]=0;if((e|0)==1){break g}z=d,A=Vb(f),v[z+64>>2]=A;z=d,A=Zb(f),v[z+48>>2]=A;if(Gb(d- -64|0,d+48|0)){while(1){if((w[v[d- -64>>2]]-1&255)>>>0>7){break f}e=d- -64|0;Pe(e);if(Gb(e,d+48|0)){continue}break}}z=a,A=w[lc(f,0)|0],v[z+480196>>2]=A;e=w[d+311|0];p=w[d+313|0];g=mc(d- -64|0);v[22656]=0;h=p+1|0;W(358,b|0,g|0,h|0)|0;i=v[22656];v[22656]=0;j:{if((i|0)==1){break j}v[22656]=0;i=a+484344|0;R(330,i|0,h|0);h=v[22656];v[22656]=0;if((h|0)==1){break j}q=e+1|0;k:{l:{if(!(c&1)){break l}h=0;while(1){c=w[lc(g,h)|0];v[22656]=0;c=W(331,i|0,c|0,q|0)|0;e=v[22656];v[22656]=0;if((e|0)==1){break k}if(!c){break l}c=0;n=_b(i,w[lc(g,h)|0]);k=0;while(1){if(v[n+12>>2]){r=c+1|0;e=0;while(1){v[22656]=0;c=T(374,b|0)|0;l=v[22656];v[22656]=0;m:{n:{if((l|0)!=1){if(!(c&128)){break n}e=(c&127)+e|0;break m}e=P()|0;O()|0;break c}v[22656]=0;l=Yc(n,e,k&65535);s=v[22656];v[22656]=0;o:{if((s|0)!=1){if((c|0)!=1){break o}t[l|0]=254;break m}e=P()|0;O()|0;break c}if((c-1&255)>>>0>96){break m}t[l+1|0]=r;t[l|0]=c+12}e=e+1|0;if(e>>>0<y[n+12>>2]){continue}break}}e=k&65535;c=k+1|0;k=c;if(e>>>0<7){continue}break}c=(h|0)==(p|0);h=h+1|0;if(!c){continue}break}}c=0;e=0;p:{q:{r:{s:{t:{u:{v:{while(1){b=Sb(j);v[22656]=0;h=e&65535;b=Q(472,b|0,h|0)|0;k=v[22656];v[22656]=0;if((k|0)==1){break v}w:{if(!b){v[22656]=0;b=W(545,i|0,q|0,0)|0;k=v[22656];v[22656]=0;if((k|0)==1){break u}if((b|0)==65535){break w}z=sc(Sb(j),c),A=b,u[z>>1]=A}z=d,A=Zb(_b(i,x[sc(Sb(j),c)>>1])),v[z+32>>2]=A;z=d,A=bD(d+32|0,1),v[z+48>>2]=A;b=w[lc(f,(c+1>>>0)%(m>>>0)|0)|0];if((b|0)==w[v[d+48>>2]+5|0]){break w}x:{if(w[v[d+48>>2]+3|0]!=16){break x}c=Sb(j);v[22656]=0;c=Q(546,c|0,h|0)|0;h=v[22656];v[22656]=0;if((h|0)==1){break p}if((c|0)==65535){break x}z=d,A=Zb(_b(i,c)),v[z+32>>2]=A;z=d,A=bD(d+32|0,1),v[z+48>>2]=A}t[v[d+48>>2]+3|0]=16;t[v[d+48>>2]+5|0]=b}e=e+1|0;c=e&65535;if(o>>>0>=c>>>0){continue}break}v[22656]=0;b=Q(2,d+48|0,5747)|0;c=v[22656];v[22656]=0;if((c|0)==1){break t}Eb(a+1298304|0,b);vb(b);v[22656]=0;b=Q(2,d+48|0,3141)|0;c=v[22656];v[22656]=0;if((c|0)==1){break s}Eb(a+1298316|0,b);vb(b);v[22656]=0;_j(d+16|0,2,d+107|0);b=v[22656];v[22656]=0;if((b|0)==1){break r}v[22656]=0;R(324,d+32|0,d+16|0);b=v[22656];v[22656]=0;if((b|0)==1){break r}v[22656]=0;U(13,d+48|0,5,d+32|0);b=v[22656];v[22656]=0;e=1;if((b|0)==1){break q}b=d+48|0;Eb(a+1298328|0,b);vb(b);vb(d+32|0);v[a+1298364>>2]=5;gc(g);break e}e=P()|0;O()|0;break c}e=P()|0;O()|0;break c}e=P()|0;O()|0;break c}e=P()|0;O()|0;break c}e=P()|0;O()|0;break c}e=P()|0;O()|0;vb(d+32|0);break c}e=P()|0;O()|0;break c}e=P()|0;O()|0;break c}e=P()|0;O()|0;break c}e=P()|0;O()|0;vb(d+48|0);break a}e=P()|0;O()|0;vb(d- -64|0);break a}e=P()|0;O()|0;break b}e=0}gc(f)}gb=d+320|0;return e|0}gc(g)}gc(f)}S(e|0);L()}function dla(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;d=gb-176|0;gb=d;vc(b);a:{if(!dD(b,d+128|0)){break a}if(!lU(d+128|0)){break a}if(!Pb(b,Qc(kU(d+128|0),jb))){break a}b:{if(!c){break b}Gd(a,256);h=d+16|0;_j(h,2,d+128|0);g=d+48|0;Bc(g,h);Eb(a+1298268|0,g);vb(g);e=Tb(g,12473);Eb(a+1298304|0,e);vb(e);e=Tb(g,7390);Eb(a+1298316|0,e);vb(e);Df(h,1380);v[22656]=0;R(371,d+112|0,d+159|0);e=v[22656];v[22656]=0;c:{d:{e:{f:{g:{if((e|0)!=1){v[22656]=0;Y(885,d+48|0,d+16|0,d+158|0,d+112|0);e=v[22656];v[22656]=0;if((e|0)==1){break g}e=d+48|0;Eb(a+1298328|0,e);vb(e);vb(d+112|0);Hb(d+16|0);v[a+1298364>>2]=5;v[a+480260>>2]=64;v[a+480264>>2]=32767;v[a+480188>>2]=2031620;f=w[d+160|0];if(w[d+159|0]<=20){e=((f&255)>>>0)/10|0;f=e<<4|f-B(e,10)}h=(f&255?f:96)&255;e=FP(h);v[a+480196>>2]=h>>>4;v[a+480204>>2]=e;if(w[d+159|0]>10){break e}break d}f=P()|0;O()|0;break f}f=P()|0;O()|0;vb(d+112|0)}Hb(d+16|0);break c}t[d+48|0]=64;p=a,q=w[ac(d+162|0,d+48|0)|0]<<2,v[p+480200>>2]=q}f=0;while(1){e=(f<<5)+a|0;We(e+480280|0);u[e+480284>>1]=f&1?64:192;f=f+1|0;if((f|0)!=4){continue}break}f=1;h:{i:{while(1){gv(b,d+16|0);if(w[d+28|0]!=46?w[d+28|0]:0){break i}j=gb-32|0;gb=j;i=(B(f,104)+a|0)+484380|0;ud(i,0);g=d+16|0;k=g;Mk(j,2,g);e=j+16|0;Bc(e,j);v[22656]=0;Q(303,i+43|0,e|0)|0;e=v[22656];v[22656]=0;j:{k:{if((e|0)!=1){h=j+16|0;vb(h);e=k+24|0;v[i+24>>2]=w[e|0]|w[e+1|0]<<8;t[j+16|0]=w[k+22|0];t[j|0]=64;p=i,q=w[ac(h,j)|0]<<2,u[p+30>>1]=q;e=k+16|0;v[i>>2]=w[e|0]|w[e+1|0]<<8;e=k+18|0;v[i+4>>2]=w[e|0]|w[e+1|0]<<8;e=k+20|0;k=w[e|0]|w[e+1|0]<<8;v[i+8>>2]=k;h=v[i>>2];if(h>>>0>1){break k}v[i>>2]=0;break j}a=P()|0;O()|0;vb(j+16|0);S(a|0);L()}e=v[i+4>>2];if((k|0)==65535|h>>>0<=e>>>0|e>>>0>=k>>>0){break j}u[i+34>>1]=2;p=i,q=v[Fb(i+8|0,i)>>2],v[p+8>>2]=q}gb=j+32|0;Mk(d,2,g);e=d+112|0;Bc(e,d);v[22656]=0;Q(301,((f<<5)+a|0)+946304|0,e|0)|0;e=v[22656];v[22656]=0;if((e|0)==1){break h}vb(d+112|0);u[((f<<1)+d|0)+46>>1]=w[d+30|0]|w[d+31|0]<<8;f=f+1|0;if((f|0)!=32){continue}break}e=a+484360|0;kp(Sb(e),b,w[d+159|0]?128:64,65535,65535);e=Sb(e);p=d,q=Vb(e),v[p+16>>2]=q;p=d,q=Zb(e),v[p+112>>2]=q;if(Gb(d+16|0,d+112|0)){while(1){e=v[d+16>>2];h=x[e>>1];l:{if(!((h|0)!=255&(h|0)!=99)){u[e>>1]=65535;break l}if(h>>>0>63){break i}}e=d+16|0;of(e);if(Gb(e,d+112|0)){continue}break}}k=c&1;if(k){Ag(a+484344|0,w[d+161|0])}if(w[d+161|0]){o=a+484344|0;while(1){m:{n:{if(k){if(wh(o,m&65535,64)){break n}}f=0;while(1){if((Ae(b)+5&255)>>>0>=3){Rb(b,3)}f=f+1|0;if((f|0)!=256){continue}break}break m}p=d,q=Vb(_b(o,m)),v[p+112>>2]=q;v[d>>2]=63;l=65535;n=0;while(1){f=0;while(1){h=f;g=0;f=0;i=0;j=0;o:{p:{q:{r:{s:{t:{e=Ae(b);switch(e-251|0){case 1:break o;case 0:break r;case 2:break t;default:break s}}t[v[d+112>>2]]=254;break o}g=d+16|0;Vr(g,b);f=w[ic(g,0)|0];i=w[ic(g,1)|0];j=w[ic(g,2)|0];g=254;if((e|0)==254){break q}g=e;if(e>>>0>95){break p}}g=(B(g>>>4|0,12)+(g&15)|0)+37|0}e=g;t[v[d+112>>2]]=e}t[v[d+112>>2]+1|0]=(f&248)>>>3;if(w[v[d+112>>2]+1|0]>=32){t[v[d+112>>2]+1|0]=0}e=i>>>1&120|f&7;if(e>>>0<=64){t[v[d+112>>2]+2|0]=1;t[v[d+112>>2]+4|0]=e}t[v[d+112>>2]+3|0]=w[(i&15)+33344|0];t[v[d+112>>2]+5|0]=j;u:{switch(w[v[d+112>>2]+3|0]-11|0){case 0:g=v[d+112>>2];e=w[g+5|0];if(w[v[d+112>>2]+5|0]&15){t[g+5|0]=e&15;break o}t[g+5|0]=e&240;break o;case 3:e=w[v[d+112>>2]+5|0];t[v[d+112>>2]+5|0]=B(e&240,10)|e&15;v:{if((l|0)!=65535){if(w[v[d+112>>2]+5|0]){break v}t[v[d+112>>2]+3|0]=12;t[v[d+112>>2]+5|0]=l}l=65535}qc(d,n);break o;case 1:l=w[v[d+112>>2]+5|0];v[d>>2]=63;t[v[d+112>>2]+3|0]=0;break o;case 5:if(w[d+159|0]<=20){e=w[v[d+112>>2]+5|0];t[v[d+112>>2]+5|0]=(e>>>0)%10|(e>>>0)/10<<4}if(w[v[d+112>>2]+5|0]){break o}t[v[d+112>>2]+3|0]=0;break o;case 7:break o;default:break u}}if(w[v[d+112>>2]+5|0]){break o}t[v[d+112>>2]+3|0]=0}bk(d+112|0);f=h+1|0;if((h&65535)>>>0<3){continue}break}n=n+1|0;if((n|0)!=64){continue}break}if((l|0)==65535){break m}Jm(_b(o,m),qp(Ue(Be(d+16|0,12,l&255),v[d>>2])))}m=m+1|0;if(m>>>0<w[d+161|0]){continue}break}}f=1;if(!(c&2)){break a}h=Rc(d+16|0,8,1,0,0);while(1){c=B(f,104)+a|0;e=c+484380|0;w:{if(!v[e>>2]|!x[c+484410>>1]){break w}c=x[((f<<1)+d|0)+46>>1];if(c>>>0<4){break w}if(!Wc(b,c<<4)){break w}Dg(h,e,b)}f=f+1|0;if((f|0)!=32){continue}break}break b}f=0;break a}f=P()|0;O()|0;vb(d+112|0)}S(f|0);L()}f=1}gb=d+176|0;return f|0}function Noa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;m=gb-736|0;gb=m;a:{b:{if(d>>>0<=511){d=0;a=gb-32|0;gb=a;e=a+24|0;g=m+56|0;bc(e,g,554);e=yb(e);k=v[a+28>>2];j=v[a+24>>2];v[a+8>>2]=j;v[a+12>>2]=k;v[a>>2]=j;v[a+4>>2]=k;k=a+16|0;cc(k,b,a);k=yb(k);if((k|0)==(e|0)){Rb(b,yb(a+24|0))}gb=a+32|0;a=(e|0)==(k|0);if(!a){Qb(g,0,554)}if(!a){break b}b=gb-32|0;gb=b;c:{d:{a=m+56|0;e:{if((w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24))!=1229999433){break e}Dp(b,3,a+32|0);d=b+16|0;Bc(d,b);v[22656]=0;Q(301,c+492|0,d|0)|0;d=v[22656];v[22656]=0;if((d|0)==1){break d}d=b+16|0;vb(d);ki(b,1,a+4|0);Bc(d,b);v[22656]=0;Q(301,c+524|0,d|0)|0;d=v[22656];v[22656]=0;if((d|0)==1){break d}vb(b+16|0);d=w[a+24|0]|w[a+25|0]<<8;v[c+4>>2]=64;v[c+8>>2]=128;v[c>>2]=d<<6;t[c+16|0]=w[a+26|0];t[c+17|0]=w[a+27|0];e=c+108|0;k=c+236|0;while(1){g=a+(h<<1)|0;d=w[g- -64|0];g=w[g+65|0];o=vd(k,h),p=g,u[o>>1]=p;o=ic(e,h),p=(d>>>0<120?d:h)+1|0,t[o|0]=p;h=h+1|0;if((h|0)!=120){continue}break}t[c+60|0]=w[c+60|0]&254|t[a+17|0]&1;t[c+60|0]=w[c+60|0]&253|w[a+17|0]&2;t[c+60|0]=w[c+60|0]&251|w[a+17|0]&4;k=c+61|0;t[k|0]=w[a+18|0];g=c+62|0;t[g|0]=w[a+19|0];j=c+63|0;t[j|0]=w[a+20|0];i=c- -64|0;t[i|0]=w[a+21|0];d=c+48|0;kh(d,25);h=0;while(1){f:{f=h<<1;e=w[(f+a|0)+504|0];o=Mb(d,h),p=e,u[o>>1]=p;if((e|0)==255){kh(d,h);break f}e=w[(a+(f|1)|0)+504|0];o=Mb(d,h),p=e,t[o+2|0]=p;h=h+1|0;if((h|0)!=25){continue}}break}a=w[df(k,g)|0];if(Nb(d)>>>0<=a>>>0){t[c+60|0]=w[c+60|0]&253}a=w[df(j,i)|0];if(Nb(d)>>>0>a>>>0){break e}t[c+60|0]=w[c+60|0]&251}gb=b+32|0;break c}a=P()|0;O()|0;vb(b+16|0);S(a|0);L()}d=554;break b}k=v[b+8>>2];h=m+56|0;i=h;g=gb-48|0;gb=g;v[g+44>>2]=674;v[g+24>>2]=674;d=b;j=v[Fb(g+44|0,g+24|0)>>2];if(!Pb(d,j)){j=nf(d)}f=g+24|0;UW(f,i);n=wd(g+32|0,v[f>>2],j);l=v[n+4>>2];v[g+8>>2]=v[n>>2];v[g+12>>2]=l;cc(g+16|0,d,g+8|0);UW(f,i);Qb(v[g+24>>2]+j|0,0,674-j|0);Rb(d,v[g+44>>2]);gb=g+48|0;g=b;j=c;d=c;n=v[a+480180>>2];i=gb-32|0;gb=i;g:{h:{a=h;if((w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24))==1229999433){Dp(i,3,a+32|0);f=i+16|0;Bc(f,i);v[22656]=0;Q(301,d+492|0,f|0)|0;f=v[22656];v[22656]=0;if((f|0)==1){break h}f=i+16|0;vb(f);ki(i,1,a+4|0);Bc(f,i);v[22656]=0;Q(301,d+524|0,f|0)|0;f=v[22656];v[22656]=0;if((f|0)==1){break h}f=i+16|0;vb(f);v[d>>2]=(w[a+20|0]|w[a+21|0]<<8)<<5;v[d+4>>2]=w[a+24|0]>>>1;qc(d+4|0,64);l=w[a+25|0]&127;v[d+8>>2]=l>>>0>64?128:l<<2;t[d+15|0]=w[d+15|0]&254|((w[a+25|0]^-1)&128)>>>7;t[i+16|0]=w[a+26|0];t[i|0]=100;o=d,p=w[ac(f,i)|0],t[o+20|0]=p;t[i+16|0]=w[a+27|0];t[i|0]=64;o=d,p=w[ac(f,i)|0],t[o+19|0]=p;t[d+16|0]=w[a+17|0];t[d+17|0]=w[a+18|0];t[d+18|0]=w[a+19|0];t[d+26|0]=w[a+22|0];t[d+27|0]=w[a+23|0];hm(d,w[a+58|0]&127,w[a+58|0]>>>7|0);gm(d,w[a+59|0]&127,w[a+59|0]>>>7|0);i:{j:{k:{f=w[a+28|0]|w[a+29|0]<<8;if(!((f|0)==514|(f|0)==529|(w[a+28|0]|w[a+29|0]<<8)==544)){if((w[a+28|0]|w[a+29|0]<<8)!=532){break k}}if(w[a+61|0]==255){break k}if(w[a+61|0]<=128){t[d+30|0]=w[a+61|0]}e=w[a+62|0]|w[a+63|0]<<8;if(e>>>0<129){break j}break i}if(t[a+61|0]>=0){t[d+30|0]=w[a+61|0]+1}e=t[a+62|0]>=0?w[a+62|0]+1|0:e;if(t[a+63|0]<0){break j}e=(w[a+63|0]<<7)+e|0}u[d+28>>1]=e}e=t[a+60|0];t[d+31|0]=e;if((e|0)<0){t[d+31|0]=0;t[d+34|0]=e^128}e=0;f=n&16777216?240:25;Aw(a+304|0,d+48|0,0,f);Aw(a+386|0,d+68|0,32,f);Aw(a+468|0,d+88|0,32,f);t[d+100|0]=w[d+100|0]&239|w[a+468|0]>>>3&16;f=d+108|0;n=d+236|0;while(1){l=a+(e<<1)|0;d=w[l- -64|0];l=w[l+65|0];o=vd(n,e),p=l,u[o>>1]=p;o=ic(f,e),p=(d>>>0<120?d:e)+1|0,t[o|0]=p;e=e+1|0;if((e|0)!=120){continue}break}e=554}gb=i+32|0;a=e;break g}a=P()|0;O()|0;vb(i+16|0);S(a|0);L()}if(a){d=w[h+550|0]|w[h+551|0]<<8|(w[h+552|0]<<16|w[h+553|0]<<24);if(!((d|0)!=1481920589&(d|0)!=1297110104)){d=j+236|0;a=0;while(1){e=w[(a+h|0)+554|0];j=vd(d,a);u[j>>1]=x[j>>1]|e<<8;a=a+1|0;if((a|0)!=120){continue}break}a=674}}else{a=0}d=a;Wc(g,k+d|0);if(!Gh(b,11287)){break b}e=m+8|0;Td(e,b,sg(b));a=kc(m+32|0,e);xb(e);v[22656]=0;e=T(195,a|0)|0;b=v[22656];v[22656]=0;if((b|0)==1){break a}v[22656]=0;b=Q(555,a|0,11078)|0;h=v[22656];v[22656]=0;if((h|0)==1){break a}if(b){v[22656]=0;b=T(374,a|0)|0;h=v[22656];v[22656]=0;if((h|0)==1){break a}t[c+34|0]=b>>>0>250?0:b}d=(d+e|0)+8|0;xb(a)}gb=m+736|0;return d|0}b=P()|0;O()|0;xb(a);S(b|0);L()}function sL(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0;e=gb-416|0;gb=e;t[e+415|0]=c;a:{if(rk(b)){break a}f=w[vl(b)|0];if((f|0)==33){d=1}else{if((f|0)!=63){break a}d=0}Kl(e+160|0,b,v[b+4>>2]-1|0);f=v[e+164>>2];v[b>>2]=v[e+160>>2];v[b+4>>2]=f}f=e+160|0;Ld(f);g=v[e+160>>2];Ld(e+376|0);h=ul(g,v[e+380>>2],b);Ld(f);f=v[b>>2];g=v[b+4>>2];b:{c:{d:{e:{f:{g:{h:{if((h|0)==v[e+164>>2]){v[e+400>>2]=f;v[e+404>>2]=g;a=uc(e+392|0,18726);c=v[e+404>>2];v[e+8>>2]=v[e+400>>2];v[e+12>>2]=c;c=v[a+4>>2];v[e>>2]=v[a>>2];v[e+4>>2]=c;if(Gc(e+8|0,e)){a=ba(8)|0;v[22656]=0;R(2056,e+376|0,e+415|0);b=v[22656];v[22656]=0;if((b|0)!=1){v[22656]=0;U(2037,e+160|0,14728,e+376|0);b=v[22656];v[22656]=0;if((b|0)==1){break g}rc(a,e+160|0);v[22656]=0;U(186,a|0,54952,1936);a=v[22656];v[22656]=0;if((a|0)!=1){break b}b=P()|0;O()|0;vb(e+160|0);vb(e+376|0);break c}b=P()|0;O()|0;break d}if(!d){break h}a=ba(8)|0;v[22656]=0;c=Q(2057,e+344|0,b|0)|0;b=v[22656];v[22656]=0;i:{j:{k:{l:{m:{n:{o:{p:{if((b|0)!=1){v[22656]=0;U(2037,e+360|0,14764,c|0);b=v[22656];v[22656]=0;if((b|0)==1){break p}v[22656]=0;R(2054,e+376|0,e+360|0);b=v[22656];v[22656]=0;d=1;if((b|0)==1){break o}v[22656]=0;R(2056,e+328|0,e+415|0);b=v[22656];v[22656]=0;if((b|0)==1){break n}v[22656]=0;U(2058,e+160|0,e+376|0,e+328|0);b=v[22656];v[22656]=0;if((b|0)==1){break m}rc(a,e+160|0);v[22656]=0;U(186,a|0,54952,1936);b=v[22656];v[22656]=0;if((b|0)!=1){break b}b=P()|0;O()|0;vb(e+160|0);d=0;break l}b=P()|0;O()|0;break i}b=P()|0;O()|0;vb(c);break i}b=P()|0;O()|0;break j}b=P()|0;O()|0;break k}b=P()|0;O()|0}vb(e+328|0)}vb(e+376|0)}vb(e+360|0);vb(c);if(!d){break c}}ca(a|0);break c}v[e+320>>2]=f;v[e+324>>2]=g;d=uc(e+312|0,18726);f=v[e+324>>2];v[e+152>>2]=v[e+320>>2];v[e+156>>2]=f;f=v[d+4>>2];v[e+144>>2]=v[d>>2];v[e+148>>2]=f;if(Gc(e+152|0,e+144|0)){a=ba(8)|0;v[22656]=0;R(2056,e+376|0,e+415|0);b=v[22656];v[22656]=0;if((b|0)!=1){v[22656]=0;U(2037,e+160|0,14728,e+376|0);b=v[22656];v[22656]=0;if((b|0)==1){break f}rc(a,e+160|0);v[22656]=0;U(186,a|0,54952,1936);a=v[22656];v[22656]=0;if((a|0)!=1){break b}b=P()|0;O()|0;vb(e+160|0);vb(e+376|0);break c}b=P()|0;O()|0;break e}d=v[b+4>>2];v[e+304>>2]=v[b>>2];v[e+308>>2]=d;d=uc(e+296|0,4506);f=v[e+308>>2];v[e+136>>2]=v[e+304>>2];v[e+140>>2]=f;f=v[d+4>>2];v[e+128>>2]=v[d>>2];v[e+132>>2]=f;q:{if(!Gc(e+136|0,e+128|0)){d=v[b+4>>2];v[e+288>>2]=v[b>>2];v[e+292>>2]=d;d=uc(e+280|0,4488);f=v[e+292>>2];v[e+120>>2]=v[e+288>>2];v[e+124>>2]=f;f=v[d+4>>2];v[e+112>>2]=v[d>>2];v[e+116>>2]=f;if(!Gc(e+120|0,e+112|0)){break q}}t[a+60|0]=c;break h}d=v[b+4>>2];v[e+272>>2]=v[b>>2];v[e+276>>2]=d;d=uc(e+264|0,3991);f=v[e+276>>2];v[e+104>>2]=v[e+272>>2];v[e+108>>2]=f;f=v[d+4>>2];v[e+96>>2]=v[d>>2];v[e+100>>2]=f;r:{if(!Gc(e+104|0,e+96|0)){d=v[b+4>>2];v[e+256>>2]=v[b>>2];v[e+260>>2]=d;d=uc(e+248|0,3972);f=v[e+260>>2];v[e+88>>2]=v[e+256>>2];v[e+92>>2]=f;f=v[d+4>>2];v[e+80>>2]=v[d>>2];v[e+84>>2]=f;if(!Gc(e+88|0,e+80|0)){break r}}t[a+61|0]=c;break h}d=v[b+4>>2];v[e+240>>2]=v[b>>2];v[e+244>>2]=d;d=uc(e+232|0,4075);f=v[e+244>>2];v[e+72>>2]=v[e+240>>2];v[e+76>>2]=f;f=v[d+4>>2];v[e+64>>2]=v[d>>2];v[e+68>>2]=f;if(Gc(e+72|0,e- -64|0)){t[a+62|0]=c;break h}d=v[b+4>>2];v[e+224>>2]=v[b>>2];v[e+228>>2]=d;d=uc(e+216|0,3156);f=v[e+228>>2];v[e+56>>2]=v[e+224>>2];v[e+60>>2]=f;f=v[d+4>>2];v[e+48>>2]=v[d>>2];v[e+52>>2]=f;if(Gc(e+56|0,e+48|0)){t[a+63|0]=c;break h}d=v[b+4>>2];v[e+208>>2]=v[b>>2];v[e+212>>2]=d;d=uc(e+200|0,4555);f=v[e+212>>2];v[e+40>>2]=v[e+208>>2];v[e+44>>2]=f;f=v[d+4>>2];v[e+32>>2]=v[d>>2];v[e+36>>2]=f;if(Gc(e+40|0,e+32|0)){t[a+64|0]=c;break h}d=v[b+4>>2];v[e+192>>2]=v[b>>2];v[e+196>>2]=d;b=uc(e+184|0,10720);d=v[e+196>>2];v[e+24>>2]=v[e+192>>2];v[e+28>>2]=d;d=v[b+4>>2];v[e+16>>2]=v[b>>2];v[e+20>>2]=d;if(!Gc(e+24|0,e+16|0)){break h}d=a+24|0;b=v[d>>2];f=b+24664|0;g=v[f+4>>2];v[e+176>>2]=v[f>>2];v[e+180>>2]=g;f=b+24656|0;g=v[f+4>>2];v[e+168>>2]=v[f>>2];v[e+172>>2]=g;f=v[b+24652>>2];v[e+160>>2]=v[b+24648>>2];v[e+164>>2]=f;b=e;if(c){a=FK(v[a+56>>2])}else{a=0}v[b+180>>2]=a;if(!Qy(e+160|0,v[d>>2]+24648|0)){break h}_z(v[d>>2],e+160|0)}gb=e+416|0;return}b=P()|0;O()|0;vb(e+376|0);break d}b=P()|0;O()|0;vb(e+376|0)}ca(a|0);break c}ca(a|0)}S(b|0)}L()}function Xja(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;e=gb-192|0;gb=e;a:{if(!Pb(c,8)){break a}Rb(c,4);while(1){n=wv(c);if(n){break a}p=gb-288|0;gb=p;f=PR(p);g=gb-384|0;gb=g;i=g+96|0;PR(i);j=hc(f,i,282);f=0;b:{c:{d:{e:{f:{g:{h:{h=c;if(Gh(h,10979)){pg(h,4);l=le(g+72|0,h);v[22656]=0;i=Q(1105,l|0,j|0)|0;k=v[22656];v[22656]=0;if((k|0)==1){break e}i:{if(!i){break i}i=w[j+26|0];v[22656]=0;i=Q(191,l|0,i|0)|0;k=v[22656];v[22656]=0;if((k|0)==1){break e}if(!i){break i}k=0;j:{k:{l:{if(w[j+26|0]){while(1){v[22656]=0;i=T(309,l|0)|0;m=v[22656];v[22656]=0;if((m|0)==1){break l}t[(j+k|0)+27|0]=i;f=f+i|0;k=k+1|0;if(k>>>0<w[j+26|0]){continue}break}k=f&65535}f=0;v[22656]=0;i=Q(191,l|0,k|0)|0;m=v[22656];v[22656]=0;if((m|0)==1){break d}if(!i){break i}v[22656]=0;Q(318,l|0,k|0)|0;f=v[22656];v[22656]=0;if((f|0)==1){break d}pg(l,QR(j));i=Ui(g- -64|0);f=g+96|0;_A(f);v[22656]=0;R(1106,l|0,f|0);f=v[22656];v[22656]=0;if((f|0)==1){break k}u[g+118>>1]=0;u[g+120>>1]=0;OR(i,g+96|0,g+123|0);f=w[j+26|0];v[22656]=0;Q(318,l|0,f|0)|0;f=v[22656];v[22656]=0;if((f|0)==1){break k}f=j+27|0;OR(i,f,f+w[j+26|0]|0);v[22656]=0;U(288,g+16|0,l|0,k|0);f=v[22656];v[22656]=0;if((f|0)!=1){break j}f=P()|0;O()|0;break c}f=P()|0;O()|0;break c}f=P()|0;O()|0;break c}f=g+16|0;k=kc(g+40|0,f);xb(f);v[22656]=0;R(757,f|0,k|0);f=v[22656];v[22656]=0;if((f|0)==1){break h}v[22656]=0;Yv(g+8|0,g+16|0);f=v[22656];v[22656]=0;if((f|0)==1){break g}f=i;o=g+8|0;m=v[o>>2];o=v[o+4>>2];if((m|0)!=(o|0)){while(1){MR(f,zb(w[m|0]));m=m+1|0;if((o|0)!=(m|0)){continue}break}}zc(g+16|0);xb(k);f=0;if(v[i>>2]!=(w[j+22|0]|w[j+23|0]<<8|(w[j+24|0]<<16|w[j+25|0]<<24))){break i}f=QR(j);v[22656]=0;Q(318,h|0,f|0)|0;i=v[22656];v[22656]=0;f=1;if((i|0)==1){break d}}xb(l)}gb=g+384|0;break b}f=P()|0;O()|0;break f}f=P()|0;O()|0;zc(g+16|0)}xb(k);break c}f=P()|0;O()|0;break c}f=P()|0;O()|0}xb(l);S(f|0);L()}gb=p+288|0;if(f){continue}break}}t[d|0]=w[d|0]!=0|n;vc(c);m:{n:{o:{p:{q:{r:{if(n){i=sg(c);d=e+144|0;Td(d,c,nf(c));f=kc(e+168|0,d);xb(d);u[a+34>>1]=x[a+34>>1]&65534|w[b|0]>15;b=x[a+34>>1]&-65|(w[b+1|0]!=1)<<6;u[a+34>>1]=b;v[a>>2]=i>>>(b&1)>>>(b>>>6&1);v[e+140>>2]=0;v[e+136>>2]=0;v[22656]=0;R(757,d|0,f|0);b=v[22656];v[22656]=0;if((b|0)==1){break r}v[22656]=0;b=Sd(e+144|0);c=v[22656];v[22656]=0;if((c|0)!=1){c=v[e+144>>2];d=zb(b);i=Ti(c);v[22656]=0;i=fa(756,d|0,i|0,e+140|0,e+136|0,0)|0;d=v[22656];v[22656]=0;if((d|0)==1){break o}v[22656]=0;Q(318,f|0,v[e+140>>2])|0;d=v[22656];v[22656]=0;if((d|0)==1){break o}if(!i){break p}h=v[e+140>>2];v[22656]=0;T(386,a|0)|0;d=v[22656];v[22656]=0;if((d|0)==1){break o}d=c-h|0;b=b+h|0;n=v[e+136>>2];c=0;while(1){s:{if(n){if(!d|(n|0)!=1){break q}if(y[a>>2]>c>>>0){break s}break q}if(y[a>>2]<=c>>>0){break q}}if(!Jd(a)){break q}v[e+132>>2]=0;v[e+128>>2]=0;h=zb(b);g=Ti(d);v[22656]=0;h=la(758,i|0,h|0,g|0,e+132|0,e+124|0,e+128|0)|0;g=v[22656];v[22656]=0;if((g|0)==1){break o}v[22656]=0;v[e+140>>2]=h;Q(318,f|0,h|0)|0;h=v[22656];v[22656]=0;if((h|0)==1){break o}j=v[e+140>>2];dk(e+128|0,Ti(v[a>>2]-c|0));t:{if(v[e+128>>2]<=0){break t}if(v[e+132>>2]!=(fd(a)|0)){break t}if(t[a+34|0]&1){h=mg(e+112|0,v[a+20>>2]+(B(fd(a),c)<<1)|0,fd(a),v[e+128>>2]);g=mg(e+96|0,v[e+124>>2],v[e+132>>2],v[e+128>>2]);v[22656]=0;v[e+56>>2]=v[h+8>>2];l=v[h+4>>2];v[e+48>>2]=v[h>>2];v[e+52>>2]=l;v[e+40>>2]=v[g+8>>2];h=v[g+4>>2];v[e+32>>2]=v[g>>2];v[e+36>>2]=h;R(759,e+48|0,e+32|0);h=v[22656];v[22656]=0;if((h|0)!=1){break t}break o}h=mg(e+80|0,v[a+20>>2]+B(fd(a),c)|0,fd(a),v[e+128>>2]);g=mg(e- -64|0,v[e+124>>2],v[e+132>>2],v[e+128>>2]);v[22656]=0;v[e+24>>2]=v[h+8>>2];l=v[h+4>>2];v[e+16>>2]=v[h>>2];v[e+20>>2]=l;v[e+8>>2]=v[g+8>>2];h=v[g+4>>2];v[e>>2]=v[g>>2];v[e+4>>2]=h;R(760,e+16|0,e|0);h=v[22656];v[22656]=0;if((h|0)==1){break o}}v[22656]=0;h=v[e+128>>2];n=oy(i);g=v[22656];v[22656]=0;if((g|0)==1){break o}d=d-j|0;b=b+j|0;v[e+136>>2]=n;c=c+h|0;continue}}break o}Dg(b,a,c);a=1;break m}a=P()|0;O()|0;break n}v[22656]=0;py(i);a=v[22656];v[22656]=0;if((a|0)!=1){break p}break o}a=(i|0)!=0;zc(e+144|0);xb(f);break m}a=P()|0;O()|0;zc(e+144|0)}xb(f);S(a|0);L()}gb=e+192|0;return a|0}function $la(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;g=gb-256|0;gb=g;vc(b);a:{if(!vY(b,g+184|0)){break a}if(!bV(g+184|0)){break a}if(!Pb(b,Qc(aV(g+184|0),jb))){break a}b:{if(!c){break b}Gd(a,16);e=g+24|0;f=g+184|0;_j(e,2,f|4);d=g+48|0;Bc(d,e);Eb(a+1298268|0,d);vb(d);u[a+480190>>1]=w[g+214|0];u[a+480188>>1]=w[g+217|0];i=Tb(d,5512);Eb(a+1298304|0,i);vb(i);i=Tb(d,7399);Eb(a+1298316|0,i);vb(i);Df(e,1320);f=f|3;v[g>>2]=w[f|0]>>>4;f=w[f|0];v[22656]=0;v[g+180>>2]=f&15;Y(460,d|0,e|0,g|0,g+180|0);e=v[22656];v[22656]=0;d=1;c:{d:{e:{if((e|0)!=1){e=g+48|0;Eb(a+1298328|0,e);vb(e);Hb(g+24|0);v[a+1298364>>2]=5;if(x[a+480190>>1]){e=1;while(1){i=g+48|0;EE(b,i);j=gb-16|0;gb=j;h=(B(d,104)+a|0)+484380|0;ud(h,0);f=i;u[j+14>>1]=w[f+35|0]<<2;u[j+12>>1]=256;q=h,r=x[Pc(j+14|0,j+12|0)>>1],u[q+30>>1]=r;f:{if((w[f+22|0]|w[f+23|0]<<8|(w[f+24|0]<<16|w[f+25|0]<<24))>>>0<3){break f}v[h>>2]=w[f+22|0]|w[f+23|0]<<8|(w[f+24|0]<<16|w[f+25|0]<<24);v[h+4>>2]=w[f+26|0]|w[f+27|0]<<8|(w[f+28|0]<<16|w[f+29|0]<<24);v[j+8>>2]=w[f+30|0]|w[f+31|0]<<8|(w[f+32|0]<<16|w[f+33|0]<<24);v[j+4>>2]=1;q=h,r=v[Lc(j+8|0,j+4|0)>>2]-1|0,v[q+8>>2]=r;qc(h+8|0,v[h>>2]);g:{if(y[h+8>>2]<=v[h+4>>2]+4>>>0){v[h+4>>2]=0;v[h+8>>2]=0;break g}u[h+34>>1]=x[h+34>>1]|2}t[h+37|0]=w[f+34|0];q=h,r=Mu(0,t[f+34|0]<<4),v[q+24>>2]=r;if(!(t[f+36|0]&1)){break f}u[h+34>>1]=x[h+34>>1]|1;v[h>>2]=v[h>>2]>>>1;v[h+4>>2]=v[h+4>>2]>>>1;v[h+8>>2]=v[h+8>>2]>>>1}gb=j+16|0;Rk(g,2,i);f=g+24|0;Bc(f,g);v[22656]=0;Q(301,((d<<5)+a|0)+946304|0,f|0)|0;d=v[22656];v[22656]=0;if((d|0)==1){break e}vb(g+24|0);e=e+1|0;d=e&65535;if(d>>>0<=x[a+480190>>1]){continue}break}}if(x[a+480188>>1]){d=0;while(1){e=(d<<5)+a|0;We(e+480280|0);u[e+480284>>1]=(w[(d+g|0)+218|0]<<4|8)&248;d=d+1|0;if(d>>>0<x[a+480188>>1]){continue}break}}i=g+48|0;e=i;f=gb-32|0;gb=f;d=b;h:{if(!Pb(d,128)){d=gb-16|0;gb=d;h=e+128|0;while(1){Hf(e);e=e+1|0;if((h|0)!=(e|0)){continue}break}gb=d+16|0;break h}CW(f+24|0,e);e=v[f+28>>2];v[f+8>>2]=v[f+24>>2];v[f+12>>2]=e;kd(f+16|0,d,f+8|0)}gb=f+32|0;OE(Sb(a+484360|0),i,w[g+211|0]+1|0);h=w[g+216|0]?w[g+216|0]:64;Td(g,b,B(w[g+208|0]|w[g+209|0]<<8,192));l=kc(g+24|0,g);xb(g);i:{j:{if(!(c&1)){break j}d=w[g+210|0];v[22656]=0;o=a+484344|0;R(330,o|0,d+1|0);d=v[22656];v[22656]=0;if((d|0)==1){break d}while(1){v[22656]=0;e=W(331,o|0,m&65535,h|0)|0;d=v[22656];v[22656]=0;if((d|0)==1){break i}d=0;if(!e){break j}while(1){v[22656]=0;e=T(287,b|0)|0;f=v[22656];v[22656]=0;if((f|0)==1){break d}j=d;k:{if(!e|e>>>0>(w[g+208|0]|w[g+209|0]<<8)>>>0){break k}d=j&65535;if(d>>>0>=x[a+480188>>1]){break k}v[22656]=0;Q(190,l|0,B(e,192)-192|0)|0;e=v[22656];v[22656]=0;if((e|0)==1){break d}e=_b(o,m);v[22656]=0;d=Yc(e,0,d);e=v[22656];v[22656]=0;if((e|0)==1){break d}p=0;if(!h){break k}while(1){v[22656]=0;R(723,g|0,l|0);e=v[22656];v[22656]=0;if((e|0)==1){break d}k=qd(g);n=Ve(g);f=d;i=g;e=w[g|0];if(e>>>0>=4){t[d|0]=(e>>>2|0)+37;e=w[i|0]}t[f+1|0]=e<<4&48|w[k|0]>>>4;e=w[n|0];f=0;i=0;l:{m:{n:{o:{p:{q:{k=w[k|0]&15;switch(k-8|0){case 0:break n;case 6:break p;case 2:break q;default:break o}}e=(e&240?-16:15)&e;k=10;break m}k=14;n=(e+16&240)>>>4|0;if(n>>>0>8){break m}if(1<<n&435){break n}break m}f=k;i=e}k=f;e=i;if(!((f|e)&255)){break l}}t[d+5|0]=e;t[d+3|0]=k;v[22656]=0;Of(d);e=v[22656];v[22656]=0;if((e|0)!=1){break l}break d}d=B(x[a+480188>>1],6)+d|0;p=p+1|0;if((p|0)!=(h|0)){continue}break}}d=j+1|0;if((j&65535)>>>0<31){continue}break}d=w[g+210|0]>m>>>0;m=m+1|0;if(d){continue}break}}if(w[g+212|0]|w[g+213|0]<<8){d=w[g+212|0]|w[g+213|0]<<8;v[22656]=0;fa(473,a+1298292|0,b|0,d|0,39,1)|0;d=v[22656];v[22656]=0;if((d|0)==1){break d}}if(!(!(c&2)|!x[a+480190>>1])){d=1;while(1){c=B(d&65535,104)+a|0;e=Rc(g,u[c+484414>>1]&1?16:8,1,0,1);v[22656]=0;W(329,e|0,c+484380|0,b|0)|0;c=v[22656];v[22656]=0;if((c|0)==1){break d}d=d+1|0;if(x[a+480190>>1]>=(d&65535)>>>0){continue}break}}v[a+480260>>2]=64;v[a+480264>>2]=32767;xb(l);break b}break d}d=P()|0;O()|0;Hb(g+24|0);break c}d=P()|0;O()|0;vb(g+24|0);break c}d=P()|0;O()|0;xb(l)}S(d|0);L()}d=1}gb=g+256|0;return d|0}function CP(a,b,c,d,e){var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,y=0,z=0;i=gb-16|0;gb=i;a:{if(!ve(d&255)){break a}j=(B(b,872)+a|0)+1074992|0;b:{if(!(e?1:!(v[a+480180>>2]&17825824)|!x[a+480192>>1])){break b}if(tk(j)){break b}c=B(b,872)+a|0;d=c+1075068|0;if(!v[d>>2]){break a}c=v[c+1075080>>2];if(c&1024){break a}e=B(b,872)+a|0;g=e+1075012|0;e=e+1075016|0;if(!(v[g>>2]|v[e>>2])){break a}c:{if(!(c&512)){break c}c=a+1298260|0;if(!Dd(c)){break c}Oi(v[c>>2],b,0);break a}c=wA(a,b);if((c|0)==65535){break a}m=B(c,872);c=a+1074992|0;a=m+c|0;qu(a,j);t[a+831|0]=0;t[a+805|0]=0;u[a+786>>1]=b+1;v[a+88>>2]=v[a+88>>2]&-918529;ap(a+788|0);v[a+696>>2]=0;v[a+88>>2]=v[a+88>>2]|2101248;v[d>>2]=0;v[j>>2]=0;v[j+4>>2]=0;a=c+B(b,872)|0;v[a+92>>2]=0;v[a+96>>2]=0;v[g>>2]=0;v[e>>2]=0;break a}e=B(b,872)+a|0;n=v[e+1075096>>2];c=x[a+480192>>1]<c>>>0?0:c;h=v[(c?((c<<2)+a|0)+900380|0:e+1075648|0)>>2];d:{if(!h){break d}f=d-1|0;c=x[vd(h+236|0,f)>>1];k=i+8|0;g=a+1074312|0;Db(k,g,104);e:{if(Cb(k)){Db(i,g,34);if(Cb(i)){break e}}d=w[ic(h+108|0,f)|0]}if((c-1&65535)>>>0<=3998){n=(B(c,104)+a|0)+484380|0;break d}c=i+8|0;Db(c,g,43);if(!Cb(c)){break d}if(!Kj(h)){break a}}if(w[e+1075081|0]&4){break a}g=a+1298260|0;k=a+1074312|0;if(b>>>0<256){q=b+1|0;c=b;while(1){f:{if((b|0)!=(c|0)&x[a+480188>>1]>c>>>0){break f}e=B(c,872)+a|0;if(x[e+1075778>>1]!=(q|0)&(b|0)!=(c|0)){break f}p=e+1075648|0;f=v[p>>2];if(!f){break f}l=e+1074992|0;g:{h:{i:{j:{k:{l:{m:{switch(w[f+17|0]-1|0){case 0:if(!d){break f}m=w[e+1075789|0]==(d|0)&(f|0)==(h|0);o=m;if(!h){break l}if(m){break i}break f;case 1:if(!n|v[e+1075096>>2]!=(n|0)){break f}if((f|0)==(h|0)){break g}f=i+8|0;Db(f,k,104);if(!Cb(f)){break g}break f;case 3:break k;case 2:break m;default:break f}}if(h){break j}o=(f|0)==(h|0)}if(o){break g}break f}if(!h){break f}m=w[h+34|0];if(!m){break f}if((m|0)==w[f+34|0]){break h}break f}if((f|0)!=(h|0)){break f}}if(!w[h+34|0]){break g}}if(!w[e+1075789|0]|w[f+18|0]>2){break g}f=i+8|0;Db(f,k,34);Mm(a,c&65535,IS(l,Cb(f))+255|0,0);t[e+1075792|0]=0}n:{o:{switch(w[v[p>>2]+18|0]){case 0:Do(a,l);v[e+1075680>>2]=0;if(!(w[e+1075081|0]&2)){break n}if(!Dd(g)){break n}Oi(v[g>>2],c&65535,1);break n;case 1:Do(a,l);if(!(w[e+1075081|0]&2)){break n}if(!Dd(g)){break n}vk(v[g>>2],c&65535);break n;case 2:break o;default:break n}}l=e+1075080|0;f=v[l>>2];v[l>>2]=f|4096;if(!(f&512)){break n}if(!Dd(g)){break n}f=i+8|0;Db(f,k,105);if(Cb(f)){break n}vk(v[g>>2],c&65535)}if(v[e+1075680>>2]){break f}v[e+1075688>>2]=0;e=e+1075080|0;v[e>>2]=v[e>>2]|2101248}c=c+1|0;if((c&65535)!=256){continue}break}}e=0;c=0;p:{if(!tk(j)){break p}c=0;if(!ve(w[(B(b,872)+a|0)+1075789|0])){break p}d=Lm(a,b,2,1);c=0;if((d-1&255)>>>0>249){break p}e=v[(B(d,160)+a|0)+906140>>2];if(!e){e=0;c=0;break p}c=i+8|0;Db(c,k,34);c=(s=e,y=IS(j,Cb(c)),z=b,r=v[v[e>>2]+100>>2],kb[r](s|0,y|0,z|0)|0)}if(!(r=1,z=Mi(j),y=c,y?r:z)){break a}h=wA(a,b);if((h|0)==65535){break a}f=B(h,872)+a|0;d=f+1075080|0;n=f+1074992|0;q:{if(!(w[f+1075081|0]&2)){break q}if(!Dd(g)){break q}Oi(v[g>>2],h,1)}qu(n,j);v[d>>2]=v[d>>2]&-917505;t[f+1075823|0]=0;l=x[a+480188>>1];t[f+1075797|0]=0;u[f+1075778>>1]=b>>>0<l>>>0?b+1|0:0;r:{if(!(c&(e|0)!=0)){break r}c=w[(B(b,872)+a|0)+1075790|0];if(c>>>0>3|(c|0)==1){break r}Mm(a,b,255,0);t[(B(b,872)+a|0)+1075792|0]=0}s:{t:{switch(w[(B(b,872)+a|0)+1075790|0]){case 2:Do(a,n);if(!(w[d+1|0]&2)){break s}if(!Dd(g)){break s}vk(v[g>>2],b);c=i+8|0;Db(c,k,105);if(!Cb(c)){break s}bB(v[g>>2],b,h);break s;case 0:v[(B(h,872)+a|0)+1075688>>2]=0;c=v[d>>2];v[d>>2]=c|4096;if(!(c&512)){break s}if(!Dd(g)){break s}Oi(v[g>>2],b,1);break s;case 3:c=v[d>>2];v[d>>2]=c|4096;if(!(c&512)){break s}if(!Dd(g)){break s}c=i+8|0;Db(c,k,105);e=Cb(c);c=v[g>>2];if(e){bB(c,b,h);break s}vk(c,b);break s;case 1:break t;default:break s}}if(!(w[d+1|0]&2)){break s}if(!Dd(g)){break s}bB(v[g>>2],b,h)}if(!v[(B(h,872)+a|0)+1075680>>2]){v[(B(h,872)+a|0)+1075688>>2]=0;v[d>>2]=v[d>>2]|2101248}a=B(b,872)+a|0;v[a+1075068>>2]=0;v[j>>2]=0;v[j+4>>2]=0;a=a+1075084|0;v[a>>2]=0;v[a+4>>2]=0}gb=i+16|0}function lfa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0;e=gb-112|0;gb=e;f=e+88|0;g=a+140|0;Tm(f,g,1296125513);v[22656]=0;f=T(275,f|0)|0;h=v[22656];v[22656]=0;a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{if((h|0)!=1){if(f){f=Kb(e+32|0);v[22656]=0;h=T(195,e+88|0)|0;i=v[22656];v[22656]=0;if((i|0)==1){break o}v[22656]=0;U(1438,e+88|0,f|0,h|0);h=v[22656];v[22656]=0;if((h|0)==1){break o}h=x[a+174>>1];v[22656]=0;Y(1439,e+72|0,h|0,8,f|0);h=v[22656];v[22656]=0;if((h|0)==1){break n}v[22656]=0;U(9,e+8|0,c|0,e+72|0);c=v[22656];v[22656]=0;if((c|0)==1){break m}v[22656]=0;Q(301,d|0,e+8|0)|0;c=v[22656];v[22656]=0;if((c|0)==1){break l}vb(e+8|0);vb(e+72|0);vb(f)}if(w[a+176|0]){v[22656]=0;R(1440,e+32|0,d|0);c=v[22656];v[22656]=0;if((c|0)==1){break i}v[22656]=0;Q(303,b+43|0,e+32|0)|0;c=v[22656];v[22656]=0;if((c|0)==1){break h}vb(e+32|0)}v[22656]=0;U(1430,e+32|0,g|0,1413894985);c=v[22656];v[22656]=0;if((c|0)==1){break g}v[22656]=0;f=T(1441,e+32|0)|0;c=v[22656];v[22656]=0;if((c|0)==1){break f}g=e+32|0;xb(g);c=a+40|0;vc(c);v[22656]=0;g=Q(1442,c|0,g|0)|0;h=v[22656];v[22656]=0;if((h|0)==1){break c}if(!g){break d}if((w[e+60|0]|w[e+61|0]<<8|(w[e+62|0]<<16|w[e+63|0]<<24))>>>0<2){break e}v[22656]=0;g=Q(1443,c|0,e+8|0)|0;h=v[22656];v[22656]=0;if((h|0)==1){break b}if(!g){break e}g=v[b>>2];v[22656]=0;Cz(e+8|0,b+12|0,b+16|0,g,b+34|0,8,16,f);g=v[22656];v[22656]=0;if((g|0)!=1){break e}break b}a=P()|0;O()|0;break a}a=P()|0;O()|0;break j}a=P()|0;O()|0;break j}a=P()|0;O()|0;break k}a=P()|0;O()|0;vb(e+8|0)}vb(e+72|0)}vb(f);break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;vb(e+32|0);break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;xb(e+32|0);break a}v[22656]=0;c=Q(1443,c|0,e+8|0)|0;g=v[22656];v[22656]=0;if((g|0)==1){break b}if(c){c=v[b>>2];v[22656]=0;Cz(e+8|0,b+4|0,b+8|0,c,b+34|0,2,4,f);c=v[22656];v[22656]=0;if((c|0)==1){break b}}c=w[e+44|0]|w[e+45|0]<<8|(w[e+46|0]<<16|w[e+47|0]<<24);t[b+42|0]=c&128?0:c+1|0;v[22656]=0;xk(b);c=v[22656];v[22656]=0;if((c|0)==1){break b}}p:{q:{if(w[b+42|0]){break q}v[22656]=0;c=a+60|0;f=Q(861,c|0,7)|0;g=v[22656];v[22656]=0;if((g|0)==1){break c}if(!f){break q}vc(c);v[22656]=0;c=Q(1445,c|0,e+8|0)|0;f=v[22656];v[22656]=0;if((f|0)==1){break p}if(!c){break q}c=t[e+8|0];t[b+42|0]=(c|0)<0?0:c+1|0}v[22656]=0;h=a+120|0;c=T(275,h|0)|0;f=v[22656];v[22656]=0;if((f|0)==1){break c}r:{if(!c){break r}c=0;v[22656]=0;f=T(192,h|0)|0;g=v[22656];v[22656]=0;s:{if((g|0)!=1){v[e+72>>2]=f;g=b+68|0;qc(e+72|0,9);if(v[e+72>>2]){f=e+8|4;while(1){v[22656]=0;R(1446,h|0,e+8|0);i=v[22656];v[22656]=0;if((i|0)==1){break s}i=w[f|0]|w[f+1|0]<<8|(w[f+2|0]<<16|w[f+3|0]<<24);j=Fe(g,c),k=i,v[j>>2]=k;c=c+1|0;if(c>>>0<y[e+72>>2]){continue}break}}c=v[e+72>>2];f=lX(g);v[22656]=0;ZB(g+(c<<2)|0,f,36536);c=v[22656];v[22656]=0;if((c|0)!=1){break r}}a=P()|0;O()|0;break a}a=P()|0;O()|0;break a}a=a+80|0;vc(a);v[22656]=0;c=Q(1448,a|0,e+8|0)|0;f=v[22656];v[22656]=0;t:{u:{v:{w:{x:{if((f|0)==1){break x}if(!c){break u}if(w[e+8|0]&32){u[b+34>>1]=x[b+34>>1]|32}c=e+8|4;u[e+72>>1]=w[c|0]|w[c+1|0]<<8;v[22656]=0;u[e+6>>1]=256;c=Pc(e+72|0,e+6|0);f=v[22656];v[22656]=0;if((f|0)==1){break t}u[b+28>>1]=x[c>>1];c=e+8|6;u[e+72>>1]=w[c|0]|w[c+1|0]<<8;v[22656]=0;u[e+6>>1]=256;c=Pc(e+72|0,e+6|0);f=v[22656];v[22656]=0;if((f|0)==1){break w}u[b+30>>1]=x[c>>1];u[e+72>>1]=w[e+16|0]|w[e+17|0]<<8;v[22656]=0;u[e+6>>1]=64;c=Pc(e+72|0,e+6|0);f=v[22656];v[22656]=0;if((f|0)==1){break v}u[b+32>>1]=x[c>>1];t[b+38|0]=w[e+20|0];t[b+39|0]=w[e+21|0];t[b+40|0]=w[e+22|0];t[b+41|0]=w[e+23|0];v[22656]=0;c=Q(191,a|0,32)|0;f=v[22656];v[22656]=0;if((f|0)==1){break x}if(!c){break u}v[22656]=0;W(1449,a|0,d|0,32)|0;c=v[22656];v[22656]=0;if((c|0)==1){break x}v[22656]=0;c=T(467,a|0)|0;d=v[22656];v[22656]=0;if((d|0)==1){break x}v[22656]=0;U(1450,a|0,b+43|0,c|0);a=v[22656];v[22656]=0;if((a|0)!=1){break u}}a=P()|0;O()|0;break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;break a}xb(e+88|0);gb=e+112|0;return}a=P()|0;O()|0;break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;break a}a=P()|0;O()|0}xb(e+88|0);S(a|0);L()}function KO(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;i=gb-16|0;gb=i;a:{b:{if(!ve(c)|(!d|v[b+480180>>2]!=16777216)|x[b+480192>>1]<d>>>0){break b}d=v[((d<<2)+b|0)+900380>>2];if(!d){break b}e=v[d+44>>2];if(!e){break b}u[i+14>>1]=c-61;d=gb-80|0;gb=d;c=u[e+28>>1];g=i+14|0;b=u[g>>1];f=e+4|0;Nb(f);c:{d:{if((b|0)>=(c|0)){if((b|0)<=(x[e+28>>1]+Nb(f)<<16)-65536>>16){break d}}Kb(a);break c}e:{b=x[e+30>>1];if(!b){b=e+52|0;k=d,l=lz(b,g),v[k+56>>2]=l;k=d,l=Dh(b),v[k+40>>2]=l;if(!og(d+56|0,d+40|0)){break e}gg(a,ue(d+56|0)+4|0);break c}c=to(u[g>>1],b<<16>>16);u[d+78>>1]=c;b=Kb(a);a=e+52|0;k=d,l=lz(a,d+78|0),v[k+72>>2]=l;k=d,l=Dh(a),v[k+56>>2]=l;f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{t:{u:{v:{if(og(d+72|0,d+56|0)){a=ue(d+72|0);v[22656]=0;Q(156,b|0,a+4|0)|0;a=v[22656];v[22656]=0;if((a|0)==1){break v}a=u[e+30>>1];c=u[g>>1];v[22656]=0;k=d,l=kz(c,a)+5|0,v[k+40>>2]=l;R(153,d+56|0,d+40|0);a=v[22656];v[22656]=0;if((a|0)==1){break g}v[22656]=0;Q(113,b|0,d+56|0)|0;a=v[22656];v[22656]=0;if((a|0)!=1){vb(d+56|0);break c}a=P()|0;O()|0;vb(d+56|0);break f}if(u[e+30>>1]>26){break s}v[22656]=0;c=W(716,d+40|0,1,(c<<24)+1090519040>>24)|0;a=v[22656];v[22656]=0;if((a|0)==1){break u}v[22656]=0;U(13,d+56|0,0,c|0);a=v[22656];v[22656]=0;if((a|0)==1){break t}a=d+56|0;Eb(b,a);vb(a);vb(c);v[22656]=0;Q(154,b|0,11846)|0;a=v[22656];v[22656]=0;if((a|0)!=1){break r}}a=P()|0;O()|0;break f}a=P()|0;O()|0;break f}a=P()|0;O()|0;vb(c);break f}v[22656]=0;a=(c<<16>>16)/16|0;v[d+36>>2]=c-(a<<4)<<16>>16;R(1503,d+40|0,d+36|0);f=v[22656];v[22656]=0;if((f|0)==1){break q}v[22656]=0;v[d+20>>2]=(a<<16>>16)%16;R(1503,d+24|0,d+20|0);a=v[22656];v[22656]=0;if((a|0)==1){break p}v[22656]=0;U(3,d+56|0,d+40|0,d+24|0);a=v[22656];v[22656]=0;if((a|0)==1){break o}a=d+56|0;Eb(b,a);vb(a);vb(d+24|0);vb(d+40|0);if(c<<16>>16<256){break r}v[22656]=0;U(9,d+8|0,0,b|0);a=v[22656];v[22656]=0;if((a|0)==1){break m}v[22656]=0;XS(d+40|0,d+8|0);a=v[22656];v[22656]=0;if((a|0)==1){break l}v[22656]=0;U(13,d+56|0,0,d+40|0);a=v[22656];v[22656]=0;if((a|0)==1){break k}a=d+56|0;Eb(b,a);vb(a);vb(d+40|0);vb(d+8|0)}a=u[e+30>>1];c=u[g>>1];v[22656]=0;k=d,l=kz(c,a)+5|0,v[k+40>>2]=l;R(153,d+56|0,d+40|0);a=v[22656];v[22656]=0;if((a|0)==1){break i}v[22656]=0;Q(113,b|0,d+56|0)|0;a=v[22656];v[22656]=0;if((a|0)==1){break h}vb(d+56|0);break c}a=P()|0;O()|0;break f}a=P()|0;O()|0;break n}a=P()|0;O()|0;vb(d+24|0)}vb(d+40|0);break f}a=P()|0;O()|0;break f}a=P()|0;O()|0;break j}a=P()|0;O()|0;vb(d+40|0)}vb(d+8|0);break f}a=P()|0;O()|0;break f}a=P()|0;O()|0;vb(d+56|0);break f}a=P()|0;O()|0}vb(b);S(a|0);L()}b=a;a=gb-16|0;gb=a;c=a;f=gb-32|0;gb=f;e=He(f+16|0,1,0);QP(f+8|0,Jb(e),Jb(e)+Ab(e)|0,u[g>>1]);w:{x:{if(v[f+12>>2]){while(1){h=Ab(e);v[22656]=0;v[f+4>>2]=h;h=xf(f+4|0);j=v[22656];v[22656]=0;if((j|0)==1){break x}v[22656]=0;U(75,e|0,h|0,0);h=v[22656];v[22656]=0;if((h|0)==1){break x}QP(f+8|0,Jb(e),Jb(e)+Ab(e)|0,u[g>>1]);if(v[f+12>>2]){continue}break}}g=v[f+8>>2];h=Jb(e);v[22656]=0;R(76,e|0,g-h|0);g=v[22656];v[22656]=0;if((g|0)==1){break x}v[22656]=0;R(86,c|0,e|0);c=v[22656];v[22656]=0;if((c|0)!=1){break w}}a=P()|0;O()|0;vb(e);S(a|0);L()}vb(e);gb=f+32|0;v[22656]=0;R(85,b|0,a|0);b=v[22656];v[22656]=0;y:{if((b|0)!=1){vb(a);gb=a+16|0;break y}b=P()|0;O()|0;vb(a);S(b|0);L()}}gb=d+80|0;break a}e=v[b>>2];b=gb-32|0;gb=b;d=gb-16|0;gb=d;t[d+15|0]=c;t[d+14|0]=251;t[d+13|0]=255;f=Mv(d+15|0,d+14|0,d+13|0);gb=d+16|0;z:{if(f){v[b+16>>2]=v[9588];d=v[9587];v[b+8>>2]=v[9586];v[b+12>>2]=d;d=v[9585];v[b>>2]=v[9584];v[b+4>>2]=d;Tb(a,(b+(c<<2)|0)-1004|0);break z}if(ve(c)){d=Kb(b);v[22656]=0;f=c-1|0;c=(f<<16>>16)/12|0;e=Q(1322,d|0,e+(f-B(c,12)<<16>>16<<2)|0)|0;f=v[22656];v[22656]=0;A:{if((f|0)==1){break A}v[22656]=0;c=Q(1323,e|0,c+48&65535)|0;e=v[22656];v[22656]=0;if((e|0)==1){break A}v[22656]=0;Q(4,a|0,c|0)|0;a=v[22656];v[22656]=0;if((a|0)==1){break A}vb(d);break z}a=P()|0;O()|0;vb(d);S(a|0);L()}if(!c){Tb(a,13839);break z}Tb(a,11817)}gb=b+32|0}gb=i+16|0}function lea(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0;e=gb-144|0;gb=e;d=-1;a:{b:{c:{d:{if(!Fl(v[v[b>>2]-12>>2]+b|0)){b=Hm(e+40|0,b);v[22656]=0;d=Q(620,e+24|0,11257)|0;f=v[22656];v[22656]=0;e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{t:{u:{v:{w:{x:{y:{z:{A:{B:{C:{D:{E:{if((f|0)!=1){v[22656]=0;v[e+16>>2]=83886084;v[e+20>>2]=0;U(621,b|0,d|0,e+16|0);f=v[22656];v[22656]=0;if((f|0)==1){break E}Hb(d);t[e+15|0]=0;v[22656]=0;d=Q(620,e+24|0,11945)|0;f=v[22656];v[22656]=0;if((f|0)==1){break D}v[22656]=0;W(622,b|0,e+15|0,d|0)|0;f=v[22656];v[22656]=0;if((f|0)==1){break C}Hb(d);v[22656]=0;f=w[e+15|0];d=Q(620,e+24|0,12908)|0;g=v[22656];v[22656]=0;if((g|0)==1){break B}v[22656]=0;f=f?0:c;Y(1506,b|0,a+40|0,d|0,f|0);c=v[22656];v[22656]=0;if((c|0)==1){break A}Hb(d);u[e+12>>1]=65535;v[22656]=0;c=Q(620,e+24|0,12589)|0;d=v[22656];v[22656]=0;if((d|0)==1){break z}v[22656]=0;W(1094,b|0,e+12|0,c|0)|0;d=v[22656];v[22656]=0;if((d|0)==1){break y}Hb(c);u[e+10>>1]=0;v[22656]=0;c=Q(620,e+24|0,12488)|0;d=v[22656];v[22656]=0;if((d|0)==1){break x}v[22656]=0;W(1094,b|0,e+10|0,c|0)|0;d=v[22656];v[22656]=0;if((d|0)==1){break w}Hb(c);u[a>>1]=x[e+10>>1];v[22656]=0;c=Q(620,e+24|0,12250)|0;d=v[22656];v[22656]=0;if((d|0)==1){break v}v[22656]=0;Y(1507,b|0,a+52|0,c|0,f|0);d=v[22656];v[22656]=0;if((d|0)==1){break u}Hb(c);v[22656]=0;c=Q(620,e+24|0,12199)|0;d=v[22656];v[22656]=0;if((d|0)==1){break t}v[22656]=0;W(1479,b|0,a+36|0,c|0)|0;d=v[22656];v[22656]=0;if((d|0)==1){break s}Hb(c);v[22656]=0;c=Q(620,e+24|0,12591)|0;d=v[22656];v[22656]=0;if((d|0)==1){break r}v[22656]=0;f=a+4|0;U(1508,b|0,f|0,c|0);d=v[22656];v[22656]=0;if((d|0)==1){break q}Hb(c);v[22656]=0;c=Q(620,e+24|0,12490)|0;d=v[22656];v[22656]=0;if((d|0)==1){break p}v[22656]=0;g=a+28|0;U(1509,b|0,g|0,c|0);d=v[22656];v[22656]=0;if((d|0)==1){break o}Hb(c);v[22656]=0;c=Q(620,e+24|0,12351)|0;d=v[22656];v[22656]=0;if((d|0)==1){break n}v[22656]=0;U(1509,b|0,a+30|0,c|0);d=v[22656];v[22656]=0;if((d|0)==1){break m}Hb(c);v[22656]=0;c=Q(620,e+24|0,12223)|0;d=v[22656];v[22656]=0;if((d|0)==1){break l}v[22656]=0;U(1510,b|0,a+32|0,c|0);d=v[22656];v[22656]=0;if((d|0)==1){break k}Hb(c);u[e+8>>1]=0;v[22656]=0;c=Q(620,e+24|0,12178)|0;d=v[22656];v[22656]=0;if((d|0)==1){break d}v[22656]=0;W(1094,b|0,e+8|0,c|0)|0;d=v[22656];v[22656]=0;if((d|0)==1){break j}Hb(c);d=-1;if(v[b>>2]&1073741824|(x[g>>1]+300&65535)>>>0>=601){break e}c=x[a>>1];if(c>>>0>3|(c|0)==2|u[a+30>>1]<0){break e}i=e,j=Ti(v[a+36>>2]),v[i+24>>2]=j;v[22656]=0;v[e+16>>2]=0;c=dj(e+24|0,e+16|0,49672);h=v[22656];v[22656]=0;if((h|0)==1){break c}v[a+36>>2]=v[c>>2];if(Nb(f)>>>0>32767){break e}switch(x[a>>1]-1|0){case 2:break i;case 0:break h;default:break g}}a=P()|0;O()|0;break a}a=P()|0;O()|0;Hb(d);break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;Hb(d);break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;Hb(d);break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;Hb(c);break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;Hb(c);break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;Hb(c);break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;Hb(c);break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;Hb(c);break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;Hb(c);break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;Hb(c);break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;Hb(c);break a}a=P()|0;O()|0;Hb(c);break a}c=u[e+8>>1];if((c|0)<=0){break e}u[e+6>>1]=x[a+30>>1];z[e+24>>2]=z[a+32>>2];f=x[a+28>>1];u[e+16>>1]=f;v[22656]=0;u[e+18>>1]=(c+f|0)-1;a=da(1511,a|0,e+6|0,e+24|0,e+16|0)|0;c=v[22656];v[22656]=0;if((c|0)!=1){if(a){break f}break e}a=P()|0;O()|0;break a}c=u[e+8>>1];if((c|0)<=0){break e}z[e+24>>2]=z[a+32>>2];h=x[a+28>>1];u[e+16>>1]=h;v[22656]=0;u[e+18>>1]=(c+h|0)-1;a=fa(1512,a|0,f|0,e+24|0,e+16|0,g|0)|0;c=v[22656];v[22656]=0;if((c|0)!=1){if(a){break f}break e}a=P()|0;O()|0;break a}v[22656]=0;_(1513,a|0);a=v[22656];v[22656]=0;if((a|0)==1){break b}}d=1}gh(b)}gb=e+144|0;return d|0}a=P()|0;O()|0;break a}a=P()|0;O()|0;break a}a=P()|0;O()|0}gh(b);S(a|0);L()}function QL(a,b,c,d,e,f,g,h,i){var j=0,k=0,l=0,m=0,n=0,o=0;l=gb-48|0;gb=l;v[l+44>>2]=0;if(i?1:d|g|h){j=g?l+44|0:0;a:{if(!j){break a}k=v[j>>2];if(!k){break a}Yb(k);v[j>>2]=0}v[22656]=0;X(2027);k=v[22656];v[22656]=0;b:{c:{if((k|0)==1){m=Ta(89116,54736,54792,54952,89292,89396,89344,89236,89224,89540,89508,89476,89464,89092,0)|0;d:{e:{n=O()|0;if((n|0)==(ea(89116)|0)){k=Z(m|0)|0;v[22656]=0;R(2028,j|0,k|0);j=v[22656];v[22656]=0;k=277;if((j|0)==1){break e}break b}if((ea(54736)|0)==(n|0)){k=Z(m|0)|0;v[22656]=0;R(2028,j|0,k|0);j=v[22656];v[22656]=0;k=358;if((j|0)!=1){break b}a=P()|0;O()|0;v[22656]=0;X(20);b=v[22656];v[22656]=0;if((b|0)!=1){break c}break d}if((ea(54792)|0)==(n|0)){k=Z(m|0)|0;v[22656]=0;R(2028,j|0,k|0);j=v[22656];v[22656]=0;k=359;if((j|0)!=1){break b}a=P()|0;O()|0;v[22656]=0;X(20);b=v[22656];v[22656]=0;if((b|0)!=1){break c}break d}if((ea(54952)|0)==(n|0)){k=Z(m|0)|0;v[22656]=0;R(2028,j|0,k|0);j=v[22656];v[22656]=0;k=357;if((j|0)!=1){break b}a=P()|0;O()|0;v[22656]=0;X(20);b=v[22656];v[22656]=0;if((b|0)!=1){break c}break d}if((ea(89292)|0)==(n|0)){k=Z(m|0)|0;v[22656]=0;R(2028,j|0,k|0);j=v[22656];v[22656]=0;k=300;if((j|0)!=1){break b}a=P()|0;O()|0;v[22656]=0;X(20);b=v[22656];v[22656]=0;if((b|0)!=1){break c}break d}if((ea(89396)|0)==(n|0)){k=Z(m|0)|0;v[22656]=0;R(2028,j|0,k|0);j=v[22656];v[22656]=0;k=299;if((j|0)!=1){break b}a=P()|0;O()|0;v[22656]=0;X(20);b=v[22656];v[22656]=0;if((b|0)!=1){break c}break d}if((ea(89344)|0)==(n|0)){k=Z(m|0)|0;v[22656]=0;R(2028,j|0,k|0);j=v[22656];v[22656]=0;k=298;if((j|0)!=1){break b}a=P()|0;O()|0;v[22656]=0;X(20);b=v[22656];v[22656]=0;if((b|0)!=1){break c}break d}if((ea(89236)|0)==(n|0)){k=Z(m|0)|0;v[22656]=0;R(2028,j|0,k|0);j=v[22656];v[22656]=0;k=297;if((j|0)!=1){break b}a=P()|0;O()|0;v[22656]=0;X(20);b=v[22656];v[22656]=0;if((b|0)!=1){break c}break d}if((ea(89224)|0)==(n|0)){k=Z(m|0)|0;v[22656]=0;R(2028,j|0,k|0);j=v[22656];v[22656]=0;k=296;if((j|0)!=1){break b}a=P()|0;O()|0;v[22656]=0;X(20);b=v[22656];v[22656]=0;if((b|0)!=1){break c}break d}if((ea(89540)|0)==(n|0)){k=Z(m|0)|0;v[22656]=0;R(2028,j|0,k|0);j=v[22656];v[22656]=0;k=289;if((j|0)!=1){break b}a=P()|0;O()|0;v[22656]=0;X(20);b=v[22656];v[22656]=0;if((b|0)!=1){break c}break d}if((ea(89508)|0)==(n|0)){k=Z(m|0)|0;v[22656]=0;R(2028,j|0,k|0);j=v[22656];v[22656]=0;k=288;if((j|0)!=1){break b}a=P()|0;O()|0;v[22656]=0;X(20);b=v[22656];v[22656]=0;if((b|0)!=1){break c}break d}if((ea(89476)|0)==(n|0)){k=Z(m|0)|0;v[22656]=0;R(2028,j|0,k|0);j=v[22656];v[22656]=0;k=287;if((j|0)!=1){break b}a=P()|0;O()|0;v[22656]=0;X(20);b=v[22656];v[22656]=0;if((b|0)!=1){break c}break d}if((ea(89464)|0)==(n|0)){k=Z(m|0)|0;v[22656]=0;R(2028,j|0,k|0);j=v[22656];v[22656]=0;k=286;if((j|0)!=1){break b}a=P()|0;O()|0;v[22656]=0;X(20);b=v[22656];v[22656]=0;if((b|0)!=1){break c}break d}o=ea(89092)|0;k=257;m=Z(m|0)|0;if((n|0)!=(o|0)){break b}v[22656]=0;R(2028,j|0,m|0);j=v[22656];v[22656]=0;k=267;if((j|0)!=1){break b}a=P()|0;O()|0;v[22656]=0;X(20);b=v[22656];v[22656]=0;if((b|0)==1){break d}break c}a=P()|0;O()|0;v[22656]=0;X(20);b=v[22656];v[22656]=0;if((b|0)!=1){break c}}V(0)|0;O()|0;Bb()}L()}S(a|0);L()}$()}o=!g;if(d){j=kb[d|0](k,e)|0}else{j=3}if(!(o|!(j&2))){v[g+16>>2]=k;m=v[l+44>>2];f:{if(m){o=ie(m);break f}o=ie(18726)}v[g+20>>2]=o}if(h){v[h>>2]=k}if(i){g=v[l+44>>2];g:{if(g){g=ie(g);break g}g=ie(18726)}v[i>>2]=g}g=v[l+44>>2];if(g){Yb(g);v[l+44>>2]=0}h:{if(!(j&1)){break h}v[22656]=0;R(1912,l+32|0,a|0);g=v[22656];v[22656]=0;i:{j:{if((g|0)!=1){k:{if(f){v[22656]=0;R(1913,f|0,l+32|0);g=v[22656];v[22656]=0;if((g|0)!=1){break k}break j}g=Jb(l+32|0);if(b){v[22656]=0;R(b|0,g|0,c|0);g=v[22656];v[22656]=0;if((g|0)==1){break j}break k}Lt(g,l)}vb(l+32|0);break h}g=V(0)|0;O()|0;break i}g=V(0)|0;O()|0;vb(l+32|0)}Z(g|0)|0;v[l+28>>2]=f;v[l+24>>2]=e;v[l+20>>2]=d;v[l+16>>2]=c;v[l+12>>2]=b;v[l+8>>2]=a?a:18726;v[l+4>>2]=250;v[l>>2]=6331;ZI(14942,l);nt(90160);$()}gb=l+48|0}function fea(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=C(0),l=0,m=0;d=gb-128|0;gb=d;i=-1;a:{b:{c:{d:{if(!_f(v[v[b>>2]-12>>2]+b|0)){break d}se(d+112|0,b);e=v[d+120>>2];f=v[d+124>>2];h=d+104|0;jm(h);ll(b,h,8);if((w[d+104|0]|w[d+105|0]<<8|(w[d+106|0]<<16|w[d+107|0]<<24))!=1414681667|(w[d+108|0]|w[d+109|0]<<8|(w[d+110|0]<<16|w[d+111|0]<<24))!=776101705){a=sh(d+88|0,e,f);c=v[a+12>>2];v[d+16>>2]=v[a+8>>2];v[d+20>>2]=c;c=v[a+4>>2];v[d+8>>2]=v[a>>2];v[d+12>>2]=c;lk(b,d+8|0);break d}u[d+86>>1]=0;ag(b,d+86|0);if((x[d+86>>1]&65534)!=2){break d}e=d+78|0;jm(e);ll(b,e,8);if((w[d+78|0]|w[d+79|0]<<8|(w[d+80|0]<<16|w[d+81|0]<<24))!=1933333571|(w[d+82|0]|w[d+83|0]<<8|(w[d+84|0]<<16|w[d+85|0]<<24))!=1111389030){break d}u[d+76>>1]=0;ag(b,d+76|0);e=x[d+76>>1];if((e-3&65535)>>>0>1){break d}e:{f:{g:{h:{i:{j:{k:{if(e>>>0<=3){e=Kb(d+112|0);v[22656]=0;f=W(653,b|0,e|0,65535)|0;h=v[22656];v[22656]=0;if((h|0)==1){break b}if(!f){break j}v[22656]=0;U(13,d- -64|0,c|0,e|0);f=v[22656];v[22656]=0;if((f|0)!=1){break k}break b}e=Kb(d+112|0);v[22656]=0;f=W(655,b|0,e|0,255)|0;h=v[22656];v[22656]=0;if((h|0)==1){break c}if(!f){break i}v[22656]=0;U(13,d- -64|0,c|0,e|0);f=v[22656];v[22656]=0;if((f|0)==1){break c}}f=d- -64|0;Eb(a+40|0,f);vb(f);vb(e);u[d+62>>1]=0;ag(b,d+62|0);u[d+60>>1]=0;ag(b,d+60|0);u[a>>1]=x[d+60>>1];u[d+58>>1]=0;l:{if(u[d+76>>1]<=3){v[d+112>>2]=0;Ik(b,d+112|0);e=v[d+112>>2];if(e>>>0>65535){break d}e=Qv(e);u[d+58>>1]=e;break l}ag(b,d+58|0);e=x[d+58>>1]}m:{n:{o:{p:{if(e&65535){h=a+52|0;f=0;while(1){e=Kb(d+112|0);v[22656]=0;u[d+40>>1]=0;Q(1514,b|0,d+40|0)|0;g=v[22656];v[22656]=0;if((g|0)==1){break g}q:{if(u[d+76>>1]<=3){v[22656]=0;g=W(653,b|0,e|0,65535)|0;j=v[22656];v[22656]=0;if((j|0)==1){break g}if(g){break q}break e}v[22656]=0;g=W(655,b|0,e|0,255)|0;j=v[22656];v[22656]=0;if((j|0)==1){break g}if(!g){break e}}v[22656]=0;U(13,d- -64|0,c|0,e|0);g=v[22656];v[22656]=0;if((g|0)==1){break p}v[22656]=0;g=Q(1515,h|0,d+40|0)|0;j=v[22656];v[22656]=0;if((j|0)==1){break o}j=g;g=d- -64|0;Eb(j,g);vb(g);vb(e);f=f+1|0;if(x[d+58>>1]>(f&65535)>>>0){continue}break}}c=d- -64|0;jm(c);ll(b,c,8);if((w[d+64|0]|w[d+65|0]<<8|(w[d+66|0]<<16|w[d+67|0]<<24))!=1933333571|(w[d+68|0]|w[d+69|0]<<8|(w[d+70|0]<<16|w[d+71|0]<<24))!=1161720678){break d}c=x[a>>1];if(c>>>0>3|(c|0)==2){break d}c=a+4|0;if(u[d+86>>1]>2){break n}if(kN(b,c)){break m}break d}b=P()|0;O()|0;break f}b=P()|0;O()|0;vb(d- -64|0);break f}if(!jN(b,c)){break d}}e=a+16|0;r:{if(u[d+86>>1]<=2){if(kN(b,e)){break r}break d}if(!jN(b,e)){break d}}l=a,m=Nb(e),v[l+36>>2]=m;u[d+56>>1]=0;ag(b,d+56|0);e=x[d+56>>1];u[a+28>>1]=e;if((e+200&65535)>>>0>400){break d}u[d+54>>1]=0;ag(b,d+54|0);e=u[d+54>>1];u[a+30>>1]=e;if((e|0)<0){break d}v[d+48>>2]=0;mq(b,d+48|0);k=z[d+48>>2];z[a+32>>2]=k;if(k<C(0)){break d}e=d+40|0;jm(e);ll(b,e,8);if((w[d+40|0]|w[d+41|0]<<8|(w[d+42|0]<<16|w[d+43|0]<<24))!=1414681667|(w[d+44|0]|w[d+45|0]<<8|(w[d+46|0]<<16|w[d+47|0]<<24))!=776298313){break d}if(Nb(c)>>>0>32767){break d}b=x[a>>1];if(!(b?!(z[a+32>>2]<=C(0))&u[a+30>>1]>0:1)){break d}s:{switch(b-1|0){case 0:case 2:if(Nb(c)>>>0<u[a+30>>1]>>>0){break d}break;default:break s}}b=0;e=v[a+36>>2];if(e){b=e-1|0;v[a+36>>2]=b}l=d,m=Ti(b),v[l+112>>2]=m;v[d+32>>2]=0;l=a,m=v[dj(d+112|0,d+32|0,49672)>>2],v[l+36>>2]=m;nq(a);i=1;if(x[a>>1]!=3){break d}if((pN(Nb(c))|0)<(u[a+30>>1]-u[a+28>>1]|0)){break d}e=mc(d+112|0);b=0;if(u[a+30>>1]>0){while(1){i=Mb(c,b-u[a+28>>1]|0);v[22656]=0;R(1516,e|0,i|0);i=v[22656];v[22656]=0;if((i|0)==1){break h}b=b+1|0;if((b|0)<u[a+30>>1]){continue}break}}b=x[a+28>>1];u[d+32>>1]=b;l=d,m=(Nb(c)+b|0)-1|0,u[l+34>>1]=m;v[22656]=0;u[d+30>>1]=0;fa(1512,a|0,e|0,a+32|0,d+32|0,d+30|0)|0;a=v[22656];v[22656]=0;i=1;if((a|0)!=1){Nc(e);break d}break h}vb(e);break d}vb(e);break d}b=P()|0;O()|0;Nc(e);break a}b=P()|0;O()|0}vb(e);break a}vb(e)}gb=d+128|0;return i|0}b=P()|0;O()|0;vb(e);break a}b=P()|0;O()|0;vb(e)}S(b|0);L()}function Woa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;g=gb-976|0;gb=g;vc(b);f=gb-32|0;gb=f;d=f+24|0;j=g+872|0;IX(d,j);h=yb(d);d=v[f+28>>2];i=v[f+24>>2];v[f+8>>2]=i;v[f+12>>2]=d;v[f>>2]=i;v[f+4>>2]=d;i=f+16|0;d=b;cc(i,d,f);i=yb(i);if((i|0)==(h|0)){Rb(d,yb(f+24|0))}gb=f+32|0;d=(h|0)==(i|0);if(!d){HX(j)}a:{if(!d){break a}if(!LX(g+872|0)){break a}if(!Pb(b,Qc(KX(g+872|0),jb))){break a}b:{if(!c){break b}Gd(a,512);v[a+480228>>2]=32;u[a+480188>>1]=16;v[a+480196>>2]=w[g+947|0];v[a+480208>>2]=16;v[a+480200>>2]=256;v[a+480204>>2]=8e5;Ob(a+1074312|0,7,1);d=g+96|0;e=Tb(d,5357);Eb(a+1298304|0,e);vb(e);e=Tb(d,6043);Eb(a+1298316|0,e);vb(e);v[a+1298364>>2]=5;e=g+16|0;eD(e,2,g+872|4);Bc(d,e);Eb(a+1298268|0,d);vb(d);e=0;while(1){d=(e<<5)+a|0;f=d+480280|0;We(f);h=f;f=(g+872|0)+e|0;v[h>>2]=!w[f+50|0]<<10;u[d+480284>>1]=(w[f+76|0]<<4|8)&248;e=e+1|0;if((e|0)!=16){continue}break}if(w[g+968|0]|w[g+969|0]<<8){tB(a+1298292|0,b,w[g+968|0]|w[g+969|0]<<8,132,0)}e=0;f=gb-32|0;gb=f;d=f+24|0;j=g+96|0;bc(d,j,771);h=yb(d);d=v[f+28>>2];i=v[f+24>>2];v[f+8>>2]=i;v[f+12>>2]=d;v[f>>2]=i;v[f+4>>2]=d;i=f+16|0;d=b;cc(i,d,f);i=yb(i);if((i|0)==(h|0)){Rb(d,yb(f+24|0))}gb=f+32|0;d=(h|0)==(i|0);if(!d){Qb(j,0,771)}if(!d){break a}d=a+484360|0;JX(Sb(d),g+96|0,w[g+353|0]);cf(Sb(d),w[g+354|0]);Wc(b,w[g+919|0]|w[g+920|0]<<8);i=a+484344|0;r=c&1;f=0;c:{d:{while(1){d=(f<<1)+g|0;if(w[d+355|0]|w[d+356|0]<<8){e=g+72|0;Td(e,b,w[d+355|0]|w[d+356|0]<<8);p=kc(g+16|0,e);xb(e);d=w[d+355|0]|w[d+356|0]<<8;j=(d-2|0)/64|0;e:{if(!r){break e}v[22656]=0;e=W(331,i|0,f&65535,j|0)|0;h=v[22656];v[22656]=0;if((h|0)==1){break d}if(!e){break e}v[22656]=0;m=T(374,p|0)|0;e=v[22656];v[22656]=0;if((e|0)==1){break d}v[22656]=0;Q(318,g+16|0,1)|0;e=v[22656];v[22656]=0;if((e|0)==1){break d}if(d>>>0>=66){s=j>>>0>1?j:1;k=0;while(1){d=_b(i,f);v[22656]=0;n=Tf(d,k);d=v[22656];v[22656]=0;e=0;if((d|0)==1){break d}f:{while(1){g:{v[22656]=0;R(532,g+72|0,p|0);d=v[22656];v[22656]=0;if((d|0)==1){break g}d=g+72|0;l=qd(d);h=Ve(d);o=ej(d);d=w[d|0];if((d-1&255)>>>0<=71){q=B(e,6)+n|0;t[q|0]=d+36;t[q+1|0]=w[l|0]+1}if((w[h|0]-1&255)>>>0<=15){d=B(e,6)+n|0;t[d+2|0]=1;t[d+4|0]=((w[h|0]<<6)+-64>>>0)/15}d=B(e,6)+n|0;l=w[o|0];h=l&15;t[d+5|0]=h;h:{i:{switch((w[o|0]>>>4|0)-1|0){case 0:case 1:t[d+5|0]=l|240;break h;case 2:t[d+5|0]=h<<2;break h;case 3:t[d+5|0]=(6/(h+1>>>0)|0)+1;break h;case 5:case 6:t[d+5|0]=h<<3;break h;case 9:t[d+4|0]=(h<<2)+4;t[d+2|0]=1;break h;case 10:t[d+5|0]=h|128;break h;case 11:break i;default:break h}}t[d+5|0]=(6/(h+1>>>0)|0)+1|13}t[d+3|0]=w[(w[o|0]>>>4|0)+28608|0];e=e+1|0;if((e|0)!=16){continue}break f}break}break d}k=k+1|0;if((s|0)!=(k|0)){continue}break}}d=_b(i,f);v[22656]=0;e=Be(g+72|0,14,0);h=v[22656];v[22656]=0;if((h|0)==1){break d}e=Fh(Ue(e,m?j-2>>>0>m>>>0?m+1|0:-1:-1));v[22656]=0;Q(431,d|0,e|0)|0;d=v[22656];v[22656]=0;if((d|0)==1){break d}}xb(g+16|0)}f=f+1|0;if((f|0)!=256){continue}break}e=1;if(!(c&2)){break a}PY(b,g- -64|0);e=0;while(1){j:{k:{if(!(w[g- -64+(e>>>3)|0]>>>(e&7)&1)){e=e+1|0;break k}if(!dD(b,g+16|0)){break b}e=e+1|0;u[a+480190>>1]=e;Ke(g,1,g+16|0);c=g+72|0;Bc(c,g);d=x[a+480190>>1];v[22656]=0;Q(301,((d<<5)+a|0)+946304|0,c|0)|0;c=v[22656];v[22656]=0;if((c|0)==1){break j}f=g+72|0;vb(f);h=(B(e,104)+a|0)+484380|0;c=h;ud(c,0);j=g+16|0;d=j;v[c>>2]=w[d+32|0]|w[d+33|0]<<8|(w[d+34|0]<<16|w[d+35|0]<<24);v[c+4>>2]=w[d+38|0]|w[d+39|0]<<8|(w[d+40|0]<<16|w[d+41|0]<<24);i=w[d+42|0]|w[d+43|0]<<8|(w[d+44|0]<<16|w[d+45|0]<<24);v[c+24>>2]=16726;v[c+8>>2]=i;u[c+30>>1]=w[d+37|0]<<4;if(t[d+46|0]&1){v[c>>2]=v[c>>2]>>>1;v[c+4>>2]=v[c+4>>2]>>>1;v[c+8>>2]=v[c+8>>2]>>>1}if(!(!(w[d+47|0]&8)|y[c+8>>2]<=y[c+4>>2])){u[c+34>>1]=x[c+34>>1]|2}Rc(f,t[j+46|0]&1?16:8,1,0,0);Dg(f,h,b)}if((e|0)!=64){continue}break b}break}e=P()|0;O()|0;vb(g+72|0);break c}e=P()|0;O()|0;xb(g+16|0)}S(e|0);L()}e=1}gb=g+976|0;return e|0}function _I(a,b,c,d,e){var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,w=0,x=0,y=0,z=0;h=gb-560|0;gb=h;g=c;c=(c-3|0)/24|0;s=(c|0)>0?c:0;l=g+B(s,-24)|0;n=v[(e<<2)+70784>>2];j=d-1|0;if((n+j|0)>=0){g=d+n|0;c=s-j|0;while(1){A[(h+320|0)+(i<<3)>>3]=(c|0)<0?0:+v[(c<<2)+70800>>2];c=c+1|0;i=i+1|0;if((g|0)!=(i|0)){continue}break}}q=l-24|0;i=(n|0)>0?n:0;g=0;while(1){f=0;if((d|0)>0){k=g+j|0;c=0;while(1){f=f+A[(c<<3)+a>>3]*A[(h+320|0)+(k-c<<3)>>3];c=c+1|0;if((d|0)!=(c|0)){continue}break}}A[(g<<3)+h>>3]=f;c=(g|0)==(i|0);g=g+1|0;if(!c){continue}break}y=47-l|0;t=48-l|0;z=l-25|0;g=n;while(1){f=A[(g<<3)+h>>3];c=0;i=g;o=(g|0)<=0;if(!o){while(1){k=(h+480|0)+(c<<2)|0;m=f;f=f*5.960464477539063e-8;a:{if(D(f)<2147483648){j=~~f;break a}j=-2147483648}f=+(j|0);m=m+f*-16777216;b:{if(D(m)<2147483648){j=~~m;break b}j=-2147483648}v[k>>2]=j;i=i-1|0;f=A[(i<<3)+h>>3]+f;c=c+1|0;if((g|0)!=(c|0)){continue}break}}f=ii(f,q);f=f+H(f*.125)*-8;c:{if(D(f)<2147483648){k=~~f;break c}k=-2147483648}f=f-+(k|0);d:{e:{f:{u=(q|0)<=0;g:{if(!u){i=(g<<2)+h|0;j=v[i+476>>2];c=j>>t;r=i;i=j-(c<<t)|0;v[r+476>>2]=i;k=c+k|0;j=i>>y;break g}if(q){break f}j=v[((g<<2)+h|0)+476>>2]>>23}if((j|0)<=0){break d}break e}j=2;if(f>=.5){break e}j=0;break d}c=0;i=0;if(!o){while(1){r=(h+480|0)+(c<<2)|0;o=v[r>>2];w=16777215;h:{i:{if(i){break i}w=16777216;if(o){break i}i=0;break h}v[r>>2]=w-o;i=1}c=c+1|0;if((g|0)!=(c|0)){continue}break}}j:{if(u){break j}c=8388607;k:{switch(z|0){case 1:c=4194303;break;case 0:break k;default:break j}}o=(g<<2)+h|0;v[o+476>>2]=v[o+476>>2]&c}k=k+1|0;if((j|0)!=2){break d}f=1-f;j=2;if(!i){break d}f=f-ii(1,q)}l:{m:{if(f==0){i=0;c=g;if((n|0)>=(c|0)){break l}while(1){c=c-1|0;i=v[(h+480|0)+(c<<2)>>2]|i;if((c|0)>(n|0)){continue}break}if(!i){break l}l=q;while(1){l=l-24|0;g=g-1|0;if(!v[(h+480|0)+(g<<2)>>2]){continue}break}break m}f=ii(f,24-l|0);n:{if(f>=16777216){d=(h+480|0)+(g<<2)|0;m=f;f=f*5.960464477539063e-8;o:{if(D(f)<2147483648){c=~~f;break o}c=-2147483648}f=m+ +(c|0)*-16777216;p:{if(D(f)<2147483648){a=~~f;break p}a=-2147483648}v[d>>2]=a;g=g+1|0;break n}if(D(f)<2147483648){c=~~f}else{c=-2147483648}l=q}v[(h+480|0)+(g<<2)>>2]=c}f=ii(1,l);if((g|0)>=0){d=g;while(1){a=d;A[(d<<3)+h>>3]=f*+v[(h+480|0)+(d<<2)>>2];d=d-1|0;f=f*5.960464477539063e-8;if(a){continue}break}c=g;while(1){a=c;d=g-c|0;f=0;c=0;while(1){q:{f=f+A[(c<<3)+73568>>3]*A[(a+c<<3)+h>>3];if((c|0)>=(n|0)){break q}i=c>>>0<d>>>0;c=c+1|0;if(i){continue}}break}A[(h+160|0)+(d<<3)>>3]=f;c=a-1|0;if((a|0)>0){continue}break}}r:{s:{t:{switch(e|0){case 3:u:{if((g|0)<=0){break u}d=(h+160|0)+(g<<3)|0;f=A[d>>3];c=g;while(1){m=f;e=h+160|0;a=c-1|0;i=e+(a<<3)|0;x=A[i>>3];f=f+x;A[e+(c<<3)>>3]=m+(x-f);A[i>>3]=f;e=c>>>0>1;c=a;if(e){continue}break}if((g|0)<2){break u}f=A[d>>3];c=g;while(1){m=f;d=h+160|0;a=c-1|0;e=d+(a<<3)|0;p=A[e>>3];f=f+p;A[d+(c<<3)>>3]=m+(p-f);A[e>>3]=f;d=c>>>0>2;c=a;if(d){continue}break}p=0;while(1){p=p+A[(h+160|0)+(g<<3)>>3];a=(g|0)>2;g=g-1|0;if(a){continue}break}}f=A[h+160>>3];if(j){break s}A[b>>3]=f;f=A[h+168>>3];A[b+16>>3]=p;A[b+8>>3]=f;break r;case 0:f=0;if((g|0)>=0){while(1){a=g;g=g-1|0;f=f+A[(h+160|0)+(a<<3)>>3];if(a){continue}break}}A[b>>3]=j?-f:f;break r;case 1:case 2:break t;default:break r}}f=0;if((g|0)>=0){d=g;while(1){a=d;d=d-1|0;f=f+A[(h+160|0)+(a<<3)>>3];if(a){continue}break}}A[b>>3]=j?-f:f;f=A[h+160>>3]-f;c=1;if((g|0)>0){while(1){f=f+A[(h+160|0)+(c<<3)>>3];a=(c|0)!=(g|0);c=c+1|0;if(a){continue}break}}A[b+8>>3]=j?-f:f;break r}A[b>>3]=-f;f=A[h+168>>3];A[b+16>>3]=-p;A[b+8>>3]=-f}gb=h+560|0;return k&7}c=1;while(1){i=c;c=c+1|0;if(!v[(h+480|0)+(n-i<<2)>>2]){continue}break}i=g+i|0;while(1){j=d+g|0;g=g+1|0;A[(h+320|0)+(j<<3)>>3]=v[(s+g<<2)+70800>>2];c=0;f=0;if((d|0)>0){while(1){f=f+A[(c<<3)+a>>3]*A[(h+320|0)+(j-c<<3)>>3];c=c+1|0;if((d|0)!=(c|0)){continue}break}}A[(g<<3)+h>>3]=f;if((g|0)<(i|0)){continue}break}g=i;continue}}function l3(a,b,c,d,e,f,g,h){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0;h=gb+-64|0;gb=h;v[h+56>>2]=b;v[e>>2]=0;Fc(h,d);v[22656]=0;i=T(2452,h|0)|0;j=v[22656];v[22656]=0;a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{t:{u:{v:{w:{x:{y:{z:{A:{if((j|0)!=1){Wb(h);switch(g-65|0){case 54:break j;case 19:break k;case 18:break l;case 17:break m;case 49:break n;case 47:break o;case 45:case 51:break p;case 12:break q;case 44:break r;case 41:break s;case 8:break t;case 7:break u;case 5:break v;case 3:break w;case 35:case 36:break x;case 34:break y;case 1:case 33:case 39:break z;case 0:case 32:break A;case 2:case 4:case 6:case 9:case 10:case 11:case 13:case 14:case 15:case 16:case 20:case 21:case 22:case 25:case 26:case 27:case 28:case 29:case 30:case 31:case 37:case 38:case 40:case 42:case 43:case 46:case 48:case 50:case 52:case 53:break d;case 24:break f;case 56:break g;case 23:break h;case 55:break i;default:break e}}a=P()|0;O()|0;Wb(h);S(a|0);L()}oH(a,f+24|0,h+56|0,c,e,i);break b}nH(a,f+16|0,h+56|0,c,e,i);break b}g=a;a=kb[v[v[a+8>>2]+12>>2]](a+8|0)|0;k=h,l=jk(g,b,c,d,e,f,Jb(a),Jb(a)+(Ab(a)<<2)|0),v[k+56>>2]=l;break b}a=e;b=oj(h+56|0,c,a,i,2);c=v[a>>2];B:{if(!(c&4|(b|0)<=0|(b|0)>31)){v[f+12>>2]=b;break B}v[a>>2]=c|4}break b}g=v[20279];v[h+24>>2]=v[20278];v[h+28>>2]=g;g=v[20277];v[h+16>>2]=v[20276];v[h+20>>2]=g;g=v[20275];v[h+8>>2]=v[20274];v[h+12>>2]=g;g=v[20273];v[h>>2]=v[20272];v[h+4>>2]=g;k=h,l=jk(a,b,c,d,e,f,h,h+32|0),v[k+56>>2]=l;break b}g=v[20287];v[h+24>>2]=v[20286];v[h+28>>2]=g;g=v[20285];v[h+16>>2]=v[20284];v[h+20>>2]=g;g=v[20283];v[h+8>>2]=v[20282];v[h+12>>2]=g;g=v[20281];v[h>>2]=v[20280];v[h+4>>2]=g;k=h,l=jk(a,b,c,d,e,f,h,h+32|0),v[k+56>>2]=l;break b}a=e;b=oj(h+56|0,c,a,i,2);c=v[a>>2];C:{if(!(c&4|(b|0)>23)){v[f+8>>2]=b;break C}v[a>>2]=c|4}break b}a=e;b=oj(h+56|0,c,a,i,2);c=v[a>>2];D:{if(!(c&4|(b|0)<=0|(b|0)>12)){v[f+8>>2]=b;break D}v[a>>2]=c|4}break b}a=e;b=oj(h+56|0,c,a,i,3);c=v[a>>2];E:{if(!(c&4|(b|0)>365)){v[f+28>>2]=b;break E}v[a>>2]=c|4}break b}a=e;b=oj(h+56|0,c,a,i,2);c=v[a>>2];F:{if(!(c&4|(b|0)>12)){v[f+16>>2]=b-1;break F}v[a>>2]=c|4}break b}a=e;b=oj(h+56|0,c,a,i,2);c=v[a>>2];G:{if(!(c&4|(b|0)>59)){v[f+4>>2]=b;break G}v[a>>2]=c|4}break b}a=gb-16|0;gb=a;v[a+8>>2]=c;b=h+56|0;H:{if(!ym(b,a+8|0)){break H}while(1){if(!kl(i,8192,xm(b))){break H}wm(b);if(ym(b,a+8|0)){continue}break}}if(jl(b,a+8|0)){v[e>>2]=v[e>>2]|2}gb=a+16|0;break b}b=h+56|0;a=kb[v[v[a+8>>2]+8>>2]](a+8|0)|0;I:{if((Ab(a)|0)==(0-Ab(a+12|0)|0)){v[e>>2]=v[e>>2]|4;break I}a=Rs(b,c,a,a+24|0,i,e,0)-a|0;b=v[f+8>>2];if(!(a|(b|0)!=12)){v[f+8>>2]=0;break I}if(!((a|0)!=12|(b|0)>11)){v[f+8>>2]=b+12}}break b}g=hc(h,81152,44);k=g,l=jk(a,b,c,d,e,f,g,g+44|0),v[k+56>>2]=l;break b}v[h+16>>2]=v[20304];g=v[20303];v[h+8>>2]=v[20302];v[h+12>>2]=g;g=v[20301];v[h>>2]=v[20300];v[h+4>>2]=g;k=h,l=jk(a,b,c,d,e,f,h,h+20|0),v[k+56>>2]=l;break b}a=e;b=oj(h+56|0,c,a,i,2);c=v[a>>2];J:{if(!(c&4|(b|0)>60)){v[f>>2]=b;break J}v[a>>2]=c|4}break b}g=v[20315];v[h+24>>2]=v[20314];v[h+28>>2]=g;g=v[20313];v[h+16>>2]=v[20312];v[h+20>>2]=g;g=v[20311];v[h+8>>2]=v[20310];v[h+12>>2]=g;g=v[20309];v[h>>2]=v[20308];v[h+4>>2]=g;k=h,l=jk(a,b,c,d,e,f,h,h+32|0),v[k+56>>2]=l;break b}a=e;b=oj(h+56|0,c,a,i,1);c=v[a>>2];K:{if(!(c&4|(b|0)>6)){v[f+24>>2]=b;break K}v[a>>2]=c|4}break b}a=kb[v[v[a>>2]+20>>2]](a,b,c,d,e,f)|0;break a}g=a;a=kb[v[v[a+8>>2]+24>>2]](a+8|0)|0;k=h,l=jk(g,b,c,d,e,f,Jb(a),Jb(a)+(Ab(a)<<2)|0),v[k+56>>2]=l;break b}mH(f+20|0,h+56|0,c,e,i);break b}a=oj(h+56|0,c,e,i,4);if(!(w[e|0]&4)){v[f+20>>2]=a-1900}break b}if((g|0)==37){break c}}v[e>>2]=v[e>>2]|4;break b}a=gb-16|0;gb=a;v[a+8>>2]=c;b=6;c=h+56|0;L:{M:{if(jl(c,a+8|0)){break M}b=4;if((Sn(i,xm(c))|0)!=37){break M}b=2;if(!jl(wm(c),a+8|0)){break L}}v[e>>2]=v[e>>2]|b}gb=a+16|0}a=v[h+56>>2]}gb=h- -64|0;return a|0}function U8(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0;f=gb-128|0;gb=f;a:{if(gd(b)){break a}e=w[uL(b)|0];if((e|0)==33){d=1}else{if((e|0)!=63){break a}d=0}e=f+112|0;Qs(e,b,0,Ab(b)-1|0);Eb(b,e);vb(e)}g=f+112|0;Ld(g);e=v[f+112>>2];Ld(f+96|0);e=tL(e,v[f+100>>2],b);Ld(g);b:{c:{d:{e:{if((e|0)==v[f+116>>2]){if(qe(b,18726)){a=ba(8)|0;v[22656]=0;U(2053,f+112|0,14728,c|0);b=v[22656];v[22656]=0;if((b|0)==1){break d}rc(a,f+112|0);v[22656]=0;U(186,a|0,54952,1936);a=v[22656];v[22656]=0;if((a|0)!=1){break b}b=P()|0;O()|0;vb(f+112|0);break c}if(!d){break e}a=ba(8)|0;v[22656]=0;U(2053,f+80|0,14764,b|0);b=v[22656];v[22656]=0;f:{g:{h:{i:{if((b|0)!=1){v[22656]=0;R(2054,f+96|0,f+80|0);b=v[22656];v[22656]=0;if((b|0)==1){break i}v[22656]=0;U(718,f+112|0,f+96|0,c|0);b=v[22656];v[22656]=0;d=1;if((b|0)==1){break h}rc(a,f+112|0);v[22656]=0;U(186,a|0,54952,1936);b=v[22656];v[22656]=0;if((b|0)!=1){break b}b=P()|0;O()|0;vb(f+112|0);d=0;break g}b=P()|0;O()|0;break f}b=P()|0;O()|0;vb(f+80|0);break f}b=P()|0;O()|0}vb(f+96|0);vb(f+80|0);if(!d){break c}}ca(a|0);break c}j:{switch(v[e+4>>2]){case 0:Eg(f+72|0,b);b=gb-192|0;gb=b;e=b+16|0;$f(e,c);v[22656]=0;R(99,b+32|0,e|0);c=v[22656];v[22656]=0;k:{l:{m:{n:{o:{if((c|0)!=1){v[22656]=0;c=W(100,b+48|0,b+32|0,8)|0;e=v[22656];v[22656]=0;if((e|0)==1){break o}vb(b+32|0);vb(b+16|0);e=v[v[c>>2]-12>>2];v[22656]=0;g=ga(79)|0;h=v[22656];v[22656]=0;if((h|0)==1){break m}v[22656]=0;U(80,b+8|0,e+(b+48|0)|0,g|0);e=v[22656];v[22656]=0;if((e|0)==1){break m}Wb(b+8|0);v[22656]=0;e=Q(2055,c|0,b+32|0)|0;g=v[22656];v[22656]=0;if((g|0)==1){break m}g=v[v[e>>2]-12>>2];v[22656]=0;e=Fl(e+g|0);g=v[22656];v[22656]=0;if((g|0)==1){break m}g=w[b+32|0];vf(c);gb=b+192|0;b=(e^-1)&(g|0)!=0;break k}a=P()|0;O()|0;break n}a=P()|0;O()|0;vb(b+32|0)}vb(b+16|0);break l}a=P()|0;O()|0;vf(c)}S(a|0);L()}c=v[f+76>>2];v[f>>2]=v[f+72>>2];v[f+4>>2]=c;sL(a,f,b,d);break e;case 1:Eg(f- -64|0,b);b=gb-192|0;gb=b;e=b+16|0;$f(e,c);v[22656]=0;R(99,b+32|0,e|0);c=v[22656];v[22656]=0;p:{q:{r:{s:{t:{if((c|0)!=1){v[22656]=0;c=W(100,b+48|0,b+32|0,8)|0;e=v[22656];v[22656]=0;if((e|0)==1){break t}vb(b+32|0);vb(b+16|0);e=v[v[c>>2]-12>>2];v[22656]=0;g=ga(79)|0;h=v[22656];v[22656]=0;if((h|0)==1){break r}v[22656]=0;U(80,b+8|0,e+(b+48|0)|0,g|0);e=v[22656];v[22656]=0;if((e|0)==1){break r}Wb(b+8|0);v[22656]=0;e=Q(110,c|0,b+32|0)|0;g=v[22656];v[22656]=0;if((g|0)==1){break r}g=v[v[e>>2]-12>>2];v[22656]=0;e=Fl(e+g|0);g=v[22656];v[22656]=0;if((g|0)==1){break r}g=v[b+32>>2];h=v[b+36>>2];vf(c);gb=b+192|0;b=e?0:g;c=e?0:h;break p}a=P()|0;O()|0;break s}a=P()|0;O()|0;vb(b+32|0)}vb(b+16|0);break q}a=P()|0;O()|0;vf(c)}S(a|0);L()}e=v[f+68>>2];v[f+8>>2]=v[f+64>>2];v[f+12>>2]=e;rL(a,f+8|0,b,c,d);break e;case 2:Eg(f+56|0,b);b=gb-192|0;gb=b;e=b+16|0;$f(e,c);v[22656]=0;R(99,b+32|0,e|0);c=v[22656];v[22656]=0;u:{v:{w:{x:{y:{if((c|0)!=1){v[22656]=0;c=W(100,b+48|0,b+32|0,8)|0;e=v[22656];v[22656]=0;if((e|0)==1){break y}vb(b+32|0);vb(b+16|0);e=v[v[c>>2]-12>>2];v[22656]=0;g=ga(79)|0;h=v[22656];v[22656]=0;if((h|0)==1){break w}v[22656]=0;U(80,b+8|0,e+(b+48|0)|0,g|0);e=v[22656];v[22656]=0;if((e|0)==1){break w}Wb(b+8|0);v[22656]=0;e=Q(111,c|0,b+32|0)|0;g=v[22656];v[22656]=0;if((g|0)==1){break w}g=v[v[e>>2]-12>>2];v[22656]=0;e=Fl(e+g|0);g=v[22656];v[22656]=0;if((g|0)==1){break w}i=A[b+32>>3];vf(c);gb=b+192|0;i=e?0:i;break u}a=P()|0;O()|0;break x}a=P()|0;O()|0;vb(b+32|0)}vb(b+16|0);break v}a=P()|0;O()|0;vf(c)}S(a|0);L()}b=v[f+60>>2];v[f+16>>2]=v[f+56>>2];v[f+20>>2]=b;qL(a,f+16|0,i,d);break e;case 3:break j;default:break e}}Eg(f+48|0,b);Eg(f+40|0,c);b=v[f+52>>2];v[f+32>>2]=v[f+48>>2];v[f+36>>2]=b;b=v[f+44>>2];v[f+24>>2]=v[f+40>>2];v[f+28>>2]=b;pL(a,f+32|0,f+24|0,d)}gb=f+128|0;return}b=P()|0;O()|0;ca(a|0)}S(b|0)}L()}function Ko(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;d=gb-112|0;gb=d;p=XA(a);q=Ri(p);f=q;c=a;e=Ec(c);a:{if(f>>>0>e>>>0){m=gb-32|0;gb=m;b:{i=f-e|0;c:{if(i>>>0<=(v[wb(c)>>2]-v[c+4>>2]|0)/12>>>0){f=gb-16|0;gb=f;i=Np(f,c,i);h=v[i+4>>2];e=v[i+8>>2];if((h|0)!=(e|0)){while(1){wb(c);gR(h);h=h+12|0;v[i+4>>2]=h;if((e|0)!=(h|0)){continue}break}}$b(i);gb=f+16|0;break c}e=wb(c);j=Zu(m+8|0,UB(c,Ec(c)+i|0),Ec(c),e);v[22656]=0;R(1132,j|0,i|0);e=v[22656];v[22656]=0;if((e|0)==1){break b}$p(c);wb(c);f=j+4|0;l=f;k=v[c+4>>2];e=v[c>>2];if((k|0)!=(e|0)){i=v[l>>2];while(1){k=k-12|0;YB(i-12|0,k);i=v[l>>2]-12|0;v[l>>2]=i;if((e|0)!=(k|0)){continue}break}}wc(c,f);wc(c+4|0,j+8|0);wc(wb(c),dc(j));v[j>>2]=v[j+4>>2];ax(c,Ec(c));hR(j)}gb=m+32|0;break a}a=P()|0;O()|0;hR(j);S(a|0);L()}if(e>>>0>f>>>0){f=v[c>>2]+B(f,12)|0;Ec(c);lR(c,f);iR(c)}}if(b){c=a+12|0;Kq(c,Yd(c));r=wb(c),s=0,v[r>>2]=s;r=c,s=fc(c),v[r>>2]=s;r=fc(c),s=0,v[r>>2]=s;v[a+28>>2]=0}n=mc(d+96|0);c=v[a+24>>2];v[22656]=0;e=oq(c+484344|0);c=v[22656];v[22656]=0;d:{e:{f:{g:{if((c|0)==1){break g}v[22656]=0;j=W(796,d+80|0,e|0,36524)|0;c=v[22656];v[22656]=0;if((c|0)==1){break g}h=0;u[d+78>>1]=0;if(q){o=a+12|0;while(1){l=x[sc(p,h&65535)>>1];c=wR(a,l);v[d+72>>2]=c;f=Ad(a,x[d+78>>1]);h:{if(b){v[22656]=0;t[d+32|0]=0;U(1126,f|0,c|0,d+32|0);c=v[22656];v[22656]=0;if((c|0)!=1){break h}g=P()|0;O()|0;break e}v[22656]=0;U(948,f|0,c|0,0);c=v[22656];v[22656]=0;if((c|0)==1){break f}}v[22656]=0;e=Q(472,p|0,x[d+78>>1])|0;c=v[22656];v[22656]=0;if((c|0)==1){break f}i:{if(!e){break i}g=0;g=b?g:v[f+4>>2];v[22656]=0;v[d+32>>2]=g;e=Fb(d+32|0,d+72|0);c=v[22656];v[22656]=0;j:{k:{if((c|0)!=1){v[d+68>>2]=v[e>>2];i=Dh(o);if(x[sc(j,l)>>1]!=65535){e=uR(o,Um(d+32|0,sc(j,l),d+68|0));v[d+64>>2]=e;r=d,s=Dh(o),v[r+8>>2]=s;f=d;l:{if(og(d- -64|0,d+8|0)){c=uR(o,Um(d+32|0,sc(j,l),d+72|0));break l}c=Dh(o)}v[f+56>>2]=c;v[d+48>>2]=e;if(!og(d+48|0,d+56|0)){break i}while(1){m:{f=dd(d+32|0);c=tg(ue(d+48|0)+8|0);v[22656]=0;R(1127,f|0,c|0);c=v[22656];v[22656]=0;if((c|0)==1){break m}DB(d+16|0,i);c=Um(d+8|0,d+78|0,ue(d+48|0)+4|0);v[22656]=0;e=da(1128,o|0,v[d+16>>2],c|0,f|0)|0;c=v[22656];v[22656]=0;if((c|0)==1){break m}v[d+24>>2]=e;tR(d+24|0);i=v[d+24>>2];Lq(f);if(og(tR(d+48|0),d+56|0)){continue}break i}break}g=P()|0;O()|0;Lq(f);break e}f=_b(v[a+24>>2]+484344|0,l);v[22656]=0;e=Ji(f);c=v[22656];v[22656]=0;n:{o:{if((c|0)!=1){v[22656]=0;t[d+32|0]=0;U(1130,n|0,e|0,d+32|0);c=v[22656];v[22656]=0;if((c|0)==1){break o}k=v[d+72>>2];if((k|0)!=v[d+68>>2]){break n}break j}g=P()|0;O()|0;break e}g=P()|0;O()|0;break e}p:while(1){q:{h=0;v[22656]=0;k=k-1|0;v[d+64>>2]=k;g=Tf(f,k);c=v[22656];v[22656]=0;m=1;if((c|0)==1){break k}while(1){r:{v[22656]=0;e=Ji(f);c=v[22656];v[22656]=0;s:{if((c|0)!=1){if(m>>>0<16&e>>>0>h>>>0){break s}if(m>>>0>1){e=dd(d+32|0);v[22656]=0;R(1127,e|0,m|0);c=v[22656];v[22656]=0;if((c|0)==1){break r}DB(d,i);c=Um(d+8|0,d+78|0,d- -64|0);v[22656]=0;i=da(1128,o|0,v[d>>2],c|0,e|0)|0;c=v[22656];v[22656]=0;if((c|0)==1){break q}Lq(e)}if(v[d+68>>2]==(k|0)){break j}continue p}g=P()|0;O()|0;break e}e=w[lc(n,h)|0];t:{u:{v:{switch(w[g+3|0]-19|0){case 1:c=w[g+5|0];if((c&240)==176){break u}break t;case 0:break v;default:break t}}c=w[g+5|0];if((c&240)!=96){break t}}r=lc(n,h),s=c&15,t[r|0]=s;if(!w[lc(n,h)|0]){break t}e=w[lc(n,h)|0]}m=B(e?e+1|0:1,m);g=g+6|0;h=h+1|0;continue}break}}break}g=P()|0;O()|0;Lq(e);break e}g=P()|0;O()|0;break e}g=P()|0;O()|0;break e}if(k){break i}c=x[d+78>>1];r=sc(j,l),s=c,u[r>>1]=s}h=x[d+78>>1]+1|0;u[d+78>>1]=h;if((h&65535)>>>0<q>>>0){continue}break}}Ze(j);gc(n);gb=d+112|0;return}g=P()|0;O()|0;break d}g=P()|0;O()|0}Ze(j)}gc(n);S(g|0);L()}function r3(a,b,c,d,e,f,g,h){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0;h=gb-32|0;gb=h;v[h+24>>2]=b;v[e>>2]=0;i=h+8|0;Fc(i,d);v[22656]=0;i=T(21,i|0)|0;j=v[22656];v[22656]=0;a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{t:{u:{v:{w:{x:{y:{z:{A:{if((j|0)!=1){Wb(h+8|0);switch(g-65|0){case 54:break j;case 19:break k;case 18:break l;case 17:break m;case 49:break n;case 47:break o;case 45:case 51:break p;case 12:break q;case 44:break r;case 41:break s;case 8:break t;case 7:break u;case 5:break v;case 3:break w;case 35:case 36:break x;case 34:break y;case 1:case 33:case 39:break z;case 0:case 32:break A;case 2:case 4:case 6:case 9:case 10:case 11:case 13:case 14:case 15:case 16:case 20:case 21:case 22:case 25:case 26:case 27:case 28:case 29:case 30:case 31:case 37:case 38:case 40:case 42:case 43:case 46:case 48:case 50:case 52:case 53:break d;case 24:break f;case 56:break g;case 23:break h;case 55:break i;default:break e}}a=P()|0;O()|0;Wb(h+8|0);S(a|0);L()}sH(a,f+24|0,h+24|0,c,e,i);break b}qH(a,f+16|0,h+24|0,c,e,i);break b}g=a;a=kb[v[v[a+8>>2]+12>>2]](a+8|0)|0;k=h,l=kk(g,b,c,d,e,f,Jb(a),Jb(a)+Ab(a)|0),v[k+24>>2]=l;break b}a=e;b=pj(h+24|0,c,a,i,2);c=v[a>>2];B:{if(!(c&4|(b|0)<=0|(b|0)>31)){v[f+12>>2]=b;break B}v[a>>2]=c|4}break b}v[h+8>>2]=623865125;v[h+12>>2]=2032480100;k=h,l=kk(a,b,c,d,e,f,h+8|0,h+16|0),v[k+24>>2]=l;break b}v[h+8>>2]=623728933;v[h+12>>2]=1680158061;k=h,l=kk(a,b,c,d,e,f,h+8|0,h+16|0),v[k+24>>2]=l;break b}a=e;b=pj(h+24|0,c,a,i,2);c=v[a>>2];C:{if(!(c&4|(b|0)>23)){v[f+8>>2]=b;break C}v[a>>2]=c|4}break b}a=e;b=pj(h+24|0,c,a,i,2);c=v[a>>2];D:{if(!(c&4|(b|0)<=0|(b|0)>12)){v[f+8>>2]=b;break D}v[a>>2]=c|4}break b}a=e;b=pj(h+24|0,c,a,i,3);c=v[a>>2];E:{if(!(c&4|(b|0)>365)){v[f+28>>2]=b;break E}v[a>>2]=c|4}break b}a=e;b=pj(h+24|0,c,a,i,2);c=v[a>>2];F:{if(!(c&4|(b|0)>12)){v[f+16>>2]=b-1;break F}v[a>>2]=c|4}break b}a=e;b=pj(h+24|0,c,a,i,2);c=v[a>>2];G:{if(!(c&4|(b|0)>59)){v[f+4>>2]=b;break G}v[a>>2]=c|4}break b}a=gb-16|0;gb=a;v[a+8>>2]=c;b=h+24|0;H:{if(!nk(b,a+8|0)){break H}while(1){if(!nh(i,8192,pl(b))){break H}ol(b);if(nk(b,a+8|0)){continue}break}}if(mk(b,a+8|0)){v[e>>2]=v[e>>2]|2}gb=a+16|0;break b}b=h+24|0;a=kb[v[v[a+8>>2]+8>>2]](a+8|0)|0;I:{if((Ab(a)|0)==(0-Ab(a+12|0)|0)){v[e>>2]=v[e>>2]|4;break I}a=Ts(b,c,a,a+24|0,i,e,0)-a|0;b=v[f+8>>2];if(!(a|(b|0)!=12)){v[f+8>>2]=0;break I}if(!((a|0)!=12|(b|0)>11)){v[f+8>>2]=b+12}}break b}g=w[81076]|w[81077]<<8|(w[81078]<<16|w[81079]<<24);t[h+15|0]=g;t[h+16|0]=g>>>8;t[h+17|0]=g>>>16;t[h+18|0]=g>>>24;g=w[81073]|w[81074]<<8|(w[81075]<<16|w[81076]<<24);v[h+8>>2]=w[81069]|w[81070]<<8|(w[81071]<<16|w[81072]<<24);v[h+12>>2]=g;k=h,l=kk(a,b,c,d,e,f,h+8|0,h+19|0),v[k+24>>2]=l;break b}t[h+12|0]=w[81084];v[h+8>>2]=w[81080]|w[81081]<<8|(w[81082]<<16|w[81083]<<24);k=h,l=kk(a,b,c,d,e,f,h+8|0,h+13|0),v[k+24>>2]=l;break b}a=e;b=pj(h+24|0,c,a,i,2);c=v[a>>2];J:{if(!(c&4|(b|0)>60)){v[f>>2]=b;break J}v[a>>2]=c|4}break b}v[h+8>>2]=624576549;v[h+12>>2]=1394948685;k=h,l=kk(a,b,c,d,e,f,h+8|0,h+16|0),v[k+24>>2]=l;break b}a=e;b=pj(h+24|0,c,a,i,1);c=v[a>>2];K:{if(!(c&4|(b|0)>6)){v[f+24>>2]=b;break K}v[a>>2]=c|4}break b}a=kb[v[v[a>>2]+20>>2]](a,b,c,d,e,f)|0;break a}g=a;a=kb[v[v[a+8>>2]+24>>2]](a+8|0)|0;k=h,l=kk(g,b,c,d,e,f,Jb(a),Jb(a)+Ab(a)|0),v[k+24>>2]=l;break b}pH(f+20|0,h+24|0,c,e,i);break b}a=pj(h+24|0,c,e,i,4);if(!(w[e|0]&4)){v[f+20>>2]=a-1900}break b}if((g|0)==37){break c}}v[e>>2]=v[e>>2]|4;break b}a=gb-16|0;gb=a;v[a+8>>2]=c;b=6;c=h+24|0;L:{M:{if(mk(c,a+8|0)){break M}b=4;if((Tn(i,pl(c))|0)!=37){break M}b=2;if(!mk(ol(c),a+8|0)){break L}}v[e>>2]=v[e>>2]|b}gb=a+16|0}a=v[h+24>>2]}gb=h+32|0;return a|0}function oe(a,b){var c=C(0),d=0,e=0,f=C(0),g=0,h=0,i=C(0),k=0,m=C(0),n=C(0),o=0,r=0,s=C(0),t=C(0),u=C(0);i=C(1);a:{b:{c:{k=(p(b),j(2));d=k&2147483647;d:{if(!d){break d}h=(p(a),j(2));if((h|0)==1065353216){break d}e=h&2147483647;c=C(a+b);if(!(d>>>0<2139095041&e>>>0<=2139095040)){break a}e:{f:{if((h|0)>=0){break f}o=2;if(d>>>0>1266679807){break e}if(d>>>0<1065353216){break f}g=150-(d>>>23|0)|0;r=d>>>g|0;o=0;if((d|0)!=r<<g){break e}o=2-(r&1)|0;break e}o=0}g=o;g:{if((d|0)!=1065353216){if((d|0)!=2139095040){break g}if((e|0)==1065353216){break d}c=(k|0)>=0?b:C(0);if(e>>>0>=1065353217){break a}c=(k|0)>=0?C(0):C(-b);break a}c=(k|0)>=0?a:C(C(1)/a);break a}c=C(a*a);if((k|0)==1073741824){break a}c=C(K(a));if(!((k|0)!=1056964608|(h|0)<0)){break a}f=C(D(a));if(!(e?(h&1073741823)!=1065353216:0)){i=(k|0)<0?C(C(1)/f):f;if((h|0)>=0){break d}if(!(g|e-1065353216)){a=C(i-i);c=C(a/a);break a}c=(g|0)==1?C(-i):i;break a}h:{if((h|0)>=0){break h}i:{switch(g|0){case 0:a=C(a-a);c=C(a/a);break a;case 1:break i;default:break h}}i=C(-1)}j:{if(d>>>0>=1291845633){c=(k|0)<0?C(C(i*C(1.0000000150474662e30))*C(1.0000000150474662e30)):C(C(i*C(1.0000000031710769e-30))*C(1.0000000031710769e-30));if(e>>>0<=1065353207){break a}c=(k|0)>0?C(C(i*C(1.0000000150474662e30))*C(1.0000000150474662e30)):C(C(i*C(1.0000000031710769e-30))*C(1.0000000031710769e-30));if(e>>>0>=1065353224){break a}a=C(f+C(-1));c=C(C(a*C(7052607543300837e-21))+C(C(C(a*a)*C(C(.5)-C(a*C(C(a*C(-.25))+C(.3333333432674408)))))*C(-1.4426950216293335)));f=c;a=C(a*C(1.44268798828125));c=(l(2,(p(C(c+a)),j(2))&-4096),q());f=C(f-C(c-a));break j}d=e>>>0<8388608;e=d?(p(C(f*C(16777216))),j(2)):e;h=e&8388607;g=h|1065353216;d=(e>>23)+(d?-151:-127)|0;e=0;k:{if(h>>>0<1885298){break k}if(h>>>0<6140887){e=1;break k}g=h|1056964608;d=d+1|0}h=e<<2;a=z[h+90064>>2];n=(l(2,g),q());m=C(C(1)/C(a+n));s=C(n-a);f=C(s*m);c=(l(2,(p(f),j(2))&-4096),q());t=C(c*c);u=m;m=(l(2,((g>>>1&536866816)+(e<<21)|0)+541065216|0),q());n=C(u*C(C(s-C(m*c))-C(C(n-C(m-a))*c)));a=C(f*f);m=C(C(n*C(f+c))+C(C(a*a)*C(C(a*C(C(a*C(C(a*C(C(a*C(C(a*C(.20697501301765442))+C(.23066075146198273)))+C(.2727281153202057)))+C(.3333333432674408)))+C(.4285714328289032)))+C(.6000000238418579))));a=(l(2,(p(C(C(t+C(3))+m)),j(2))&-4096),q());f=C(C(n*a)+C(f*C(m-C(C(a+C(-3))-t))));c=C(c*a);a=(l(2,(p(C(f+c)),j(2))&-4096),q());n=z[h+90080>>2];f=C(z[h+90072>>2]+C(C(C(f-C(a-c))*C(.9617967009544373))+C(a*C(-.00011736857413779944))));a=C(a*C(.9619140625));m=C(d|0);c=(l(2,(p(C(C(n+C(f+a))+m)),j(2))&-4096),q());f=C(f-C(C(C(c-m)-n)-a))}n=(l(2,k&-4096),q());a=C(c*n);b=C(C(f*b)+C(C(b-n)*c));c=C(a+b);g=(p(c),j(2));if((g|0)>=1124073473){break c}e=1124073472;l:{m:{if((g|0)==1124073472){if(!(C(b+C(4.299566569443414e-8))>C(c-a))){break m}break c}e=g&2147483647;if(!(!(b<=C(c-a))|(g|0)!=-1021968384)|e>>>0>=1125515265){break b}d=0;if(e>>>0<1056964609){break l}}k=(8388608>>>(e>>>23|0)-126|0)+g|0;e=k>>>23&255;d=(k&8388607|8388608)>>>150-e|0;d=(g|0)<0?0-d|0:d;a=C(a-(l(2,k&-8388608>>e-127),q()));g=(p(C(b+a)),j(2))}c=(l(2,g&-32768),q());f=C(c*C(.693145751953125));c=C(C(c*C(14286065379565116e-22))+C(C(b-C(c-a))*C(.6931471824645996)));a=C(f+c);b=C(a*a);b=C(a-C(b*C(C(b*C(C(b*C(C(b*C(C(b*C(4.138136944220605e-8))+C(-16533901998627698e-22)))+C(661375597701408e-19)))+C(-.0027777778450399637)))+C(.1666666716337204))));m=C(C(a*b)/C(b+C(-2)));b=C(c-C(a-f));a=C(C(a-C(m-C(b+C(a*b))))+C(1));g=(p(a),j(2))+(d<<23)|0;n:{if((g|0)<=8388607){a=$I(a,d);break n}a=(l(2,g),q())}i=C(i*a)}c=i;break a}c=C(C(i*C(1.0000000150474662e30))*C(1.0000000150474662e30));break a}c=C(C(i*C(1.0000000031710769e-30))*C(1.0000000031710769e-30))}return c}function gha(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;g=gb-11360|0;gb=g;vc(c);a:{b:{if(!Pb(c,4)){break b}c:{while(1){d:{j=g+16|0;d=j;f=gb-32|0;gb=f;h=c;e:{if(!Pb(c,3)){k=gb-16|0;gb=k;i=d+3|0;while(1){Hf(d);d=d+1|0;if((i|0)!=(d|0)){continue}break}gb=k+16|0;break e}eY(f+24|0,d);d=v[f+28>>2];v[f+8>>2]=v[f+24>>2];v[f+12>>2]=d;kd(f+16|0,h,f+8|0)}gb=f+32|0;f:{if(!sd(j,12228,3)){d=g+4648|0;f=gb-32|0;gb=f;g:{if(!Pb(c,7)){h=gb-16|0;gb=h;j=d+7|0;while(1){Hf(d);d=d+1|0;if((j|0)!=(d|0)){continue}break}gb=h+16|0;break g}tn(f+24|0,d);d=v[f+28>>2];v[f+8>>2]=v[f+24>>2];v[f+12>>2]=d;kd(f+16|0,h,f+8|0)}gb=f+32|0;f=3;d=0;while(1){h=w[(g+4648|0)+f|0];if(h&128){break c}d=h|d<<7;f=f+1|0;if((f|0)!=7){continue}break}Rb(c,d);break f}h:{if(sd(g+16|0,11433,3)){break h}if(!xV(c,10883)){break h}Rb(c,sg(c)+16|0);break f}if(!sd(g+16|0,36527,3)){break f}if(!sd(g+16|0,36531,3)){break f}if(w[g+16|0]){break d}pg(c,2)}if(Pb(c,4)){continue}break b}break}if(RS(g+16|0)){break b}}f=0;break a}vc(c);d=g+11336|0;TC(d,c);k=v[d>>2];v[22656]=0;c=Sd(d);d=v[22656];v[22656]=0;i:{j:{k:{l:{if((d|0)!=1){c=zb(c);i=mc(g+11320|0);d=g+4648|0;Qb(d,0,6668);v[22656]=0;tt(d);d=v[22656];v[22656]=0;if((d|0)!=1){d=g+4640|0;v[d>>2]=0;v[d+4>>2]=0;d=g+4632|0;v[d>>2]=0;v[d+4>>2]=0;v[g+4624>>2]=0;v[g+4628>>2]=0;h=0;d=0;while(1){f=Ac(k,l);v[22656]=0;m=fa(1137,g+4648|0,c|0,f|0,g+16|0,g+4624|0)|0;f=v[22656];v[22656]=0;m:{n:{if((f|0)!=1){if((m|0)<0){break k}f=v[g+4624>>2];if((f|0)<0|(f?0:m)|!(f|m)){break k}if(!f){break m}j=v[g+4636>>2];if((j|0)!=(h|0)?h:0){break k}f=v[g+4632>>2];if((f|0)!=(d|0)?d:0){break k}if((j|0)<=0|f-1>>>0>1){break l}v[g+12>>2]=0;d=Ac(k,l);v[22656]=0;v[g+8>>2]=d;d=dj(g+4624|0,g+12|0,g+8|0);h=v[22656];v[22656]=0;o:{if((h|0)!=1){d=v[d>>2];v[g+12>>2]=0;h=Ac(k,l);v[22656]=0;v[g+8>>2]=h;h=dj(g+4624|0,g+12|0,g+8|0);n=v[22656];v[22656]=0;if((n|0)==1){break o}c=c+d|0;d=k;h=v[h>>2];k=d-h|0;l=l-((h>>31)+(d>>>0<h>>>0)|0)|0;if(!m){break n}v[22656]=0;d=g+16|0;U(1139,i|0,d|0,d+(B(f,m)<<1)|0);d=v[22656];v[22656]=0;if((d|0)!=1){break n}d=V(89116)|0;if((O()|0)!=(ea(89116)|0)){break j}Z(d|0)|0;v[22656]=0;X(20);c=v[22656];v[22656]=0;h=j;d=f;if((c|0)!=1){break k}d=P()|0;O()|0;break j}d=P()|0;O()|0;break j}d=P()|0;O()|0;break j}d=P()|0;O()|0;break j}h=j;d=f}if((tc(i)>>>0)/(d>>>0)>>>0>268435456){break k}if(!!k&(l|0)>=0|(l|0)>0){continue}break}break k}d=P()|0;O()|0;break j}d=P()|0;O()|0;break i}h=j;d=f}f=0;p:{q:{r:{s:{t:{if(!h|!d){break t}if(cd(i)){break t}if((tc(i)>>>0)/(d>>>0)>>>0>268435456){break t}v[22656]=0;Q(1140,a|0,b|0)|0;c=v[22656];v[22656]=0;if((c|0)==1){break p}if(!e){v[22656]=0;c=Q(70,g+16|0,18726)|0;f=v[22656];v[22656]=0;if((f|0)==1){break s}v[22656]=0;Q(301,((b<<5)+a|0)+946304|0,c|0)|0;f=v[22656];v[22656]=0;if((f|0)==1){break r}vb(c);v[22656]=0;c=B(b,104)+a|0;R(424,c+484380|0,0);f=v[22656];v[22656]=0;if((f|0)==1){break p}v[c+484404>>2]=h}h=B(b,104)+a|0;c=h+484380|0;o=c,p=(tc(i)>>>0)/(d>>>0)|0,v[o>>2]=p;f=h+484414|0;h=x[f>>1];u[f>>1]=(d|0)==2?h|65:h&65470|1;v[22656]=0;T(386,c|0)|0;d=v[22656];v[22656]=0;if((d|0)==1){break p}if(Jd(c)){d=Vb(i);h=Zb(i);b=v[(B(b,104)+a|0)+484400>>2];v[22656]=0;W(1141,d|0,h|0,b|0)|0;b=v[22656];v[22656]=0;if((b|0)==1){break p}}if(!e){b=v[a+480180>>2];v[22656]=0;U(1142,c|0,32,b|0);b=v[22656];v[22656]=0;if((b|0)==1){break q}v[22656]=0;_h(c,a,0);a=v[22656];v[22656]=0;if((a|0)==1){break p}}f=Jd(c)}Ze(i);zc(g+11336|0);break a}d=P()|0;O()|0;break j}d=P()|0;O()|0;vb(c);break j}d=P()|0;O()|0;break j}d=P()|0;O()|0}Ze(i)}zc(g+11336|0);S(d|0);L()}gb=g+11360|0;return f|0}function a_(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;g=gb-576|0;gb=g;vc(b);f=gb-32|0;gb=f;d=f+24|0;i=g+72|0;KE(d,i);e=yb(d);d=v[f+28>>2];h=v[f+24>>2];v[f+8>>2]=h;v[f+12>>2]=d;v[f>>2]=h;v[f+4>>2]=d;h=f+16|0;d=b;cc(h,d,f);h=yb(h);if((h|0)==(e|0)){Rb(d,yb(f+24|0))}gb=f+32|0;d=(e|0)==(h|0);if(!d){JE(i)}a:{if(!d){break a}if(!QE(g+72|0)){break a}b:{if(!c){break b}if(!Pb(b,Qc(PE(g+72|0),jb))){break a}Gd(a,64);v[a+480260>>2]=112;v[a+480264>>2]=13696;v[a+480204>>2]=78e4;v[a+480196>>2]=4;u[a+480188>>1]=8;f=1;Ob(a+1074312|0,7,1);d=g+40|0;e=Tb(d,11859);Eb(a+1298304|0,e);vb(e);d=Tb(d,11892);Eb(a+1298316|0,d);vb(d);Xc(a+1298328|0,x[g+72>>1]==26217?11859:11887);v[a+1298364>>2]=5;d=w[g+182|0];u[a+480190>>1]=d;c:{d:{e:{if(d){i=1;while(1){h=gb-32|0;gb=h;d=h+24|0;e=g+40|0;bc(d,e,25);k=yb(d);d=v[h+28>>2];j=v[h+24>>2];v[h+8>>2]=j;v[h+12>>2]=d;v[h>>2]=j;v[h+4>>2]=d;j=h+16|0;d=b;cc(j,d,h);j=yb(j);if((j|0)==(k|0)){Rb(d,yb(h+24|0))}gb=h+32|0;if((j|0)!=(k|0)){t[e|0]=0;t[e+1|0]=0;t[e+2|0]=0;t[e+3|0]=0;t[e+4|0]=0;t[e+5|0]=0;t[e+6|0]=0;t[e+7|0]=0;t[e+24|0]=0;t[e+16|0]=0;t[e+17|0]=0;t[e+18|0]=0;t[e+19|0]=0;t[e+20|0]=0;t[e+21|0]=0;t[e+22|0]=0;t[e+23|0]=0;t[e+8|0]=0;t[e+9|0]=0;t[e+10|0]=0;t[e+11|0]=0;t[e+12|0]=0;t[e+13|0]=0;t[e+14|0]=0;t[e+15|0]=0}if((w[g+53|0]|w[g+54|0]<<8|(w[g+55|0]<<16|w[g+56|0]<<24))>>>0>67108863){break a}e=(B(f,104)+a|0)+484380|0;ud(e,0);v[e+24>>2]=8363;h=g+40|0;d=h;v[e>>2]=w[d+13|0]|w[d+14|0]<<8|(w[d+15|0]<<16|w[d+16|0]<<24);v[e+4>>2]=w[d+17|0]|w[d+18|0]<<8|(w[d+19|0]<<16|w[d+20|0]<<24);d=w[d+21|0]|w[d+22|0]<<8|(w[d+23|0]<<16|w[d+24|0]<<24);d=d>>>0>y[e>>2]?v[e+4>>2]?d:0:d;v[e+8>>2]=d;if(d){u[e+34>>1]=2;xk(e)}d=g+8|0;ki(d,2,h);e=g+24|0;Bc(e,d);v[22656]=0;Q(301,((f<<5)+a|0)+946304|0,e|0)|0;d=v[22656];v[22656]=0;if((d|0)==1){break e}vb(g+24|0);i=i+1|0;f=i&65535;if(f>>>0<=x[a+480190>>1]){continue}break}}f=g+24|0;e=g+72|2;Xe(f,3,e,36);d=g+40|0;Bc(d,f);Eb(a+1298268|0,d);vb(d);f=0;QS(a+1298292|0,zb(e),108,36,0);d=a+484360|0;OE(Sb(d),g+185|0,128);if(x[sc(Sb(d),w[g+184|0])>>1]<w[g+183|0]){break d}break c}a=P()|0;O()|0;vb(g+24|0);S(a|0);L()}cf(Sb(d),w[g+184|0])}while(1){d=(f<<5)+a|0;We(d+480280|0);u[d+480284>>1]=f&1?208:48;f=f+1|0;if((f|0)!=8){continue}break}h=a+484344|0;Ag(h,w[g+183|0]);n=1;if(w[g+183|0]){o=c&1;e=0;while(1){f:{g:{if(o){if(wh(h,e&65535,64)){break g}}Rb(b,1536);break f}v[g+24>>2]=-1;v[g+28>>2]=-1;j=0;while(1){f=Tf(_b(h,e),j);k=0;while(1){i=g+40|0;Vr(i,b);d=qd(i);m=Ve(i);l=w[d|0];d=w[i|0];if(d>>>0<=253){t[f|0]=(d>>>2|0)+37;t[f+1|0]=(d<<4&48|l>>>4)+1;t[(g+24|0)+k|0]=255;d=w[i|0]}if((d&255)!=255){t[f+2|0]=1;t[f+4|0]=(((l&15)<<6|8)>>>0)/15}l=(g+24|0)+k|0;h:{i:{i=w[m|0];j:{if((i|0)!=255){t[l|0]=i;d=i&15;if(d|(i|0)==48){break j}break i}i=w[l|0];if((i|0)==255){break h}d=i&15}t[f+5|0]=d;k:{if(i<<24>>24<0){break k}m=i>>>4|0;t[f+3|0]=w[m+28392|0];l:{switch(m-3|0){case 0:t[f+5|0]=d|32;break i;case 1:t[f+5|0]=B(d,17);break h;case 2:break i;case 3:break l;default:break h}}m:{switch(i&15){case 0:t[f+5|0]=79;break h;case 1:break m;default:break k}}t[f+5|0]=244;break h}t[f+3|0]=0;break h}t[l|0]=255}f=f+6|0;k=k+1|0;if((k|0)!=8){continue}break}j=j+1|0;if((j|0)!=64){continue}break}d=(g+72|0)+e|0;f=d;if(w[d+369|0]<63){Jm(_b(h,e),Fh(Ue(Be(g+40|0,14,0),w[f+369|0])))}Jm(_b(h,e),Fh(Be(g+40|0,16,w[d+241|0])))}e=e+1|0;if(e>>>0<w[g+183|0]){continue}break}}if(!(c&2)){break a}f=1;c=Rc(g+40|0,8,1,0,1);if(!x[a+480190>>1]){break b}while(1){Dg(c,(B(f&65535,104)+a|0)+484380|0,b);f=f+1|0;if(x[a+480190>>1]>=(f&65535)>>>0){continue}break}}n=1}gb=g+576|0;return n|0}function hk(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,k=0,m=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0;c=1;o(+b);e=j(1)|0;f=j(0)|0;a:{b:{h=e;v=e;k=e&2147483647;i=f;c:{if(!(k|f)){break c}o(+a);m=j(1)|0;f=j(0)|0;e=m;x=e;s=f;if(f?0:(e|0)==1072693248){break c}m=x&2147483647;if(!(!(m>>>0>2146435072|(m|0)==2146435072&(s|0)!=0|k>>>0>2146435072)&(!i|(k|0)!=2146435072))){return a+b}d:{e:{f:{g:{if((e|0)>0|(e|0)>=0){break g}t=2;if(k>>>0>1128267775){break f}if(k>>>0<1072693248){break g}f=k>>>20|0;if(k>>>0>=1094713344){d=1075-f|0;f=i>>>d|0;t=0;if((i|0)!=f<<d){break f}t=2-(f&1)|0;break f}if(i){break d}f=1043-f|0;i=k>>>f|0;if((k|0)!=i<<f){break e}d=2-(i&1)|0;break e}t=0}d=t;if(i){break d}}if((k|0)==2146435072){if(!(m-1072693248|s)){break c}if(m>>>0>=1072693248){return(h|0)>0|(h|0)>=0?b:0}return(h|0)>0|(h|0)>=0?0:-b}if((k|0)==1072693248){if((h|0)>0|(h|0)>=0){return a}return 1/a}if((v|0)==1073741824){return a*a}if((v|0)!=1071644672|(e|0)<0){break d}return K(a)}c=D(a);if(!((m?(x&1073741823)!=1072693248:0)|s)){c=(h|0)<0?1/c:c;if((e|0)>0|(e|0)>=0){break c}if(!(m-1072693248|d)){a=c-c;return a/a}return(d|0)==1?-c:c}q=1;h:{if((e|0)>0|(e|0)>=0){break h}i:{switch(d|0){case 0:a=a-a;return a/a;case 1:break i;default:break h}}q=-1}j:{if(k>>>0>=1105199105){if(k>>>0>=1139802113){if(m>>>0<=1072693247){return(h|0)<0?N:0}return(v|0)>0?N:0}if(m>>>0<=1072693246){return(h|0)<0?q*1e300*1e300:q*1e-300*1e-300}if(m>>>0>=1072693249){return(v|0)>0?q*1e300*1e300:q*1e-300*1e-300}a=c+-1;c=a*1.9259629911266175e-8+a*a*(.5-a*(a*-.25+.3333333333333333))*-1.4426950408889634;g=c;c=a*1.4426950216293335;o(+(g+c));d=j(1)|0;j(0)|0;l(0,0);l(1,d|0);a=+n();g=g-(a-c);break j}a=c*9007199254740992;e=m>>>0<1048576;c=e?a:c;o(+a);d=j(1)|0;j(0)|0;i=e?d:m;f=i&1048575;d=f|1072693248;i=(i>>20)+(e?-1076:-1023)|0;e=0;k:{if(f>>>0<235663){break k}if(f>>>0<767610){e=1;break k}d=f|1071644672;i=i+1|0}s=e<<3;y=A[s+90112>>3];a=A[s+90096>>3];o(+c);j(1)|0;f=0;l(0,j(0)|f);l(1,d|0);p=+n();c=1/(a+p);r=c;g=p-a;w=g;l(0,f|0);l(1,((e<<18)+(d>>>1|0)|0)+537395200|0);u=+n();g=g*c;o(+g);d=j(1)|0;j(0)|0;l(0,0);l(1,d|0);c=+n();a=r*(w-u*c-(p-(u-a))*c);r=a;p=c*c;w=a*(g+c);a=g*g;u=w+a*a*(a*(a*(a*(a*(a*.20697501780033842+.23066074577556175)+.272728123808534)+.33333332981837743)+.4285714285785502)+.5999999999999946);o(+(p+3+u));d=j(1)|0;j(0)|0;l(0,0);l(1,d|0);a=+n();g=r*a+g*(u-(a+-3-p));c=c*a;o(+(g+c));d=j(1)|0;j(0)|0;l(0,0);l(1,d|0);a=+n();c=y+((g-(a-c))*.9617966939259756+a*-7.028461650952758e-9);r=c;g=A[s+90128>>3];c=a*.9617967009544373;p=+(i|0);o(+(g+(r+c)+p));d=j(1)|0;j(0)|0;l(0,0);l(1,d|0);a=+n();g=r-(a-p-g-c)}l(0,0);l(1,h|0);p=+n();c=a*p;a=g*b+(b-p)*a;b=c+a;o(+b);h=j(1)|0;d=j(0)|0;f=h;e=d;l:{if((f|0)>=1083179008){if(e|h-1083179008){break b}if(!(a+8.008566259537294e-17>b-c)){break l}break b}if((h&2147482624)>>>0<1083231232){break l}if(e|h+1064252416){break a}if(!(a<=b-c)){break l}break a}e=0;i=h&2147483647;if(i>>>0>=1071644673){d=h+(1048576>>>(i>>>20|0)-1022|0)|0;h=d>>>20&2047;e=(d&1048575|1048576)>>>1043-h|0;e=(f|0)<0?0-e|0:e;l(0,0);l(1,d&-1048576>>h-1023);c=c-+n();o(+(a+c));f=j(1)|0;j(0)|0}l(0,0);l(1,f|0);b=+n();g=b*.6931471824645996;c=(a-(b-c))*.6931471805599453+b*-1.904654299957768e-9;a=g+c;b=a*a;b=a-b*(b*(b*(b*(b*4.1381367970572385e-8+-16533902205465252e-22)+6613756321437934e-20)+-.0027777777777015593)+.16666666666666602);r=a*b/(b+-2);b=c-(a-g);a=a-(r-(b+a*b))+1;o(+a);d=j(1)|0;f=j(0)|0;d=(e<<20)+d|0;m:{if((d|0)<=1048575){a=ii(a,e);break m}l(0,f|0);l(1,d|0);a=+n()}c=q*a}return c}return q*1e300*1e300}return q*1e-300*1e-300}function qL(a,b,c,d){a=a|0;b=b|0;c=+c;d=d|0;var e=0,f=0,g=0,h=0;e=gb-256|0;gb=e;A[e+248>>3]=c;a:{if(rk(b)){break a}f=w[vl(b)|0];if((f|0)==33){d=1}else{if((f|0)!=63){break a}d=0}Kl(e+216|0,b,v[b+4>>2]-1|0);f=v[e+220>>2];v[b>>2]=v[e+216>>2];v[b+4>>2]=f}f=e+216|0;Ld(f);g=v[e+216>>2];Ld(e+200|0);h=ul(g,v[e+204>>2],b);Ld(f);f=v[b>>2];g=v[b+4>>2];b:{c:{d:{e:{f:{g:{h:{i:{if((h|0)==v[e+220>>2]){v[e+240>>2]=f;v[e+244>>2]=g;a=uc(e+232|0,18726);f=v[e+244>>2];v[e+16>>2]=v[e+240>>2];v[e+20>>2]=f;f=v[a+4>>2];v[e+8>>2]=v[a>>2];v[e+12>>2]=f;if(Gc(e+16|0,e+8|0)){a=ba(8)|0;v[22656]=0;R(2060,e+200|0,e+248|0);b=v[22656];v[22656]=0;if((b|0)!=1){v[22656]=0;U(2037,e+216|0,14728,e+200|0);b=v[22656];v[22656]=0;if((b|0)==1){break g}rc(a,e+216|0);v[22656]=0;U(186,a|0,54952,1936);a=v[22656];v[22656]=0;if((a|0)!=1){break b}b=P()|0;O()|0;vb(e+216|0);vb(e+200|0);break c}b=P()|0;O()|0;break d}if(!d){break i}a=ba(8)|0;v[22656]=0;f=Q(2057,e+168|0,b|0)|0;b=v[22656];v[22656]=0;j:{k:{l:{m:{n:{o:{p:{q:{if((b|0)!=1){v[22656]=0;U(2037,e+184|0,14764,f|0);b=v[22656];v[22656]=0;if((b|0)==1){break q}v[22656]=0;R(2054,e+200|0,e+184|0);b=v[22656];v[22656]=0;d=1;if((b|0)==1){break p}v[22656]=0;R(2060,e+152|0,e+248|0);b=v[22656];v[22656]=0;if((b|0)==1){break o}v[22656]=0;U(2058,e+216|0,e+200|0,e+152|0);b=v[22656];v[22656]=0;if((b|0)==1){break n}rc(a,e+216|0);v[22656]=0;U(186,a|0,54952,1936);b=v[22656];v[22656]=0;if((b|0)!=1){break b}b=P()|0;O()|0;vb(e+216|0);d=0;break m}b=P()|0;O()|0;break j}b=P()|0;O()|0;vb(f);break j}b=P()|0;O()|0;break k}b=P()|0;O()|0;break l}b=P()|0;O()|0}vb(e+152|0)}vb(e+200|0)}vb(e+184|0);vb(f);if(!d){break c}}ca(a|0);break c}v[e+144>>2]=f;v[e+148>>2]=g;d=uc(e+136|0,18726);f=v[e+148>>2];v[e+80>>2]=v[e+144>>2];v[e+84>>2]=f;f=v[d+4>>2];v[e+72>>2]=v[d>>2];v[e+76>>2]=f;if(Gc(e+80|0,e+72|0)){a=ba(8)|0;v[22656]=0;R(2060,e+200|0,e+248|0);b=v[22656];v[22656]=0;if((b|0)!=1){v[22656]=0;U(2037,e+216|0,14728,e+200|0);b=v[22656];v[22656]=0;if((b|0)==1){break f}rc(a,e+216|0);v[22656]=0;U(186,a|0,54952,1936);a=v[22656];v[22656]=0;if((a|0)!=1){break b}b=P()|0;O()|0;vb(e+216|0);vb(e+200|0);break c}b=P()|0;O()|0;break e}d=v[b+4>>2];v[e+128>>2]=v[b>>2];v[e+132>>2]=d;d=uc(e+120|0,4823);f=v[e+132>>2];v[e+64>>2]=v[e+128>>2];v[e+68>>2]=f;f=v[d+4>>2];v[e+56>>2]=v[d>>2];v[e+60>>2]=f;if(Gc(e- -64|0,e+56|0)){if(!w[a+28|0]){break i}if(c<=0|c>4){a=ba(8)|0;v[22656]=0;d=Q(70,e+216|0,4918)|0;b=v[22656];v[22656]=0;if((b|0)==1){break h}rc(a,d);v[22656]=0;U(186,a|0,54952,1936);a=v[22656];v[22656]=0;if((a|0)!=1){break b}b=P()|0;O()|0;vb(d);break c}b=Ah(65536/c);a=a+24|0;v[v[a>>2]+480244>>2]=b;yq(v[a>>2]);break i}d=v[b+4>>2];v[e+112>>2]=v[b>>2];v[e+116>>2]=d;d=uc(e+104|0,4875);f=v[e+116>>2];v[e+48>>2]=v[e+112>>2];v[e+52>>2]=f;f=v[d+4>>2];v[e+40>>2]=v[d>>2];v[e+44>>2]=f;if(Gc(e+48|0,e+40|0)){if(!w[a+28|0]){break i}if(c<=0|c>4){a=ba(8)|0;v[22656]=0;d=Q(70,e+216|0,4939)|0;b=v[22656];v[22656]=0;if((b|0)!=1){rc(a,d);v[22656]=0;U(186,a|0,54952,1936);a=v[22656];v[22656]=0;if((a|0)!=1){break b}b=P()|0;O()|0;vb(d);break c}b=P()|0;O()|0;ca(a|0);break c}b=Ah(c*65536);a=a+24|0;v[v[a>>2]+480240>>2]=b;yq(v[a>>2]);break i}d=v[b+4>>2];v[e+96>>2]=v[b>>2];v[e+100>>2]=d;b=uc(e+88|0,4893);d=v[e+100>>2];v[e+32>>2]=v[e+96>>2];v[e+36>>2]=d;d=v[b+4>>2];v[e+24>>2]=v[b>>2];v[e+28>>2]=d;if(!Gc(e+32|0,e+24|0)){break i}b=Ro(c*65536);v[v[a+24>>2]+480236>>2]=b}gb=e+256|0;return}b=P()|0;O()|0;ca(a|0);break c}b=P()|0;O()|0;vb(e+200|0);break d}b=P()|0;O()|0;vb(e+200|0)}ca(a|0);break c}ca(a|0)}S(b|0)}L()}function _ma(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,u=0,x=0,z=0,A=0,B=0,C=0;e=gb-48|0;gb=e;a:{b:{c:{d:{if(!c){break d}B=e,C=Ae(a),t[B+32|0]=C;k=e+32|0;d=b;e:{if(y[d+4>>2]<y[wb(d)>>2]){h=gb-16|0;gb=h;f=Ai(h,d,1);wb(d);Bd(v[f+4>>2],k);v[f+4>>2]=v[f+4>>2]+1;$b(f);gb=h+16|0;break e}f=gb-32|0;gb=f;h=wb(d);h=Zg(f+8|0,qh(d,oc(d)+1|0),oc(d),h);Bd(v[h+8>>2],k);v[h+8>>2]=v[h+8>>2]+1;v[22656]=0;R(296,d|0,h|0);d=v[22656];v[22656]=0;f:{if((d|0)!=1){be(h);gb=f+32|0;break f}a=P()|0;O()|0;be(h);S(a|0);L()}}h=c-1|0;if(!h){break c}while(1){g:{h:{c=i<<1;i=c&254;i:{if(!i){if(!lf(a,e+32|0)){break d}c=w[e+32|0]<<1|1;i=c&255;if(c>>>0<256){break i}break h}if((c&65535)>>>0>255){break h}}if(!lf(a,e+32|0)){break d}g=e+32|0;c=b;j:{if(v[c+4>>2]!=v[wb(c)>>2]){oM(c,g);break j}k=gb-32|0;gb=k;f=wb(c);j=Zg(k+8|0,qh(c,oc(c)+1|0),oc(c),f);d=v[j+8>>2];v[22656]=0;rl(f,d,g);d=v[22656];v[22656]=0;k:{if((d|0)==1){break a}v[j+8>>2]=v[j+8>>2]+1;v[22656]=0;R(296,c|0,j|0);c=v[22656];v[22656]=0;if((c|0)==1){break a}be(j);gb=k+32|0;break k}}h=h-1|0;break g}d=1;while(1){l:{m:{n:{c=i<<1&254;o:{if(c){g=i>>>0>127}else{if(!lf(a,e+32|0)){break o}f=w[e+32|0]<<1|1;c=f&255;g=f>>>0>255}d=g|d<<1;i=c<<1&254;if(i){break m}if(lf(a,e+32|0)){break n}}i=0;break l}c=w[e+32|0]<<1|1;i=c&255;if(c>>>0>255){continue}break l}if(c>>>0>127){continue}}break}p:{if((d|0)<=2){f=0;g=d-2|0;break p}c=lf(a,e+32|0);if(!c){break d}c=c?(w[e+32|0]|d<<8)-768|0:s;f=((c|0)>1279?2:1)+((c|0)>31999)|0;s=c^-1;g=0}c=i<<1&254;if(c){d=i>>>0>127}else{if(!lf(a,e+32|0)){break d}d=w[e+32|0]<<1|1;c=d&255;d=d>>>0>255}k=h;i=c<<1&254;if(i){c=c>>>0>127}else{if(!lf(a,e+32|0)){break d}c=w[e+32|0]<<1|1;i=c&255;c=c>>>0>255}c=c|(g<<2|(d?2:0));if(!c){d=1;while(1){q:{r:{s:{c=i<<1&254;t:{if(c){g=i>>>0>127}else{if(!lf(a,e+32|0)){break t}g=w[e+32|0]<<1|1;c=g&255;g=g>>>0>255}d=g|d<<1;i=c<<1&254;if(i){break r}if(lf(a,e+32|0)){break s}}i=0;break q}c=w[e+32|0]<<1|1;i=c&255;if(c>>>0>255){continue}break q}if(c>>>0>127){continue}}break}c=d+2|0}g=k;k=c+f|0;d=0;if(g>>>0<k>>>0|(k|0)<=0|(s|0)>=0){break b}d=0;if((0-oc(b)|0)>(s|0)){break b}B=e,C=Zb(b),v[B+32>>2]=C;Fd(e+40|0,e+32|0);t[e+24|0]=0;A=e+24|0;q=A;m=gb-32|0;gb=m;v[m+24>>2]=v[e+40>>2];c=b;d=v[c>>2];B=m,C=Vb(c),v[B>>2]=C;d=ck(m+24|0,m)+d|0;u:{g=k;f=v[wb(c)>>2];l=v[c+4>>2];v:{if(g>>>0<=f-l>>>0){f=g;j=l-d|0;if(f>>>0>j>>>0){En(c,g-j|0,q);f=j;if(!f){break v}}x=gb-16|0;gb=x;n=c;r=l;j=d;p=v[c+4>>2];o=(p-(d+g|0)|0)+d|0;z=Ai(x,c,l-o|0);if(l>>>0>o>>>0){u=v[z+4>>2];l=o;while(1){wb(n);Bd(u,l);u=u+1|0;v[z+4>>2]=u;l=l+1|0;if(r>>>0>l>>>0){continue}break}}$b(z);zr(j,o,p);gb=x+16|0;ni(d,f,q+(d>>>0<=q>>>0?q>>>0<y[c+4>>2]?g:0:0)|0);break v}f=wb(c);j=Zg(m,qh(c,oc(c)+g|0),d-v[c>>2]|0,f);v[22656]=0;U(638,j|0,g|0,q|0);f=v[22656];v[22656]=0;if((f|0)==1){break a}n=c;vt(c);r=j;f=v[j+4>>2];g=d;o=j+4|0;Dk(wb(c),v[c>>2],d,o);wb(c);l=j+8|0;p=l;d=v[c+4>>2];if((g|0)!=(d|0)){c=v[p>>2];while(1){Bd(c,g);c=v[p>>2]+1|0;v[p>>2]=c;g=g+1|0;if((d|0)!=(g|0)){continue}break}}xc(n,o);xc(n+4|0,l);xc(wb(n),dc(r));v[r>>2]=v[r+4>>2];ut(n,oc(n));d=f;be(j)}Hg(d);gb=m+32|0;break u}B=e,C=Zb(b),v[B+16>>2]=C;B=e,C=MV(e+16|0,k),v[B+24>>2]=C;B=e,C=we(A,s),v[B+32>>2]=C;B=e,C=Zb(b),v[B+16>>2]=C;B=e,C=MV(e+16|0,k),v[B+24>>2]=C;c=k;while(1){B=e,C=LV(e+32|0),v[B+16>>2]=C;d=w[v[e+16>>2]];B=e,C=LV(e+24|0),v[B+8>>2]=C;t[v[e+8>>2]]=d;d=c>>>0>1;c=c-1|0;if(d){continue}break}h=h-k|0}if(h){continue}break}break c}d=0;break b}d=1}gb=e+48|0;return d|0}a=P()|0;O()|0;be(j);S(a|0);L()}function S7(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=gb-352|0;gb=d;a:{if(rk(b)){break a}e=w[vl(b)|0];if((e|0)==33){c=1}else{if((e|0)!=63){break a}c=0}Kl(d+320|0,b,v[b+4>>2]-1|0);e=v[d+324>>2];v[b>>2]=v[d+320>>2];v[b+4>>2]=e}f=d+320|0;Ld(f);e=v[d+320>>2];Ld(d+304|0);e=ul(e,v[d+308>>2],b);Ld(f);b:{c:{d:{e:{f:{g:{if((e|0)==v[d+324>>2]){a=v[b+4>>2];v[d+344>>2]=v[b>>2];v[d+348>>2]=a;a=uc(d+336|0,18726);e=v[d+348>>2];v[d+8>>2]=v[d+344>>2];v[d+12>>2]=e;e=v[a+4>>2];v[d>>2]=v[a>>2];v[d+4>>2]=e;if(Gc(d+8|0,d)){a=ba(8)|0;v[22656]=0;c=Q(70,d+320|0,7752)|0;b=v[22656];v[22656]=0;if((b|0)==1){break f}rc(a,c);v[22656]=0;U(186,a|0,54952,1936);a=v[22656];v[22656]=0;if((a|0)!=1){break b}b=P()|0;O()|0;vb(c);break c}e=0;if(!c){break g}a=ba(8)|0;v[22656]=0;c=Q(2057,d+304|0,b|0)|0;b=v[22656];v[22656]=0;if((b|0)!=1){v[22656]=0;U(2037,d+320|0,14764,c|0);b=v[22656];v[22656]=0;if((b|0)==1){break e}rc(a,d+320|0);v[22656]=0;U(186,a|0,54952,1936);a=v[22656];v[22656]=0;if((a|0)!=1){break b}b=P()|0;O()|0;vb(d+320|0);vb(c);break c}b=P()|0;O()|0;break d}if(v[e+4>>2]){a=ba(8)|0;v[22656]=0;c=Q(70,d+320|0,8874)|0;b=v[22656];v[22656]=0;if((b|0)!=1){rc(a,c);v[22656]=0;U(186,a|0,54952,1936);a=v[22656];v[22656]=0;if((a|0)!=1){break b}b=P()|0;O()|0;vb(c);break c}b=P()|0;O()|0;ca(a|0);break c}c=v[b+4>>2];v[d+296>>2]=v[b>>2];v[d+300>>2]=c;c=uc(d+288|0,18726);e=v[d+300>>2];v[d+152>>2]=v[d+296>>2];v[d+156>>2]=e;e=v[c+4>>2];v[d+144>>2]=v[c>>2];v[d+148>>2]=e;if(Gc(d+152|0,d+144|0)){a=ba(8)|0;v[22656]=0;c=Q(70,d+320|0,7752)|0;b=v[22656];v[22656]=0;if((b|0)!=1){rc(a,c);v[22656]=0;U(186,a|0,54952,1936);a=v[22656];v[22656]=0;if((a|0)!=1){break b}b=P()|0;O()|0;vb(c);break c}b=P()|0;O()|0;ca(a|0);break c}c=v[b+4>>2];v[d+280>>2]=v[b>>2];v[d+284>>2]=c;c=uc(d+272|0,4506);e=v[d+284>>2];v[d+136>>2]=v[d+280>>2];v[d+140>>2]=e;e=v[c+4>>2];v[d+128>>2]=v[c>>2];v[d+132>>2]=e;h:{if(!Gc(d+136|0,d+128|0)){c=v[b+4>>2];v[d+264>>2]=v[b>>2];v[d+268>>2]=c;c=uc(d+256|0,4488);e=v[d+268>>2];v[d+120>>2]=v[d+264>>2];v[d+124>>2]=e;e=v[c+4>>2];v[d+112>>2]=v[c>>2];v[d+116>>2]=e;if(!Gc(d+120|0,d+112|0)){break h}}e=w[a+60|0]!=0;break g}c=v[b+4>>2];v[d+248>>2]=v[b>>2];v[d+252>>2]=c;c=uc(d+240|0,3991);e=v[d+252>>2];v[d+104>>2]=v[d+248>>2];v[d+108>>2]=e;e=v[c+4>>2];v[d+96>>2]=v[c>>2];v[d+100>>2]=e;i:{if(!Gc(d+104|0,d+96|0)){c=v[b+4>>2];v[d+232>>2]=v[b>>2];v[d+236>>2]=c;c=uc(d+224|0,3972);e=v[d+236>>2];v[d+88>>2]=v[d+232>>2];v[d+92>>2]=e;e=v[c+4>>2];v[d+80>>2]=v[c>>2];v[d+84>>2]=e;if(!Gc(d+88|0,d+80|0)){break i}}e=w[a+61|0]!=0;break g}c=v[b+4>>2];v[d+216>>2]=v[b>>2];v[d+220>>2]=c;c=uc(d+208|0,4075);e=v[d+220>>2];v[d+72>>2]=v[d+216>>2];v[d+76>>2]=e;e=v[c+4>>2];v[d+64>>2]=v[c>>2];v[d+68>>2]=e;if(Gc(d+72|0,d- -64|0)){e=w[a+62|0]!=0;break g}c=v[b+4>>2];v[d+200>>2]=v[b>>2];v[d+204>>2]=c;c=uc(d+192|0,3156);e=v[d+204>>2];v[d+56>>2]=v[d+200>>2];v[d+60>>2]=e;e=v[c+4>>2];v[d+48>>2]=v[c>>2];v[d+52>>2]=e;if(Gc(d+56|0,d+48|0)){e=w[a+63|0]!=0;break g}c=v[b+4>>2];v[d+184>>2]=v[b>>2];v[d+188>>2]=c;c=uc(d+176|0,4555);e=v[d+188>>2];v[d+40>>2]=v[d+184>>2];v[d+44>>2]=e;e=v[c+4>>2];v[d+32>>2]=v[c>>2];v[d+36>>2]=e;if(Gc(d+40|0,d+32|0)){e=w[a+64|0]!=0;break g}c=v[b+4>>2];v[d+168>>2]=v[b>>2];v[d+172>>2]=c;b=uc(d+160|0,10720);c=v[d+172>>2];v[d+24>>2]=v[d+168>>2];v[d+28>>2]=c;c=v[b+4>>2];v[d+16>>2]=v[b>>2];v[d+20>>2]=c;e=0;if(!Gc(d+24|0,d+16|0)){break g}e=v[v[a+24>>2]+24668>>2]!=0}gb=d+352|0;return e|0}b=P()|0;O()|0;ca(a|0);break c}b=P()|0;O()|0;vb(c)}ca(a|0)}S(b|0)}L()}function vP(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;h=gb-16|0;gb=h;f=a+1074376|0;g=B(b,872);d=(f+g|0)+616|0;e=c&15;a:{b:{switch((c&240)-16>>>4|0){case 0:a=(a+g|0)+1075080|0;v[a>>2]=v[a>>2]&-1048577|((e|0)!=0)<<20;break a;case 1:if(!(w[a+480209|0]&16)){break a}if(Mj(d)){a=B(b,872)+a|0;u[a+1075764>>1]=e-8;a=a+1075843|0;t[a|0]=w[a|0]|32;break a}if(v[a+480180>>2]!=64){b=B(b,872)+a|0;u[b+1075764>>1]=e<<28>>24;c=x[(e<<1)+39728>>1];v[b+1075696>>2]=c;d=b+1075692|0;if(!v[d>>2]){break a}k=d,l=_g(a,w[b+1075789|0],e<<28>>24,c),v[k>>2]=l;break a}a=B(b,872)+a|0;b=v[a+1075096>>2];if(!b){break a}v[a+1075696>>2]=v[b+24>>2]+B(e,80);break a;case 2:if(v[a+480180>>2]==2){t[(B(b,872)+a|0)+1075814|0]=c&3;break a}d=h+8|0;Db(d,a+1074312|0,21);if(Cb(d)){t[(B(b,872)+a|0)+1075814|0]=e>>>0<4?e:0;break a}t[(B(b,872)+a|0)+1075814|0]=c&7;break a;case 3:if(v[a+480180>>2]==2){t[(B(b,872)+a|0)+1075817|0]=c&3;break a}d=h+8|0;Db(d,a+1074312|0,21);if(Cb(d)){t[(B(b,872)+a|0)+1075817|0]=e>>>0<4?e:0;break a}t[(B(b,872)+a|0)+1075817|0]=c&7;break a;case 4:d=h+8|0;Db(d,a+1074312|0,21);if(Cb(d)){a=B(b,872)+a|0;t[a+1075813|0]=0;t[a+1075820|0]=e>>>0<4?e:0;break a}t[(B(b,872)+a|0)+1075820|0]=c&7;break a;case 5:if(v[a+1074392>>2]|!(w[a+480209|0]&16)){break a}a=a+1074400|0;v[a>>2]=v[a>>2]+e;break a;case 6:if(!(w[a+480209|0]&16)){break a}if(e>>>0<=2){e=x[a+480188>>1];if(e>>>0>255){break a}d=a+1298260|0;i=b+1|0;j=(c&15)-1|0;while(1){c=B(e,872)+a|0;c:{if((i|0)!=x[c+1075778>>1]){break c}d:{e:{switch(j|0){case 0:Do(a,c+1074992|0);if(!(w[c+1075081|0]&2)){break d}if(!Dd(d)){break d}vk(v[d>>2],e&65535);break d;case 1:g=c+1075080|0;f=v[g>>2];v[g>>2]=f|4096;if(!(f&512)){break d}if(!Dd(d)){break d}vk(v[d>>2],e&65535);break d;default:break e}}v[c+1075688>>2]=0;g=c+1075080|0;f=v[g>>2];v[g>>2]=f|4096;if(!(f&512)){break d}if(!Dd(d)){break d}Oi(v[d>>2],e&65535,1)}f=v[c+1075648>>2];if(!f){break c}g=w[f+34|0];if(!g){break c}g=v[(B(g,160)+a|0)+906140>>2];if(!g){break c}kb[v[v[g>>2]+92>>2]](g,f,w[c+1075789|0]+255|0,0,b)}e=e+1|0;if((e&65535)!=256){continue}break}break a}pB(d,e,a);break a;case 7:if(!(w[a+480209|0]&16)){break a}Pm(a,d,e,4);break a;case 8:b=v[a+480208>>2];f:{if(!(b&4096)){break f}g:{switch(e&15){case 0:v[d+88>>2]=v[d+88>>2]&-257;break f;case 1:v[d+692>>2]=128;v[d+88>>2]=v[d+88>>2]|256;break f;case 8:v[d+88>>2]=v[d+88>>2]&-25165825|16777216;break f;case 9:v[d+88>>2]=v[d+88>>2]&-25165825|8388608;break f;case 10:v[a+480208>>2]=b&-16385;break f;case 11:v[a+480208>>2]=b|16384;break f;case 12:v[a+480208>>2]=b&-8193;break f;case 13:v[a+480208>>2]=b|8192;break f;case 14:v[d+88>>2]=v[d+88>>2]&-129;break f;case 15:break g;default:break f}}h:{if(!v[d+76>>2]|(v[d>>2]|v[d+4>>2])){break h}if(!(k=Rd(d+788|0),l=1,m=w[d+88|0]&2,m?k:l)){break h}a=d;b=v[a+76>>2]-1|0;v[a>>2]=-1;v[a+4>>2]=b}v[d+88>>2]=v[d+88>>2]|128}break a;case 9:if(!(w[a+480209|0]&16)){break a}c=B(b,872)+a|0;t[c+1075828|0]=e;f=h+8|0;Db(f,a+1074312|0,35);if(Cb(f)){break a}if(!Rd(c+1075780|0)){break a}b=v[(B(b,872)+a|0)+1075068>>2];a=e<<16;if(b>>>0<=a>>>0){break a}v[d+4>>2]=a;break a;case 10:if(!(w[a+480209|0]&16)){break a}uu(a,f,d,e);break a;case 11:i:{if(e){break i}e=1;if(v[a+480180>>2]&16777248){break i}e=0;if(v[a+480180>>2]==2){break a}}d=h+8|0;Db(d,a+1074312|0,30);c=a;if(Cb(d)){a=1}else{a=v[a+480180>>2]==2}vA(c,b,e,a);break a;case 14:break b;default:break a}}if(v[a+480180>>2]==2){break a}t[(B(b,872)+a|0)+1075836|0]=e}gb=h+16|0}function moa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;e=gb-288|0;gb=e;d=e+128|0;f=d;g=gb-48|0;gb=g;h=g+24|0;TC(h,b);v[22656]=0;Or(g+16|0,h);b=v[22656];v[22656]=0;a:{b:{if((b|0)==1){break b}v[22656]=0;b=v[g+20>>2];v[g+8>>2]=v[g+16>>2];v[g+12>>2]=b;R(640,f|0,g+8|0);b=v[22656];v[22656]=0;if((b|0)==1){break b}zc(g+24|0);gb=g+48|0;break a}a=P()|0;O()|0;zc(g+24|0);S(a|0);L()}v[22656]=0;R(610,e+24|0,d|0);b=v[22656];v[22656]=0;c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{t:{u:{v:{w:{x:{y:{z:{A:{B:{C:{D:{if((b|0)!=1){v[22656]=0;g=W(100,e+144|0,e+24|0,8)|0;b=v[22656];v[22656]=0;if((b|0)==1){break D}vb(e+24|0);gc(e+128|0);if(c>>>0<2189){break i}v[22656]=0;b=Q(619,e+24|0,g|0)|0;c=v[22656];v[22656]=0;if((c|0)==1){break e}v[22656]=0;c=Q(620,e+8|0,7394)|0;d=v[22656];v[22656]=0;if((d|0)==1){break B}v[22656]=0;v[e>>2]=19923028;v[e+4>>2]=0;U(621,b|0,c|0,e|0);d=v[22656];v[22656]=0;if((d|0)==1){break A}Hb(c);t[e|0]=0;v[22656]=0;c=Q(620,e+8|0,8280)|0;d=v[22656];v[22656]=0;if((d|0)==1){break k}d=0;v[22656]=0;W(622,b|0,e|0,c|0)|0;f=v[22656];v[22656]=0;if((f|0)==1){break z}Hb(c);if(!w[e|0]){v[22656]=0;d=Kk(a);c=v[22656];v[22656]=0;if((c|0)==1){break y}}f=v[a+4>>2];v[22656]=0;c=Q(620,e+8|0,12908)|0;h=v[22656];v[22656]=0;if((h|0)==1){break x}v[22656]=0;Y(624,b|0,f|0,c|0,d|0);f=v[22656];v[22656]=0;if((f|0)==1){break w}Hb(c);v[22656]=0;c=Q(620,e+8|0,12589)|0;f=v[22656];v[22656]=0;if((f|0)==1){break v}v[22656]=0;Y(625,b|0,a|0,c|0,d|0);d=v[22656];v[22656]=0;if((d|0)==1){break u}Hb(c);v[22656]=0;c=Q(620,e+8|0,12488)|0;d=v[22656];v[22656]=0;if((d|0)==1){break t}v[22656]=0;d=a+484360|0;U(626,b|0,d|0,c|0);f=v[22656];v[22656]=0;if((f|0)==1){break s}Hb(c);v[22656]=0;c=Q(620,e+8|0,28870)|0;f=v[22656];v[22656]=0;if((f|0)==1){break r}v[22656]=0;U(627,b|0,a+484344|0,c|0);f=v[22656];v[22656]=0;if((f|0)==1){break q}Hb(c);v[22656]=0;f=Kk(a);c=v[22656];v[22656]=0;if((c|0)==1){break p}v[22656]=0;c=Q(620,e+8|0,28876)|0;h=v[22656];v[22656]=0;if((h|0)==1){break o}v[22656]=0;Y(628,b|0,d|0,c|0,f|0);d=v[22656];v[22656]=0;if((d|0)==1){break n}Hb(c);if(v[b>>2]&1073741824){v[22656]=0;c=Q(2,e+8|0,13382)|0;d=v[22656];v[22656]=0;if((d|0)==1){break m}v[22656]=0;U(560,a|0,1,c|0);a=v[22656];v[22656]=0;if((a|0)==1){break l}vb(c)}gh(b);break h}a=P()|0;O()|0;break C}a=P()|0;O()|0;vb(e+24|0)}gc(e+128|0);break c}a=P()|0;O()|0;break j}a=P()|0;O()|0;Hb(c);break j}a=P()|0;O()|0;Hb(c);break j}a=P()|0;O()|0;break j}a=P()|0;O()|0;break j}a=P()|0;O()|0;Hb(c);break j}a=P()|0;O()|0;break j}a=P()|0;O()|0;Hb(c);break j}a=P()|0;O()|0;break j}a=P()|0;O()|0;Hb(c);break j}a=P()|0;O()|0;break j}a=P()|0;O()|0;Hb(c);break j}a=P()|0;O()|0;break j}a=P()|0;O()|0;break j}a=P()|0;O()|0;Hb(c);break j}a=P()|0;O()|0;break j}a=P()|0;O()|0;vb(c);break j}a=P()|0;O()|0}gh(b);break d}b=Kb(e+24|0);d=v[a+4>>2];v[22656]=0;f=Kk(a);h=v[22656];v[22656]=0;if((h|0)==1){break g}v[22656]=0;d=da(629,d|0,g|0,b|0,f|0)|0;f=v[22656];v[22656]=0;if((f|0)==1){break g}E:{if((d|0)!=1){v[22656]=0;c=Q(2,e+8|0,13688)|0;d=v[22656];v[22656]=0;F:{if((d|0)!=1){v[22656]=0;U(560,a|0,1,c|0);a=v[22656];v[22656]=0;if((a|0)==1){break F}vb(c);break E}a=P()|0;O()|0;break f}a=P()|0;O()|0;vb(c);break f}v[22656]=0;d=Kk(a);f=v[22656];v[22656]=0;if((f|0)==1){break g}v[22656]=0;Y(630,g|0,a|0,d|0,c>>>0<2188|0);a=v[22656];v[22656]=0;if((a|0)==1){break g}}vb(b)}vf(g);gb=e+288|0;return}a=P()|0;O()|0}vb(b);break d}a=P()|0;O()|0}vf(g)}S(a|0);L()}function yg(a,b,c,d,e,f,g,h,i){var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;k=gb-112|0;gb=k;l=h;o=i&2147483647;n=c-!b|0;j=b-1|0;p=(j|0)==-1&(n|0)==-1;r=d;q=(c|0)==(n|0)&b>>>0>j>>>0|c>>>0>n>>>0;m=d+q|0;n=e&2147483647;j=n;j=m>>>0<q>>>0?j+1|0:j;q=m-1|0;a:{b:{j=j-!m|0;if(!((q|0)==-1&(j|0)==2147418111?p:j>>>0>2147418111)){j=f;m=g-!j|0;j=j-1|0;p=(j|0)!=-1|(m|0)!=-1;q=(g|0)==(m|0)&f>>>0>j>>>0|g>>>0>m>>>0;m=q+l|0;j=o;j=m>>>0<q>>>0?j+1|0:j;q=m;m=m-1|0;j=j-!q|0;if((m|0)==-1&(j|0)==2147418111?p:(j|0)==2147418111&(m|0)!=-1|j>>>0<2147418111){break b}}if(!(!r&(n|0)==2147418112?!(b|c):n>>>0<2147418112)){h=d;i=e|32768;f=b;g=c;break a}if(!(!l&(o|0)==2147418112?!(f|g):o>>>0<2147418112)){i=i|32768;break a}if(!(b|r|(n^2147418112|c))){j=d;d=!(b^f|d^h|(c^g|e^i^-2147483648));h=d?0:j;i=d?2147450880:e;f=d?0:b;g=d?0:c;break a}if(!(f|l|(o^2147418112|g))){break a}if(!(b|r|(c|n))){if(f|l|(g|o)){break a}f=b&f;g=c&g;h=d&h;i=e&i;break a}if(f|l|(g|o)){break b}f=b;g=c;h=d;i=e;break a}j=(n|0)==(o|0);p=j&(l|0)==(r|0)?(c|0)==(g|0)&b>>>0<f>>>0|c>>>0<g>>>0:j&l>>>0>r>>>0|n>>>0<o>>>0;j=p;m=j?f:b;o=j?g:c;l=j?i:e;r=l;n=j?h:d;j=l&65535;i=p?e:i;e=i;h=p?d:h;q=i>>>16&32767;l=l>>>16&32767;if(!l){d=!(j|n);i=d<<6;l=E(d?m:n)+32|0;d=E(d?o:j);d=i+((d|0)==32?l:d)|0;Kf(k+96|0,m,o,n,j,d-15|0);n=v[k+104>>2];m=v[k+96>>2];o=v[k+100>>2];l=16-d|0;j=v[k+108>>2]}f=p?b:f;g=p?c:g;i=e&65535;if(!q){b=!(h|i);c=b<<6;d=E(b?f:h)+32|0;b=E(b?g:i);b=c+((b|0)==32?d:b)|0;Kf(k+80|0,f,g,h,i,b-15|0);q=16-b|0;h=v[k+88>>2];i=v[k+92>>2];g=v[k+84>>2];f=v[k+80>>2]}b=h;c=i<<3|b>>>29;h=b<<3|g>>>29;i=c|524288;b=n;d=j<<3|b>>>29;n=b<<3|o>>>29;p=d;s=e^r;b=f;j=g<<3|b>>>29;b=b<<3;c=j;d=l-q|0;e=b;c:{if(!d){break c}if(d>>>0>127){h=0;i=0;j=0;e=1;break c}Kf(k- -64|0,b,c,h,i,128-d|0);pm(k+48|0,b,c,h,i,d);h=v[k+56>>2];i=v[k+60>>2];j=v[k+52>>2];e=v[k+48>>2]|((v[k+64>>2]|v[k+72>>2])!=0|(v[k+68>>2]|v[k+76>>2])!=0)}f=j;d=n;p=p|524288;b=m;j=o<<3|b>>>29;c=b<<3;d:{if((s|0)<0){o=e;b=c-e|0;n=h;m=d-h|0;e=(f|0)==(j|0)&c>>>0<e>>>0|f>>>0>j>>>0;h=m-e|0;c=j-((c>>>0<o>>>0)+f|0)|0;i=(p-((d>>>0<n>>>0)+i|0)|0)-(e>>>0>m>>>0)|0;if(!(b|h|(c|i))){f=0;g=0;h=0;i=0;break a}if(i>>>0>524287){break d}f=b;d=!(h|i);e=d<<6;g=E(d?b:h)+32|0;b=E(d?c:i);b=e+((b|0)==32?g:b)|0;b=b-12|0;Kf(k+32|0,f,c,h,i,b);l=l-b|0;h=v[k+40>>2];i=v[k+44>>2];b=v[k+32>>2];c=v[k+36>>2];break d}b=c;g=b+e|0;c=f+j|0;c=b>>>0>g>>>0?c+1|0:c;b=g;g=(c|0)==(f|0)&e>>>0>b>>>0|c>>>0<f>>>0;e=d;f=d+h|0;d=i+p|0;d=e>>>0>f>>>0?d+1|0:d;e=g+f|0;h=e;i=e>>>0<f>>>0?d+1|0:d;if(!(i&1048576)){break d}b=b&1|((c&1)<<31|b>>>1);e=h;c=e<<31|c>>>1;l=l+1|0;h=(i&1)<<31|e>>>1;i=i>>>1|0}o=0;r=r&-2147483648;if((l|0)>=32767){h=o;i=r|2147418112;f=0;g=0;break a}e=0;e:{if((l|0)>0){e=l;break e}Kf(k+16|0,b,c,h,i,l+127|0);pm(k,b,c,h,i,1-l|0);b=v[k>>2]|((v[k+16>>2]|v[k+24>>2])!=0|(v[k+20>>2]|v[k+28>>2])!=0);c=v[k+4>>2];h=v[k+8>>2];i=v[k+12>>2]}j=(c&7)<<29|b>>>3;l=b&7;b=j+(l>>>0>4)|0;d=h<<29|c>>>3;c=b>>>0<j>>>0?d+1|0:d;f=b;g=c;b=(d|0)==(c|0)&b>>>0<j>>>0|c>>>0<d>>>0;d=o|((i&7)<<29|h>>>3);b=b+d|0;j=r|(i>>>3&65535|e<<16);h=b;i=b>>>0<d>>>0?j+1|0:j;f:{if((l|0)==4){j=i;c=0;d=g+c|0;e=f&1;b=f+e|0;d=b>>>0<f>>>0?d+1|0:d;f=b;g=d;c=(c|0)==(d|0)&b>>>0<e>>>0|c>>>0>d>>>0;b=c+h|0;h=b;i=b>>>0<c>>>0?j+1|0:j;break f}if(!l){break a}}}v[a>>2]=f;v[a+4>>2]=g;v[a+8>>2]=h;v[a+12>>2]=i;gb=k+112|0}function aea(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;e=gb-176|0;gb=e;se(e+160|0,b);m=a;l=c;h=d;j=gb-48|0;gb=j;v[j+44>>2]=0;f=b;Ik(f,j+44|0);a:{b:{c:{if(v[j+44>>2]!=(An(11379)|0)){break c}v[j+40>>2]=0;g=gb-32|0;gb=g;v[g+28>>2]=0;bX(g+8|0,g+28|0);i=v[g+12>>2];v[g>>2]=v[g+8>>2];v[g+4>>2]=i;i=g+16|0;ot(i,f,g);yb(i);v[g+16>>2]=v[g+28>>2];v[j+40>>2]=w[i|0]|w[i+1|0]<<8|(w[i+2|0]<<16|w[i+3|0]<<24);gb=g+32|0;g=-1;i=v[j+40>>2];if(i-1>>>0>1){break c}d:{e:{f:{if(i>>>0<=1){i=Kb(j+24|0);v[22656]=0;k=W(653,f|0,i|0,256)|0;n=v[22656];v[22656]=0;if((n|0)==1){break b}if(!k){break e}v[22656]=0;U(13,j+8|0,h|0,i|0);k=v[22656];v[22656]=0;if((k|0)!=1){break f}break b}i=Kb(j+24|0);v[22656]=0;k=W(655,f|0,i|0,255)|0;n=v[22656];v[22656]=0;if((n|0)==1){break b}if(!k){break d}v[22656]=0;U(13,j+8|0,h|0,i|0);k=v[22656];v[22656]=0;if((k|0)==1){break b}}k=l;l=j+8|0;Eb(k,l);vb(l);vb(i);i=0;u[j+8>>1]=0;ag(f,l);v[j+24>>2]=0;Ik(f,j+24|0);l=v[j+24>>2];if(l>>>0>50){break c}if(l){while(1){if(!$M(m,f,h)){break c}i=i+1|0;if(i>>>0<y[j+24>>2]){continue}break}}v[j+24>>2]=0;Ik(f,j+24|0);g=v[j+24>>2]==(An(11417)|0)?1:-1;break c}vb(i);break c}vb(i)}gb=j+48|0;f=g;break a}a=P()|0;O()|0;vb(i);S(a|0);L()}g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{if(!f){oo(v[v[b>>2]-12>>2]+b|0,0);f=v[e+172>>2];v[e+8>>2]=v[e+168>>2];v[e+12>>2]=f;f=v[e+164>>2];v[e>>2]=v[e+160>>2];v[e+4>>2]=f;lk(b,e);b=Hm(e+56|0,b);v[22656]=0;f=Q(620,e+40|0,11505)|0;h=v[22656];v[22656]=0;if((h|0)==1){break h}v[22656]=0;v[e+32>>2]=3;v[e+36>>2]=0;U(621,b|0,f|0,e+32|0);h=v[22656];v[22656]=0;if((h|0)==1){break i}Hb(f);t[e+31|0]=0;v[22656]=0;f=Q(620,e+40|0,11945)|0;h=v[22656];v[22656]=0;if((h|0)==1){break j}v[22656]=0;W(622,b|0,e+31|0,f|0)|0;h=v[22656];v[22656]=0;if((h|0)==1){break k}Hb(f);v[22656]=0;f=w[e+31|0];h=T(1520,b|0)|0;g=v[22656];v[22656]=0;if((g|0)==1){break l}v[22656]=0;g=T(1521,b|0)|0;m=v[22656];v[22656]=0;if((m|0)==1){break m}v[e+32>>2]=g;v[e+24>>2]=h;if(Gb(e+24|0,e+32|0)){f=f?0:d;while(1){u[e+22>>1]=65535;v[22656]=0;d=Q(620,e+40|0,12908)|0;h=v[22656];v[22656]=0;if((h|0)==1){break p}v[22656]=0;h=W(1522,b|0,e+24|0,d|0)|0;g=v[22656];v[22656]=0;if((g|0)==1){break o}Hb(d);s:{if(!h){v[22656]=0;Y(1523,b|0,e+24|0,c|0,f|0);d=v[22656];v[22656]=0;if((d|0)==1){break n}break s}v[22656]=0;d=Q(620,e+40|0,12589)|0;h=v[22656];v[22656]=0;t:{u:{if((h|0)!=1){v[22656]=0;h=W(1522,b|0,e+24|0,d|0)|0;g=v[22656];v[22656]=0;if((g|0)==1){break u}Hb(d);if(h){break t}v[22656]=0;U(1524,b|0,e+24|0,e+22|0);d=v[22656];v[22656]=0;if((d|0)!=1){break s}break n}a=P()|0;O()|0;break g}a=P()|0;O()|0;Hb(d);break g}v[22656]=0;d=Q(620,e+40|0,12488)|0;h=v[22656];v[22656]=0;if((h|0)==1){break r}v[22656]=0;h=W(1522,b|0,e+24|0,d|0)|0;g=v[22656];v[22656]=0;if((g|0)==1){break q}Hb(d);if(h){break s}v[22656]=0;Y(1525,b|0,e+24|0,a|0,f|0);d=v[22656];v[22656]=0;if((d|0)==1){break n}}d=e+24|0;_o(d);if(Gb(d,e+32|0)){continue}break}}a=v[b>>2];gh(b);f=a&1073741824?-1:1}gb=e+176|0;return f|0}a=P()|0;O()|0;break g}a=P()|0;O()|0;Hb(d);break g}a=P()|0;O()|0;break g}a=P()|0;O()|0;Hb(d);break g}a=P()|0;O()|0;break g}a=P()|0;O()|0;break g}a=P()|0;O()|0;break g}a=P()|0;O()|0;Hb(f);break g}a=P()|0;O()|0;break g}a=P()|0;O()|0;Hb(f);break g}a=P()|0;O()|0}gh(b);S(a|0);L()}function x_(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;d=gb-160|0;gb=d;vc(b);ss(a);f=gb-32|0;gb=f;e=f+24|0;j=d+120|0;uF(e,j);h=yb(e);e=v[f+28>>2];g=v[f+24>>2];v[f+8>>2]=g;v[f+12>>2]=e;v[f>>2]=g;v[f+4>>2]=e;g=f+16|0;e=b;cc(g,e,f);g=yb(g);if((g|0)==(h|0)){Rb(e,yb(f+24|0))}gb=f+32|0;e=(g|0)==(h|0);if(!e){vF(j)}a:{if(!e){break a}if(!XN(d+120|0)){break a}h=b;g=0;k=Nf(10441);if(k){p=v[h+8>>2];if(Wc(h,w[d+136|0]|w[d+137|0]<<8|(w[d+138|0]<<16|w[d+139|0]<<24))){b:{if(!(w[d+132|0]|w[d+133|0]<<8|(w[d+134|0]<<16|w[d+135|0]<<24))){break b}while(1){if(!Pb(h,5)){break b}c:{if((w[d+124|0]|w[d+125|0]<<8)>>>0>=64){if((Ki(h)|0)<=0){break c}}g=0;f=1;while(1){e=Ae(h);if(e){q=Zq(e<<24>>24);m=g>>>0>=k>>>0;j=m&f;e=j;d:{if(m){break d}e=j;if(!(f&1)){break d}e=w[g+10441|0]==(q&255)}f=e;g=g+1|0;continue}break}Rb(h,4);i=(g|0)==(k|0)?f?1:i:i}n=n+1|0;if(n>>>0<(w[d+132|0]|w[d+133|0]<<8|(w[d+134|0]<<16|w[d+135|0]<<24))>>>0){continue}break}}g=i&1}Wc(h,p)}if(!g){break a}if(!Pb(b,WN(d+120|0))){break a}if(!c){l=1;break a}f=gb-16|0;gb=f;c=b;j=d+120|0;e=j;Wc(c,w[e+16|0]|w[e+17|0]<<8|(w[e+18|0]<<16|w[e+19|0]<<24));g=d+104|0;h=mc(g);i=w[e+12|0]|w[e+13|0]<<8|(w[e+14|0]<<16|w[e+15|0]<<24);v[22656]=0;R(1421,h|0,i|0);i=v[22656];v[22656]=0;e:{f:{g:{if((i|0)!=1){h:{i:{j:{if(!(w[e+12|0]|w[e+13|0]<<8|(w[e+14|0]<<16|w[e+15|0]<<24))){break j}while(1){v[22656]=0;i=Q(191,c|0,5)|0;k=v[22656];v[22656]=0;if((k|0)==1){break g}if(!i){break j}i=w[e+4|0]|w[e+5|0]<<8;v[22656]=0;U(1422,f|0,c|0,i|0);i=v[22656];v[22656]=0;if((i|0)==1){break i}v[22656]=0;R(1423,h|0,f|0);i=v[22656];v[22656]=0;if((i|0)==1){break h}vb(f);o=o+1|0;if(o>>>0<(w[e+12|0]|w[e+13|0]<<8|(w[e+14|0]<<16|w[e+15|0]<<24))>>>0){continue}break}}gb=f+16|0;break e}a=P()|0;O()|0;break f}a=P()|0;O()|0;vb(f);break f}a=P()|0;O()|0;break f}a=P()|0;O()|0}yd(h);S(a|0);L()}v[22656]=0;Y(273,d+88|0,b|0,j|0,g|0);c=v[22656];v[22656]=0;k:{l:{if((c|0)!=1){c=w[d+144|0]|w[d+145|0]<<8|(w[d+146|0]<<16|w[d+147|0]<<24);v[22656]=0;Q(190,b|0,c|0)|0;c=v[22656];v[22656]=0;m:{if((c|0)!=1){if(!(w[d+140|0]|w[d+141|0]<<8|(w[d+142|0]<<16|w[d+143|0]<<24))){break k}h=d+36|0;n:{o:{p:{q:{while(1){v[22656]=0;c=Q(191,b|0,8)|0;e=v[22656];v[22656]=0;r:{if((e|0)!=1){if(c){break r}break k}b=P()|0;O()|0;break m}v[22656]=0;ka(274,d- -64|0,b|0,d+120|0,d+88|0,d+104|0,10441);c=v[22656];v[22656]=0;if((c|0)!=1){v[22656]=0;c=d- -64|0;f=T(275,c|0)|0;e=v[22656];v[22656]=0;if((e|0)==1){break q}e=c;if(f){v[22656]=0;f=T(276,d+24|0)|0;j=v[22656];v[22656]=0;if((j|0)==1){break p}j=v[c+20>>2];s:{if((j|0)<0){break s}if(Ec(d+104|0)>>>0<=j>>>0){break s}c=Ad(d+104|0,v[c+20>>2]);v[22656]=0;U(13,d+8|0,2,c|0);c=v[22656];v[22656]=0;if((c|0)==1){break o}c=d+8|0;Eb(d+24|0,c);vb(c)}Hw(h,e);v[22656]=0;R(277,a|0,f|0);c=v[22656];v[22656]=0;if((c|0)==1){break o}Ow(f)}xb(d- -64|0);l=l+1|0;if(l>>>0<(w[d+140|0]|w[d+141|0]<<8|(w[d+142|0]<<16|w[d+143|0]<<24))>>>0){continue}break k}break}b=P()|0;O()|0;break m}b=P()|0;O()|0;break n}b=P()|0;O()|0;break n}b=P()|0;O()|0;Ow(f)}xb(d- -64|0);break m}b=P()|0;O()|0}Nc(d+88|0);break l}b=P()|0;O()|0}yd(d+104|0);S(b|0);L()}l=cd(a)^1;Nc(d+88|0);yd(d+104|0)}gb=d+160|0;return l|0}function $1(){var a=0,b=0,c=0;Xd(465768);v[116442]=81272;v[22656]=0;X(2499);a=v[22656];v[22656]=0;a:{b:{c:{d:{e:{if((a|0)!=1){v[22656]=0;Q(70,465920,11509)|0;a=v[22656];v[22656]=0;if((a|0)==1){break e}Od(465776);Xd(465456);v[116364]=82596;v[22656]=0;X(2500);a=v[22656];v[22656]=0;if((a|0)==1){break d}Xd(465464);v[116366]=82628;v[22656]=0;X(2501);a=v[22656];v[22656]=0;if((a|0)==1){break d}Xd(465472);v[116368]=81292;t[465484]=0;v[116370]=0;b=465480,c=Zp(),v[b>>2]=c;v[22656]=0;X(2502);a=v[22656];v[22656]=0;if((a|0)==1){break d}Xd(465488);v[116372]=81776;v[22656]=0;X(2503);a=v[22656];v[22656]=0;if((a|0)==1){break d}Xd(465496);v[116374]=81924;v[22656]=0;X(2504);a=v[22656];v[22656]=0;if((a|0)==1){break d}v[22656]=0;X(2505);a=v[22656];v[22656]=0;if((a|0)==1){break d}v[22656]=0;X(2506);a=v[22656];v[22656]=0;if((a|0)==1){break d}Xd(465520);v[116380]=82072;v[22656]=0;X(2507);a=v[22656];v[22656]=0;if((a|0)==1){break d}Xd(465528);v[116382]=82188;v[22656]=0;X(2508);a=v[22656];v[22656]=0;if((a|0)==1){break d}Xd(465536);u[232772]=11310;v[116384]=81392;Kb(465548);v[22656]=0;X(2509);a=v[22656];v[22656]=0;if((a|0)==1){break d}Xd(465560);v[116392]=46;v[116393]=44;v[116390]=81432;Kb(465576);v[22656]=0;X(2510);a=v[22656];v[22656]=0;if((a|0)==1){break d}Xd(465592);v[116398]=82660;v[22656]=0;X(2511);a=v[22656];v[22656]=0;if((a|0)==1){break d}Xd(465600);v[116400]=82904;v[22656]=0;X(2512);a=v[22656];v[22656]=0;if((a|0)==1){break d}Xd(465608);v[116402]=83116;v[22656]=0;X(2513);a=v[22656];v[22656]=0;if((a|0)==1){break d}Xd(465616);v[116404]=83348;v[22656]=0;X(2514);a=v[22656];v[22656]=0;if((a|0)==1){break d}Xd(465624);v[116406]=84332;v[22656]=0;X(2515);a=v[22656];v[22656]=0;if((a|0)==1){break d}Xd(465632);v[116408]=84480;v[22656]=0;X(2516);a=v[22656];v[22656]=0;if((a|0)==1){break d}Xd(465640);v[116410]=84596;v[22656]=0;X(2517);a=v[22656];v[22656]=0;if((a|0)==1){break d}Xd(465648);v[116412]=84712;v[22656]=0;X(2518);a=v[22656];v[22656]=0;if((a|0)==1){break d}Xd(465656);v[116414]=84828;v[22656]=0;X(2519);a=v[22656];v[22656]=0;if((a|0)==1){break d}Xd(465664);v[116416]=84992;v[22656]=0;X(2520);a=v[22656];v[22656]=0;if((a|0)==1){break d}Xd(465672);v[116418]=85156;v[22656]=0;X(2521);a=v[22656];v[22656]=0;if((a|0)==1){break d}Xd(465680);v[116420]=85320;v[22656]=0;X(2522);a=v[22656];v[22656]=0;if((a|0)==1){break d}Xd(465688);v[116424]=86576;v[116424]=83596;v[116422]=83548;v[22656]=0;X(2523);a=v[22656];v[22656]=0;if((a|0)==1){break d}Xd(465704);v[116428]=86612;v[116428]=83860;v[116426]=83812;v[22656]=0;X(2524);a=v[22656];v[22656]=0;if((a|0)==1){break d}v[22656]=0;X(2525);a=v[22656];v[22656]=0;if((a|0)==1){break d}v[22656]=0;X(2526);a=v[22656];v[22656]=0;if((a|0)==1){break d}v[22656]=0;X(2527);a=v[22656];v[22656]=0;if((a|0)==1){break d}v[22656]=0;X(2528);a=v[22656];v[22656]=0;if((a|0)==1){break d}Xd(465752);v[116438]=85484;v[22656]=0;X(2529);a=v[22656];v[22656]=0;if((a|0)==1){break d}Xd(465760);v[116440]=85604;v[22656]=0;X(2530);a=v[22656];v[22656]=0;if((a|0)==1){break d}break a}a=P()|0;O()|0;break b}a=P()|0;O()|0;break c}a=P()|0;O()|0;vb(465920)}wx(465776)}S(a|0);L()}v[116041]=465768}function eM(a){var b=C(0),c=C(0),d=0,e=0,f=0,g=C(0),h=0,i=C(0),j=C(0),k=C(0),l=0,m=0,n=C(0),o=C(0),p=0,q=0,r=C(0),s=C(0),u=C(0),w=0,x=0,y=C(0);m=gb-16|0;gb=m;w=a,x=Lj(C(z[a+4256>>2]*C(3))),v[w+4264>>2]=x;w=a,y=C(wf(v[a+16>>2])>>>((v[a+4264>>2]>>>1^-1)&1)>>>0),z[w+4268>>2]=y;z[a+4272>>2]=C(z[a+4244>>2]*C(100))*C(.0061803399585187435);w=m,y=oe(C(10),C(C(dM(a)+C(C(z[a+4228>>2]*C(11e3))+C(-1e4)))/C(2e3))),z[w+12>>2]=y;v[m+8>>2]=1065353216;w=a,y=C(z[Gm(m+12|0,m+8|0)>>2]*C(.7609999775886536)),z[w+4280>>2]=y;h=a;b=oe(C(10),C(C(C(C(z[a+4212>>2]*C(1e4))+C(-1e4))/C(100))/C(10)));if(b!=C(1)){c=Qp(C(C(cM(a)*C(6.2831854820251465))/z[a+4268>>2]));j=C(b*b);k=C(K(C(C(C(C(b*C(8))+C(c*C(C(c*j)*C(4))))-C(j*C(4)))-C(C(b*c)*C(8)))));b=C(b+b);k=Ho(C(C(k+C(C(c*b)+C(-2)))/C(b+C(-2))),C(0),C(1))}else{k=C(0)}z[h+4276>>2]=k;l=gb-16|0;gb=l;e=a;b=z[a+4268>>2];c=C(z[a+4232>>2]*C(.30000001192092896));z[l+12>>2]=z[a+4240>>2]*C(.10000000149011612);v[l+8>>2]=1000593162;h=a;j=z[dz(l+12|0,l+8|0)>>2];i=C(b*C(C(c+j)+C(.007000000216066837)));a:{if(C(D(i))<C(2147483648)){f=~~i;break a}f=-2147483648}v[h+4352>>2]=f;d=1;while(1){h=((B(d&1,24)+e|0)+(d<<1&-4)|0)+4352|0;i=C(b*C(c+C(j*z[(d<<2)+52752>>2])));b:{if(C(D(i))<C(2147483648)){f=~~i;break b}f=-2147483648}v[h>>2]=f;d=d+1|0;if((d|0)!=12){continue}break}z[l+12>>2]=C(C(C(z[e+4248>>2]*C(100))/C(100))+C(.10000000149011612))*C(.9090999960899353);v[l+8>>2]=1065353216;c=z[Gm(l+12|0,l+8|0)>>2];j=C(b*C(C(c*C(75))/C(1e3)));c=C(b*C(C(c*C(67))/C(1e3)));d=0;while(1){p=(d<<2)+e|0;h=p+4316|0;q=d+q|0;i=oe(C(.9300000071525574),C(q|0));g=C(j*i);c:{if(C(D(g))<C(2147483648)){f=~~g;break c}f=-2147483648}v[h>>2]=f;h=p+4292|0;i=C(c*i);d:{if(C(D(i))<C(2147483648)){f=~~i;break d}f=-2147483648}v[h>>2]=f;d=d+1|0;if((d|0)!=6){continue}break}h=e+4348|0;c=C(b*C(.0035299998708069324));e:{if(C(D(c))<C(2147483648)){f=~~c;break e}f=-2147483648}v[h>>2]=f;h=e+4344|0;c=C(b*C(.0032500000670552254));f:{if(C(D(c))<C(2147483648)){f=~~c;break f}f=-2147483648}v[h>>2]=f;h=e+4340|0;b=C(b*C(.009999999776482582));g:{if(C(D(b))<C(2147483648)){f=~~b;break g}f=-2147483648}v[h>>2]=f;d=0;while(1){fM((B(d,24)+e|0)+4504|0,v[((d<<2)+e|0)+4292>>2]);d=d+1|0;if((d|0)!=15){continue}break}gb=l+16|0;d=gb-16|0;gb=d;b=th(a,5);c=th(a,11);k=C(C(b*C(.02250000089406967))+C(0));b=C(b*th(a,4));j=C(k+C(b*C(.03999999910593033)));k=C(C(c*C(.02250000089406967))+C(0));c=C(c*th(a,10));i=C(k+C(c*C(.03999999910593033)));if(t[a+4264|0]&1){g=th(e,3);n=th(e,9);g=C(b*g);b=C(g*th(e,2));j=C(C(j+C(g*C(.12250000238418579)))+C(b*C(.1444000005722046)));g=C(c*n);c=C(g*th(e,8));i=C(C(i+C(g*C(.12250000238418579)))+C(c*C(.1444000005722046)))}th(e,12);g=z[e+4496>>2];n=th(e,1);o=th(e,7);s=th(e,0);u=th(e,6);w=d,y=oe(C(10),C(C(dM(e)+C(C(z[e+4236>>2]*C(12e3))+C(-1e4)))/C(2e3))),z[w+12>>2]=y;v[d+8>>2]=1065353216;r=z[Gm(d+12|0,d+8|0)>>2];k=b;b=C(g*g);g=C(n*C(k*b));n=C(s*g);b=C(o*C(c*b));c=C(u*b);o=C(C(C(n+c)*C(-.5))+C(1));z[e+4284>>2]=r*C(K(C(o/C(C(j+C(b*C(.1444000005722046)))+C(n*C(.1444000005722046))))));z[e+4288>>2]=r*C(K(C(o/C(C(i+C(g*C(.1444000005722046)))+C(c*C(.1444000005722046))))));gb=d+16|0;t[a+5046|0]=0;gb=m+16|0}function aO(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;a:{b:{if(b){f=a+327720|0;b=gb-400|0;gb=b;LR(b+384|0,8);v[22656]=0;ta(1108,b+368|0,9);g=v[22656];v[22656]=0;c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{if((g|0)!=1){v[22656]=0;g=Q(1109,b+352|0,14)|0;d=v[22656];v[22656]=0;if((d|0)==1){break n}v[22656]=0;R(1110,b+384|0,g|0);d=v[22656];v[22656]=0;if((d|0)==1){break m}v[22656]=0;R(1110,b+368|0,g|0);d=v[22656];v[22656]=0;if((d|0)==1){break m}KR(b+280|0,4900);KR(b+208|0,32e3);GR(b+136|0,8377175819504598e-21,16754351639009197e-21,8377175819504598e-21,-1.991112714669597,.9911462233728751);v[22656]=0;d=Q(1111,b+104|0,b+384|0)|0;e=v[22656];v[22656]=0;if((e|0)==1){break l}Fu(b+120|0,b+280|0,d);Mf(d);v[22656]=0;d=Q(1111,b+72|0,b+368|0)|0;e=v[22656];v[22656]=0;if((e|0)==1){break k}Fu(b+88|0,b+208|0,d);Mf(d);v[22656]=0;d=Q(1111,b+40|0,b+120|0)|0;e=v[22656];v[22656]=0;if((e|0)==1){break j}Fu(b+56|0,b+136|0,d);Mf(d);v[22656]=0;e=Q(1111,b+8|0,b+88|0)|0;d=v[22656];v[22656]=0;if((d|0)==1){break i}d=b+24|0;Fu(d,b+136|0,e);Mf(e);e=b+120|0;Pq(e);j=b+56|0;Pq(j);k=b+88|0;Pq(k);Pq(d);m=b+368|0;Pq(m);Oq(e,Jj(f,0));Oq(j,Jj(f,1));Oq(k,Jj(f,2));Oq(d,Jj(f,3));Oq(m,Jj(f,4));Mf(d);Mf(j);Mf(k);Mf(e);Nq(g);Mf(m);Mf(b+384|0);gb=b+400|0;break c}a=P()|0;O()|0;break d}a=P()|0;O()|0;break e}a=P()|0;O()|0;break f}a=P()|0;O()|0;break f}a=P()|0;O()|0;break g}a=P()|0;O()|0;break h}a=P()|0;O()|0;Mf(b+56|0)}Mf(b+88|0)}Mf(b+120|0)}Nq(g)}Mf(b+368|0)}Mf(b+384|0);S(a|0);L()}Mz(a+131112|0,9.6377,.97);Mz(a+196648|0,8.5,.5);Mz(a+262184|0,2.7625,.425);Lz(a+368680|0,a);break b}if(Lz(a+368680|0,a)){break a}}e=a+24|0;p=A[a+8>>3];f=w[a+16|0];d=gb+-64|0;gb=d;while(1){q=+(l-4096|0)*.0001220703125;n=0;b=0;while(1){i=p;g=f;h=1;c=+(b|0)-q;o=c+-3.5;if(!(D(o)<1e-8)){o:{p:{switch(g|0){case 0:h=.5-Me(c*.8975979010256552)*.5;break o;case 1:h=Me(c*.8975979010256552)*-.46+.54;break o;case 2:h=Me(c*1.7951958020513104)*.08+(Me(c*.8975979010256552)*-.5+.42);break o;case 3:h=Me(c*1.7951958020513104)*.05677+(Me(c*.8975979010256552)*-.49364+.44959);break o;case 4:h=Me(c*1.7951958020513104)*.07922+(Me(c*.8975979010256552)*-.49755+.42323);break o;case 5:h=Me(c*1.7951958020513104)*.14128+(Me(c*.8975979010256552)*-.48829+.35875)+Me(c*2.6927937030769655)*-.01168;break o;case 6:h=Me(c*1.7951958020513104)*.09392+(Me(c*.8975979010256552)*-.49703+.40217)+Me(c*2.6927937030769655)*-.00183;break o;case 7:break p;default:break o}}h=Me(c*1.7951958020513104)*.09831+(Me(c*.8975979010256552)*-.49804+.40243)+Me(c*2.6927937030769655)*-.00122}c=o*3.141592653589793;i=ri(c*i)/c}i=h*i;A[d+(b<<3)>>3]=i;n=n+i;b=b+1|0;if((b|0)!=8){continue}break}i=1/n;j=l<<3;b=0;while(1){k=e+(b+j<<1)|0;c=H(i*(A[d+(b<<3)>>3]*32768)+.5);c=c<-32768?-32768:F(c,32768);q:{if(D(c)<2147483648){g=~~c;break q}g=-2147483648}u[k>>1]=g;b=b+1|0;if((b|0)!=8){continue}break}l=l+1|0;if((l|0)!=8193){continue}break}gb=d- -64|0;f=v[a+20>>2];b=a+368696|0;v[b>>2]=v[a+16>>2];v[b+4>>2]=f;f=v[a+12>>2];b=a+368688|0;v[b>>2]=v[a+8>>2];v[b+4>>2]=f;b=v[a+4>>2];v[a+368680>>2]=v[a>>2];v[a+368684>>2]=b}}function Zpa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;e=gb-736|0;gb=e;vc(b);g=gb-32|0;gb=g;f=g+24|0;k=e+120|0;zY(f,k);i=yb(f);f=v[g+28>>2];j=v[g+24>>2];v[g+8>>2]=j;v[g+12>>2]=f;v[g>>2]=j;v[g+4>>2]=f;j=g+16|0;f=b;cc(j,f,g);j=yb(j);if((j|0)==(i|0)){Rb(f,yb(g+24|0))}gb=g+32|0;f=(i|0)==(j|0);if(!f){yY(k)}a:{if(!f){break a}if(!BY(e+120|0)){break a}b:{if(!c){break b}Gd(a,67108864);Bg(a);d=w[e+145|0];u[a+480190>>1]=31;u[a+480188>>1]=d;v[a+480228>>2]=256/(d>>>0);d=Tb(e,5312);Eb(a+1298304|0,d);vb(d);d=Tb(e,8058);Eb(a+1298316|0,d);vb(d);d=e+96|0;Df(d,1283);v[e+72>>2]=w[e+144|0]>>>4;f=w[e+144|0];v[22656]=0;v[e+116>>2]=f&15;Y(460,e|0,d|0,e+72|0,e+116|0);d=v[22656];v[22656]=0;c:{d:{if((d|0)!=1){Eb(a+1298328|0,e);vb(e);Hb(e+96|0);v[a+1298364>>2]=2;Er(Sb(a+484360|0),e+168|0,w[e+167|0]+1|0);while(1){d=h+1|0;g=B(d,104)+a|0;i=g+484380|0;ud(i,1);f=(e+120|0)+(h<<2)|0;o=i,p=Xb(w[f+176|0]|w[f+177|0]<<8|(w[f+178|0]<<16|w[f+179|0]<<24)),v[o>>2]=p;k=Xb(w[f+300|0]|w[f+301|0]<<8|(w[f+302|0]<<16|w[f+303|0]<<24));v[g+484384>>2]=k;o=g+484388|0,p=Xb(w[f+424|0]|w[f+425|0]<<8|(w[f+426|0]<<16|w[f+427|0]<<24))+k|0,v[o>>2]=p;if(Xb(w[f+424|0]|w[f+425|0]<<8|(w[f+426|0]<<16|w[f+427|0]<<24))){f=g+484414|0;u[f>>1]=x[f>>1]|2}xk(i);h=(e+120|0)+h|0;t[e|0]=w[h+548|0];t[e+96|0]=64;o=g+484410|0,p=w[ac(e,e+96|0)|0]<<2,u[o>>1]=p;t[g+484417|0]=w[h+579|0]<<4;h=d;if((d|0)!=31){continue}break}Uv(b,a+1298268|0,32);d=1;while(1){AY(b,((d<<5)+a|0)+946304|0,30);d=d+1|0;if((d|0)!=32){continue}break}j=c&1;if(j){Ag(a+484344|0,w[e+166|0]+1|0)}k=a+484344|0;d=0;e:{while(1){f=d;g=Jh(e+96|0);f:{if(w[e+146|0]){v[22656]=0;d=T(416,b|0)|0;h=v[22656];v[22656]=0;if((h|0)==1){break e}v[22656]=0;U(288,e+72|0,b|0,d|0);d=v[22656];v[22656]=0;if((d|0)==1){break e}break f}d=x[a+480188>>1];v[22656]=0;U(288,e+72|0,b|0,d<<8);d=v[22656];v[22656]=0;if((d|0)==1){break d}}d=e+72|0;Vc(g,kc(e,d));xb(e);xb(d);g:{if(!j){break g}v[22656]=0;d=W(331,k|0,f&65535,64)|0;h=v[22656];v[22656]=0;if((h|0)==1){break d}if(!d){break g}if(!w[e+146|0]){h=0;if(!x[a+480188>>1]){break g}while(1){d=0;while(1){i=_b(k,f);v[22656]=0;i=Yc(i,d,h&65535);l=v[22656];v[22656]=0;if((l|0)==1){break d}v[22656]=0;R(461,g|0,i|0);i=v[22656];v[22656]=0;if((i|0)==1){break d}d=d+1|0;if((d|0)!=64){continue}break}h=h+1|0;if(x[a+480188>>1]>(h&65535)>>>0){continue}break}break g}i=0;v[22656]=0;R(462,g|0,e|0);d=v[22656];v[22656]=0;if((d|0)==1){break d}while(1){d=_b(k,f);v[22656]=0;l=Tf(d,i);d=v[22656];v[22656]=0;if((d|0)==1){break d}if(x[a+480188>>1]){m=e+i|0;d=128;h=0;while(1){h:{if(!(w[m|0]&d)){break h}v[22656]=0;R(461,g|0,l+B(h,6)|0);n=v[22656];v[22656]=0;if((n|0)!=1){break h}break d}d=d>>>1|0;h=h+1|0;if(h>>>0<x[a+480188>>1]){continue}break}}i=i+1|0;if((i|0)!=64){continue}break}}d=f+1|0;xb(e+96|0);if(f>>>0<w[e+166|0]){continue}break}d=1;if(!(c&2)){break a}c=Rc(e,8,1,1,0);while(1){Dg(c,(B(d,104)+a|0)+484380|0,b);d=d+1|0;if((d|0)!=32){continue}break}break b}break d}d=P()|0;O()|0;Hb(e+96|0);break c}d=P()|0;O()|0;xb(e+96|0)}S(d|0);L()}d=1}gb=e+736|0;return d|0}function Yb(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;a:{if(!a){break a}d=a-8|0;b=v[a-4>>2];a=b&-8;f=d+a|0;b:{if(b&1){break b}if(!(b&3)){break a}b=v[d>>2];d=d-b|0;if(d>>>0<y[116510]){break a}a=a+b|0;if(v[116511]!=(d|0)){if(b>>>0<=255){e=v[d+8>>2];b=b>>>3|0;c=v[d+12>>2];if((c|0)==(e|0)){i=466024,j=v[116506]&oqa(-2,b),v[i>>2]=j;break b}v[e+12>>2]=c;v[c+8>>2]=e;break b}h=v[d+24>>2];b=v[d+12>>2];c:{if((d|0)!=(b|0)){c=v[d+8>>2];v[c+12>>2]=b;v[b+8>>2]=c;break c}d:{e=d+20|0;c=v[e>>2];if(c){break d}e=d+16|0;c=v[e>>2];if(c){break d}b=0;break c}while(1){g=e;b=c;e=b+20|0;c=v[e>>2];if(c){continue}e=b+16|0;c=v[b+16>>2];if(c){continue}break}v[g>>2]=0}if(!h){break b}e=v[d+28>>2];c=(e<<2)+466328|0;e:{if(v[c>>2]==(d|0)){v[c>>2]=b;if(b){break e}i=466028,j=v[116507]&oqa(-2,e),v[i>>2]=j;break b}v[h+(v[h+16>>2]==(d|0)?16:20)>>2]=b;if(!b){break b}}v[b+24>>2]=h;c=v[d+16>>2];if(c){v[b+16>>2]=c;v[c+24>>2]=b}c=v[d+20>>2];if(!c){break b}v[b+20>>2]=c;v[c+24>>2]=b;break b}b=v[f+4>>2];if((b&3)!=3){break b}v[116508]=a;v[f+4>>2]=b&-2;v[d+4>>2]=a|1;v[a+d>>2]=a;return}if(d>>>0>=f>>>0){break a}b=v[f+4>>2];if(!(b&1)){break a}f:{if(!(b&2)){if(v[116512]==(f|0)){v[116512]=d;a=v[116509]+a|0;v[116509]=a;v[d+4>>2]=a|1;if(v[116511]!=(d|0)){break a}v[116508]=0;v[116511]=0;return}if(v[116511]==(f|0)){v[116511]=d;a=v[116508]+a|0;v[116508]=a;v[d+4>>2]=a|1;v[a+d>>2]=a;return}a=(b&-8)+a|0;g:{if(b>>>0<=255){e=v[f+8>>2];b=b>>>3|0;c=v[f+12>>2];if((c|0)==(e|0)){i=466024,j=v[116506]&oqa(-2,b),v[i>>2]=j;break g}v[e+12>>2]=c;v[c+8>>2]=e;break g}h=v[f+24>>2];b=v[f+12>>2];h:{if((f|0)!=(b|0)){c=v[f+8>>2];v[c+12>>2]=b;v[b+8>>2]=c;break h}i:{e=f+20|0;c=v[e>>2];if(c){break i}e=f+16|0;c=v[e>>2];if(c){break i}b=0;break h}while(1){g=e;b=c;e=b+20|0;c=v[e>>2];if(c){continue}e=b+16|0;c=v[b+16>>2];if(c){continue}break}v[g>>2]=0}if(!h){break g}e=v[f+28>>2];c=(e<<2)+466328|0;j:{if(v[c>>2]==(f|0)){v[c>>2]=b;if(b){break j}i=466028,j=v[116507]&oqa(-2,e),v[i>>2]=j;break g}v[h+(v[h+16>>2]==(f|0)?16:20)>>2]=b;if(!b){break g}}v[b+24>>2]=h;c=v[f+16>>2];if(c){v[b+16>>2]=c;v[c+24>>2]=b}c=v[f+20>>2];if(!c){break g}v[b+20>>2]=c;v[c+24>>2]=b}v[d+4>>2]=a|1;v[a+d>>2]=a;if(v[116511]!=(d|0)){break f}v[116508]=a;return}v[f+4>>2]=b&-2;v[d+4>>2]=a|1;v[a+d>>2]=a}if(a>>>0<=255){a=a>>>3|0;b=(a<<3)+466064|0;c=v[116506];a=1<<a;k:{if(!(c&a)){v[116506]=a|c;a=b;break k}a=v[b+8>>2]}v[b+8>>2]=d;v[a+12>>2]=d;v[d+12>>2]=b;v[d+8>>2]=a;return}e=31;v[d+16>>2]=0;v[d+20>>2]=0;if(a>>>0<=16777215){b=a>>>8|0;g=b+1048320>>>16&8;b=b<<g;e=b+520192>>>16&4;b=b<<e;c=b+245760>>>16&2;b=(b<<c>>>15|0)-(c|(e|g))|0;e=(b<<1|a>>>b+21&1)+28|0}v[d+28>>2]=e;g=(e<<2)+466328|0;l:{m:{c=v[116507];b=1<<e;n:{if(!(c&b)){v[116507]=b|c;v[g>>2]=d;v[d+24>>2]=g;break n}e=a<<((e|0)==31?0:25-(e>>>1|0)|0);b=v[g>>2];while(1){c=b;if((v[b+4>>2]&-8)==(a|0)){break m}b=e>>>29|0;e=e<<1;g=c+(b&4)|0;b=v[g+16>>2];if(b){continue}break}v[g+16>>2]=d;v[d+24>>2]=c}v[d+12>>2]=d;v[d+8>>2]=d;break l}a=v[c+8>>2];v[a+12>>2]=d;v[c+8>>2]=d;v[d+24>>2]=0;v[d+12>>2]=c;v[d+8>>2]=a}a=v[116514]-1|0;v[116514]=a?a:-1}}function Ika(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,z=0;f=gb-4144|0;gb=f;a:{b:{if(!Ib(w[a+14|0]|w[a+15|0]<<8)){break b}i=a;if(Ib(w[a+14|0]|w[a+15|0]<<8)>>>0>20|x[b+480190>>1]<=w[a+23|0]){break b}ud(d,32);u[d+34>>1]=1;h=f+24|0;g=h;a=a+20|0;td(g,a,a+80|0);a=f+4136|0;NT(a,g,Ib(w[i+14|0]|w[i+15|0]<<8));j=Bk(b,w[Mb(a,0)+3|0]+1|0);v[f+24>>2]=1;n=1/+y[Lc(j+24|0,g)>>2];if(c){j=br(f+4136|0)}else{j=1}NT(g,a,j);a=v[h>>2];g=v[h+4>>2];if((a|0)!=(g|0)){while(1){if(!(t[a+1|0]<0|x[b+480190>>1]<=w[a+3|0])){h=Bk(b,w[a+3|0]+1|0);j=v[h>>2];s=d,z=Ah(n*(Ek(+(t[a+1|0]-t[Mb(f+4136|0,0)+1|0]|0)/-12)*+(j>>>0)*+y[h+24>>2]))+v[d>>2]|0,v[s>>2]=z}a=a+4|0;if((g|0)!=(a|0)){continue}break}}q=Ql(d);if(q){j=(e<<12>>>0)/1e4|0;e=br(f+4136|0);a=f+4120|0;h=vh(a);c:{if(!e){break c}v[22656]=0;R(939,a|0,e|0);g=v[22656];v[22656]=0;if((g|0)!=1){v[22656]=0;R(940,a|0,e|0);e=v[22656];v[22656]=0;if((e|0)!=1){break c}}break a}h=a;d:{if(!br(f+4136|0)){break d}a=0;while(1){e:{e=Mb(f+4136|0,a);g=MT(h,a);f:{if(t[e+1|0]<0|x[b+480190>>1]<=w[e+3|0]){break f}k=0;k=w[e+2|0]<242|w[e+2|0]>247?k:t[w[e+2|0]+33118|0];l=Bk(b,w[e+3|0]+1|0);e=t[e+1|0];o=Mb(f+4136|0,0);p=v[l+24>>2];m=n*(Ek(+(k<<24>>24)/96+ +(e-t[o+1|0]|0)/12)*+(p>>>0));if(m<=0){break f}v[22656]=0;k=Oa(934,+m)|0;e=O()|0;o=k|0;p=v[22656];v[22656]=0;k=g;g:{h:{if((p|0)!=1){v[g+8>>2]=o;v[g+12>>2]=e;v[g+16>>2]=v[l+20>>2];e=v[l>>2];v[g+76>>2]=e;v[g+88>>2]=x[l+34>>1]&1023;if(!c){break h}v[g+664>>2]=r;m=RB(g+8|0);v[22656]=0;e=Ah(+(e>>>0)/m);l=v[22656];v[22656]=0;if((l|0)==1){break e}r=e+r|0;e=j;break g}break a}e=(j>>>0)/(Ib(w[i+14|0]|w[i+15|0]<<8)>>>0)|0}v[k+20>>2]=e;v[g+24>>2]=e}a=a+1|0;if(br(f+4136|0)>>>0>a>>>0){continue}break d}break}break a}a=v[d>>2];if(a){k=b+24648|0;c=0;while(1){Qb(f+24|0,0,4096);v[f+16>>2]=512;v[22656]=0;v[f+8>>2]=a-c;a=Fb(f+16|0,f+8|0);b=v[22656];v[22656]=0;i:{j:{if((b|0)!=1){g=v[a>>2];s=f,z=Vb(h),v[s+16>>2]=z;s=f,z=Zb(h),v[s+8>>2]=z;if(Gb(f+16|0,f+8|0)){break j}break i}break a}while(1){k:{a=v[f+16>>2];if(!v[a+16>>2]){break k}b=v[a+664>>2];if(b>>>0>=g>>>0){v[a+664>>2]=b-g;break k}e=v[a+88>>2];v[f+4>>2]=g-b;b=v[a+76>>2];n=RB(a);m=RB(a+8|0);v[22656]=0;b=Ah((+(b>>>0)-n)/m);i=v[22656];v[22656]=0;if((i|0)==1){break a}v[22656]=0;v[f>>2]=b;b=Fb(f+4|0,f);i=v[22656];v[22656]=0;if((i|0)==1){break a}b=v[b>>2];i=v[a+664>>2];v[22656]=0;Y(v[((e&1|(e&64?18:16))<<2)+33696>>2],a|0,k|0,(f+24|0)+(i<<3)|0,b|0);b=v[22656];v[22656]=0;if((b|0)!=1){v[a+664>>2]=0;if(y[a+76>>2]>y[a+4>>2]){break k}v[a+16>>2]=0;break k}break a}a=f+16|0;v[a>>2]=v[a>>2]+872;if(Gb(a,f+8|0)){continue}break}}e=v[d+20>>2]+(c<<1)|0;i=f+24|0;b=gb-16|0;gb=b;v[b+12>>2]=g;qc(b+12|0,512);a=v[b+12>>2];v[b+12>>2]=a-1;if(a){while(1){a=e;j=id(v[i>>2]+2048|0,12);if((j|0)<-32768){j=-32768}u[a>>1]=(j|0)>32767?32767:j;a=v[b+12>>2];v[b+12>>2]=a-1;i=i+8|0;e=e+2|0;if(a){continue}break}}gb=b+16|0;a=v[d>>2];c=c+g|0;if(a>>>0>c>>>0){continue}break}}FT(h)}h=(q|0)!=0}gb=f+4144|0;return h|0}a=P()|0;O()|0;FT(h);S(a|0);L()}function hX(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;g=gb-128|0;gb=g;j=Jk(g+112|0);a:{b:{c:{if(d){v[22656]=0;U(645,a|0,j|0,c|0);c=v[22656];v[22656]=0;if((c|0)!=1){break c}break b}v[22656]=0;U(646,a|0,j|0,c|0);c=v[22656];v[22656]=0;if((c|0)==1){break b}}k=mc(g+96|0);if(x[b+480192>>1]){d=1;c=1;while(1){v[22656]=0;u[g+94>>1]=0;Q(647,a|0,g+94|0)|0;f=v[22656];v[22656]=0;d:{e:{f:{if((f|0)!=1){l=gb-16|0;gb=l;p=l+8|0;i=gb-16|0;gb=i;f=j;m=f;o=g+94|0;q=o;e=Yd(f);h=fc(f);n=gb-16|0;gb=n;if(e){wb(m);while(1){m=RC(e+16|0,q);h=m?h:e;e=v[(m?4:0)+e>>2];if(e){continue}break}}e=v[yc(n+8|0,h)>>2];gb=n+16|0;v[i+8>>2]=e;r=i,s=Ch(f),v[r>>2]=s;g:{if(Gb(i+8|0,i)){if(!SC(wb(f),o,ue(i+8|0))){break g}}e=Ch(f)}gb=i+16|0;f=v[yc(p,e)>>2];gb=l+16|0;v[g+88>>2]=f;i=((d<<2)+b|0)+900380|0;if(!v[i>>2]){break d}r=g,s=Dh(j),v[r+72>>2]=s;if(og(g+88|0,g+72|0)){d=ue(g+88|0);v[22656]=0;d=Q(4,g+72|0,d+4|0)|0;f=v[22656];v[22656]=0;h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{t:{u:{v:{w:{x:{y:{if((f|0)!=1){v[22656]=0;f=Q(2,g+56|0,13855)|0;e=v[22656];v[22656]=0;if((e|0)==1){break i}e=vr(d,f);vb(f);if(e){break r}f=v[b+4>>2];v[22656]=0;f=Q(648,f|0,d|0)|0;e=v[22656];v[22656]=0;if((e|0)==1){break x}v[v[i>>2]+44>>2]=f;if(!v[v[i>>2]+44>>2]){break y}break e}b=P()|0;O()|0;break f}v[22656]=0;f=Q(2,g+56|0,10751)|0;e=v[22656];v[22656]=0;if((e|0)==1){break w}z:{A:{if(vr(d,f)){vb(f);break A}v[22656]=0;e=Q(2,g+40|0,10963)|0;h=v[22656];v[22656]=0;if((h|0)==1){break v}h=vr(d,e);vb(e);vb(f);if(!h){break z}}v[22656]=0;f=T(649,d|0)|0;e=v[22656];v[22656]=0;if((e|0)==1){break u}v[g+56>>2]=f;f=v[b+4>>2];pi(g+32|0,g+56|0);v[22656]=0;f=Q(650,f|0,v[g+32>>2])|0;e=v[22656];v[22656]=0;if((e|0)==1){break t}Jg(g+56|0);if(f){break e}}h=Vb(k);l=Zb(k);f=d;e=gb-16|0;gb=e;v[e>>2]=l;v[e+8>>2]=h;if(Gb(e+8|0,e)){while(1){if(!vr(v[e+8>>2],f)){h=e+8|0;sr(h);if(Gb(h,e)){continue}}break}h=v[e+8>>2]}gb=e+16|0;v[g+56>>2]=h;r=g,s=Zb(k),v[r+40>>2]=s;if(Gb(g+56|0,g+40|0)){break r}v[22656]=0;R(651,k|0,d|0);f=v[22656];v[22656]=0;if((f|0)!=1){break s}}b=P()|0;O()|0;break h}b=P()|0;O()|0;break h}b=P()|0;O()|0;vb(f);break h}b=P()|0;O()|0;break h}b=P()|0;O()|0;Jg(g+56|0);break h}v[22656]=0;f=Q(2,g+16|0,14557)|0;e=v[22656];v[22656]=0;if((e|0)==1){break q}v[22656]=0;U(652,g+40|0,f|0,d|0);e=v[22656];v[22656]=0;if((e|0)==1){break p}v[22656]=0;e=Q(2,g|0,13431)|0;h=v[22656];v[22656]=0;if((h|0)==1){break o}v[22656]=0;U(3,g+56|0,g+40|0,e|0);h=v[22656];v[22656]=0;if((h|0)==1){break n}v[22656]=0;U(560,b|0,2,g+56|0);h=v[22656];v[22656]=0;if((h|0)==1){break m}vb(g+56|0);vb(e);vb(g+40|0);vb(f)}v[v[i>>2]+44>>2]=0;break e}b=P()|0;O()|0;break h}b=P()|0;O()|0;break j}b=P()|0;O()|0;break k}b=P()|0;O()|0;break l}b=P()|0;O()|0;vb(g+56|0)}vb(e)}vb(g+40|0)}vb(f);break h}b=P()|0;O()|0}vb(d);break f}if(!v[i>>2]){break d}v[v[i>>2]+44>>2]=0;break d}b=P()|0;O()|0}sm(k);break a}vb(d)}c=c+1|0;d=c&65535;if(d>>>0<=x[b+480192>>1]){continue}break}}sm(k);cX(j);gb=g+128|0;return}b=P()|0;O()|0}cX(j);S(b|0);L()}function tA(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,u=0,z=0,A=0,C=0;h=gb-16|0;gb=h;i=B(b,872)+a|0;l=i+1075800|0;j=w[l|0];e=h+8|0;k=a+1074312|0;Db(e,k,23);g=c&15;a:{b:{c:{if(Cb(e)){if(!(v[a+1074392>>2]|!w[(B(b,872)+a|0)+1075780|0])){t[l|0]=g;e=0;break c}e=w[l|0];if(e){f=e-1|0;t[l|0]=f;e=0;if(f&255){break c}}t[l|0]=g;e=1;break c}e=h+8|0;Db(e,k,52);f=c&256;if(!(!Cb(e)|!f)){d:{if(!(w[a+480209|0]&16)){break d}e=B(b,872)+a|0;if(w[e+1075781|0]){j=aD(e+1075780|0)?1:j}if(w[e+1075782|0]!=1){break d}if(w[(B(b,872)+a|0)+1075784|0]){break b}}e=0;if((j&255)>>>0<g>>>0){break c}if(w[a+480209|0]&16){if(Rd((B(b,872)+a|0)+1075780|0)){break c}}j=0;e=1;break c}if(v[a+480180>>2]&16777250){e=j&255;if(e){e=(e>>>0)%((g?g:1)>>>0)|0}else{e=1}e=!e;j=j+1|0;break c}if(v[a+480180>>2]==1){f=y[a+1074392>>2]%y[a+1074416>>2]|0;if(!f){if(Rd((B(b,872)+a|0)+1075780|0)){break a}}e=0;e=g?!((f>>>0)%(g>>>0)|0):e;break c}if(v[a+480180>>2]==16){e=v[a+1074392>>2]==(g|0)&(g|0)!=0;break c}e:{f:{g:{h:{i:{if(f){e=B(b,872)+a|0;if(w[e+1075782|0]==1){g=(w[e+1075785|0]>15)+g|0}g=g?g:1;break i}if(w[a+480209|0]&16){break f}g=g?g:1;if(v[a+1074416>>2]){break h}}e=0;break g}e=!(y[a+1074392>>2]%(g>>>0)|0)}j=j+1|0;break e}e=0;j=v[a+480180>>2]&1048580?0:j}if(!(!(w[(B(b,872)+a|0)+1075780|0]|!f?v[a+1074392>>2]:1)|(j&255)>>>0<g>>>0)){e=1}g=h+8|0;Db(g,k,52);if(!Cb(g)|c){break c}e=!v[a+1074392>>2]}g=i+1074992|0;i=(B(b,872)+a|0)+1075068|0;j:{if(v[i>>2]){break j}f=h+8|0;Db(f,k,38);if(!Cb(f)){break j}if(!tk(g)){break a}}f=h+8|0;Db(f,k,106);if(z=0,A=Cb(f),C=v[(B(b,872)+a|0)+1075688>>2],C?z:A){break a}if(e){f=B(b,872)+a|0;p=f+1075680|0;v[h+4>>2]=v[p>>2];e=c>>>4&15;if(e){m=h+8|0;Db(m,k,52);k:{if(z=Cb(m),A=0,C=w[(B(b,872)+a|0)+1075782|0]==1,C?z:A){break k}if(!(16191>>>e&1)){v[h+4>>2]=(B(v[h+4>>2],t[e+40144|0])|0)/16;break k}v[h+4>>2]=v[h+4>>2]+(t[e+40160|0]<<2)}Zd(h+4|0,0,256);e=(B(b,872)+a|0)+1075080|0;v[e>>2]=v[e>>2]|2097152}q=f+1075692|0;m=v[q>>2];e=w[f+1075794|0];l:{if(!v[i>>2]|(e-1&255)>>>0>119){break l}if(!(!(w[(B(b,872)+a|0)+1075081|0]&2)|v[a+480180>>2]!=2)){f=h+8|0;Db(f,k,108);if(!Cb(f)){break l}}CP(a,b,0,e,1)}f=0;m:{if(!(v[a+480180>>2]&1048580)){break m}i=w[(B(b,872)+a|0)+1075781|0];f=(c|0)<256;if(!i|(c|0)>255){break m}Fo(a,g,i,0,0,1);f=1}i=B(b,872)+a|0;n=i+1075652|0;s=v[n>>2];v[n>>2]=0;o=i+1075080|0;u=v[o>>2];r=h+8|0;Db(r,k,23);tu(a,g,e,Cb(r),f,0,b);if(!w[i+1075781|0]){v[n>>2]=s}if(!(!(u&4096)|v[a+480180>>2]!=4)){v[o>>2]=v[o>>2]|4096}f=i+1075780|0;v[p>>2]=v[h+4>>2];if(x[a+480192>>1]){t[f|0]=e;jO(a,b)}if(!(!(v[a+480180>>2]&16777248)|(w[f|0]|!m))){v[q>>2]=m}e=v[a+480180>>2];f=h+8|0;Db(f,k,23);if(Cb(f)){v[g>>2]=0;v[g+4>>2]=0}e=e&16777250;f=(B(b,872)+a|0)+1075096|0;n:{if(!v[f>>2]|(d|0)<=0){break n}i=d-1|0;if((i|0)>9){break n}o:{if(!i){b=v[(B(b,872)+a|0)+1075656>>2];break o}i=(B(b,872)+a|0)+1075656|0;b=v[Fe(v[f>>2]+68|0,d-2|0)>>2];v[i>>2]=b}Om(a,g,b)}j=e?j:0}a=h+8|0;Db(a,k,52);b=Cb(a);Db(a,k,23);if(Cb(a)){break a}j=(b&(c&256)>>>8)+j|0}t[l|0]=j}gb=h+16|0}function rL(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0;f=gb-224|0;gb=f;v[f+216>>2]=c;v[f+220>>2]=d;a:{if(rk(b)){break a}g=w[vl(b)|0];if((g|0)==33){e=1}else{if((g|0)!=63){break a}e=0}Kl(f+184|0,b,v[b+4>>2]-1|0);g=v[f+188>>2];v[b>>2]=v[f+184>>2];v[b+4>>2]=g}g=f+184|0;Ld(g);h=v[f+184>>2];Ld(f+168|0);i=ul(h,v[f+172>>2],b);Ld(g);g=v[b>>2];h=v[b+4>>2];b:{c:{d:{e:{f:{g:{h:{if((i|0)==v[f+188>>2]){v[f+208>>2]=g;v[f+212>>2]=h;a=uc(f+200|0,18726);c=v[f+212>>2];v[f+16>>2]=v[f+208>>2];v[f+20>>2]=c;c=v[a+4>>2];v[f+8>>2]=v[a>>2];v[f+12>>2]=c;if(Gc(f+16|0,f+8|0)){a=ba(8)|0;v[22656]=0;R(2059,f+168|0,f+216|0);b=v[22656];v[22656]=0;if((b|0)!=1){v[22656]=0;U(2037,f+184|0,14728,f+168|0);b=v[22656];v[22656]=0;if((b|0)==1){break g}rc(a,f+184|0);v[22656]=0;U(186,a|0,54952,1936);a=v[22656];v[22656]=0;if((a|0)!=1){break b}b=P()|0;O()|0;vb(f+184|0);vb(f+168|0);break c}b=P()|0;O()|0;break d}if(!e){break h}c=ba(8)|0;v[22656]=0;d=Q(2057,f+136|0,b|0)|0;a=v[22656];v[22656]=0;i:{j:{k:{l:{m:{n:{o:{p:{if((a|0)!=1){v[22656]=0;U(2037,f+152|0,14764,d|0);a=v[22656];v[22656]=0;if((a|0)==1){break p}v[22656]=0;R(2054,f+168|0,f+152|0);b=v[22656];v[22656]=0;a=1;if((b|0)==1){break o}v[22656]=0;R(2059,f+120|0,f+216|0);a=v[22656];v[22656]=0;if((a|0)==1){break n}v[22656]=0;U(2058,f+184|0,f+168|0,f+120|0);b=v[22656];v[22656]=0;a=1;if((b|0)==1){break m}rc(c,f+184|0);v[22656]=0;U(186,c|0,54952,1936);a=v[22656];v[22656]=0;if((a|0)!=1){break b}b=P()|0;O()|0;vb(f+184|0);a=0;break l}b=P()|0;O()|0;break i}b=P()|0;O()|0;vb(d);break i}b=P()|0;O()|0;break j}b=P()|0;a=1;O()|0;break k}b=P()|0;O()|0}vb(f+120|0)}vb(f+168|0)}vb(f+152|0);vb(d);if(!a){break c}}ca(c|0);break c}v[f+112>>2]=g;v[f+116>>2]=h;e=uc(f+104|0,18726);g=v[f+116>>2];v[f+64>>2]=v[f+112>>2];v[f+68>>2]=g;g=v[e+4>>2];v[f+56>>2]=v[e>>2];v[f+60>>2]=g;if(Gc(f- -64|0,f+56|0)){a=ba(8)|0;v[22656]=0;R(2059,f+168|0,f+216|0);b=v[22656];v[22656]=0;if((b|0)!=1){v[22656]=0;U(2037,f+184|0,14728,f+168|0);b=v[22656];v[22656]=0;if((b|0)==1){break f}rc(a,f+184|0);v[22656]=0;U(186,a|0,54952,1936);a=v[22656];v[22656]=0;if((a|0)!=1){break b}b=P()|0;O()|0;vb(f+184|0);vb(f+168|0);break c}b=P()|0;O()|0;break e}e=v[b+4>>2];v[f+96>>2]=v[b>>2];v[f+100>>2]=e;e=uc(f+88|0,8207);g=v[f+100>>2];v[f+48>>2]=v[f+96>>2];v[f+52>>2]=g;g=v[e+4>>2];v[f+40>>2]=v[e>>2];v[f+44>>2]=g;if(Gc(f+48|0,f+40|0)){dL(a,Ac(c,d));break h}e=v[b+4>>2];v[f+80>>2]=v[b>>2];v[f+84>>2]=e;b=uc(f+72|0,5758);e=v[f+84>>2];v[f+32>>2]=v[f+80>>2];v[f+36>>2]=e;e=v[b+4>>2];v[f+24>>2]=v[b>>2];v[f+28>>2]=e;if(!Gc(f+32|0,f+24|0)){break h}b=OA(c,d);c=gb-16|0;gb=c;a=v[a+32>>2];b=b>>>0<4?b:1;q:{if((Ky(a)|0)==(b|0)){d=a+120|0;Bi(d);b=gb-16|0;gb=b;v[b+8>>2]=c+8;a=gb-16|0;gb=a;e=v[14914];v[a+8>>2]=v[14913];v[a+12>>2]=e;e=v[14912];v[a>>2]=v[14911];v[a+4>>2]=e;kb[v[Rh(a,Yg(d))>>2]](b+8|0,d);gb=a+16|0;gb=b+16|0;break q}DK(a,b,EK(a))}gb=c+16|0}gb=f+224|0;return}b=P()|0;O()|0;vb(f+168|0);break d}b=P()|0;O()|0;vb(f+168|0)}ca(a|0);break c}ca(a|0)}S(b|0)}L()}function _L(a){var b=C(0),c=C(0),d=0,e=C(0),f=0,g=C(0),h=0,i=C(0),k=C(0),m=C(0),n=C(0),o=C(0),r=C(0),s=0,t=C(0);VP(a+4208|0,z[a+4272>>2]);c=C(C(z[a+4208>>2]*C(15920))+C(80));d=wf(v[a+16>>2]);o=oe(C(10),C(C(C(z[a+4216>>2]+C(-.5))*C(30))/C(40)));b=C(C(c/C(d>>>0))*C(6.2831854820251465));c=AG(b);r=Qp(b);s=a;t=c;k=C(C(b*C(C(C(z[a+4212>>2]*C(35))+C(1))*C(.02888113260269165)))/c);i=(l(2,(p(k),j(2))&-2147483648|1056964608),q());h=(p(k),j(2))&2147483647;c=(l(2,h),q());a:{if(h>>>0<=1118925334){b:{c:{d:{e:{f:{g:{f=(p(c),j(2));d=f&2147483647;if(d>>>0>=1100331076){if(d>>>0>2139095040){break c}b=C(-1);if((f|0)<0){break b}if(!(c>C(88.7216796875))){break g}b=C(c*C(1.7014118346046923e38));break b}if(d>>>0<1051816473){break e}if(d>>>0>1065686417){break g}if((f|0)>=0){d=1;e=C(905800061445916e-20);b=C(c+C(-.6931381225585938));break f}d=-1;e=C(-905800061445916e-20);b=C(c+C(.6931381225585938));break f}b=C(C(c*C(1.4426950216293335))+(l(2,(p(c),j(2))&-2147483648|1056964608),q()));h:{if(C(D(b))<C(2147483648)){d=~~b;break h}d=-2147483648}b=C(d|0);e=C(b*C(905800061445916e-20));b=C(c+C(b*C(-.6931381225585938)))}c=b;c=C(c-e);e=C(C(b-c)-e);break d}if(d>>>0<855638016){break c}d=0}m=C(c*C(.5));g=C(c*m);b=C(C(g*C(C(g*C(.0015807170420885086))+C(-.03333321213722229)))+C(1));n=b;b=C(C(3)-C(m*b));m=C(g*C(C(n-b)/C(C(6)-C(c*b))));b=C(c-C(C(c*m)-g));if(!d){break b}e=C(C(C(c*C(m-e))-e)-g);i:{switch(d+1|0){case 0:b=C(C(C(c-e)*C(.5))+C(-.5));break b;case 2:b=C(C(e-C(c+C(.5)))*C(-2));if(c<C(-.25)){break b}c=C(c-e);b=C(C(c+c)+C(1));break b;default:break i}}f=d<<23;b=(l(2,f+1065353216|0),q());if(d>>>0>=57){c=C(C(c-e)+C(1));b=C(((d|0)==128?C(C(c+c)*C(1.7014118346046923e38)):C(c*b))+C(-1));break b}g=(l(2,1065353216-f|0),q());c=C((d>>>0<=22?C(C(C(1)-g)+C(c-e)):C(C(c-C(e+g))+C(1)))*b)}b=c}if(h>>>0<=1065353215){if(h>>>0<964689920){break a}k=C(i*C(C(b+b)-C(C(b*b)/C(b+C(1)))));break a}k=C(i*C(b+C(b/C(b+C(1)))));break a}g=C(i+i);i=C(0);c=C(c+C(-162.88958740234375));h=(p(c),j(2));f=h>>>31|0;j:{k:{l:{m:{n:{n=c;o:{p:{d=h&2147483647;q:{if(d>>>0>=1118743632){b=c;if(d>>>0>2139095040){break j}b=C(c*C(1.7014118346046923e38));if(!((h|0)<0|d>>>0<1118925336)){break j}if(d>>>0<=1120924084|(h|0)>=0){break q}break l}if(d>>>0<1051816473){break n}if(d>>>0<1065686419){break p}}c=C(C(c*C(1.4426950216293335))+z[(f<<2)+70768>>2]);if(C(D(c))<C(2147483648)){d=~~c;break o}d=-2147483648;break o}d=!f-f|0}b=C(d|0);c=C(n+C(b*C(-.693145751953125)));i=C(b*C(1428606765330187e-21));b=C(c-i);break m}if(d>>>0<=956301312){break k}d=0;b=c}n=c;e=C(b*b);c=C(b-C(e*C(C(e*C(-.0027667332906275988))+C(.16666625440120697))));e=C(C(n+C(C(C(b*c)/C(C(2)-c))-i))+C(1));if(!d){break l}e=$I(e,d)}b=e;break j}b=C(c+C(1))}k=C(g*C(C(b*C(1.661534994731145e35))*C(1.661534994731145e35)))}b=C(t*k);e=C(b/o);c=C(e+C(1));z[s+4236>>2]=C(C(1)-e)/c;e=C(C(r*C(-2))/c);z[a+4232>>2]=e;b=C(o*b);z[a+4228>>2]=C(C(1)-b)/c;z[a+4224>>2]=e;z[a+4220>>2]=C(b+C(1))/c}function Bs(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;f=a+b|0;c=v[a+4>>2];a:{b:{if(c&1){break b}if(!(c&3)){break a}c=v[a>>2];b=c+b|0;c:{a=a-c|0;if((a|0)!=v[116511]){if(c>>>0<=255){e=v[a+8>>2];c=c>>>3|0;d=v[a+12>>2];if((d|0)!=(e|0)){break c}i=466024,j=v[116506]&oqa(-2,c),v[i>>2]=j;break b}h=v[a+24>>2];c=v[a+12>>2];d:{if((c|0)!=(a|0)){d=v[a+8>>2];v[d+12>>2]=c;v[c+8>>2]=d;break d}e:{e=a+20|0;d=v[e>>2];if(d){break e}e=a+16|0;d=v[e>>2];if(d){break e}c=0;break d}while(1){g=e;c=d;e=c+20|0;d=v[e>>2];if(d){continue}e=c+16|0;d=v[c+16>>2];if(d){continue}break}v[g>>2]=0}if(!h){break b}e=v[a+28>>2];d=(e<<2)+466328|0;f:{if(v[d>>2]==(a|0)){v[d>>2]=c;if(c){break f}i=466028,j=v[116507]&oqa(-2,e),v[i>>2]=j;break b}v[h+(v[h+16>>2]==(a|0)?16:20)>>2]=c;if(!c){break b}}v[c+24>>2]=h;d=v[a+16>>2];if(d){v[c+16>>2]=d;v[d+24>>2]=c}d=v[a+20>>2];if(!d){break b}v[c+20>>2]=d;v[d+24>>2]=c;break b}c=v[f+4>>2];if((c&3)!=3){break b}v[116508]=b;v[f+4>>2]=c&-2;v[a+4>>2]=b|1;v[f>>2]=b;return}v[e+12>>2]=d;v[d+8>>2]=e}c=v[f+4>>2];g:{if(!(c&2)){if(v[116512]==(f|0)){v[116512]=a;b=v[116509]+b|0;v[116509]=b;v[a+4>>2]=b|1;if(v[116511]!=(a|0)){break a}v[116508]=0;v[116511]=0;return}if(v[116511]==(f|0)){v[116511]=a;b=v[116508]+b|0;v[116508]=b;v[a+4>>2]=b|1;v[a+b>>2]=b;return}b=(c&-8)+b|0;h:{if(c>>>0<=255){e=v[f+8>>2];c=c>>>3|0;d=v[f+12>>2];if((d|0)==(e|0)){i=466024,j=v[116506]&oqa(-2,c),v[i>>2]=j;break h}v[e+12>>2]=d;v[d+8>>2]=e;break h}h=v[f+24>>2];c=v[f+12>>2];i:{if((f|0)!=(c|0)){d=v[f+8>>2];v[d+12>>2]=c;v[c+8>>2]=d;break i}j:{d=f+20|0;e=v[d>>2];if(e){break j}d=f+16|0;e=v[d>>2];if(e){break j}c=0;break i}while(1){g=d;c=e;d=c+20|0;e=v[d>>2];if(e){continue}d=c+16|0;e=v[c+16>>2];if(e){continue}break}v[g>>2]=0}if(!h){break h}e=v[f+28>>2];d=(e<<2)+466328|0;k:{if(v[d>>2]==(f|0)){v[d>>2]=c;if(c){break k}i=466028,j=v[116507]&oqa(-2,e),v[i>>2]=j;break h}v[h+(v[h+16>>2]==(f|0)?16:20)>>2]=c;if(!c){break h}}v[c+24>>2]=h;d=v[f+16>>2];if(d){v[c+16>>2]=d;v[d+24>>2]=c}d=v[f+20>>2];if(!d){break h}v[c+20>>2]=d;v[d+24>>2]=c}v[a+4>>2]=b|1;v[a+b>>2]=b;if(v[116511]!=(a|0)){break g}v[116508]=b;return}v[f+4>>2]=c&-2;v[a+4>>2]=b|1;v[a+b>>2]=b}if(b>>>0<=255){b=b>>>3|0;c=(b<<3)+466064|0;d=v[116506];b=1<<b;l:{if(!(d&b)){v[116506]=b|d;b=c;break l}b=v[c+8>>2]}v[c+8>>2]=a;v[b+12>>2]=a;v[a+12>>2]=c;v[a+8>>2]=b;return}e=31;v[a+16>>2]=0;v[a+20>>2]=0;if(b>>>0<=16777215){c=b>>>8|0;g=c+1048320>>>16&8;c=c<<g;e=c+520192>>>16&4;c=c<<e;d=c+245760>>>16&2;c=(c<<d>>>15|0)-(d|(e|g))|0;e=(c<<1|b>>>c+21&1)+28|0}v[a+28>>2]=e;g=(e<<2)+466328|0;m:{d=v[116507];c=1<<e;n:{if(!(d&c)){v[116507]=c|d;v[g>>2]=a;v[a+24>>2]=g;break n}e=b<<((e|0)==31?0:25-(e>>>1|0)|0);c=v[g>>2];while(1){d=c;if((v[c+4>>2]&-8)==(b|0)){break m}c=e>>>29|0;e=e<<1;g=d+(c&4)|0;c=v[g+16>>2];if(c){continue}break}v[g+16>>2]=a;v[a+24>>2]=d}v[a+12>>2]=a;v[a+8>>2]=a;return}b=v[d+8>>2];v[b+12>>2]=a;v[d+8>>2]=a;v[a+24>>2]=0;v[a+12>>2]=d;v[a+8>>2]=b}}function O8(a,b,c){a=a|0;b=+b;c=c|0;var d=0,e=0,f=0,g=0;d=gb-192|0;gb=d;v[d+184>>2]=c;a:{b:{c:{d:{if(b>=.8){v[22656]=0;c=ga(2070)|0;e=v[22656];v[22656]=0;e:{f:{g:{if((e|0)!=1){v[d+88>>2]=c;c=v[d+184>>2];v[22656]=0;c=T(2071,c|0)|0;e=v[22656];v[22656]=0;if((e|0)==1){break f}v[d+72>>2]=c;no(v[d+88>>2],v[d+72>>2]);c=v[d+88>>2];a=le(d+160|0,a);v[22656]=0;e=v[a+12>>2];v[d+56>>2]=v[a+8>>2];v[d+60>>2]=e;v[d- -64>>2]=v[a+16>>2];e=v[a+4>>2];v[d+48>>2]=v[a>>2];v[d+52>>2]=e;a=W(2061,c|0,d+48|0,15)|0;c=v[22656];v[22656]=0;if((c|0)==1){break g}if(a){a=v[d+88>>2];v[22656]=0;T(1291,a|0)|0;a=v[22656];v[22656]=0;f=1;if((a|0)==1){break g}}Ci(d+72|0);Di(d+88|0);break c}c=V(0)|0;O()|0;break d}c=V(0)|0;O()|0;Ci(d+72|0);break e}c=V(0)|0;O()|0}Di(d+88|0);break d}if(b>=.6){v[22656]=0;c=ga(2070)|0;e=v[22656];v[22656]=0;h:{i:{j:{if((e|0)!=1){v[d+88>>2]=c;c=v[d+184>>2];v[22656]=0;c=T(2071,c|0)|0;e=v[22656];v[22656]=0;if((e|0)==1){break i}v[d+72>>2]=c;no(v[d+88>>2],v[d+72>>2]);c=v[d+88>>2];a=le(d+136|0,a);v[22656]=0;e=v[a+12>>2];v[d+32>>2]=v[a+8>>2];v[d+36>>2]=e;v[d+40>>2]=v[a+16>>2];e=v[a+4>>2];v[d+24>>2]=v[a>>2];v[d+28>>2]=e;a=W(2061,c|0,d+24|0,2)|0;c=v[22656];v[22656]=0;if((c|0)==1){break j}if(a){a=v[d+88>>2];v[22656]=0;T(1291,a|0)|0;a=v[22656];v[22656]=0;f=.8;if((a|0)==1){break j}}Ci(d+72|0);Di(d+88|0);break c}c=V(0)|0;O()|0;break d}c=V(0)|0;O()|0;Ci(d+72|0);break h}c=V(0)|0;O()|0}Di(d+88|0);break d}f=.2;if(b>=.2){v[22656]=0;c=ga(2070)|0;e=v[22656];v[22656]=0;k:{l:{m:{if((e|0)!=1){v[d+88>>2]=c;c=v[d+184>>2];v[22656]=0;c=T(2071,c|0)|0;e=v[22656];v[22656]=0;if((e|0)==1){break l}v[d+72>>2]=c;no(v[d+88>>2],v[d+72>>2]);c=v[d+88>>2];a=le(d+112|0,a);v[22656]=0;e=v[a+12>>2];v[d+8>>2]=v[a+8>>2];v[d+12>>2]=e;v[d+16>>2]=v[a+16>>2];e=v[a+4>>2];v[d>>2]=v[a>>2];v[d+4>>2]=e;a=W(2061,c|0,d|0,0)|0;c=v[22656];v[22656]=0;if((c|0)==1){break m}f=0;if(a){a=v[d+88>>2];v[22656]=0;T(1291,a|0)|0;a=v[22656];v[22656]=0;f=.6;if((a|0)==1){break m}}Ci(d+72|0);Di(d+88|0);break c}c=V(0)|0;O()|0;break d}c=V(0)|0;O()|0;Ci(d+72|0);break k}c=V(0)|0;O()|0}Di(d+88|0);break d}if(!(b>=.1)){break c}v[22656]=0;U(755,d+88|0,a|0,2048);c=v[22656];v[22656]=0;n:{o:{p:{if((c|0)!=1){v[22656]=0;c=Sd(d+88|0);e=v[22656];v[22656]=0;if((e|0)==1){break o}e=v[d+88>>2];v[22656]=0;a=T(195,a|0)|0;g=v[22656];v[22656]=0;if((g|0)==1){break o}v[22656]=0;a=wG(2072,3,0,c,e,a,0);c=v[22656];v[22656]=0;if((c|0)==1){break o}a=a+1|0;if(a>>>0>=3){break p}f=A[(a<<3)+59664>>3];zc(d+88|0);break c}c=V(0)|0;O()|0;break d}a=ba(8)|0;v[22656]=0;e=Q(70,d+72|0,18726)|0;c=v[22656];v[22656]=0;if((c|0)!=1){rc(a,e);v[22656]=0;U(186,a|0,54952,1936);a=v[22656];v[22656]=0;if((a|0)!=1){break b}c=V(0)|0;O()|0;vb(e);break n}c=V(0)|0;O()|0;ca(a|0);break n}c=V(0)|0;O()|0}zc(d+88|0)}Z(c|0)|0;v[22656]=0;X(20);a=v[22656];v[22656]=0;f=0;if((a|0)==1){break a}}eg(d+184|0);gb=d+192|0;return+f}L()}a=P()|0;O()|0;eg(d+184|0);S(a|0);L()}function fga(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;v[a+24588>>2]=0;v[a+24592>>2]=0;v[a+8>>2]=49440;v[a+4>>2]=0;v[a>>2]=38432;b=a+24596|0;v[b>>2]=0;v[b+4>>2]=0;Wq(a+24604|0);cP(a+24648|0,0);v[a+397448>>2]=0;v[a+397452>>2]=0;b=a+397456|0;v[b>>2]=8;v[b+4>>2]=0;v[b+16>>2]=0;v[b+20>>2]=0;t[b+12|0]=0;v[b+8>>2]=0;u[b+24>>1]=0;Qb(b+28|0,0,40);Qb(b+68|0,0,49824);Qb(b+49892|0,0,32832);t[a+480224|0]=0;u[a+480212>>1]=0;v[a+480204>>2]=0;v[a+480208>>2]=0;v[a+480180>>2]=0;v[a+480184>>2]=0;b=a+480186|0;u[b>>1]=0;u[b+2>>1]=0;u[b+4>>1]=0;u[b+6>>1]=0;v[a+480240>>2]=65536;v[a+480244>>2]=65536;k=Io(a+480248|0);v[a+480272>>2]=0;b=a+484344|0;c=a+480280|0;a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{while(1){v[22656]=0;c=bP(c);e=v[22656];v[22656]=0;if((e|0)==1){break k}c=c+32|0;if((b|0)!=(c|0)){continue}break}e=a+484344|0;dd(e);v[e+12>>2]=a;v[22656]=0;l=Q(1282,a+484360|0,a|0)|0;b=v[22656];v[22656]=0;if((b|0)==1){break j}b=a+900380|0;c=a+484380|0;while(1){v[22656]=0;c=Q(895,c|0,0)|0;f=v[22656];v[22656]=0;if((f|0)==1){break i}c=c+104|0;if((b|0)!=(c|0)){continue}break}v[22656]=0;T(1283,a+901404|0)|0;b=v[22656];v[22656]=0;if((b|0)==1){break h}c=a+946300|0;f=a+906300|0;b=f;while(1){b=aP(b)+160|0;if((c|0)!=(b|0)){continue}break}v[a+946300>>2]=0;d=a+1074304|0;g=a+946304|0;b=g;while(1){v[22656]=0;b=Uq(b);h=v[22656];v[22656]=0;if((h|0)==1){break g}b=b+32|0;if((d|0)!=(b|0)){continue}break}v[a+1074304>>2]=0;v[a+1074308>>2]=0;sA(a+1074312|0);v[22656]=0;b=ga(1284)|0;d=v[22656];v[22656]=0;if((d|0)==1){break f}v[22656]=0;b=T(1285,b|0)|0;d=v[22656];v[22656]=0;if((d|0)==1){break f}v[a+1074328>>2]=b;v[22656]=0;hO(a+1074332|0);b=v[22656];v[22656]=0;if((b|0)==1){break f}v[22656]=0;T(1287,a+1074376|0)|0;b=v[22656];v[22656]=0;if((b|0)==1){break f}v[22656]=0;d=W(1248,a+1298224|0,a|0,255)|0;b=v[22656];v[22656]=0;if((b|0)==1){break f}h=zh(a+1298260|0);b=gb-16|0;gb=b;v[b+12>>2]=0;i=a+1298264|0;xq(i,b+12|0);gb=b+16|0;m=Kb(a+1298268|0);n=Kb(a+1298280|0);j=a+1298292|0;Kb(j);o=$O(a+1298304|0);p=dd(a+1298368|0);t[a+1298380|0]=0;b=a+1298384|0;v[b>>2]=0;v[b+4>>2]=0;v[b+32>>2]=0;v[b+36>>2]=1072693248;v[b+24>>2]=0;v[b+28>>2]=0;v[b+16>>2]=0;v[b+20>>2]=0;v[b+8>>2]=0;v[b+12>>2]=0;v[a+1298424>>2]=0;Aq(a+12|0);Yo(a+8204|0);v[22656]=0;Yo(a+12300|0);b=v[22656];v[22656]=0;if((b|0)==1){break e}v[a+480216>>2]=4;v[a+480220>>2]=16;b=a+1074408|0;v[b>>2]=4;v[b+4>>2]=16;ZO(a+900380|0);v[22656]=0;qA(g);b=v[22656];v[22656]=0;if((b|0)==1){break e}v[22656]=0;b=T(1290,12)|0;g=v[22656];v[22656]=0;if((g|0)==1){break e}v[b>>2]=0;v[b+4>>2]=0;v[b+8>>2]=0;hh(b);v[a+4>>2]=b;return a|0}b=P()|0;O()|0;break a}b=P()|0;O()|0;break b}b=P()|0;O()|0;break c}b=P()|0;O()|0;break c}b=P()|0;O()|0;break d}b=P()|0;O()|0;break d}b=P()|0;O()|0;rA(p);mu(o);vb(j);vb(n);vb(m);lu(i);ku(h);Eq(d)}while(1){c=Bq(c-160|0);if((f|0)!=(c|0)){continue}break}}Ju(l)}pA(e)}Nc(k);S(b|0);L()}function tO(a,b){var c=0,d=0,e=0,f=0,g=0,h=C(0),i=0,j=0,k=C(0),l=0,m=0,n=0,o=0,p=C(0),q=0,r=0,s=C(0),t=0,w=0,A=C(0),E=0;if(b){wq(a);c=a+24596|0;v[c>>2]=0;v[c+4>>2]=0;v[a+24588>>2]=0;v[a+24592>>2]=0;LO(a)}sO(a+24648|0);t=v[a+24620>>2];g=gb-144|0;gb=g;f=a+397456|0;c=v[f+4>>2];if(c>>>0>=29){v[f+4>>2]=0;c=0}j=B(c,44)+53312|0;if(!(b?0:(j|0)==v[f+8>>2])){v[f+8>>2]=j;s=C(t>>>0);h=s;c=g+8|0;d=v[j+24>>2];v[c>>2]=d;e=v[j+16>>2];v[c+4>>2]=e;v[c+8>>2]=v[j+4>>2];n=(d|0)>(e|0)?d:e;if((n|0)<=-601){m=e;e=n+600|0;v[c+4>>2]=m-e;v[c>>2]=d-e}e=c;k=C(z[j+36>>2]*C(79.30999755859375));a:{if(C(D(k))<C(2147483648)){d=~~k;break a}d=-2147483648}v[e+16>>2]=d- -8192;d=c;k=C(C(C(z[j+32>>2]*C(.0036000001709908247))+C(.15000000596046448))*C(32767));b:{if(C(D(k))<C(2147483648)){e=~~k;break b}e=-2147483648}v[d+20>>2]=(e|0)<32512?e:32512;n=0;k=z[j+8>>2];e=c;p=C(C(F(z[j+20>>2],C(.10000000149011612)))*h);c:{if(C(D(p))<C(2147483648)){d=~~p;break c}d=-2147483648}i=(d|0)<96;o=i?96:d;q=o-7500|0;l=o>>>0<q>>>0?0:q;p=C(z[j+28>>2]*h);d:{if(C(D(p))<C(2147483648)){m=~~p;break d}m=-2147483648}d=l+(m+(i?d-96|0:0)|0)|0;i=(d|0)<128;m=e;e=i?128:d;q=e>>>0<3800?e:3800;v[m+24>>2]=q;l=i?d-128|0:0;m=c;h=C(k*h);e:{if(C(D(h))<C(2147483648)){i=~~h;break e}i=-2147483648}d=e-3800|0;i=(i+l|0)+(d>>>0>e>>>0?0:d)|0;v[m+32>>2]=i;o=o>>>0<7500?o:7500;while(1){d=B(n,12);e=d+c|0;u[e+42>>1]=x[d+54602>>1];u[e+36>>1]=x[d+54596>>1];l=d+54598|0;l=x[l>>1]|x[l+2>>1]<<16;u[e+38>>1]=l;u[e+40>>1]=l>>>16;v[e+44>>2]=o+((B(v[d+54592>>2],q)+50|0)/100|0);n=n+1|0;if((n|0)!=8){continue}break}e=c;h=C(i|0);k=C(oe(C(.0010000000474974513),(i|0)<4721?C(1):C(C(4720)/h))*C(32768));f:{if(C(D(k))<C(2147483648)){d=~~k;break f}d=-2147483648}v[e+12>>2]=d;h=C(z[j+12>>2]*h);w=c,A=oe(C(.0010000000474974513),h<=C(4720)?C(1):C(C(4720)/h)),z[w+28>>2]=A;v[f+20>>2]=v[g+40>>2];c=SL(TL(v[g+16>>2]),s);u[f+86>>1]=c;u[f+84>>1]=c;c=x[g+24>>1]<<1;u[f+94>>1]=c;u[f+92>>1]=c;while(1){c=(r<<4)+f|0;d=(g+8|0)+B(r,12)|0;e=v[d+44>>2];v[c+100>>2]=e;v[c+104>>2]=e;u[c+108>>1]=x[d+36>>1];u[c+110>>1]=x[d+42>>1];u[c+112>>1]=x[d+40>>1];u[c+114>>1]=x[d+38>>1];r=r+1|0;if((r|0)!=8){continue}break}v[f+49892>>2]=v[g+32>>2];c=f;d=v[g+12>>2];if((d|0)>-9e3){e=RL(d)}else{e=0}v[c+80>>2]=e;e=f+49948|0;c=v[g+8>>2];if((c|0)>=-8999){c=RL(c)}else{c=0}v[e>>2]=c;c=v[g+28>>2];d=f+49932|0;v[d>>2]=268464128;v[d+4>>2]=1879052288;c=c>>>0<32512?c:32512;u[f+49906>>1]=c;u[f+49904>>1]=c;u[f+49902>>1]=c;u[f+49900>>1]=c;v[g+4>>2]=v[g+20>>2];Zd(g+4|0,0,32752);c=x[g+4>>1];u[f+49914>>1]=c;d=f+49910|0;u[d>>1]=0;u[d+2>>1]=0;u[f+49908>>1]=c;h=z[g+36>>2];w=g,E=SL(C(h*h),s),v[w>>2]=E;Zd(g,256,32512);c=x[g>>1];u[f+49922>>1]=c;d=f+49918|0;u[d>>1]=0;u[d+2>>1]=0;u[f+49916>>1]=c}c=a+397448|0;d=a+397452|0;if(b){v[f+16>>2]=0;VL(f,c,d)}b=B(t,5);if(b>>>0>y[f+20>>2]){v[f+20>>2]=b}gb=g+144|0;b=a+1298260|0;if(Dd(b)){TR(v[b>>2],v[a+24620>>2])}}function Gfa(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0;a=gb-144|0;gb=a;a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{t:{u:{v:{w:{x:{y:{z:{A:{B:{C:{D:{E:{if((c|0)<=5){Bz(a+96|0,c);v[22656]=0;c=Q(2,a+80|0,14864)|0;d=v[22656];v[22656]=0;if((d|0)==1){break E}v[22656]=0;U(3,a+112|0,a+96|0,c|0);d=v[22656];v[22656]=0;if((d|0)==1){break D}v[22656]=0;d=Q(4,a+48|0,e|0)|0;e=v[22656];v[22656]=0;if((e|0)==1){break C}v[22656]=0;e=Q(2,a+32|0,16669)|0;f=v[22656];v[22656]=0;if((f|0)==1){break B}v[22656]=0;U(5,a- -64|0,d|0,e|0);f=v[22656];v[22656]=0;if((f|0)==1){break A}v[22656]=0;U(3,a+128|0,a+112|0,a- -64|0);f=v[22656];v[22656]=0;if((f|0)==1){break z}vb(a- -64|0);vb(e);vb(d);d=a+112|0;vb(d);vb(c);vb(a+96|0);c=v[b>>2];v[22656]=0;U(6,d|0,1,(c?c:18726)|0);c=v[22656];v[22656]=0;if((c|0)==1){break t}c=v[b+4>>2];v[22656]=0;U(6,a+96|0,1,(c?c:18726)|0);c=v[22656];v[22656]=0;if((c|0)==1){break s}b=v[b+8>>2];v[22656]=0;v[a+64>>2]=b;R(7,a+80|0,a- -64|0);b=v[22656];v[22656]=0;if((b|0)==1){break r}v[22656]=0;b=Q(8,463448,14743)|0;c=v[22656];v[22656]=0;if((c|0)==1){break q}v[22656]=0;U(9,a- -64|0,0,a+112|0);c=v[22656];v[22656]=0;if((c|0)==1){break p}v[22656]=0;b=Q(10,b|0,a- -64|0)|0;c=v[22656];v[22656]=0;if((c|0)==1){break o}v[22656]=0;b=Q(8,b|0,14517)|0;c=v[22656];v[22656]=0;if((c|0)==1){break o}v[22656]=0;U(9,a+32|0,0,a+80|0);c=v[22656];v[22656]=0;if((c|0)==1){break n}v[22656]=0;b=Q(10,b|0,a+32|0)|0;c=v[22656];v[22656]=0;if((c|0)==1){break m}v[22656]=0;b=Q(8,b|0,14514)|0;c=v[22656];v[22656]=0;if((c|0)==1){break m}v[22656]=0;b=Q(8,b|0,14864)|0;c=v[22656];v[22656]=0;if((c|0)==1){break m}v[22656]=0;U(9,a+16|0,0,a+128|0);c=v[22656];v[22656]=0;if((c|0)==1){break l}v[22656]=0;b=Q(10,b|0,a+16|0)|0;c=v[22656];v[22656]=0;if((c|0)==1){break k}v[22656]=0;b=Q(8,b|0,10777)|0;c=v[22656];v[22656]=0;if((c|0)==1){break k}v[22656]=0;U(9,a|0,0,a+96|0);c=v[22656];v[22656]=0;if((c|0)==1){break j}v[22656]=0;b=Q(10,b|0,a|0)|0;c=v[22656];v[22656]=0;if((c|0)==1){break i}v[22656]=0;b=Q(8,b|0,10775)|0;c=v[22656];v[22656]=0;if((c|0)==1){break i}v[22656]=0;Q(11,b|0,12)|0;b=v[22656];v[22656]=0;if((b|0)==1){break i}vb(a);vb(a+16|0);vb(a+32|0);vb(a- -64|0);vb(a+80|0);vb(a+96|0);vb(a+112|0);vb(a+128|0)}gb=a+144|0;return}b=P()|0;O()|0;break u}b=P()|0;O()|0;break v}b=P()|0;O()|0;break w}b=P()|0;O()|0;break x}b=P()|0;O()|0;break y}b=P()|0;O()|0;vb(a- -64|0)}vb(e)}vb(d)}vb(a+112|0)}vb(c)}vb(a+96|0);break a}b=P()|0;O()|0;break b}b=P()|0;O()|0;break c}b=P()|0;O()|0;break d}b=P()|0;O()|0;break e}b=P()|0;O()|0;break e}b=P()|0;O()|0;break f}b=P()|0;O()|0;break f}b=P()|0;O()|0;break g}b=P()|0;O()|0;break g}b=P()|0;O()|0;break h}b=P()|0;O()|0;break h}b=P()|0;O()|0;vb(a)}vb(a+16|0)}vb(a+32|0)}vb(a- -64|0)}vb(a+80|0)}vb(a+96|0)}vb(a+112|0)}vb(a+128|0)}S(b|0);L()}function t_(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;e=gb-32|0;gb=e;v[e+28>>2]=b;a:{b:{if((d|0)<=0){a=0}else{v[e+8>>2]=d;v[e+16>>2]=214748364;r=e,s=B(v[Fb(e+28|0,e+16|0)>>2],20),v[r+20>>2]=s;Nt(c,v[Fb(e+8|0,e+20|0)>>2]);v[e+8>>2]=a;v[e+12>>2]=v[e+28>>2];a=0;while(1){c:{b=e+8|0;f=lh(b,a);i=lh(b,a+4|0);o=lh(b,a+5|0);r=e,s=lh(b,a+6|0)<<8|lh(b,a+7|0),v[r+24>>2]=s;b=o|i<<8;p=a+8|0;d:{e:{switch(f|0){case 0:f:{if((b|0)<=(d|0)){i=0;o=0;if(b){break f}break d}a=ba(8)|0;v[22656]=0;T(283,a|0)|0;b=v[22656];v[22656]=0;if((b|0)!=1){break a}break b}while(1){r=e,s=lh(e+8|0,i+p|0),t[r+20|0]=s;kq(c,e+20|0);i=i+1|0;if((b|0)!=(i|0)){continue}break};i=b;o=b;break d;case 1:break e;default:break c}}dk(e+24|0,d);i=v[e+24>>2];m=lh(e+8|0,a+10|0);t[e+20|0]=m;kq(c,e+20|0);f=v[e+24>>2];v[e+24>>2]=f-1;o=b+3&65532;if((f|0)<2){break d}h=a+11|0;k=0;n=0;j=0;b=0;while(1){a=qg(h,b,1,e+8|0);g:{h:{i:{j:{k:{if((j|0)<=7){if(a){f=b;break h}b=b+1|0;k=8;break k}f=b+1|0;l:{if(!a){if(!qg(h,f,1,e+8|0)){break h}f=2;m:{n:{a=b+2|0;if(!qg(h,a,1,e+8|0)){break n}f=3;a=b+3|0;if(!qg(h,a,1,e+8|0)){break n}f=qg(h,a,3,e+8|0);b=b+6|0;break m}b=a+1|0}a=4;f=((k<<3)+f|0)-17|0;if((f|0)<0){a=ba(8)|0;v[22656]=0;T(283,a|0)|0;b=v[22656];v[22656]=0;if((b|0)!=1){break a}break b}if(f>>>0>=56){a=ba(8)|0;v[22656]=0;T(283,a|0)|0;b=v[22656];v[22656]=0;if((b|0)!=1){break a}break b}k=w[f+28336|0];if((k|0)!=8){break j}break l}a=4;b=f;if((k|0)!=8){break j}}k=8;a=1;if((n|0)>19){break j}}a=0;break i}n=n+8|0}g=v[e+24>>2];o:{if((g|0)<=0){break o}while(1){f=e+8|0;l=(b|0)/8|0;g=l+h|0;q=lh(f,g);m=m-((lh(f,g+1|0)<<8|q<<16|lh(f,g+2|0))<<(b-(l<<3)|0)+8>>32-k)|0;t[e+20|0]=m;kq(c,e+20|0);f=v[e+24>>2];g=f-1|0;v[e+24>>2]=g;b=b+k|0;if(!a){break o}a=a-1|0;if((f|0)>1){continue}break}}j=(j|0)==31?31:j+1|0;break g}p:{q:{r:{a=f+1|0;if(!qg(h,a,1,e+8|0)){f=2;break r}a=f+2|0;if(!qg(h,a,1,e+8|0)){f=4;break r}a=f+3|0;if(!qg(h,a,1,e+8|0)){f=6;break r}a=f+5|0;if(!qg(h,f+4|0,1,e+8|0)){b=f+8|0;a=qg(h,a,3,e+8|0)+8|0;break p}b=f+10|0;f=16;a=qg(h,a,5,e+8|0);break q}b=a+2|0;a=qg(h,a+1|0,1,e+8|0)}a=a+f|0}s:{if(qg(h,b,1,e+8|0)){f=-256;g=12;break s}b=b+1|0;g=qg(h,b,1,e+8|0);f=g?-4352:0;g=g?14:8}b=b+1|0;l=qg(h,b,g,e+8|0);if((a|0)>=3){j=j-((a|0)!=3)|0;j=((j|0)>1?j:1)-1|0}f=oc(c)+((l^-1)+f|0)|0;if(f>>>0<oc(c)>>>0){b=b+g|0;g=v[e+24>>2];if((a|0)<=0|(g|0)<=0){break g}while(1){m=w[lc(c,f)|0];t[e+20|0]=m;kq(c,e+20|0);l=v[e+24>>2];g=l-1|0;v[e+24>>2]=g;if(a>>>0<2){break g}f=f+1|0;a=a-1|0;if((l|0)>1){continue}break}break g}a=ba(8)|0;v[22656]=0;T(283,a|0)|0;b=v[22656];v[22656]=0;if((b|0)==1){break b}break a}n=n-(n>>3)|0;if((g|0)>0){continue}break}}a=o+p|0;d=d-i|0;if((d|0)>0){continue}}break}a=cd(c)^1}gb=e+32|0;return a|0}b=P()|0;O()|0;ca(a|0);S(b|0);L()}ia(a|0,28304,206);L()}function an(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;d=gb-96|0;gb=d;g=mc(a);v[22656]=0;e=T(426,b|0)|0;a=v[22656];v[22656]=0;a:{b:{c:{d:{e:{if((a|0)==1){break e}v[22656]=0;a=Q(191,b|0,e|0)|0;f=v[22656];v[22656]=0;if((f|0)==1){break e}if(a){break d}v[22656]=0;a=T(467,b|0)|0;f=v[22656];v[22656]=0;if((f|0)==1){break e}v[22656]=0;Q(318,b|0,a|0)|0;a=v[22656];v[22656]=0;if((a|0)!=1){break c}}a=P()|0;O()|0;break a}v[22656]=0;U(288,d+48|0,b|0,e|0);b=v[22656];v[22656]=0;a=d;f:{g:{h:{i:{if((b|0)!=1){b=d+48|0;f=kc(d+72|0,b);xb(b);if(e>>>0<10){break g}v[22656]=0;b=T(930,f|0)|0;c=v[22656];v[22656]=0;if((c|0)==1){break b}if(!b){break g}v[22656]=0;b=T(426,f|0)|0;c=v[22656];v[22656]=0;if((c|0)==1){break b}v[d+44>>2]=b;v[d+40>>2]=e-10;b=v[d+40>>2];if(b>>>0>25264513){break i}b=B(b,170);break h}a=P()|0;O()|0;break a}b=-1}v[a+40>>2]=b;qc(d+44|0,b);v[22656]=0;R(440,g|0,v[d+44>>2]);a=v[22656];v[22656]=0;if((a|0)==1){break b}e=v[d+44>>2];b=0;while(1){j:{v[22656]=0;a=T(931,f|0)|0;c=v[22656];v[22656]=0;k:{l:{m:{n:{if((c|0)!=1){if(a){break j}v[22656]=0;a=T(707,f|0)|0;c=v[22656];v[22656]=0;if((c|0)==1){break b}switch(a|0){case 3:break k;case 2:break l;case 1:break m;case 0:break n;default:break j}}break b}v[22656]=0;a=T(374,f|0)|0;c=v[22656];v[22656]=0;if((c|0)==1){break b}if(a>>>0>e>>>0){break j}v[22656]=0;c=Q(191,f|0,a|0)|0;h=v[22656];v[22656]=0;if((h|0)==1){break b}if(!c){break j}v[22656]=0;Vd(d+48|0,g);c=v[22656];v[22656]=0;if((c|0)==1){break b}v[22656]=0;Y(932,d+24|0,d+48|0,b|0,a|0);c=v[22656];v[22656]=0;if((c|0)==1){break b}v[22656]=0;c=v[d+28>>2];v[d+8>>2]=v[d+24>>2];v[d+12>>2]=c;U(633,d+16|0,f|0,d+8|0);c=v[22656];v[22656]=0;if((c|0)!=1){e=e-a|0;b=a+b|0;continue}break b}v[22656]=0;a=T(374,f|0)|0;c=v[22656];v[22656]=0;if((c|0)==1){break b}c=a<<2;if(c>>>0>e>>>0){break j}v[22656]=0;h=Q(933,f|0,d+32|0)|0;i=v[22656];v[22656]=0;if((i|0)==1){break b}if(!h){break j}e=e-c|0;if(!a){continue}while(1){c=d+32|0;h=fc(c);j=d,k=Vb(g),v[j+48>>2]=k;Wu(c,h,we(d+48|0,b));b=b+4|0;a=a-1|0;if(a&255){continue}break}continue}if(e>>>0<8){break j}v[22656]=0;a=Q(933,f|0,d+32|0)|0;c=v[22656];v[22656]=0;if((c|0)==1){break b}if(!a){break j}a=d+32|0;c=fc(a);j=d,k=Vb(g),v[j+48>>2]=k;i=c;c=d+48|0;Wu(a,i,we(c,b));h=fc(a);j=d,k=Vb(g),v[j+16>>2]=k;j=d,k=we(d+16|0,b),v[j+48>>2]=k;Wu(a,h,we(c,4));e=e-8|0;b=b+8|0;continue}v[22656]=0;a=T(374,f|0)|0;c=v[22656];v[22656]=0;if((c|0)==1){break b}if(a>>>0>e>>>0){break j}e=e-a|0;b=a+b|0;continue}break}if(!e){break f}a=mc(d+48|0);xc(a,g);xc(a+4|0,g+4|0);xc(wb(a),wb(g));wb(a);wb(g);gc(a);break f}v[22656]=0;W(506,f|0,g|0,e|0)|0;a=v[22656];v[22656]=0;if((a|0)==1){break b}}xb(f)}gb=d+96|0;return}a=P()|0;O()|0;xb(f)}gc(g);S(a|0);L()}function Cka(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=gb-96|0;gb=d;a:{b:{c:{d:{if(w[a|0]==23){e=t[a+1|0];f=d,g=FA(c,+w[a+2|0]*1e4/240),t[f+8|0]=g;v[d+80>>2]=127;v[d+64>>2]=(B(w[a+3|0],127)>>>0)/185;f=d,g=v[pd(d+80|0,d- -64|0)>>2],t[f+95|0]=g;e:{switch(((e>>>0)%5|0)-1|0){case 0:Df(d- -64|0,12700);v[22656]=0;R(737,d+48|0,d+8|0);a=v[22656];v[22656]=0;f:{g:{h:{i:{j:{k:{if((a|0)!=1){v[22656]=0;R(737,d+32|0,d+95|0);a=v[22656];v[22656]=0;if((a|0)==1){break k}v[22656]=0;Y(738,d+80|0,d- -64|0,d+48|0,d+32|0);a=v[22656];v[22656]=0;if((a|0)==1){break j}v[22656]=0;R(444,d+16|0,b|0);a=v[22656];v[22656]=0;if((a|0)==1){break i}v[22656]=0;Q(401,d+16|0,d+80|0)|0;a=v[22656];v[22656]=0;if((a|0)==1){break i}vb(d+80|0);vb(d+32|0);vb(d+48|0);Hb(d- -64|0);break b}b=P()|0;O()|0;break f}b=P()|0;O()|0;break g}b=P()|0;O()|0;break h}b=P()|0;O()|0;vb(d+80|0)}vb(d+32|0)}vb(d+48|0)}Hb(d- -64|0);break c;case 1:Df(d- -64|0,12640);v[22656]=0;R(737,d+48|0,d+8|0);a=v[22656];v[22656]=0;l:{m:{n:{o:{p:{q:{if((a|0)!=1){v[22656]=0;R(737,d+32|0,d+95|0);a=v[22656];v[22656]=0;if((a|0)==1){break q}v[22656]=0;Y(738,d+80|0,d- -64|0,d+48|0,d+32|0);a=v[22656];v[22656]=0;if((a|0)==1){break p}v[22656]=0;R(444,d+16|0,b|0);a=v[22656];v[22656]=0;if((a|0)==1){break o}v[22656]=0;Q(401,d+16|0,d+80|0)|0;a=v[22656];v[22656]=0;if((a|0)==1){break o}vb(d+80|0);vb(d+32|0);vb(d+48|0);Hb(d- -64|0);break b}b=P()|0;O()|0;break l}b=P()|0;O()|0;break m}b=P()|0;O()|0;break n}b=P()|0;O()|0;vb(d+80|0)}vb(d+32|0)}vb(d+48|0)}Hb(d- -64|0);break c;default:break e}}a=Tb(d+80|0,12727);v[22656]=0;R(444,d- -64|0,b|0);b=v[22656];v[22656]=0;if((b|0)==1){break d}v[22656]=0;Q(401,d- -64|0,a|0)|0;b=v[22656];v[22656]=0;if((b|0)==1){break d}vb(a);break b}if(w[a|0]==24){t[d+95|0]=t[a+1|0]<=4?w[a+1|0]:0;t[d+31|0]=t[a+2|0]>=0?w[a+2|0]:127;t[d+30|0]=t[a+3|0]>=0?w[a+3|0]:127;a=gb-16|0;gb=a;c=Tb(a,1157);Dc(d- -64|0,c);vb(c);gb=a+16|0;v[22656]=0;R(737,d+48|0,d+95|0);a=v[22656];v[22656]=0;r:{s:{t:{u:{v:{w:{x:{y:{if((a|0)!=1){v[22656]=0;R(737,d+32|0,d+31|0);a=v[22656];v[22656]=0;if((a|0)==1){break y}v[22656]=0;R(737,d+16|0,d+30|0);a=v[22656];v[22656]=0;if((a|0)==1){break x}v[22656]=0;ha(937,d+80|0,d- -64|0,d+48|0,d+32|0,d+16|0);a=v[22656];v[22656]=0;if((a|0)==1){break w}v[22656]=0;R(444,d+8|0,b|0);a=v[22656];v[22656]=0;if((a|0)==1){break v}v[22656]=0;Q(401,d+8|0,d+80|0)|0;a=v[22656];v[22656]=0;if((a|0)==1){break v}vb(d+80|0);vb(d+16|0);vb(d+32|0);vb(d+48|0);Hb(d- -64|0);break b}b=P()|0;O()|0;break r}b=P()|0;O()|0;break s}b=P()|0;O()|0;break t}b=P()|0;O()|0;break u}b=P()|0;O()|0;vb(d+80|0)}vb(d+16|0)}vb(d+32|0)}vb(d+48|0)}Hb(d- -64|0);break c}a=0;break a}b=P()|0;O()|0;vb(a)}S(b|0);L()}a=1}gb=d+96|0;return a|0}function Uy(a){var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;e=gb-96|0;gb=e;a:{b:{c:{if(j=1,k=nd(a,11),l=v[a+4>>2],l?j:k){g=v[a+28>>2];b=e;d=v[a+12>>2];f=v[a+64>>2];c=f+v[a+8>>2]|0;d=sh(b+80|0,c,c>>>0<f>>>0?d+1|0:d);c=v[d+12>>2];v[b+32>>2]=v[d+8>>2];v[b+36>>2]=c;b=v[d+4>>2];v[e+24>>2]=v[d>>2];v[e+28>>2]=b;lk(g,e+24|0);b=v[a+28>>2];if(Fl(v[v[b>>2]-12>>2]+b|0)){uh(a,1073741826);break a}d=v[a+92>>2];g=a+44|0;b=g;c=uf(b);d:{if(d>>>0>c>>>0){f=gb-32|0;gb=f;e:{c=d-c|0;f:{if(c>>>0<=v[wb(b)>>2]-v[b+4>>2]>>4>>>0){h=gb-16|0;gb=h;c=cq(h,b,c);d=v[c+4>>2];i=v[c+8>>2];if((d|0)!=(i|0)){while(1){wb(b);iI(d);d=d+16|0;v[c+4>>2]=d;if((d|0)!=(i|0)){continue}break}}$b(c);gb=h+16|0;break f}d=wb(b);d=WI(f+8|0,fy(b,uf(b)+c|0),uf(b),d);v[22656]=0;SI(d,c);c=v[22656];v[22656]=0;if((c|0)==1){break e}Zx(b);wb(b);c=d+4|0;ml(v[b>>2],v[b+4>>2],c);wc(b,c);wc(b+4|0,d+8|0);wc(wb(b),dc(d));v[d>>2]=v[d+4>>2];rI(b,uf(b));OI(d)}gb=f+32|0;break d}a=P()|0;O()|0;OI(d);S(a|0);L()}if(c>>>0>d>>>0){d=v[b>>2]+(d<<4)|0;uf(b);LI(b,d);xi(b);uf(b)}}h=a+32|0;Nt(h,v[a+92>>2]<<2);if(v[a+92>>2]){c=0;while(1){b=v[a+28>>2];if(Fl(v[v[b>>2]-12>>2]+b|0)){uh(a,1073741828);break a}b=x[a+16>>1];u[e+78>>1]=b;if((b|0)==65535){Vy(v[a+28>>2],e+78|0);b=x[e+78>>1]}f=oc(h);v[e+72>>2]=f;g:{if(!b){break g}d=b;f=v[e+72>>2];if(b>>>0>-1-f>>>0){break g}Ty(h,d+f|0);ll(v[a+28>>2],lc(h,v[e+72>>2]),d);f=v[e+72>>2]}j=Tc(g,c),k=b,u[j+12>>1]=k;j=Tc(g,c),k=f,v[j>>2]=k;if(nd(a,6)){zl(v[a+28>>2],e+56|0);if(y[e+60>>2]>2147483647){break c}j=Tc(g,c),k=v[e+56>>2],v[j+4>>2]=k}b=v[a+4>>2];h:{if(b){j=Tc(g,c),k=b,v[j+8>>2]=k;break h}if(!nd(a,7)){break h}zl(v[a+28>>2],e+56|0);if(y[e+60>>2]>2147483647){break b}j=Tc(g,c),k=v[e+56>>2],v[j+8>>2]=k}i:{if(v[Tc(g,c)+8>>2]==-1){break i}if(nd(a,6)){break i}if(c){b=Tc(g,c-1|0);b=v[b+8>>2]+v[b+4>>2]|0}else{b=0}j=Tc(g,c),k=b,v[j+4>>2]=k}if(nd(a,8)){u[e+56>>1]=0;Vy(v[a+28>>2],e+56|0);b=nd(a,9);zm(v[a+28>>2],x[e+56>>1]<<b,-1)}c=c+1|0;if(c>>>0<y[a+92>>2]){continue}break}}se(e+56|0,v[a+28>>2]);b=v[e+68>>2];v[a+72>>2]=v[e+64>>2];v[a+76>>2]=b}Al(a,4,1);g=v[a+76>>2];f=v[a+88>>2];c=f+v[a+8>>2]|0;d=v[a+12>>2];d=c>>>0<f>>>0?d+1|0:d;b=c;c=(f|0)==v[a+64>>2];f=c?v[a+72>>2]:b;v[a+80>>2]=f;b=c?g:d;v[a+84>>2]=b;d=v[a+28>>2];b=sh(e+40|0,f,b);c=v[b+12>>2];v[e+16>>2]=v[b+8>>2];v[e+20>>2]=c;c=v[b+4>>2];v[e+8>>2]=v[b>>2];v[e+12>>2]=c;lk(d,e+8|0);if(nd(a,6)){break a}if(!(j=1,k=nd(a,7),l=v[a+4>>2],l?j:k)){break a}b=v[a+92>>2];if(!b){break a}d=a+44|0;c=v[a+80>>2];a=v[a+8>>2];c=c-a|0;a=0;while(1){g=Tc(d,a);v[g+4>>2]=c+v[g+4>>2];a=a+1|0;if((b|0)!=(a|0)){continue}break}break a}uh(a,1073741829);break a}uh(a,1073741829)}gb=e+96|0}function Gea(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;c=gb-48|0;gb=c;if(hi(b)){h=Ji(b);j=v[b+12>>2];f=c+32|0;e=Ig(f);a:{d=h;if(!d){break a}v[22656]=0;R(617,f|0,d|0);g=v[22656];v[22656]=0;if((g|0)!=1){v[22656]=0;FN(f,d);d=v[22656];v[22656]=0;if((d|0)!=1){break a}}a=P()|0;O()|0;zv(e);S(a|0);L()}b:{if(!j){break b}while(1){d=v[v[a>>2]-12>>2];v[22656]=0;d=_f(a+d|0);e=v[22656];v[22656]=0;c:{if((e|0)!=1){d:{if(!d){break b}v[22656]=0;t[c+31|0]=0;Q(1483,a|0,c+31|0)|0;d=v[22656];v[22656]=0;e:{if((d|0)!=1){d=t[c+31|0];if(d){break e}i=i+1|0;break c}break d}t[c+30|0]=0;f:{if((d|0)>=0){break f}v[22656]=0;Q(1483,a|0,c+30|0)|0;e=v[22656];v[22656]=0;if((e|0)!=1){break f}break d}t[c+29|0]=0;gi(c+16|0);g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{t:{u:{v:{w:{x:{y:{z:{A:{d=d&127;d=(d?d-1|0:0)&65535;k=d>>>0>=h>>>0;B:{C:{if(!k){v[22656]=0;g=Yc(b,i,d);e=v[22656];v[22656]=0;if((e|0)==1){break d}if(t[c+30|0]&1){break C}break z}g=c+16|0;e=w[c+30|0];if(!(e&1)){break B}}v[22656]=0;Q(1483,a|0,c+29|0)|0;e=v[22656];v[22656]=0;if((e|0)==1){break d}if(d>>>0<h>>>0){break A}e=w[c+30|0]}if(e&2){break y}break x}e=w[c+29|0];l=ad(f,d),m=e,t[l|0]=m}l=g,m=w[ad(f,d)|0],t[l|0]=m;if(!(w[c+30|0]&2)){break v}}v[22656]=0;Q(1483,a|0,c+29|0)|0;e=v[22656];v[22656]=0;if((e|0)==1){break d}if(d>>>0<h>>>0){break w}e=w[c+30|0]}if(e&4){break u}break t}e=w[c+29|0];l=ad(f,d),m=e,t[l+1|0]=m}l=g,m=w[ad(f,d)+1|0],t[l+1|0]=m;if(!(w[c+30|0]&4)){break r}}v[22656]=0;Q(1483,a|0,c+29|0)|0;e=v[22656];v[22656]=0;if((e|0)==1){break d}if(d>>>0<h>>>0){break s}e=w[c+30|0]}if(e&8){break q}break p}e=w[c+29|0];l=ad(f,d),m=e,t[l+2|0]=m}l=g,m=w[ad(f,d)+2|0],t[l+2|0]=m;if(!(w[c+30|0]&8)){break n}}v[22656]=0;Q(1483,a|0,c+29|0)|0;e=v[22656];v[22656]=0;if((e|0)==1){break d}if(d>>>0<h>>>0){break o}e=w[c+30|0]}if(e&16){break m}break l}e=w[c+29|0];l=ad(f,d),m=e,t[l+4|0]=m}l=g,m=w[ad(f,d)+4|0],t[l+4|0]=m;if(!(w[c+30|0]&16)){break j}}v[22656]=0;Q(1483,a|0,c+29|0)|0;e=v[22656];v[22656]=0;if((e|0)==1){break d}if(d>>>0<h>>>0){break k}e=w[c+30|0]}if(e&32){break i}break g}e=w[c+29|0];l=ad(f,d),m=e,t[l+3|0]=m}l=g,m=w[ad(f,d)+3|0],t[l+3|0]=m;if(!(w[c+30|0]&32)){break h}}v[22656]=0;Q(1483,a|0,c+29|0)|0;e=v[22656];v[22656]=0;if((e|0)==1){break d}if(k){break g}e=w[c+29|0];l=ad(f,d),m=e,t[l+5|0]=m}l=g,m=w[ad(f,d)+5|0],t[l+5|0]=m}if(!(w[c+30|0]&64)){break c}v[22656]=0;Q(1483,a|0,c+15|0)|0;d=v[22656];v[22656]=0;if((d|0)!=1){d=w[c+15|0];v[22656]=0;W(1484,a|0,d|0,-1)|0;d=v[22656];v[22656]=0;if((d|0)!=1){break c}}}}a=P()|0;O()|0;jn(f);S(a|0);L()}if(i>>>0<j>>>0){continue}break}}jn(f)}gb=c+48|0}function cna(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0;f=gb-16|0;gb=f;a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{t:{u:{v:{w:{x:{y:{z:{g=w[a+3|0];switch(g-4|0){case 23:break j;case 22:break k;case 21:break l;case 20:break m;case 18:break n;case 17:break o;case 16:break p;case 14:break q;case 13:break r;case 12:break s;case 11:break t;case 10:break u;case 9:break v;case 8:break w;case 5:break x;case 4:break y;case 0:break z;case 42:break c;case 37:break d;case 28:break e;case 27:break f;case 26:break g;case 25:break h;case 24:break i;default:break b}}t[a+3|0]=5;t[f+15|0]=w[a+5|0]>>>3;t[f+14|0]=15;b=w[ac(f+15|0,f+14|0)|0];t[f+13|0]=w[a+5|0]<<1&30;t[f+12|0]=15;h=a,i=w[ac(f+13|0,f+12|0)|0]|b<<4,t[h+5|0]=i;break a}t[a+3|0]=0;break a}if((w[a+5|0]-1&255)>>>0<=19){t[a+3|0]=16;break a}t[a+3|0]=0;break a}t[a+3|0]=13;b=w[a+5|0];A:{if(!e){if(b>>>0>152){break A}t[a+5|0]=B((b&240)>>>4|0,10)+(b&15);break a}t[a+5|0]=(b&127)+1>>>1;break a}t[a+3|0]=0;break a}t[a+3|0]=11;break a}t[a+3|0]=0;break a}e=w[a+5|0];if(!e){t[a+3|0]=14;break a}if(e>>>0<=240){t[a+3|0]=17;if(e>>>0<=2){t[a+5|0]=112;break a}h=a,i=gn(+(cW(e,b,c,d)>>>0)/1e4),t[h+5|0]=i;break a}t[a+3|0]=0;break a}t[a+3|0]=31;t[a+5|0]=w[a+5|0]|128;break a}t[a+3|0]=19;t[f+11|0]=15;h=a,i=w[ac(a+5|0,f+11|0)|0]|16,t[h+5|0]=i;break a}t[a+3|0]=19;t[f+10|0]=15;h=a,i=w[ac(a+5|0,f+10|0)|0]|32,t[h+5|0]=i;break a}t[a+3|0]=5;t[f+9|0]=(w[a+5|0]>>>4|0)+1;t[f+8|0]=15;b=ac(f+9|0,f+8|0);t[a+5|0]=w[a+5|0]&15|w[b|0]<<4;break a}t[a+3|0]=19;t[a+5|0]=w[a+5|0]&15|80;break a}t[a+3|0]=19;t[f+7|0]=15;h=a,i=w[ac(a+5|0,f+7|0)|0]|96,t[h+5|0]=i;break a}t[a+3|0]=19;t[f+6|0]=15;h=a,i=w[ac(a+5|0,f+6|0)|0]|192,t[h+5|0]=i;break a}t[a+3|0]=10;break a}t[a+3|0]=19;t[f+5|0]=15;h=a,i=w[ac(a+5|0,f+5|0)|0]|160,t[h+5|0]=i;break a}t[a+3|0]=19;t[f+4|0]=15;h=a,i=w[ac(a+5|0,f+4|0)|0]|176,t[h+5|0]=i;break a}b=(w[a+5|0]<<24)-16777216>>24;if((b|0)>=0){t[a+5|0]=b;t[a+3|0]=31;break a}t[a+3|0]=0;break a}t[a+3|0]=14;break a}t[a+3|0]=19;t[f+3|0]=15;h=a,i=w[ac(a+5|0,f+3|0)|0]|224,t[h+5|0]=i;break a}b=w[a+5|0];if(b&240){t[a+3|0]=19;t[a+5|0]=b>>>4|208;break a}if(b&15){t[a+3|0]=19;t[a+5|0]=b|144;break a}t[a+3|0]=0;break a}if(!(w[a+5|0]|w[a+4|0])){t[a+5|0]=159;t[a+3|0]=20;break a}t[a+3|0]=0;break a}b=w[a+4|0];if(b){t[a+3|0]=44;h=a,i=Bn(Qc(((w[a+5|0]<<8&65280)>>>0)/(b>>>0)|0,0)),t[h+5|0]=i;break a}t[a+3|0]=0;break a}b=w[a+5|0];if((b-17&255)>>>0>=223){t[a+3|0]=9;h=a,i=Xi(((b^128)<<3)-896|0),t[h+5|0]=i;break a}t[a+3|0]=0;break a}if(g>>>0<=15){Of(a);break a}t[a+3|0]=0}gb=f+16|0}function lga(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,u=0,y=0,z=0,A=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0;f=gb-32|0;gb=f;r=a+4|0;p=v[r>>2];m=a+20|0;A=v[ye(m,b)>>2];a:{if(A+1>>>0<2){break a}h=(B(b,872)+p|0)+616|0;if(!Mi(h)){if(!w[ye(m,b)+4|0]){break a}}i=B(b,872)+p|0;if(!v[i+720>>2]){break a}j=v[i+704>>2]&2;g=v[(j?i+700|0:i+692|0)>>2];s=v[i+700>>2];u=v[i+696>>2];Db(f,v[a>>2]+1074312|0,31);D=Cb(f);E=i+1362|0;k=w[E|0];F=i+624|0;e=Fw(F,c);y=jb;n=y;v[f+24>>2]=e;v[f+28>>2]=n;if(w[i+704|0]&128){v[f+24>>2]=0-e;v[f+28>>2]=0-(((e|0)!=0)+n|0)}e=0;H=e;n=g;G=j?e:0;e=u;q=j?e:0;l=s-e|0;s=l<<1;e=B(b,872)+p|0;y=e+1316|0;o=e+1467|0;u=(k&17)!=1;b:{while(1){c:{if(d>>>0>z>>>0){g=(w[E|0]&17)==1;break c}t[o|0]=w[o|0]&254;k=Yc(_b(v[a>>2]+484344|0,x[v[r>>2]+70>>1]),v[v[r>>2]+48>>2],b);j=w[k+3|0];if(w[k+2|0]==11){DA(f,v[a>>2],k,0);e=Ve(f);Bo(v[a>>2],h,x[f>>1]);g=1;if(w[e|0]){break c}}g=1;d:{switch(j-4|0){case 0:Bo(v[a>>2],h,w[k+5|0]);break c;case 2:break d;default:break c}}Bo(v[a>>2],h,0)}v[f+20>>2]=v[y>>2];if(D){du(v[a>>2],h)}if(!u){oO(v[a>>2],h,f+20|0);g=1}if(!D){du(v[a>>2],h)}v[f+16>>2]=0;qO(h,f+16|0);e:{f:{if(w[i+705|0]&2){break f}g:{if(!g){if(!w[ye(m,b)+4|0]){break g}}if(w[o|0]&48){HS(h,C(1),0,v[a>>2]);e=w[o|0];t[o|0]=(e&32?-33:-17)&e}Xz(f,v[a>>2],h,v[f+20>>2],0);g=v[f+4>>2];e=F;v[e>>2]=v[f>>2];v[e+4>>2]=g;I=ye(m,b),J=0,t[I+4|0]=J;e=Fw(e,c);j=jb;g=j;v[f+24>>2]=e;v[f+28>>2]=g;if(!(w[i+704|0]&128)){break g}v[f+24>>2]=0-e;v[f+28>>2]=0-(((e|0)!=0)+g|0)}Ub(h,f+24|0);k=v[h>>2];e=v[h+4>>2];if(k>>>0<H>>>0&(e|0)<=(n|0)|(e|0)<(n|0)){if((e|0)>=(q|0)&k>>>0>=G>>>0|(e|0)>(q|0)){break f}g=v[f+28>>2];if((g|0)>0|(g|0)>=0){break f}}g=v[i+704>>2];if(!(g&2)){break e}if(g&4){if(k>>>0<G>>>0&(e|0)<=(q|0)|(e|0)<(q|0)){g=v[i+696>>2]<<1;v[f>>2]=0;v[f+4>>2]=g;I=h,J=bg(f,h),v[I>>2]=J;v[h+4>>2]=jb;v[i+704>>2]=v[i+704>>2]^128;g=v[f+24>>2];e=0-(v[f+28>>2]+((g|0)!=0)|0)|0;v[f+24>>2]=0-g;v[f+28>>2]=e;e=v[h+4>>2]}g=v[i+696>>2];Db(f,v[a>>2]+1074312|0,33);e=(e-g>>>0)%(s-Cb(f)>>>0)|0;h:{if(e>>>0>=l>>>0){v[h+4>>2]=v[i+700>>2]+(l-e|0);g=v[i+704>>2];if(!(g&128)){break h}break f}v[h+4>>2]=e+v[i+696>>2];g=v[i+704>>2];if(!(g&128)){break f}}v[i+704>>2]=g^128;g=v[f+24>>2];e=0-(v[f+28>>2]+((g|0)!=0)|0)|0;v[f+24>>2]=0-g;v[f+28>>2]=e;break f}g=e;j=v[i+700>>2];if(e>>>0>=j+l>>>0){g=j+((g-j>>>0)%(l>>>0)|0)|0}while(1){e=g;g=e-l|0;if(e>>>0>=j>>>0){continue}break}v[h>>2]=k;v[h+4>>2]=e}z=z+1|0;if((A|0)!=(z|0)){continue}break b}break}qB(h);v[(B(b,872)+p|0)+1324>>2]=0}I=ye(m,b),J=0,v[I>>2]=J}gb=f+32|0}function Q7(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=gb-192|0;gb=d;a:{if(rk(b)){break a}e=w[vl(b)|0];if((e|0)==33){c=1}else{if((e|0)!=63){break a}c=0}Kl(d+160|0,b,v[b+4>>2]-1|0);e=v[d+164>>2];v[b>>2]=v[d+160>>2];v[b+4>>2]=e}g=d+160|0;Ld(g);e=v[d+160>>2];Ld(d+144|0);e=ul(e,v[d+148>>2],b);Ld(g);b:{c:{d:{e:{f:{g:{if((e|0)==v[d+164>>2]){a=v[b+4>>2];v[d+184>>2]=v[b>>2];v[d+188>>2]=a;a=uc(d+176|0,18726);e=v[d+188>>2];v[d+8>>2]=v[d+184>>2];v[d+12>>2]=e;e=v[a+4>>2];v[d>>2]=v[a>>2];v[d+4>>2]=e;if(Gc(d+8|0,d)){a=ba(8)|0;v[22656]=0;c=Q(70,d+160|0,7752)|0;b=v[22656];v[22656]=0;if((b|0)==1){break f}rc(a,c);v[22656]=0;U(186,a|0,54952,1936);a=v[22656];v[22656]=0;if((a|0)!=1){break b}b=P()|0;O()|0;vb(c);break c}f=0;if(!c){break g}a=ba(8)|0;v[22656]=0;c=Q(2057,d+144|0,b|0)|0;b=v[22656];v[22656]=0;if((b|0)!=1){v[22656]=0;U(2037,d+160|0,14764,c|0);b=v[22656];v[22656]=0;if((b|0)==1){break e}rc(a,d+160|0);v[22656]=0;U(186,a|0,54952,1936);a=v[22656];v[22656]=0;if((a|0)!=1){break b}b=P()|0;O()|0;vb(d+160|0);vb(c);break c}b=P()|0;O()|0;break d}if(v[e+4>>2]!=2){a=ba(8)|0;v[22656]=0;c=Q(70,d+160|0,8874)|0;b=v[22656];v[22656]=0;if((b|0)!=1){rc(a,c);v[22656]=0;U(186,a|0,54952,1936);a=v[22656];v[22656]=0;if((a|0)!=1){break b}b=P()|0;O()|0;vb(c);break c}b=P()|0;O()|0;ca(a|0);break c}c=v[b+4>>2];v[d+136>>2]=v[b>>2];v[d+140>>2]=c;c=uc(d+128|0,18726);e=v[d+140>>2];v[d+72>>2]=v[d+136>>2];v[d+76>>2]=e;e=v[c+4>>2];v[d+64>>2]=v[c>>2];v[d+68>>2]=e;if(Gc(d+72|0,d- -64|0)){a=ba(8)|0;v[22656]=0;c=Q(70,d+160|0,7752)|0;b=v[22656];v[22656]=0;if((b|0)!=1){rc(a,c);v[22656]=0;U(186,a|0,54952,1936);a=v[22656];v[22656]=0;if((a|0)!=1){break b}b=P()|0;O()|0;vb(c);break c}b=P()|0;O()|0;ca(a|0);break c}c=v[b+4>>2];v[d+120>>2]=v[b>>2];v[d+124>>2]=c;c=uc(d+112|0,4823);e=v[d+124>>2];v[d+56>>2]=v[d+120>>2];v[d+60>>2]=e;e=v[c+4>>2];v[d+48>>2]=v[c>>2];v[d+52>>2]=e;if(Gc(d+56|0,d+48|0)){f=1;if(!w[a+28|0]){break g}f=65536/+y[v[a+24>>2]+480244>>2];break g}c=v[b+4>>2];v[d+104>>2]=v[b>>2];v[d+108>>2]=c;c=uc(d+96|0,4875);e=v[d+108>>2];v[d+40>>2]=v[d+104>>2];v[d+44>>2]=e;e=v[c+4>>2];v[d+32>>2]=v[c>>2];v[d+36>>2]=e;if(Gc(d+40|0,d+32|0)){f=1;if(!w[a+28|0]){break g}f=+y[v[a+24>>2]+480240>>2]*152587890625e-16;break g}c=v[b+4>>2];v[d+88>>2]=v[b>>2];v[d+92>>2]=c;b=uc(d+80|0,4893);c=v[d+92>>2];v[d+24>>2]=v[d+88>>2];v[d+28>>2]=c;c=v[b+4>>2];v[d+16>>2]=v[b>>2];v[d+20>>2]=c;f=0;if(!Gc(d+24|0,d+16|0)){break g}f=+y[v[a+24>>2]+480236>>2]*152587890625e-16}gb=d+192|0;return+f}b=P()|0;O()|0;ca(a|0);break c}b=P()|0;O()|0;vb(c)}ca(a|0)}S(b|0)}L()}function R8(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;d=gb-192|0;gb=d;g=d+176|0;oL(g);v[g>>2]=55140;dd(g+4|0);h=a;no(v[a+24>>2],g);e=w[a+62|0];f=w[a+61|0];j=w[a+60|0];k=v[a+24>>2];b=le(d+152|0,b);v[22656]=0;i=v[b+12>>2];v[d+8>>2]=v[b+8>>2];v[d+12>>2]=i;v[d+16>>2]=v[b+16>>2];i=v[b+4>>2];v[d>>2]=v[b>>2];v[d+4>>2]=i;b=j?13:15;b=f?b&14:b;b=W(2061,k|0,d|0,(e?b&3:b)|0)|0;e=v[22656];v[22656]=0;a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{if((e|0)==1){break p}if(!b){b=ba(8)|0;v[22656]=0;c=Q(70,d+136|0,9264)|0;a=v[22656];v[22656]=0;if((a|0)!=1){rc(b,c);v[22656]=0;U(186,b|0,54952,1936);a=v[22656];v[22656]=0;if((a|0)!=1){break a}a=P()|0;O()|0;vb(c);break b}a=P()|0;O()|0;ca(b|0);break b}if(!w[a+63|0]){v[22656]=0;R(2062,a|0,a+36|0);b=v[22656];v[22656]=0;if((b|0)==1){break p}}t[a+28|0]=1;no(v[h+24>>2],v[a+4>>2]);v[22656]=0;R(2063,d+136|0,g|0);b=v[22656];v[22656]=0;if((b|0)==1){break o}b=d+136|0;l=d,m=Vb(b),v[l+128>>2]=m;l=d,m=Zb(b),v[l+120>>2]=m;if(Gb(d+128|0,d+120|0)){h=a+68|0;while(1){b=v[d+128>>2];e=v[b>>2];v[22656]=0;f=e;e=b+4|0;U(2064,a|0,f|0,e|0);f=v[22656];v[22656]=0;if((f|0)==1){break d}b=v[b>>2];v[22656]=0;R(2065,d+56|0,b|0);b=v[22656];v[22656]=0;if((b|0)==1){break e}v[22656]=0;R(2039,d+72|0,d+56|0);b=v[22656];v[22656]=0;if((b|0)==1){break g}v[22656]=0;b=Q(70,d+40|0,14864)|0;f=v[22656];v[22656]=0;if((f|0)==1){break i}v[22656]=0;U(2058,d+88|0,d+72|0,b|0);f=v[22656];v[22656]=0;if((f|0)==1){break k}v[22656]=0;U(718,d+104|0,d+88|0,e|0);e=v[22656];v[22656]=0;if((e|0)==1){break m}v[22656]=0;R(1423,h|0,d+104|0);e=v[22656];v[22656]=0;if((e|0)==1){break n}vb(d+104|0);vb(d+88|0);vb(b);vb(d+72|0);vb(d+56|0);b=d+128|0;_o(b);if(Gb(b,d+120|0)){continue}break}}l=d,m=or(c),v[l+104>>2]=m;l=d,m=Dh(c),v[l+88>>2]=m;q:{while(1){v[22656]=0;b=og(d+104|0,d+88|0);c=v[22656];v[22656]=0;r:{if((c|0)!=1){if(b){break r}Kt(d+136|0);It(g);gb=d+192|0;return}a=P()|0;O()|0;break c}v[22656]=0;c=ue(d+104|0);b=v[22656];v[22656]=0;s:{if((b|0)==1){break s}v[22656]=0;b=Q(69,d+24|0,c|0)|0;h=v[22656];v[22656]=0;if((h|0)==1){break s}v[22656]=0;Y(2e3,a|0,b|0,c+12|0,0);c=v[22656];v[22656]=0;if((c|0)==1){break q}vb(b);Uj(d+104|0);continue}break}a=P()|0;O()|0;break c}a=P()|0;O()|0;vb(b);break c}a=P()|0;O()|0;break b}a=P()|0;O()|0;break b}a=P()|0;O()|0;vb(d+104|0);break l}a=P()|0;O()|0}vb(d+88|0);break j}a=P()|0;O()|0}vb(b);break h}a=P()|0;O()|0}vb(d+72|0);break f}a=P()|0;O()|0}vb(d+56|0);break c}a=P()|0;O()|0;break c}a=P()|0;O()|0}Kt(d+136|0)}It(g);S(a|0)}L()}function vma(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,x=0;f=gb-560|0;gb=f;a:{if(!Wc(b,1464)){break a}if(!ip(b,f+556|0)){break a}Gd(a,1);d=a+1074312|0;Rf(d,83);Ob(d,84,1);Ob(d,85,1);b:{if(je(f+556|0,33202)){d=f+32|0;e=Tb(d,5577);Eb(a+1298304|0,e);vb(e);e=Tb(d,12020);Eb(a+1298316|0,e);vb(e);d=Tb(d,12085);Eb(a+1298328|0,d);break b}if(!je(f+556|0,12635)){break a}d=f+32|0;e=Tb(d,5735);Eb(a+1298304|0,e);vb(e);e=Tb(d,9516);Eb(a+1298316|0,e);vb(e);d=Tb(d,12552);Eb(a+1298328|0,d)}vb(d);v[a+1298364>>2]=2;d=0;Wc(b,0);YC(b,a+1298268|0,20);u[a+480190>>1]=31;e=1;while(1){d=kC(b,f+32|0,(B(e,104)+a|0)+484380|0,((e<<5)+a|0)+946304|0,1)+d|0;e=e+1|0;if((e|0)!=32){continue}break}if(d>>>0>40){break a}i=f+552|0;mw(i,b);m=qd(i);if(w[i|0]>128){break a}e=f+32|0;h=e;g=gb-32|0;gb=g;d=b;c:{if(!Pb(d,512)){iV(h);break c}Vv(g+24|0,h);h=v[g+28>>2];v[g+8>>2]=v[g+24>>2];v[g+12>>2]=h;kd(g+16|0,d,g+8|0)}gb=g+32|0;d=f+544|0;g=w[m|0];d:{while(1){if(g>>>0>=w[e|0]){e=e+1|0;if((d|0)!=(e|0)){continue}break d}break}break a}o=1;if(!c){break a}v[a+480260>>2]=56;v[a+480264>>2]=13696;v[a+480204>>2]=125e4;v[a+480196>>2]=6;u[a+480192>>1]=0;u[a+480188>>1]=4;v[a+480228>>2]=64;v[a+480208>>2]=v[a+480208>>2]|18874368;xh(a,0);n=a+484360|0;Af(Sb(n),w[i|0]);u[f+30>>1]=0;j=a+484344|0;Ag(j,w[i|0]);if(w[i|0]){g=0;while(1){s=sc(Sb(n),g),x=g,u[s>>1]=x;if(wh(j,g&65535,64)){p=g<<2;h=0;while(1){Wc(b,(w[f+32+(h+p)|0]<<8)+1468|0);e=Yc(_b(j,g),0,h&65535);d=0;while(1){jv(b,e);e:{f:{l=w[e+3|0];g:{if((l|0)!=14){if(!l){if(w[e+5|0]){break f}break g}if((l-5&255)>>>0<5){break g}break f}if(w[e+5|0]<=15){break f}}t[e+3|0]=0;break e}Of(e)}e=e+24|0;d=d+1|0;if((d|0)!=64){continue}break}h=h+1|0;if((h|0)!=4){continue}break}s=f,x=Vb(_b(j,g)),v[s+24>>2]=x;h=0;while(1){d=0;while(1){e=d;d=w[v[f+24>>2]+3|0];h:{if((d|0)!=16&(d|0)!=17){break h}t[v[f+24>>2]+3|0]=16;k=0;if(w[v[f+24>>2]+5|0]<16){break h}d=w[v[f+24>>2]+5|0];if(!((d&15)==(d>>>4|0)|!(d&15))){d=w[v[f+24>>2]+5|0];q=d>>>4|0;r=d&15;k=1}d=v[f+24>>2];t[d+5|0]=w[d+5|0]>>>4}bk(f+24|0);d=e+1|0;if((e&65535)>>>0<3){continue}break}t[f+31|0]=r;t[f+30|0]=q;d=k&255;if(d){Jm(_b(j,g),Ue(Be(f+8|0,16,w[(d+f|0)+29|0]),h));d=k+1|0;k=(d&255)==3?1:d}else{k=0}h=h+1|0;if((h|0)!=64){continue}break}}g=g+1|0;if(g>>>0<w[i|0]){continue}break}}if(!(c&2)){break a}Wc(b,(w[m|0]<<8)+1468|0);e=1;while(1){c=(B(e,104)+a|0)+484380|0;if(v[c>>2]){Dg(Rc(f+8|0,8,1,0,0),c,b)}e=e+1|0;if((e|0)!=32){continue}break}}gb=f+560|0;return o|0}function ZZ(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;f=gb-384|0;gb=f;vc(b);d=gb-32|0;gb=d;e=d+24|0;h=f+344|0;tE(e,h);k=yb(e);e=v[d+28>>2];g=v[d+24>>2];v[d+8>>2]=g;v[d+12>>2]=e;v[d>>2]=g;v[d+4>>2]=e;g=d+16|0;e=b;cc(g,e,d);g=yb(g);if((g|0)==(k|0)){Rb(e,yb(d+24|0))}gb=d+32|0;e=(g|0)==(k|0);if(!e){sE(h)}a:{b:{if(!e){break b}if(!GE(f+344|0)){break b}if(!Pb(b,Qc(FE(f+344|0),jb))){break b}c:{if(!c){break c}Gd(a,2097152);Bg(a);i=1;xh(a,1);u[a+480188>>1]=8;v[a+480196>>2]=w[f+376|0];v[a+480204>>2]=B(w[f+377|0],1e4);u[a+480190>>1]=w[f+378|0];if(w[f+381|0]<w[f+380|0]){cf(Sb(a+484360|0),w[f+381|0])}e=f+80|0;d=Tb(e,3576);Eb(a+1298304|0,d);vb(d);d=Tb(e,8337);Eb(a+1298316|0,d);vb(d);v[a+1298364>>2]=5;nw(b,e);Ur(Sb(a+484360|0),e,w[f+380|0],65535,65535);if(x[a+480190>>1]){j=1;while(1){e=f+40|0;EE(b,e);l=gb-16|0;gb=l;g=(B(i,104)+a|0)+484380|0;ud(g,0);k=e;t[g+37|0]=w[e+22|0]<<4;t[l+15|0]=w[e+23|0];t[l+14|0]=64;n=g,o=w[ac(l+15|0,l+14|0)|0]<<2,u[n+30>>1]=o;t[g+36|0]=w[e+24|0];d=e+25|0;v[g>>2]=w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24);h=e+33|0;d:{if((w[h|0]|w[h+1|0]<<8|(w[h+2|0]<<16|w[h+3|0]<<24))>>>0<3){break d}m=w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24);d=k+29|0;if(m>>>0<(w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24))+(w[h|0]|w[h+1|0]<<8|(w[h+2|0]<<16|w[h+3|0]<<24))>>>0){break d}u[g+34>>1]=x[g+34>>1]|2;v[g+4>>2]=w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24);v[g+8>>2]=(w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24))+(w[h|0]|w[h+1|0]<<8|(w[h+2|0]<<16|w[h+3|0]<<24))}gb=l+16|0;d=f+8|0;Rk(d,2,e);e=f+24|0;Bc(e,d);v[22656]=0;Q(301,((i<<5)+a|0)+946304|0,e|0)|0;e=v[22656];v[22656]=0;if((e|0)==1){break a}vb(f+24|0);j=j+1|0;i=j&65535;if(i>>>0<=x[a+480190>>1]){continue}break}}Rb(b,B(64-w[f+378|0]|0,37));k=a+484344|0;Ag(k,w[f+379|0]);if(w[f+379|0]){h=c&1;j=0;while(1){e:{f:{if(h){if(wh(k,j&65535,64)){break f}}Rb(b,2048);break e}e=_b(k,j);n=f,o=Vb(e),v[n+40>>2]=o;n=f,o=Zb(e),v[n+24>>2]=o;if(!Gb(f+40|0,f+24|0)){break e}while(1){e=v[f+40>>2];d=f+8|0;wn(d,b);i=qd(d);g=Ve(d);l=ej(d);d=w[d|0];if((d-1&255)>>>0<=106){t[e|0]=d+13}t[e+1|0]=w[i|0];t[e+3|0]=w[g|0];t[e+5|0]=w[l|0];Of(e);e=f+40|0;bk(e);if(Gb(e,f+24|0)){continue}break}}j=j+1|0;if(j>>>0<w[f+379|0]){continue}break}}if(!(c&2)){break c}i=1;c=Rc(f+40|0,8,1,0,0);if(!x[a+480190>>1]){break c}while(1){Dg(c,(B(i&65535,104)+a|0)+484380|0,b);i=i+1|0;if(x[a+480190>>1]>=(i&65535)>>>0){continue}break}}i=1}gb=f+384|0;return i|0}a=P()|0;O()|0;vb(f+24|0);S(a|0);L()}function z3(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;l=gb-16|0;gb=l;n=Xx(g);o=Bx(g);Ug(l,o);v[f>>2]=d;a:{b:{c:{h=a;g=w[h|0];switch(g-43|0){case 0:case 2:break c;default:break b}}v[22656]=0;g=Q(2474,n|0,g<<24>>24)|0;h=v[22656];v[22656]=0;if((h|0)==1){break a}h=v[f>>2];v[f>>2]=h+4;v[h>>2]=g;h=a+1|0}g=c-h|0;d:{if(!(w[h|0]!=48|(g|0)<2|(w[h+1|0]|32)!=120)){v[22656]=0;j=Q(2474,n|0,48)|0;i=v[22656];v[22656]=0;if((i|0)==1){break a}i=v[f>>2];v[f>>2]=i+4;v[i>>2]=j;j=t[h+1|0];v[22656]=0;j=Q(2474,n|0,j|0)|0;i=v[22656];v[22656]=0;if((i|0)==1){break a}i=v[f>>2];v[f>>2]=i+4;v[i>>2]=j;j=h+2|0;if(j>>>0>=c>>>0){g=j;break d}h=g+h|0;g=j;e:{while(1){i=t[g|0];v[22656]=0;k=ga(2448)|0;m=v[22656];v[22656]=0;if((m|0)==1){break e}v[22656]=0;i=Ox(i,k);k=v[22656];v[22656]=0;if((k|0)==1){break e}if(!i){break d}g=g+1|0;if((h|0)!=(g|0)){continue}break}g=h;break d}break a}f:{if(c>>>0<=h>>>0){g=h;break f}j=g+h|0;g=h;while(1){i=t[g|0];v[22656]=0;ga(2448)|0;k=v[22656];v[22656]=0;if((k|0)==1){break a}v[22656]=0;i=Qh(i);k=v[22656];v[22656]=0;if((k|0)==1){break a}if(!i){break f}g=g+1|0;if((j|0)!=(g|0)){continue}break}g=j}j=h}g:{if(gd(l)){h=v[f>>2];v[22656]=0;Y(2464,n|0,j|0,g|0,h|0);h=v[22656];v[22656]=0;if((h|0)==1){break a}v[f>>2]=v[f>>2]+(g-j<<2);break g}qm(j,g);v[22656]=0;p=T(2462,o|0)|0;h=v[22656];v[22656]=0;h:{i:{if((h|0)!=1){if(g>>>0>j>>>0){break i}h=v[f>>2];break h}break a}h=j;i=0;k=0;j:{while(1){k:{if(t[pc(l,i)|0]<=0){break k}if(t[pc(l,i)|0]!=(k|0)){break k}k=v[f>>2];v[f>>2]=k+4;v[k>>2]=p;i=(Ab(l)-1>>>0>i>>>0)+i|0;k=0}m=t[h|0];v[22656]=0;q=Q(2474,n|0,m|0)|0;m=v[22656];v[22656]=0;if((m|0)!=1){m=v[f>>2];v[f>>2]=m+4;v[m>>2]=q;k=k+1|0;h=h+1|0;if((h|0)==(g|0)){break j}continue}break}break a}h=m+4|0}xx((j-a<<2)+d|0,h)}l:{if(c>>>0<=g>>>0){h=v[f>>2];break l}while(1){h=w[g|0];if((h|0)==46){v[22656]=0;j=T(2465,o|0)|0;h=v[22656];v[22656]=0;if((h|0)==1){break a}i=v[f>>2];h=i+4|0;v[f>>2]=h;v[i>>2]=j;g=g+1|0;break l}v[22656]=0;j=Q(2474,n|0,h<<24>>24)|0;h=v[22656];v[22656]=0;if((h|0)==1){break a}h=v[f>>2];v[f>>2]=h+4;v[h>>2]=j;g=g+1|0;if((g|0)!=(c|0)){continue}break}h=h+4|0;g=c}v[22656]=0;Y(2464,n|0,g|0,c|0,h|0);h=v[22656];v[22656]=0;if((h|0)==1){break a}h=f;f=v[f>>2]+(c-g<<2)|0;v[h>>2]=f;v[e>>2]=(b|0)==(c|0)?f:(b-a<<2)+d|0;vb(l);gb=l+16|0;return}a=P()|0;O()|0;vb(l);S(a|0);L()}function zG(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,k=0,m=0;g=gb-48|0;gb=g;o(+a);d=j(1)|0;f=j(0)|0;a:{b:{e=d;d=e;h=e&2147483647;c:{if(h>>>0<=1074752122){if((d&1048575)==598523){break c}if(h>>>0<=1073928572){if((e|0)>0|(e|0)>=0){a=a+-1.5707963267341256;c=a+-6.077100506506192e-11;A[b>>3]=c;A[b+8>>3]=a-c+-6.077100506506192e-11;d=1;break a}a=a+1.5707963267341256;c=a+6.077100506506192e-11;A[b>>3]=c;A[b+8>>3]=a-c+6.077100506506192e-11;d=-1;break a}if((e|0)>0|(e|0)>=0){a=a+-3.1415926534682512;c=a+-1.2154201013012384e-10;A[b>>3]=c;A[b+8>>3]=a-c+-1.2154201013012384e-10;d=2;break a}a=a+3.1415926534682512;c=a+1.2154201013012384e-10;A[b>>3]=c;A[b+8>>3]=a-c+1.2154201013012384e-10;d=-2;break a}if(h>>>0<=1075594811){if(h>>>0<=1075183036){if((h|0)==1074977148){break c}if((e|0)>0|(e|0)>=0){a=a+-4.712388980202377;c=a+-1.8231301519518578e-10;A[b>>3]=c;A[b+8>>3]=a-c+-1.8231301519518578e-10;d=3;break a}a=a+4.712388980202377;c=a+1.8231301519518578e-10;A[b>>3]=c;A[b+8>>3]=a-c+1.8231301519518578e-10;d=-3;break a}if((h|0)==1075388923){break c}if((e|0)>0|(e|0)>=0){a=a+-6.2831853069365025;c=a+-2.430840202602477e-10;A[b>>3]=c;A[b+8>>3]=a-c+-2.430840202602477e-10;d=4;break a}a=a+6.2831853069365025;c=a+2.430840202602477e-10;A[b>>3]=c;A[b+8>>3]=a-c+2.430840202602477e-10;d=-4;break a}if(h>>>0>1094263290){break b}}k=a*.6366197723675814+6755399441055744+-6755399441055744;c=a+k*-1.5707963267341256;i=k*6.077100506506192e-11;a=c-i;A[b>>3]=a;o(+a);d=j(1)|0;j(0)|0;e=h>>>20|0;f=(e-(d>>>20&2047)|0)<17;if(D(k)<2147483648){d=~~k}else{d=-2147483648}d:{if(f){break d}i=c;a=k*6.077100506303966e-11;c=c-a;i=k*2.0222662487959506e-21-(i-c-a);a=c-i;A[b>>3]=a;f=e;o(+a);e=j(1)|0;j(0)|0;if((f-(e>>>20&2047)|0)<50){break d}i=c;a=k*2.0222662487111665e-21;c=c-a;i=k*8.4784276603689e-32-(i-c-a);a=c-i;A[b>>3]=a}A[b+8>>3]=c-a-i;break a}if(h>>>0>=2146435072){a=a-a;A[b>>3]=a;A[b+8>>3]=a;d=0;break a}l(0,f|0);l(1,e&1048575|1096810496);a=+n();d=0;f=1;while(1){m=(g+16|0)+(d<<3)|0;if(D(a)<2147483648){d=~~a}else{d=-2147483648}c=+(d|0);A[m>>3]=c;a=(a-c)*16777216;d=1;m=f&1;f=0;if(m){continue}break}A[g+32>>3]=a;e:{if(a!=0){d=2;break e}f=1;while(1){d=f;f=d-1|0;if(A[(g+16|0)+(d<<3)>>3]==0){continue}break}}d=_I(g+16|0,g,(h>>>20|0)-1046|0,d+1|0,1);a=A[g>>3];if((e|0)<0){A[b>>3]=-a;A[b+8>>3]=-A[g+8>>3];d=0-d|0;break a}A[b>>3]=a;A[b+8>>3]=A[g+8>>3]}gb=g+48|0;return d}function dba(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;d=gb-320|0;gb=d;e=gb-16|0;gb=e;v[a>>2]=0;f=a+32|0;Nt(f,32);t[e+15|0]=0;kq(f,e+15|0);gb=e+16|0;e=v[a+28>>2];a:{if(!_f(v[v[e>>2]-12>>2]+e|0)){uh(a,1073741825);break a}f=d+56|0;se(f,v[a+28>>2]);e=f;g=v[e+12>>2];v[a+8>>2]=v[e+8>>2];v[a+12>>2]=g;v[e>>2]=3;i=v[a+28>>2];h=d+16|0;j=h;g=0;if(v[e>>2]){while(1){Vh(i,g+j|0);g=g+1|0;if(g>>>0<y[f>>2]){continue}break}}if(sd(h,27248,3)){uh(a,1073741827);break a}g=0;t[d+319|0]=0;Vh(v[a+28>>2],d+319|0);Qb(d+56|0,0,256);e=w[d+319|0];b:{if(!e){f=d+56|0;break b}f=d+56|0;ll(v[a+28>>2],f,e);g=w[d+319|0]}e=b;b=qo(d+16|0,f,g);e=Xy(e,b);Hb(b);if(!e){uh(a,1073741830)}if(w[a+3|0]&64){break a}Vh(v[a+28>>2],d+55|0);e=w[d+55|0];b=e&3;u[a+16>>1]=(b|0)==3?4:b;if(Ej(e,6)){Al(a,9,1)}v[d+48>>2]=0;FL(v[a+28>>2],d+48|0);b=v[d+48>>2];t[d+47|0]=0;if(b>>>0>=2){Vh(v[a+28>>2],d+55|0);f=w[d+55|0];if(!f){Vh(v[a+28>>2],d+47|0);f=w[d+55|0]}zm(v[a+28>>2],b+(f&255?-1:-2)|0,-1)}v[d+32>>2]=0;v[d+36>>2]=0;c:{if(!Ej(e,4)){break c}zl(v[a+28>>2],d+32|0);b=v[d+36>>2];f=v[d+32>>2];v[a+56>>2]=f;v[a+60>>2]=b;g=v[c+4>>2];if((g|0)==(b|0)&y[c>>2]>=f>>>0|b>>>0<g>>>0){break c}uh(a,536871424)}if(Ej(e,5)){Vh(v[a+28>>2],d+55|0);zm(v[a+28>>2],w[d+55|0],-1)}d:{if(!Ej(w[d+47|0],0)){break d}Vh(v[a+28>>2],d+55|0);b=w[d+55|0];b=b&1?-1:b>>>1|0;u[a+16>>1]=b;if(b){break d}uh(a,536871168)}v[a+4>>2]=0;b=1;if(Ej(w[d+47|0],1)){FL(v[a+28>>2],a+4|0)}Al(a,6,Ej(e,2));Al(a,7,Ej(e,3));Al(a,5,x[a+16>>1]!=0);Al(a,8,Ej(e,7));e:{if(nd(a,5)){break e}if(nd(a,6)){break e}if(nd(a,7)){break e}b=nd(a,8)}Al(a,11,b);nd(a,11);b=w[d+47|0];if(Ej(b,2)){u[d+16>>1]=0;Vy(v[a+28>>2],d+16|0);zm(v[a+28>>2],B(x[d+16>>1],nd(a,9)?2:1),-1);b=w[d+47|0]}if(Ej(b,3)){zm(v[a+28>>2],5,-1)}zl(v[a+28>>2],d+32|0);c=v[d+36>>2];b=v[d+32>>2];if(!c&b>>>0>=16001|c){uh(a,1073741831);break a}v[a+92>>2]=b;if(!b){uh(a,536871040)}f:{if(!nd(a,11)){break f}zl(v[a+28>>2],d+32|0);b=v[d+36>>2];if((b|0)==2147483647|b>>>0<2147483647){break f}uh(a,1073741829);break a}se(d,v[a+28>>2]);$L(d+16|0,d,v[a+8>>2],v[a+12>>2]);b=v[d+28>>2];e=v[d+24>>2];if(!(!b&((b|0)>0|(b|0)>=0))){uh(a,1073741832);break a}v[a+88>>2]=e;k=a,l=v[(nd(a,11)?d+32|0:a+88|0)>>2],v[k+64>>2]=l;if(!nd(a,11)){c=v[a+12>>2];e=v[a+88>>2];f=e+v[a+8>>2]|0;c=f>>>0<e>>>0?c+1|0:c;v[a+72>>2]=f;v[a+76>>2]=c}Al(a,10,1)}gb=d+320|0}function BU(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;e=gb-80|0;gb=e;a:{if(v[b+4>>2]==v[d+4>>2]){f=v[b+4>>2];v[e+72>>2]=v[b>>2];v[e+76>>2]=f;b=v[c+4>>2];v[e+64>>2]=v[c>>2];v[e+68>>2]=b;f=ne(e+56|0,d);b=v[e+76>>2];v[e+8>>2]=v[e+72>>2];v[e+12>>2]=b;b=v[e+68>>2];v[e>>2]=v[e+64>>2];v[e+4>>2]=b;b=gb-16|0;gb=b;d=Rj(e,e+8|0);v[b+12>>2]=d;b:{if((d|0)<=0){break b}c=v[e+12>>2];c:{if(!c){c=v[f>>2];break c}g=32-c|0;v[b+8>>2]=g;c=v[pd(b+8|0,b+12|0)>>2];v[b+12>>2]=v[b+12>>2]-c;d=v[f>>2];g=-1<<v[e+12>>2]&-1>>>g-c;h=v[e+8>>2];v[d>>2]=v[d>>2]&(g^-1)|g&v[h>>2];c=c+v[f+4>>2]|0;v[f+4>>2]=c&31;c=d+(c>>>3&536870908)|0;v[f>>2]=c;v[e+8>>2]=h+4;d=v[b+12>>2]}h=c;d=(d|0)/32|0;c=d<<2;yh(h,v[e+8>>2],c);d=v[b+12>>2]-(d<<5)|0;v[b+12>>2]=d;g=c+v[f>>2]|0;v[f>>2]=g;if((d|0)<=0){break b}c=c+v[e+8>>2]|0;v[e+8>>2]=c;d=-1>>>32-d|0;v[g>>2]=v[g>>2]&(d^-1)|d&v[c>>2];v[f+4>>2]=v[b+12>>2]}ne(a,f);gb=b+16|0;break a}f=v[b+4>>2];v[e+48>>2]=v[b>>2];v[e+52>>2]=f;b=v[c+4>>2];v[e+40>>2]=v[c>>2];v[e+44>>2]=b;g=ne(e+32|0,d);b=v[e+52>>2];v[e+24>>2]=v[e+48>>2];v[e+28>>2]=b;b=v[e+44>>2];v[e+16>>2]=v[e+40>>2];v[e+20>>2]=b;f=gb-16|0;gb=f;d=Rj(e+16|0,e+24|0);v[f+12>>2]=d;d:{if((d|0)<=0){break d}b=v[e+28>>2];e:{if(!b){c=v[g+4>>2];break e}c=32-b|0;v[f+8>>2]=c;d=f+8|0;b=v[pd(d,f+12|0)>>2];v[f+12>>2]=v[f+12>>2]-b;h=v[g+4>>2];j=v[v[e+24>>2]>>2];k=v[e+28>>2];v[f+8>>2]=b;h=32-h|0;v[f+4>>2]=h;l=Fb(d,f+4|0);i=v[g>>2];j=j&(-1<<k&-1>>>c-b);c=v[g+4>>2];d=v[e+28>>2];k=h;h=v[l>>2];v[i>>2]=(c>>>0>d>>>0?j<<c-d:j>>>d-c|0)|v[i>>2]&(-1<<c&-1>>>k-h^-1);k=c+h|0;c=k&31;v[g+4>>2]=c;i=i+(k>>>3&536870908)|0;v[g>>2]=i;b=b-h|0;if((b|0)>0){v[i>>2]=v[i>>2]&(-1>>>32-b^-1)|j>>>d+h;v[g+4>>2]=b;c=b}v[e+24>>2]=v[e+24>>2]+4;d=v[f+12>>2]}i=32-c|0;if((d|0)>=32){k=-1<<c;l=k^-1;h=v[e+24>>2];b=v[g>>2];j=v[b>>2];while(1){d=v[h>>2];v[b>>2]=j&l|d<<c;j=k&v[b+4>>2]|d>>>i;v[b+4>>2]=j;m=v[f+12>>2];d=m-32|0;v[f+12>>2]=d;h=h+4|0;b=b+4|0;if((m|0)>63){continue}break}v[e+24>>2]=h;v[g>>2]=b}if((d|0)<=0){break d}j=v[v[e+24>>2]>>2];v[f+8>>2]=i;b=pd(f+12|0,f+8|0);c=v[g>>2];h=v[g+4>>2];b=v[b>>2];k=v[c>>2]&(-1<<h&-1>>>i-b^-1);i=j&-1>>>32-d;v[c>>2]=k|i<<h;d=b+h|0;v[g+4>>2]=d&31;c=c+(d>>>3&536870908)|0;v[g>>2]=c;d=v[f+12>>2]-b|0;v[f+12>>2]=d;if((d|0)<=0){break d}v[c>>2]=v[c>>2]&(-1>>>32-d^-1)|i>>>b;v[g+4>>2]=v[f+12>>2]}ne(a,g);gb=f+16|0}gb=e+80|0}function loa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=C(0);c=gb-128|0;gb=c;f=gb-32|0;gb=f;d=f+24|0;h=b+16|0;CW(d,h);e=yb(d);d=v[f+28>>2];g=v[f+24>>2];v[f+8>>2]=g;v[f+12>>2]=d;v[f>>2]=g;v[f+4>>2]=d;d=a;g=f+16|0;cc(g,d,f);g=yb(g);if((g|0)==(e|0)){Rb(d,yb(f+24|0))}gb=f+32|0;if((e|0)!=(g|0)){Qb(h,0,128)}fX(b+48|0);t[b+143|0]=0;v[b+152>>2]=-2147483648;v[b+156>>2]=-2147483648;d=c+80|0;Td(d,a,sg(a));f=kc(c+104|0,d);xb(d);v[22656]=0;d=T(467,f|0)|0;e=v[22656];v[22656]=0;a:{b:{if((e|0)==1){break b}v[22656]=0;e=b+4|0;R(440,e|0,d|0);d=v[22656];v[22656]=0;if((d|0)==1){break b}v[22656]=0;Vd(c+72|0,e);d=v[22656];v[22656]=0;if((d|0)==1){break b}v[22656]=0;d=v[c+76>>2];v[c+8>>2]=v[c+72>>2];v[c+12>>2]=d;U(633,c+80|0,f|0,c+8|0);d=v[22656];v[22656]=0;if((d|0)!=1){v[22656]=0;d=T(192,a|0)|0;e=v[22656];v[22656]=0;c:{if((e|0)==1){break c}v[22656]=0;U(288,c+48|0,a|0,d|0);a=v[22656];v[22656]=0;if((a|0)==1){break c}a=c+48|0;d=kc(c+80|0,a);xb(a);v[22656]=0;a=T(275,d|0)|0;e=v[22656];v[22656]=0;d:{if((e|0)!=1){e:{f:{if(!a){break f}while(1){g:{v[22656]=0;a=Q(191,d|0,5)|0;e=v[22656];v[22656]=0;if((e|0)==1){break e}if(!a){break f}v[22656]=0;Q(634,d|0,c+44|0)|0;a=v[22656];v[22656]=0;h:{if((a|0)!=1){a=4;e=w[c+44|0]|w[c+45|0]<<8|(w[c+46|0]<<16|w[c+47|0]<<24);if((e|0)==1414682436|(e|0)==1196380752){break h}v[22656]=0;a=T(192,d|0)|0;e=v[22656];v[22656]=0;if((e|0)!=1){break h}a=P()|0;O()|0;break d}a=P()|0;O()|0;break d}v[22656]=0;U(288,c+24|0,d|0,a|0);a=v[22656];v[22656]=0;i:{j:{k:{if((a|0)!=1){e=c+24|0;a=kc(c+48|0,e);xb(e);if((w[c+44|0]|w[c+45|0]<<8|(w[c+46|0]<<16|w[c+47|0]<<24))!=1414682436){break k}v[22656]=0;i=C(Ba(635,a|0));a=v[22656];v[22656]=0;if((a|0)==1){break g}z[c+24>>2]=i;v[c+20>>2]=0;v[22656]=0;v[c+16>>2]=1065353216;a=zf(c+24|0,c+20|0,c+16|0);e=v[22656];v[22656]=0;if((e|0)==1){break g}e=v[a>>2];z[b+144>>2]=z[a>>2];if(e+8388608&2130706432){break j}v[b+144>>2]=0;break j}a=P()|0;O()|0;break d}if((w[c+44|0]|w[c+45|0]<<8|(w[c+46|0]<<16|w[c+47|0]<<24))!=1196380752){break j}v[22656]=0;a=T(192,a|0)|0;e=v[22656];v[22656]=0;if((e|0)==1){break i}v[b+148>>2]=a}xb(c+48|0);continue}}break}a=P()|0;O()|0;xb(c+48|0);break d}xb(d);xb(f);gb=c+128|0;return}a=P()|0;O()|0;break d}a=P()|0;O()|0}xb(d);break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;break a}a=P()|0;O()|0}xb(f);S(a|0);L()}function Ola(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;h=gb-16|0;gb=h;a:{if(!Pb(a,2)){wh(c+484344|0,b,64);break a}m=c+484344|0;k=Md(Mr(a),1,1024);if(!wh(m,b,k)|!k){break a}n=x[c+480188>>1];while(1){o=Tf(_b(m,b),l);i=0;if(n){while(1){g=h+8|0;wn(g,a);e=B(i,6)+o|0;j=qd(g);p=Ve(g);f=ej(g);g=w[g|0];b:{if((g-1&255)>>>0>35){break b}t[e|0]=g+48;g=w[j|0]+1|0;t[e+1|0]=g;j=g;g=g&255;if((j|0)!=(g|0)|g>>>0>x[c+480190>>1]){break b}g=Bk(c,w[e+1|0]);j=ic(d,i);if(!(!w[j|0]|x[g+30>>1]>255)){t[e+4|0]=64;t[e+2|0]=1}g=g+68|0;if(!(q=v[Fe(g,0)>>2]==1,r=0,s=w[j|0],s?q:r)){if(v[Fe(g,0)>>2]|w[j|0]){break b}}t[e+1|0]=w[e+1|0]+100}c:{d:{switch(w[p|0]){case 1:if(!w[f|0]){break c}t[e+3|0]=2;t[e+5|0]=w[f|0];break c;case 2:if(!w[f|0]){break c}t[e+3|0]=3;t[e+5|0]=w[f|0];break c;case 12:if(!w[f|0]){break c}t[e+3|0]=1;t[e+5|0]=w[f|0];break c;case 13:if(!w[f|0]){break c}t[e+3|0]=39;t[h+7|0]=15;q=e,r=w[ac(h+7|0,f)|0]|16,t[q+5|0]=r;break c;case 30:if(!w[f|0]){break c}t[e+3|0]=38;t[h+6|0]=15;q=e,r=w[ac(h+6|0,f)|0]|16,t[q+5|0]=r;break c;case 21:if(!w[f|0]){break c}t[e+3|0]=39;t[h+5|0]=15;q=e,r=w[ac(h+5|0,f)|0]|80,t[q+5|0]=r;break c;case 17:if(!w[f|0]){break c}t[e+3|0]=38;t[h+4|0]=15;q=e,r=w[ac(h+4|0,f)|0]|80,t[q+5|0]=r;break c;case 15:t[e+3|0]=19;t[e+5|0]=w[f|0]!=0;break c;case 25:t[e+3|0]=12;t[e+5|0]=w[f|0];break c;case 27:ap(e);t[e|0]=255;break c;case 28:if(w[f|0]>31){break c}t[e+3|0]=16;t[e+5|0]=w[f|0];break c;case 31:g=w[f|0];if(g&15){q=e,r=w[ic(d,i)|0]?22:11,t[q+3|0]=r;t[e+5|0]=w[f|0]&15;g=w[f|0]}e:{f:{switch(g>>>4|0){case 4:if((g|0)!=64){break e}case 0:case 1:case 2:case 3:if(w[ic(d,i)|0]){t[e+3|0]=21;t[e+5|0]=w[f|0];break e}t[e+2|0]=1;f=w[f|0];t[e+3|0]=0;t[e+4|0]=f;break e;case 5:t[e+5|0]=w[e+5|0]<<4;break e;case 6:t[h+3|0]=w[e+5|0];t[h+2|0]=14;q=e,r=w[ac(h+3|0,h+2|0)|0]|240,t[q+5|0]=r;break e;case 7:t[h+1|0]=w[e+5|0];t[h|0]=14;q=e,r=w[ac(h+1|0,h)|0]<<4|15,t[q+5|0]=r;break e;default:break f}}t[e+3|0]=0}if((w[e+3|0]-21&255)>>>0>1){break c}f=B(t[ic(d,i)|0]+i|0,6)+o|0;g=f;if(Zt(f+3|0,f+5|0,1)){t[f+2|0]=w[g+3|0];t[f+4|0]=w[f+5|0]}t[g+3|0]=w[e+3|0];t[f+5|0]=w[e+5|0];break c;case 0:break c;default:break d}}t[e+3|0]=0}i=i+1|0;if((n|0)!=(i|0)){continue}break}}l=l+1|0;if((l|0)!=(k|0)){continue}break}}gb=h+16|0}function K3(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;l=gb-16|0;gb=l;m=ED(g);q=Fx(g);Ug(l,q);v[f>>2]=d;a:{b:{c:{h=a;g=w[h|0];switch(g-43|0){case 0:case 2:break c;default:break b}}v[22656]=0;g=Q(22,m|0,g<<24>>24)|0;h=v[22656];v[22656]=0;if((h|0)==1){break a}h=v[f>>2];v[f>>2]=h+1;t[h|0]=g;h=a+1|0}g=c-h|0;d:{if(!(w[h|0]!=48|(g|0)<2|(w[h+1|0]|32)!=120)){v[22656]=0;i=Q(22,m|0,48)|0;j=v[22656];v[22656]=0;if((j|0)==1){break a}j=v[f>>2];v[f>>2]=j+1;t[j|0]=i;i=t[h+1|0];v[22656]=0;i=Q(22,m|0,i|0)|0;j=v[22656];v[22656]=0;if((j|0)==1){break a}j=v[f>>2];v[f>>2]=j+1;t[j|0]=i;i=h+2|0;if(i>>>0>=c>>>0){g=i;break d}h=g+h|0;g=i;e:{while(1){j=t[g|0];v[22656]=0;k=ga(2448)|0;n=v[22656];v[22656]=0;if((n|0)==1){break e}v[22656]=0;j=Ox(j,k);k=v[22656];v[22656]=0;if((k|0)==1){break e}if(!j){break d}g=g+1|0;if((h|0)!=(g|0)){continue}break}g=h;break d}break a}f:{if(c>>>0<=h>>>0){g=h;break f}i=g+h|0;g=h;while(1){j=t[g|0];v[22656]=0;ga(2448)|0;k=v[22656];v[22656]=0;if((k|0)==1){break a}v[22656]=0;j=Qh(j);k=v[22656];v[22656]=0;if((k|0)==1){break a}if(!j){break f}g=g+1|0;if((i|0)!=(g|0)){continue}break}g=i}i=h}g:{if(gd(l)){h=v[f>>2];v[22656]=0;Y(2444,m|0,i|0,g|0,h|0);h=v[22656];v[22656]=0;if((h|0)==1){break a}v[f>>2]=v[f>>2]+(g-i|0);break g}qm(i,g);v[22656]=0;j=T(2436,q|0)|0;h=v[22656];v[22656]=0;if((h|0)==1){break a}if(g>>>0>i>>>0){h=i;while(1){h:{if(t[pc(l,p)|0]<=0){break h}if(t[pc(l,p)|0]!=(o|0)){break h}o=v[f>>2];v[f>>2]=o+1;t[o|0]=j;p=(Ab(l)-1>>>0>p>>>0)+p|0;o=0}k=t[h|0];v[22656]=0;k=Q(22,m|0,k|0)|0;n=v[22656];v[22656]=0;if((n|0)==1){break a}n=v[f>>2];v[f>>2]=n+1;t[n|0]=k;o=o+1|0;h=h+1|0;if((h|0)!=(g|0)){continue}break}}qm((i-a|0)+d|0,v[f>>2])}i:{if(c>>>0<=g>>>0){break i}while(1){h=w[g|0];if((h|0)==46){v[22656]=0;h=T(2445,q|0)|0;i=v[22656];v[22656]=0;if((i|0)==1){break a}i=v[f>>2];v[f>>2]=i+1;t[i|0]=h;g=g+1|0;break i}v[22656]=0;h=Q(22,m|0,h<<24>>24)|0;i=v[22656];v[22656]=0;if((i|0)==1){break a}i=v[f>>2];v[f>>2]=i+1;t[i|0]=h;g=g+1|0;if((g|0)!=(c|0)){continue}break}g=c}h=v[f>>2];v[22656]=0;Y(2444,m|0,g|0,c|0,h|0);h=v[22656];v[22656]=0;if((h|0)==1){break a}h=f;f=v[f>>2]+(c-g|0)|0;v[h>>2]=f;v[e>>2]=(b|0)==(c|0)?f:(b-a|0)+d|0;vb(l);gb=l+16|0;return}a=P()|0;O()|0;vb(l);S(a|0);L()}function hka(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;l=gb-48|0;gb=l;f=v[a+4>>2];e=ne(l+40|0,b);j=ne(l+32|0,c);d=gb-16|0;gb=d;e=AU(ne(d+8|0,e),ne(d,j));gb=d+16|0;d=e+v[a+4>>2]|0;v[a+4>>2]=d;a:{b:{if(!f){e=d-1|0;break b}e=d-1|0;if((e^f-1)>>>0<32){break a}}v[v[a>>2]+((d>>>0<33?0:e>>>5|0)<<2)>>2]=0}d=ne(l+24|0,b);g=ne(l+16|0,c);c=l+8|0;zp(c,a,f);b=l;j=gb-48|0;gb=j;c:{if(v[d+4>>2]==v[c+4>>2]){d=ne(j+40|0,d);e=ne(j+32|0,g);f=ne(j+24|0,c);a=gb-16|0;gb=a;c=Rj(e,d);v[a+12>>2]=c;d:{if((c|0)<=0){break d}e=v[d+4>>2];if(e){g=32-e|0;v[a+8>>2]=g;c=v[pd(a+8|0,a+12|0)>>2];v[a+12>>2]=v[a+12>>2]-c;e=v[f>>2];g=-1<<v[d+4>>2]&-1>>>g-c;v[e>>2]=v[e>>2]&(g^-1)|g&v[v[d>>2]>>2];c=c+v[f+4>>2]|0;v[f+4>>2]=c&31;v[f>>2]=e+(c>>>3&536870908);v[d>>2]=v[d>>2]+4;c=v[a+12>>2]}e=(c|0)/32|0;c=e<<2;yh(v[f>>2],v[d>>2],c);e=v[a+12>>2]-(e<<5)|0;v[a+12>>2]=e;v[f>>2]=c+v[f>>2];if((e|0)<=0){break d}c=c+v[d>>2]|0;v[d>>2]=c;d=v[f>>2];i=d;n=v[d>>2];d=-1>>>32-e|0;v[i>>2]=n&(d^-1)|d&v[c>>2];v[f+4>>2]=v[a+12>>2]}ne(b,f);gb=a+16|0;break c}e=ne(j+16|0,d);a=ne(j+8|0,g);d=ne(j,c);f=gb-16|0;gb=f;a=Rj(a,e);v[f+12>>2]=a;e:{if((a|0)<=0){break e}c=v[e+4>>2];f:{if(!c){c=v[d+4>>2];break f}c=32-c|0;v[f+8>>2]=c;g=f+8|0;a=v[pd(g,f+12|0)>>2];v[f+12>>2]=v[f+12>>2]-a;h=v[d+4>>2];k=v[v[e>>2]>>2];i=v[e+4>>2];v[f+8>>2]=a;m=32-h|0;v[f+4>>2]=m;n=Fb(g,f+4|0);h=v[d>>2];k=k&(-1<<i&-1>>>c-a);c=v[d+4>>2];g=v[e+4>>2];i=c>>>0>g>>>0?k<<c-g:k>>>g-c|0;g=v[n>>2];v[h>>2]=i|v[h>>2]&(-1<<c&-1>>>m-g^-1);i=c+g|0;c=i&31;v[d+4>>2]=c;h=h+(i>>>3&536870908)|0;v[d>>2]=h;a=a-g|0;if((a|0)>0){v[h>>2]=v[h>>2]&(-1>>>32-a^-1)|k>>>g+v[e+4>>2];v[d+4>>2]=a;c=a}v[e>>2]=v[e>>2]+4;a=v[f+12>>2]}g=32-c|0;if((a|0)>=32){k=-1<<c;i=k^-1;h=v[e>>2];while(1){a=v[d>>2];h=v[h>>2];v[a>>2]=i&v[a>>2]|h<<c;v[d>>2]=a+4;v[a+4>>2]=k&v[a+4>>2]|h>>>g;m=v[f+12>>2];a=m-32|0;v[f+12>>2]=a;h=v[e>>2]+4|0;v[e>>2]=h;if((m|0)>63){continue}break}}if((a|0)<=0){break e}k=v[v[e>>2]>>2];v[f+8>>2]=g;c=pd(f+12|0,f+8|0);e=v[d>>2];h=v[d+4>>2];c=v[c>>2];i=v[e>>2]&(-1<<h&-1>>>g-c^-1);g=k&-1>>>32-a;v[e>>2]=i|g<<h;a=c+h|0;v[d+4>>2]=a&31;a=e+(a>>>3&536870908)|0;v[d>>2]=a;e=v[f+12>>2]-c|0;v[f+12>>2]=e;if((e|0)<=0){break e}v[a>>2]=v[a>>2]&(-1>>>32-e^-1)|g>>>c;v[d+4>>2]=v[f+12>>2]}ne(b,d);gb=f+16|0}gb=j+48|0;gb=l+48|0}function Epa(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;e=gb-48|0;gb=e;a:{b:{c:{d:{i=a+24|0;e:{if(Dd(i)){break e}h=a+4|0;j=Ab(h);a=gb-48|0;gb=a;c=a+40|0;b=c;v[b>>2]=-1;v[b+4>>2]=-1;v[22656]=0;b=uG(2290);d=v[22656];v[22656]=0;if((d|0)==1){break a}v[a+8>>2]=b;v[a+12>>2]=jb;b=v[a+12>>2];v[a+16>>2]=v[a+8>>2];v[a+20>>2]=b;b=gb-16|0;gb=b;g=a+16|0;d=g;k=b,l=kqa(v[d>>2],v[d+4>>2],1e3,0),v[k>>2]=l;v[b+4>>2]=jb;d=Zl(b+8|0,b);f=v[d+4>>2];gb=b+16|0;v[a+24>>2]=v[d>>2];v[a+28>>2]=f;d=a+24|0;b=d;b=UC(v[b>>2],v[b+4>>2]);t[a+32|0]=b;t[a+33|0]=b>>>8;t[a+34|0]=b>>>16;t[a+35|0]=b>>>24;b=jb;t[a+36|0]=b;t[a+37|0]=b>>>8;t[a+38|0]=b>>>16;t[a+39|0]=b>>>24;b=v[a+36>>2];v[a+24>>2]=v[a+32>>2];v[a+28>>2]=b;gX(c,d,wb(d));v[22656]=0;b=uG(2291);f=v[22656];v[22656]=0;if((f|0)==1){break a}v[a+8>>2]=b;v[a+12>>2]=jb;b=v[a+12>>2];v[a+16>>2]=v[a+8>>2];v[a+20>>2]=b;b=gb-16|0;gb=b;f=v[g+4>>2];v[b>>2]=v[g>>2];v[b+4>>2]=f;g=Zl(b+8|0,b);f=v[g+4>>2];gb=b+16|0;v[a+24>>2]=v[g>>2];v[a+28>>2]=f;b=UC(v[d>>2],v[d+4>>2]);t[a+32|0]=b;t[a+33|0]=b>>>8;t[a+34|0]=b>>>16;t[a+35|0]=b>>>24;b=jb;t[a+36|0]=b;t[a+37|0]=b>>>8;t[a+38|0]=b>>>16;t[a+39|0]=b>>>24;b=v[a+36>>2];v[a+24>>2]=v[a+32>>2];v[a+28>>2]=b;gX(c,d,wb(d));d=v[c>>2];c=v[c+4>>2];gb=a+48|0;if(j){b=mc(e+32|0);v[22656]=0;v[e+16>>2]=c;R(40,b|0,e+16|0);a=v[22656];v[22656]=0;f:{g:{h:{if((a|0)!=1){v[22656]=0;v[e+16>>2]=d;R(40,b|0,e+16|0);a=v[22656];v[22656]=0;if((a|0)==1){break h}if(Ab(h)){a=0;while(1){c=w[pc(h,a)|0];v[22656]=0;v[e+16>>2]=c;R(40,b|0,e+16|0);c=v[22656];v[22656]=0;if((c|0)==1){break c}a=a+1|0;if(Ab(h)>>>0>a>>>0){continue}break}}a=Vb(b);c=Zb(b);v[22656]=0;c=W(41,e+16|0,a|0,c|0)|0;a=v[22656];v[22656]=0;if((a|0)==1){break g}v[22656]=0;a=T(42,c|0)|0;d=v[22656];v[22656]=0;if((d|0)==1){break f}v[e+8>>2]=a;a=e+8|0;_C(i,a);ln(a);Nc(c);Nc(b);break e}a=P()|0;O()|0;break b}a=P()|0;O()|0;break b}a=P()|0;O()|0;break b}a=P()|0;O()|0;Nc(c);break b}jb=d;v[e+16>>2]=c;v[e+20>>2]=jb;b=e+32|0;a=mc(b);v[22656]=0;U(49,b|0,e+16|0,e+24|0);c=v[22656];v[22656]=0;if((c|0)==1){b=P()|0;O()|0;Nc(a);S(b|0);L()}v[22656]=0;a=T(42,b|0)|0;c=v[22656];v[22656]=0;if((c|0)==1){break d}v[e+8>>2]=a;a=e+8|0;_C(i,a);ln(a);Nc(b)}gb=e+48|0;return}a=P()|0;O()|0;break b}a=P()|0;O()|0}Nc(b);S(a|0);L()}V(0)|0;O()|0;Bb();L()}function oR(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;g=gb-96|0;gb=g;t[g+95|0]=d;n=XA(a);o=Ri(n);u[b>>1]=0;a:{if(o){while(1){b:{if(!Po(n,h&65535)){break b}h=x[b>>1];if(Ec(a)>>>0<=h>>>0){v[c>>2]=0;a=1;break a}m=Ad(a,x[b>>1]);Ak(g+72|0,m);Vl(g- -64|0,m);h=v[g+76>>2];v[g+32>>2]=v[g+72>>2];v[g+36>>2]=h;h=v[g+68>>2];v[g+24>>2]=v[g+64>>2];v[g+28>>2]=h;l=g+80|0;e=g+32|0;j=g+24|0;h=gb-32|0;gb=h;c:{if(w[g+95|0]){f=v[e+4>>2];v[h+24>>2]=v[e>>2];v[h+28>>2]=f;e=Rj(j,e);j=v[h+28>>2];v[h+8>>2]=v[h+24>>2];v[h+12>>2]=j;j=gb-16|0;gb=j;v[j+12>>2]=e;i=h+8|0;f=v[i+4>>2];d:{if(f){v[j+8>>2]=32-f;e=Fb(j+8|0,j+12|0);k=v[i>>2];e=v[e>>2];f=v[k>>2]&(-1<<f&-1>>>v[j+8>>2]-e);if(f){td(l,k,jqa(f));break d}f=v[j+12>>2];if((f|0)==(e|0)){_Q(l,i,e);break d}e=f-e|0;v[j+12>>2]=e;v[i>>2]=k+4}if(e>>>0>=32){f=v[i>>2];while(1){k=v[f>>2];if(k){td(l,f,jqa(k));break d}f=f+4|0;v[i>>2]=f;e=e-32|0;v[j+12>>2]=e;if(e>>>0>31){continue}break}}e:{if(!e){f=v[i>>2];break e}f=v[i>>2];i=v[f>>2]&-1>>>32-e;if(!i){break e}td(l,f,jqa(i));break d}td(l,f,e)}gb=j+16|0;break c}f=v[e+4>>2];v[h+16>>2]=v[e>>2];v[h+20>>2]=f;e=Rj(j,e);j=v[h+20>>2];v[h>>2]=v[h+16>>2];v[h+4>>2]=j;f=gb-16|0;gb=f;v[f+12>>2]=e;j=h;i=v[h+4>>2];f:{if(i){v[f+8>>2]=32-i;e=v[Fb(f+8|0,f+12|0)>>2];k=-1<<i&-1>>>v[f+8>>2]-e;i=v[j>>2];k=k&(v[i>>2]^-1);if(k){td(l,i,jqa(k));break f}k=v[f+12>>2];if((k|0)==(e|0)){_Q(l,j,e);break f}e=k-e|0;v[f+12>>2]=e;v[j>>2]=i+4}if(e>>>0>=32){i=v[j>>2];while(1){k=v[i>>2];if((k|0)!=-1){td(l,i,jqa(k^-1));break f}i=i+4|0;v[j>>2]=i;e=e-32|0;v[f+12>>2]=e;if(e>>>0>31){continue}break}}g:{if(!e){i=v[j>>2];break g}i=v[j>>2];j=(v[i>>2]^-1)&-1>>>32-e;if(!j){break g}td(l,i,jqa(j));break f}td(l,i,e)}gb=f+16|0}gb=h+32|0;if(d){h=g+56|0;Vl(h,m);if(!nR(g+80|0,h)){break b}v[c>>2]=0;a=1;break a}h=g+56|0;Vl(h,m);if(nR(g+80|0,h)^1){Ak(g+48|0,m);a=v[g+84>>2];b=v[g+80>>2];v[g+40>>2]=b;v[g+44>>2]=a;d=v[g+52>>2];v[g+16>>2]=v[g+48>>2];v[g+20>>2]=d;v[g+8>>2]=b;v[g+12>>2]=a;p=c,q=CU(g+16|0,g+8|0),v[p>>2]=q;a=1;break a}if(y[m+4>>2]>=y[_b(v[a+24>>2]+484344|0,x[sc(n,x[b>>1])>>1])+12>>2]){break b}v[c>>2]=v[m+4>>2];a=1;break a}h=x[b>>1]+1|0;u[b>>1]=h;if((h&65535)>>>0<o>>>0){continue}break}}u[b>>1]=65535;v[c>>2]=-1;a=0}gb=g+96|0;return a|0}function Qea(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;d=gb-1184|0;gb=d;vc(b);a:{if(!$w(b,d+1160|0)){break a}if(!NN(d+1160|0)){break a}e=d+1168|0;if((w[e|0]|w[e+1|0]<<8|(w[e+2|0]<<16|w[e+3|0]<<24))!=(lm(b)|0)){break a}f=d+1176|0;if((w[f|0]|w[f+1|0]<<8|(w[f+2|0]<<16|w[f+3|0]<<24))!=(nf(b)|0)){break a}if(!c){g=1;break a}e=d+1104|0;Qb(e,0,56);i=-2;b:{if(!e){break b}v[e+44>>2]=0;v[e+48>>2]=0;v[e+52>>2]=0;v[e+20>>2]=0;v[e+24>>2]=0;v[e+8>>2]=0;h=v[e+32>>2];if(!h){v[e+32>>2]=2281;h=2281}if(!v[e+36>>2]){v[e+36>>2]=2282}h=kb[h|0](v[e+40>>2],1,43784)|0;i=-4;if(!h){break b}v[e+28>>2]=h;v[h+43780>>2]=1;v[h+10992>>2]=0;v[h+10996>>2]=0;v[h>>2]=0;v[h+11008>>2]=15;v[h+11e3>>2]=1;v[h+11004>>2]=0;i=0}if(i){break a}e=w[f|0]|w[f+1|0]<<8|(w[f+2|0]<<16|w[f+3|0]<<24);v[d+1100>>2]=e;g=d+1180|0;g=w[g|0]|w[g+1|0]<<8|(w[g+2|0]<<16|w[g+3|0]<<24);f=(g|0)!=0;h=oX(d+1088|0,g);c:{d:{e:{f:{g:{h:{i:{j:{if(!e|!g){break j}while(1){v[22656]=0;v[d+48>>2]=1024;e=Fb(d+48|0,d+1100|0);f=v[22656];v[22656]=0;if((f|0)==1){break d}e=v[e>>2];f=wd(d+56|0,d- -64|0,e);v[22656]=0;i=v[f+4>>2];v[d+24>>2]=v[f>>2];v[d+28>>2]=i;U(201,d+48|0,b|0,d+24|0);f=v[22656];v[22656]=0;if((f|0)==1){break h}v[22656]=0;j=xJ(j,d- -64|0,e);f=v[22656];v[22656]=0;if((f|0)==1){break i}v[d+1120>>2]=g;v[d+1108>>2]=e;v[d+1104>>2]=d- -64;f=v[h>>2];v[22656]=0;v[d+1116>>2]=f+k;l=Q(1470,d+1104|0,0)|0;f=v[22656];v[22656]=0;if((f|0)==1){break i}i=v[d+1100>>2]-e|0;v[d+1100>>2]=i;e=v[d+1120>>2];f=(e|0)!=0;if(!i|!e){break j}k=(g+k|0)-e|0;g=e;if((l|0)!=1){continue}break}}v[22656]=0;T(1471,d+1104|0)|0;b=v[22656];v[22656]=0;if((b|0)==1){break g}g=0;b=d+1172|0;if(!((w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24))!=(j|0)|f|(l|0)!=1)){v[22656]=0;Vd(d+40|0,h);b=v[22656];v[22656]=0;if((b|0)==1){break f}b=Ud(d+32|0);v[22656]=0;g=v[d+44>>2];v[d+16>>2]=v[d+40>>2];v[d+20>>2]=g;g=v[b+4>>2];v[d+8>>2]=v[b>>2];v[d+12>>2]=g;b=W(732,d- -64|0,d+16|0,d+8|0)|0;g=v[22656];v[22656]=0;if((g|0)==1){break f}v[22656]=0;g=W(1384,a|0,b|0,c|0)|0;a=v[22656];v[22656]=0;if((a|0)==1){break e}xb(b)}gc(h);break a}a=P()|0;O()|0;break c}a=P()|0;O()|0;break c}a=P()|0;O()|0;break c}a=P()|0;O()|0;break c}a=P()|0;O()|0;xb(b);break c}a=P()|0;O()|0}gc(h);S(a|0);L()}gb=d+1184|0;return g|0}function _ea(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;h=gb-16|0;gb=h;v[22656]=0;e=T(788,a|0)|0;g=v[22656];v[22656]=0;if((g|0)!=1){a:{b:{if(e){break b}v[22656]=0;e=T(374,a|0)|0;g=v[22656];v[22656]=0;if((g|0)==1){break a}i=Md(e+1|0,1,1024);v[22656]=0;k=d+484344|0;e=W(331,k|0,b|0,i|0)|0;g=v[22656];v[22656]=0;if((g|0)==1){break a}if(!e){break b}d=x[d+480188>>1];if(!d|!i){break b}l=d-1|0;while(1){v[22656]=0;d=Q(191,a|0,1)|0;e=v[22656];v[22656]=0;c:{d:{if((e|0)!=1){if(!d){break b}v[22656]=0;g=T(374,a|0)|0;d=v[22656];v[22656]=0;if((d|0)==1){break a}if(g){break d}j=j+1|0;break c}break a}d=_b(k,b);u[h+14>>1]=g&31;v[22656]=0;u[h+12>>1]=l;e=Pc(h+14|0,h+12|0);f=v[22656];v[22656]=0;if((f|0)==1){break a}e=x[e>>1];v[22656]=0;d=Yc(d,j,e);e=v[22656];v[22656]=0;if((e|0)==1){break a}if(!(g&224)){break c}e:{if(!(g&128)){break e}v[22656]=0;e=T(374,a|0)|0;f=v[22656];v[22656]=0;if((f|0)==1){break a}t[d+5|0]=e;v[22656]=0;e=T(374,a|0)|0;f=v[22656];v[22656]=0;if((f|0)==1){break a}f:{if(e>>>0>=26){break f}e=w[e+49040|0];t[d+3|0]=e;g:{switch(e-1|0){case 0:if(!w[d+5|0]){break f}break e;case 12:if(w[d+2|0]){break e}t[d+2|0]=1;e=Md(w[d+5|0],0,64);t[d+5|0]=0;t[d+3|0]=0;t[d+4|0]=e;break e;case 5:case 6:case 10:case 23:case 28:e=w[d+5|0]&240;if(!e){break e}t[d+5|0]=e;break e;case 8:e=w[d+5|0];if(e>>>0<=128){n=d,o=Xi(e<<1),t[n+5|0]=o;break e}if((e|0)!=164){break e}t[d+5|0]=145;t[d+3|0]=20;break e;case 13:e=w[d+5|0];t[d+5|0]=B(e>>>4|0,10)+(e&15);break e;case 18:v[22656]=0;$t(d);e=v[22656];v[22656]=0;if((e|0)!=1){break e}break a;case 16:if(w[d+5|0]>31){break e}t[d+3|0]=16;break e;case 27:break g;default:break e}}m=d;e=w[d+5|0];f=e&240;h:{if((f|0)==16){f=2}else{if((f|0)!=32){break h}f=3}t[m+3|0]=f}t[d+5|0]=e&15|224;break e}t[d+3|0]=0}i:{if(!(g&64)){break i}v[22656]=0;R(403,h+8|0,a|0);e=v[22656];v[22656]=0;if((e|0)==1){break a}e=h+8|0;f=qd(e);t[d+1|0]=w[e|0];e=w[f|0];t[d|0]=e;f=255;if((e|0)!=128){f=253;if(e>>>0<129){break i}}t[d|0]=f}if(!(g&32)){break c}t[d+2|0]=1;v[22656]=0;e=T(374,a|0)|0;g=v[22656];v[22656]=0;if((g|0)==1){break a}t[d+4|0]=e;if(!c){break c}t[d+4|0]=(e<<6>>>0)/127}if(i>>>0>j>>>0){continue}break}}xb(a);gb=h+16|0;return}}b=P()|0;O()|0;xb(a);S(b|0);L()}function R7(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=gb-160|0;gb=d;a:{if(rk(b)){break a}e=w[vl(b)|0];if((e|0)==33){c=1}else{if((e|0)!=63){break a}c=0}Kl(d+128|0,b,v[b+4>>2]-1|0);e=v[d+132>>2];v[b>>2]=v[d+128>>2];v[b+4>>2]=e}f=d+128|0;Ld(f);e=v[d+128>>2];Ld(d+112|0);e=ul(e,v[d+116>>2],b);Ld(f);b:{c:{d:{e:{f:{g:{if((e|0)==v[d+132>>2]){a=v[b+4>>2];v[d+152>>2]=v[b>>2];v[d+156>>2]=a;a=uc(d+144|0,18726);e=v[d+156>>2];v[d+8>>2]=v[d+152>>2];v[d+12>>2]=e;e=v[a+4>>2];v[d>>2]=v[a>>2];v[d+4>>2]=e;if(Gc(d+8|0,d)){a=ba(8)|0;v[22656]=0;c=Q(70,d+128|0,7752)|0;b=v[22656];v[22656]=0;if((b|0)==1){break f}rc(a,c);v[22656]=0;U(186,a|0,54952,1936);a=v[22656];v[22656]=0;if((a|0)!=1){break b}b=P()|0;O()|0;vb(c);break c}e=0;f=0;if(!c){break g}a=ba(8)|0;v[22656]=0;c=Q(2057,d+112|0,b|0)|0;b=v[22656];v[22656]=0;if((b|0)!=1){v[22656]=0;U(2037,d+128|0,14764,c|0);b=v[22656];v[22656]=0;if((b|0)==1){break e}rc(a,d+128|0);v[22656]=0;U(186,a|0,54952,1936);a=v[22656];v[22656]=0;if((a|0)!=1){break b}b=P()|0;O()|0;vb(d+128|0);vb(c);break c}b=P()|0;O()|0;break d}if(v[e+4>>2]!=1){a=ba(8)|0;v[22656]=0;c=Q(70,d+128|0,8874)|0;b=v[22656];v[22656]=0;if((b|0)!=1){rc(a,c);v[22656]=0;U(186,a|0,54952,1936);a=v[22656];v[22656]=0;if((a|0)!=1){break b}b=P()|0;O()|0;vb(c);break c}b=P()|0;O()|0;ca(a|0);break c}c=v[b+4>>2];v[d+104>>2]=v[b>>2];v[d+108>>2]=c;c=uc(d+96|0,18726);e=v[d+108>>2];v[d+56>>2]=v[d+104>>2];v[d+60>>2]=e;e=v[c+4>>2];v[d+48>>2]=v[c>>2];v[d+52>>2]=e;if(Gc(d+56|0,d+48|0)){a=ba(8)|0;v[22656]=0;c=Q(70,d+128|0,7752)|0;b=v[22656];v[22656]=0;if((b|0)!=1){rc(a,c);v[22656]=0;U(186,a|0,54952,1936);a=v[22656];v[22656]=0;if((a|0)!=1){break b}b=P()|0;O()|0;vb(c);break c}b=P()|0;O()|0;ca(a|0);break c}c=v[b+4>>2];v[d+88>>2]=v[b>>2];v[d+92>>2]=c;c=uc(d+80|0,8207);e=v[d+92>>2];v[d+40>>2]=v[d+88>>2];v[d+44>>2]=e;e=v[c+4>>2];v[d+32>>2]=v[c>>2];v[d+36>>2]=e;if(Gc(d+40|0,d+32|0)){a=v[a+8>>2];e=a;f=a>>31;break g}c=v[b+4>>2];v[d+72>>2]=v[b>>2];v[d+76>>2]=c;b=uc(d- -64|0,5758);c=v[d+76>>2];v[d+24>>2]=v[d+72>>2];v[d+28>>2]=c;c=v[b+4>>2];v[d+16>>2]=v[b>>2];v[d+20>>2]=c;e=0;f=0;if(!Gc(d+24|0,d+16|0)){break g}e=Ky(v[a+32>>2]);f=0}gb=d+160|0;jb=f;return e|0}b=P()|0;O()|0;ca(a|0);break c}b=P()|0;O()|0;vb(c)}ca(a|0)}S(b|0)}L()}function p9(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;a=Kb(a);v[22656]=0;X(2027);c=v[22656];v[22656]=0;a:{b:{if((c|0)==1){c=Sa(54952,89116,89092,0)|0;c:{d:{e:{d=O()|0;if((d|0)==(ea(54952)|0)){c=Z(c|0)|0;v[22656]=0;Q(1917,a|0,b|0)|0;b=v[22656];v[22656]=0;if((b|0)==1){break e}v[22656]=0;Q(1917,a|0,14864)|0;b=v[22656];v[22656]=0;if((b|0)==1){break e}v[22656]=0;Q(1917,a|0,14840)|0;b=v[22656];v[22656]=0;if((b|0)==1){break e}b=kb[v[v[c>>2]+8>>2]](c)|0;v[22656]=0;Q(1917,a|0,(b?b:18726)|0)|0;b=v[22656];v[22656]=0;if((b|0)==1){break e}v[22656]=0;X(20);b=v[22656];v[22656]=0;if((b|0)!=1){break b}b=P()|0;O()|0;break a}f:{if((ea(89116)|0)==(d|0)){c=Z(c|0)|0;v[22656]=0;Q(1917,a|0,b|0)|0;b=v[22656];v[22656]=0;if((b|0)==1){break f}v[22656]=0;Q(1917,a|0,14864)|0;b=v[22656];v[22656]=0;if((b|0)==1){break f}v[22656]=0;Q(1917,a|0,14815)|0;b=v[22656];v[22656]=0;if((b|0)==1){break f}b=kb[v[v[c>>2]+8>>2]](c)|0;v[22656]=0;Q(1917,a|0,(b?b:18726)|0)|0;b=v[22656];v[22656]=0;if((b|0)==1){break f}v[22656]=0;X(20);b=v[22656];v[22656]=0;if((b|0)!=1){break b}b=P()|0;O()|0;break a}e=ea(89092)|0;c=Z(c|0)|0;g:{if((d|0)==(e|0)){v[22656]=0;Q(1917,a|0,b|0)|0;b=v[22656];v[22656]=0;if((b|0)==1){break g}v[22656]=0;Q(1917,a|0,14864)|0;b=v[22656];v[22656]=0;if((b|0)==1){break g}v[22656]=0;Q(1917,a|0,14831)|0;b=v[22656];v[22656]=0;if((b|0)==1){break g}b=kb[v[v[c>>2]+8>>2]](c)|0;v[22656]=0;Q(1917,a|0,(b?b:18726)|0)|0;b=v[22656];v[22656]=0;if((b|0)==1){break g}v[22656]=0;X(20);b=v[22656];v[22656]=0;if((b|0)!=1){break b}b=P()|0;O()|0;break a}v[22656]=0;Q(1917,a|0,b|0)|0;b=v[22656];v[22656]=0;if((b|0)==1){break d}v[22656]=0;Q(1917,a|0,14864)|0;b=v[22656];v[22656]=0;if((b|0)==1){break d}v[22656]=0;Q(1917,a|0,11040)|0;b=v[22656];v[22656]=0;if((b|0)==1){break d}v[22656]=0;X(20);b=v[22656];v[22656]=0;if((b|0)!=1){break b}b=P()|0;O()|0;break a}b=P()|0;O()|0;v[22656]=0;X(20);c=v[22656];v[22656]=0;if((c|0)!=1){break a}break c}b=P()|0;O()|0;v[22656]=0;X(20);c=v[22656];v[22656]=0;if((c|0)!=1){break a}break c}b=P()|0;O()|0;v[22656]=0;X(20);c=v[22656];v[22656]=0;if((c|0)==1){break c}break a}b=P()|0;O()|0;v[22656]=0;X(20);c=v[22656];v[22656]=0;if((c|0)!=1){break a}}V(0)|0;O()|0;Bb()}L()}return}vb(a);S(b|0);L()}function P7(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0;e=gb-160|0;gb=e;a:{if(rk(c)){break a}f=w[vl(c)|0];if((f|0)==33){d=1}else{if((f|0)!=63){break a}d=0}Kl(e+128|0,c,v[c+4>>2]-1|0);f=v[e+132>>2];v[c>>2]=v[e+128>>2];v[c+4>>2]=f}f=e+128|0;Ld(f);g=v[e+128>>2];Ld(e+112|0);h=ul(g,v[e+116>>2],c);Ld(f);f=v[c>>2];g=v[c+4>>2];b:{c:{d:{e:{f:{g:{if((h|0)==v[e+132>>2]){v[e+152>>2]=f;v[e+156>>2]=g;b=uc(e+144|0,18726);f=v[e+156>>2];v[e+8>>2]=v[e+152>>2];v[e+12>>2]=f;f=v[b+4>>2];v[e>>2]=v[b>>2];v[e+4>>2]=f;if(Gc(e+8|0,e)){a=ba(8)|0;v[22656]=0;b=Q(70,e+128|0,7752)|0;c=v[22656];v[22656]=0;if((c|0)==1){break f}rc(a,b);v[22656]=0;U(186,a|0,54952,1936);a=v[22656];v[22656]=0;if((a|0)!=1){break b}c=P()|0;O()|0;vb(b);break c}if(d){a=ba(8)|0;v[22656]=0;b=Q(2057,e+112|0,c|0)|0;c=v[22656];v[22656]=0;if((c|0)!=1){v[22656]=0;U(2037,e+128|0,14764,b|0);c=v[22656];v[22656]=0;if((c|0)==1){break e}rc(a,e+128|0);v[22656]=0;U(186,a|0,54952,1936);a=v[22656];v[22656]=0;if((a|0)!=1){break b}c=P()|0;O()|0;vb(e+128|0);vb(b);break c}c=P()|0;O()|0;break d}Kb(a);break g}v[e+104>>2]=f;v[e+108>>2]=g;d=uc(e+96|0,18726);f=v[e+108>>2];v[e+56>>2]=v[e+104>>2];v[e+60>>2]=f;f=v[d+4>>2];v[e+48>>2]=v[d>>2];v[e+52>>2]=f;if(Gc(e+56|0,e+48|0)){a=ba(8)|0;v[22656]=0;b=Q(70,e+128|0,7752)|0;c=v[22656];v[22656]=0;if((c|0)!=1){rc(a,b);v[22656]=0;U(186,a|0,54952,1936);a=v[22656];v[22656]=0;if((a|0)!=1){break b}c=P()|0;O()|0;vb(b);break c}c=P()|0;O()|0;ca(a|0);break c}d=v[c+4>>2];v[e+88>>2]=v[c>>2];v[e+92>>2]=d;d=uc(e+80|0,9597);f=v[e+92>>2];v[e+40>>2]=v[e+88>>2];v[e+44>>2]=f;f=v[d+4>>2];v[e+32>>2]=v[d>>2];v[e+36>>2]=f;if(Gc(e+40|0,e+32|0)){h:{switch(v[b+52>>2]){case 0:Tb(a,2693);break g;case 1:Tb(a,8575);break g;case 2:Tb(a,6363);break g;default:break h}}Kb(a);break g}d=v[c+4>>2];v[e+72>>2]=v[c>>2];v[e+76>>2]=d;c=uc(e- -64|0,8812);d=v[e+76>>2];v[e+24>>2]=v[e+72>>2];v[e+28>>2]=d;d=v[c+4>>2];v[e+16>>2]=v[c>>2];v[e+20>>2]=d;if(Gc(e+24|0,e+16|0)){i:{switch(v[b+56>>2]){case 0:Tb(a,12689);break g;case 1:Tb(a,12694);break g;case 2:Tb(a,9902);break g;case 3:Tb(a,6427);break g;default:break i}}Kb(a);break g}Kb(a)}gb=e+160|0;return}c=P()|0;O()|0;ca(a|0);break c}c=P()|0;O()|0;vb(b)}ca(a|0)}S(c|0)}L()}function tZ(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,x=0,z=0,A=0,C=0,D=0,E=0,F=0,G=0;e=gb-32|0;gb=e;j=bj(e+24|0);if(v[a+12>>2]){q=b^1;r=j+3|0;s=j+5|0;x=j+4|0;z=j+2|0;A=j+1|0;d=e+16|0;C=d|5;D=d|3;while(1){E=Tf(a,n);while(1){a:{if(!Pb(c,1)){break a}k=Ae(c);if((k|0)==255){break a}h=k&31;d=Ji(a)>>>0>h>>>0;h=B(h,6)+E|0;if(k&64){l=1}else{f=Ae(c);i=f<<24>>24;g=255;f=f&127;b:{c:{if((f|0)==1){break c}g=f-1|0;if(((g&255)>>>0>120|q)!=1){break c}if((f-12&255)>>>0>96|b){break b}g=f+13|0}t[(d?h:e+24|0)|0]=g}F=d?h+1|0:A,G=Ae(c),t[F|0]=G;l=(i|0)<0}if(l){p=d?h:j;f=d?h+3|0:r;g=d?h+5|0:s;o=d?h+4|0:x;m=d?h+2|0:z;h=d?h:e+24|0;while(1){d=h;v[e+16>>2]=w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24);u[e+20>>1]=w[d+4|0]|w[d+5|0]<<8;d=Ae(c);l=d&128;i=d&63;d:{if(d&64){t[m|0]=1;t[o|0]=i;break d}d=Ae(c);t[g|0]=d;e:{f:{if(i>>>0<=15){t[f|0]=i;Of(p);g:{h:{i:{d=w[f|0];switch(d-9|0){case 1:case 2:case 3:break e;case 4:break h;case 0:break i;default:break g}}t[f|0]=9;t[g|0]=B(w[g|0]&15,17);break e}t[f|0]=0;t[m|0]=1;v[e+12>>2]=w[g|0]+1>>>1;v[e+8>>2]=64;F=o,G=v[pd(e+12|0,e+8|0)>>2],t[F|0]=G;break e}if((d|0)!=19){break e}if(w[g|0]==128){break f}$t(p);break e}if(i>>>0>44){break e}t[f|0]=w[i+28448|0];j:{switch(i-16|0){case 0:if(d>>>0>1){break f}t[g|0]=d|158;break e;case 1:case 2:t[e+12|0]=15;F=g,G=w[ac(e+12|0,g)|0]|224,t[F|0]=G;break e;case 5:case 6:v[e+12>>2]=16;v[e+8>>2]=d+1;F=g,G=v[pd(e+12|0,e+8|0)>>2]/2|240,t[F|0]=G;break e;case 14:k:{l:{m:{n:{o:{i=d>>>4|0;switch(i-1|0){case 1:break m;case 0:break n;default:break o}}switch(i-10|0){case 1:break k;case 0:break l;default:break f}}t[f|0]=2;t[g|0]=d|240;break e}t[f|0]=3;t[g|0]=d|240;break e}t[f|0]=11;t[g|0]=(d<<3&120)+8|15;break e}t[f|0]=11;t[g|0]=(d&15)+1>>>1|240;break e;case 12:break j;default:break e}}v[e+12>>2]=d+1>>>1;v[e+8>>2]=64;F=g,G=v[pd(e+12|0,e+8|0)>>2],t[F|0]=G;break e}t[f|0]=0}tz(f,g,D,C);if(Fj(w[e+19|0])>>>0<=Fj(w[f|0])>>>0){break d}p:{if(w[m|0]){break p}if(!Zt(f,g,1)){break p}t[m|0]=w[f|0];t[o|0]=w[g|0]}t[f|0]=w[e+19|0];t[g|0]=w[e+21|0]}if(l){continue}break}}if(!(k&128)){continue}}break}n=n+1|0;if(n>>>0<y[a+12>>2]){continue}break}}gb=e+32|0}function qpa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,z=0;d=gb-1120|0;gb=d;v[d+1116>>2]=c;j=sD(d+56|0,b);v[22656]=0;p=nn(j);c=v[22656];v[22656]=0;a:{b:{c:{d:{e:{f:{g:{h:{if((c|0)!=1){f=mc(a);v[22656]=0;a=T(467,b|0)|0;c=v[22656];v[22656]=0;if((c|0)==1){break h}v[d+16>>2]=a;v[22656]=0;v[d+48>>2]=85899345;a=Fb(d+16|0,d+48|0);c=v[22656];v[22656]=0;if((c|0)==1){break g}a=v[a>>2];v[22656]=0;v[d+32>>2]=B(a,50);a=Fb(d+1116|0,d+32|0);c=v[22656];v[22656]=0;if((c|0)==1){break g}a=v[a>>2];v[22656]=0;R(499,f|0,a|0);a=v[22656];v[22656]=0;if((a|0)==1){break g}v[22656]=0;e=T(513,d+32|0)|0;a=v[22656];v[22656]=0;if((a|0)==1){break f}a=0;v[22656]=0;g=Q(514,d+16|0,8192)|0;c=v[22656];v[22656]=0;if((c|0)==1){break e}while(1){s=Mb(e,a),z=8192,u[s>>1]=z;s=Mb(e,a),z=a,t[s+2|0]=z;a=a+1|0;if((a|0)!=256){continue}break}m=9;break d}a=P()|0;O()|0;break a}a=P()|0;O()|0;break b}a=P()|0;O()|0;break b}a=P()|0;O()|0;break b}a=P()|0;O()|0;break c}i:{j:while(1){c=0;n=257;while(1){q=m&255;k:{while(1){i=n&65535;while(1){v[22656]=0;h=Q(200,j|0,q|0)|0;a=v[22656];v[22656]=0;if((a|0)==1){break i}k=h&65535;if((k|0)==257|i>>>0<k>>>0){break k}if(oc(f)>>>0>=y[d+1116>>2]){break k}if((k|0)==256){m=9;continue j}a=i>>>0>k>>>0?h:c;l=8192;while(1){a=a&65535;r=w[Mb(e,a)+2|0];l=l-1|0;o=l&65535;s=lc(g,o),z=r,t[s|0]=z;a=x[Mb(e,a)>>1];if(a>>>0<8192){continue}break}s=d,z=Zb(f),v[s+48>>2]=z;Fd(d+8|0,d+48|0);s=d,z=Vb(g),v[s>>2]=z;a=we(d,o);l=Zb(g);v[22656]=0;Y(500,f|0,v[d+8>>2],a|0,l|0);a=v[22656];v[22656]=0;if((a|0)==1){break i}l:{if((i|0)!=(k|0)){break l}a=lc(g,o);v[22656]=0;R(515,f|0,a|0);a=v[22656];v[22656]=0;if((a|0)!=1){break l}break i}if(i>>>0>=8192){c=h;continue}if(oc(f)>>>0>=y[d+1116>>2]){continue}break}a=lc(g,o);s=Mb(e,i),z=w[a|0],t[s+2|0]=z;s=Mb(e,i),z=c,u[s>>1]=z;a=n+1|0;n=8192;c=h;h=a&65535;if((h|0)==8192){continue}break}m=((h|0)==1<<q)+m|0;n=a;continue}break}break}v[22656]=0;a=nn(j);c=v[22656];v[22656]=0;m:{if((c|0)!=1){v[22656]=0;Q(190,b|0,((a-p|0)+3&-4)+p|0)|0;a=v[22656];v[22656]=0;if((a|0)!=1){break m}}break i}gc(g);mD(e);xb(j);gb=d+1120|0;return}a=P()|0;O()|0;gc(g)}mD(e)}gc(f)}xb(j);S(a|0);L()}function Du(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;f=gb-48|0;gb=f;v[f+32>>2]=c;u[f+38>>1]=b;i=XA(a);a:{if(tc(i)>>>0<=b>>>0){break a}if(wR(a,x[sc(i,b)>>1])>>>0<=c>>>0){break a}b:{if(Ec(a)>>>0>b>>>0){if(y[Ad(a,b)+4>>2]>c>>>0){break b}}Ko(a,0);if(Ec(a)>>>0<=b>>>0){break a}}g=x[v[a+24>>2]+480188>>1];c=f+16|0;b=v[d>>2];v[c>>2]=b;v[c+4>>2]=b+B(g,872);d=f+24|0;b=d;v[b>>2]=-2078137563;v[b+4>>2]=-873292572;g=e?-2046629010:-2078137563;i=e?-1352371636:-873292572;b=c;if(yR(b)){while(1){e=w[MT(b,h)+841|0];l=e^kqa(g^h,i^j,435,256);e=!e;g=(o=g,p=kqa(l,jb,435,256),q=e,q?o:p);i=e?i:jb;e=h+1|0;j=e?j:j+1|0;h=e;if(!j&yR(b)>>>0>e>>>0){continue}break}}v[d>>2]=g;v[d+4>>2]=i;i=Um(c,f+38|0,f+32|0);j=gb-16|0;gb=j;e=j+8|0;h=gb-16|0;gb=h;l=a+12|0;g=l;b=Yd(g);m=fR(g,i,b,fc(g));v[h+8>>2]=m;o=h,p=Ch(g),v[o>>2]=p;c:{if(Gb(h+8|0,h)){if(!Nl(wb(g),i,ue(h+8|0))){break c}}m=Ch(g)}gb=h+16|0;b=v[yc(e,m)>>2];gb=j+16|0;v[f+8>>2]=b;o=f,p=Dh(l),v[o+16>>2]=p;b=0;if(og(f+8|0,c)){b=cd(ue(f+8|0)+8|0)^1}h=v[d>>2]!=-2078137563|v[d+4>>2]!=-873292572;c=f+16|0;Ce(c,Ad(a,x[f+38>>1]),v[f+32>>2]);m=1;i=b|h;j=Cb(c)^1;if(!(j?1:i)){break a}if(b){g=ue(f+8|0)+8|0;n=Vb(g);e=Zb(g);c=d;k=gb-16|0;gb=k;v[k>>2]=e;v[k+8>>2]=n;if(Gb(k+8|0,k)){while(1){e=v[k+8>>2];if(v[e>>2]!=v[c>>2]|v[e+4>>2]!=v[c+4>>2]){e=k+8|0;Eu(e);if(Gb(e,k)){continue}}break}n=v[k+8>>2]}gb=k+16|0;v[f+16>>2]=n;o=f,p=Zb(g),v[o+40>>2]=p;if(Gb(f+16|0,f+40|0)){break a}}if(h){v[a+28>>2]=v[a+28>>2]+1}if(i){if(!(b|j)){d:{e=pR(l,Um(f+16|0,f+38|0,f+32|0));if(y[e+4>>2]<y[wb(e)>>2]){b=gb-16|0;gb=b;c=bR(b,e);wb(e);aR(v[c+4>>2]);v[c+4>>2]=v[c+4>>2]+8;$b(c);gb=b+16|0;break d}c=gb-32|0;gb=c;b=wb(e);b=WA(c+8|0,hs(e,rf(e)+1|0),rf(e),b);aR(v[b+8>>2]);v[b+8>>2]=v[b+8>>2]+8;VA(e,b);UA(b);gb=c+32|0}}e=pR(l,Um(f+16|0,f+38|0,f+32|0));e:{if(y[e+4>>2]<y[wb(e)>>2]){b=gb-16|0;gb=b;c=bR(b,e);wb(e);$Q(v[c+4>>2],d);v[c+4>>2]=v[c+4>>2]+8;$b(c);gb=b+16|0;break e}c=gb-32|0;gb=c;b=wb(e);b=WA(c+8|0,hs(e,rf(e)+1|0),rf(e),b);$Q(v[b+8>>2],d);v[b+8>>2]=v[b+8>>2]+8;VA(e,b);UA(b);gb=c+32|0}}b=f+16|0;Ce(b,Ad(a,x[f+38>>1]),v[f+32>>2]);Uf(b,1);m=0}gb=f+48|0;return m|0}function M9(a,b,c,d,e,f,g,h,i){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0;j=gb-80|0;gb=j;a:{b:{c:{k=Wp(1,32);d:{e:{if(!k){a=ba(4)|0;nm(a);v[22656]=0;U(186,a|0,89116,1928);a=v[22656];v[22656]=0;if((a|0)!=1){break a}i=V(0)|0;O()|0;break e}v[k+12>>2]=f;v[k+8>>2]=e;v[k+4>>2]=d;v[k>>2]=c?c:1919;d=Cu(j- -64|0);f:{g:{if(!i){break g}c=v[i>>2];if(!c){break g}while(1){h:{e=v[i+4>>2];if(e){v[22656]=0;c=Q(70,j+48|0,c|0)|0;f=v[22656];v[22656]=0;i:{if((f|0)!=1){v[22656]=0;f=Q(1929,d|0,c|0)|0;l=v[22656];v[22656]=0;if((l|0)==1){break i}v[22656]=0;Q(415,f|0,e|0)|0;e=v[22656];v[22656]=0;if((e|0)==1){break i}break h}i=V(0)|0;O()|0;break f}i=V(0)|0;O()|0;vb(c);break f}v[22656]=0;c=Q(70,j+48|0,c|0)|0;e=v[22656];v[22656]=0;j:{if((e|0)!=1){v[22656]=0;R(1930,d|0,c|0);e=v[22656];v[22656]=0;if((e|0)==1){break j}break h}i=V(0)|0;O()|0;break f}i=V(0)|0;O()|0;vb(c);break f}vb(c);c=v[i+8>>2];i=i+8|0;if(c){continue}break}}c=v[a+8>>2];e=v[a+4>>2];f=v[a>>2];v[22656]=0;a=T(1290,96)|0;i=v[22656];v[22656]=0;k:{l:{m:{if((i|0)!=1){v[j+44>>2]=c;v[j+40>>2]=e;v[j+36>>2]=f;v[j+32>>2]=b;v[22656]=0;b=Q(1931,k|0,k+4|0)|0;c=v[22656];v[22656]=0;if((c|0)==1){break m}v[j+48>>2]=b;b=v[jq(j+24|0,j+48|0)>>2];c=v[j+44>>2];v[j+16>>2]=v[j+40>>2];v[j+20>>2]=c;v[22656]=0;c=v[j+36>>2];v[j+8>>2]=v[j+32>>2];v[j+12>>2]=c;da(2005,a|0,j+8|0,b|0,d|0)|0;b=v[22656];v[22656]=0;if((b|0)==1){break l}v[k+28>>2]=a;Dj(j+48|0);a=v[k+28>>2];v[k+24>>2]=a?a+8|0:0;Ll(d);break d}i=V(0)|0;O()|0;break f}i=V(0)|0;O()|0;break k}i=V(0)|0;O()|0;Dj(j+48|0)}Yb(a)}Ll(d);Z(i|0)|0;v[22656]=0;Y(1911,8630,k|0,g|0,h|0);a=v[22656];v[22656]=0;if((a|0)!=1){v[22656]=0;X(20);a=v[22656];v[22656]=0;if((a|0)!=1){a=v[k+28>>2];if(a){kb[v[v[a>>2]+4>>2]](a)}v[k+24>>2]=0;v[k+28>>2]=0;a=v[k+20>>2];if(a){Yb(a);v[k+20>>2]=0}Yb(k);k=0;break d}i=V(0)|0;O()|0;break e}i=V(0)|0;O()|0;v[22656]=0;X(20);a=v[22656];v[22656]=0;if((a|0)==1){break b}}Z(i|0)|0;k=0;v[22656]=0;Y(1911,8630,0,g|0,h|0);a=v[22656];v[22656]=0;if((a|0)==1){break c}$()}gb=j+80|0;return k|0}a=P()|0;O()|0;v[22656]=0;X(20);b=v[22656];v[22656]=0;if((b|0)==1){break b}S(a|0);L()}V(0)|0;O()|0;Bb()}L()}function Fha(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;h=gb-32|0;gb=h;v[h+24>>2]=d;k=fg(a,c);se(h,v[a+28>>2]);d=v[h+12>>2];v[h+16>>2]=v[h+8>>2];v[h+20>>2]=d;a:{if(!k){if(nd(a,5)){break a}}f=v[h+24>>2];d=gb-160|0;gb=d;i=Hm(d+56|0,v[a+28>>2]);v[22656]=0;g=Q(620,d+40|0,34104)|0;e=v[22656];v[22656]=0;b:{c:{d:{e:{if((e|0)!=1){v[22656]=0;v[d+24>>2]=19923028;v[d+28>>2]=0;U(621,i|0,g|0,d+24|0);e=v[22656];v[22656]=0;if((e|0)==1){break e}Hb(g);if(!(v[i>>2]&1073741824)){break d}break b}a=P()|0;O()|0;break c}a=P()|0;O()|0;Hb(g);break c}t[d+39|0]=0;v[22656]=0;g=Q(620,d+40|0,2597)|0;e=v[22656];v[22656]=0;f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{if((e|0)!=1){v[22656]=0;W(622,i|0,d+39|0,g|0)|0;e=v[22656];v[22656]=0;if((e|0)==1){break q}Hb(g);g=Kb(d+40|0);v[22656]=0;e=Q(620,d+24|0,7364)|0;j=v[22656];v[22656]=0;if((j|0)==1){break p}v[22656]=0;U(1093,i|0,g|0,e|0);j=v[22656];v[22656]=0;if((j|0)==1){break o}Hb(e);v[22656]=0;U(13,d+24|0,(w[d+39|0]?0:f)|0,g|0);e=v[22656];v[22656]=0;if((e|0)==1){break n}v[22656]=0;R(418,b|0,d+24|0);e=v[22656];v[22656]=0;if((e|0)==1){break m}e=d+24|0;vb(e);u[d+22>>1]=0;v[22656]=0;e=Q(620,e|0,8041)|0;f=v[22656];v[22656]=0;if((f|0)==1){break g}v[22656]=0;W(1094,i|0,d+22|0,e|0)|0;f=v[22656];v[22656]=0;if((f|0)==1){break l}Hb(e);zg(d+22|0,4e3);v[22656]=0;e=Q(620,d+24|0,10749)|0;f=v[22656];v[22656]=0;if((f|0)==1){break k}f=v[yc(d+16|0,x[d+22>>1])>>2];v[22656]=0;Y(1095,i|0,b|0,e|0,f|0);f=v[22656];v[22656]=0;if((f|0)==1){break j}Hb(e);u[d+14>>1]=65535;v[22656]=0;e=Q(620,d+24|0,6095)|0;f=v[22656];v[22656]=0;if((f|0)==1){break i}v[22656]=0;f=W(1094,i|0,d+14|0,e|0)|0;j=v[22656];v[22656]=0;if((j|0)==1){break h}j=x[d+22>>1];l=x[d+14>>1];Hb(e);if(!((f|0)==1|j>>>0<=l>>>0)){cf(b,x[d+14>>1])}vb(g);break b}a=P()|0;O()|0;break c}a=P()|0;O()|0;Hb(g);break c}a=P()|0;O()|0;break f}a=P()|0;O()|0;Hb(e);break f}a=P()|0;O()|0;break f}a=P()|0;O()|0;vb(d+24|0);break f}a=P()|0;O()|0;Hb(e);break f}a=P()|0;O()|0;break f}a=P()|0;O()|0;Hb(e);break f}a=P()|0;O()|0;break f}a=P()|0;O()|0;Hb(e);break f}a=P()|0;O()|0}vb(g)}gh(i);S(a|0);L()}gh(i);gb=d+160|0}Zf(a,k,c,h+16|0);gb=h+32|0}function $ha(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,w=0;e=gb-80|0;gb=e;r=v[a+16>>2];h=Ud(e+48|0);v[h+8>>2]=a+112;v[h+16>>2]=v[a+128>>2];t=h,w=jg(b+327720|0,v[b+20>>2],(v[a+88>>2]&16384)>>>14|0),v[t+12>>2]=w;b=v[h+16>>2];if(b){t=h,w=lg(a+8|0,b),v[t>>2]=w;v[h+4>>2]=jb}f=v[a+44>>2];v[e+32>>2]=f;m=v[a+48>>2];v[e+36>>2]=m;k=v[a+52>>2];v[e+40>>2]=k;l=v[a+56>>2];v[e+44>>2]=l;n=v[a+40>>2];o=v[a+36>>2];i=v[a+4>>2];g=v[a>>2];v[e+24>>2]=g;v[e+28>>2]=i;j=v[a+12>>2];v[e+16>>2]=v[a+8>>2];v[e+20>>2]=j;a:{if(d){while(1){m=0;f=m;j=g;v[e+72>>2]=g;v[e+76>>2]=f;i=((((i&2147483647)<<1|g>>>31)&2147483646)<<1)+r|0;b:{if((b|0)<=0){break b}while(1){g=(f&2147483647)<<1|j>>>31;Id(v[h+8>>2],(u[(g<<1|2)+i>>1]+u[i+((g&2147483646)<<1)>>1]|0)/8<<16>>16);Hd(v[h+8>>2],4);Ub(e+72|0,h);if((b|0)<2){break b}b=b-1|0;j=v[e+72>>2];f=v[e+76>>2];continue}}b=v[h+8>>2];Ub(b,b+8|0);b=v[h+8>>2];g=v[b+4>>2];if(g){f=b;b=(v[e+76>>2]&2147483647)<<1|v[e+72>>2]>>>31;Id(f,(u[(b<<1|2)+i>>1]+u[i+((b&2147483646)<<1)>>1]|0)/8<<16>>16);Hd(v[h+8>>2],g);b=v[h+8>>2];g=v[b>>2];v[b>>2]=g;v[b+4>>2]=0}d=d-1|0;f=ig(b,v[h+12>>2]);v[e+12>>2]=f;v[e+8>>2]=f;j=0;m=1;while(1){k=v[a+60>>2];l=k;i=(e+32|0)+(j<<3)|0;q=v[i>>2];b=Lb(q,-16777216,16776704);p=v[a+64>>2];g=Lb(v[i+4>>2],-16777216,16776704);s=k>>31;k=f<<8;f=k;f=kqa(l,s,f,f>>31);l=jb;p=kqa(p,p>>31,b,b>>31);f=p+f|0;b=jb+l|0;b=f>>>0<p>>>0?b+1|0:b;l=f;f=v[a+68>>2];f=kqa(f,f>>31,g,g>>31);g=l+f|0;b=jb+b|0;b=g>>>0<f>>>0?b+1|0:b;g=g+8388608|0;b=g>>>0<8388608?b+1|0:b;b=Jc(g,b,24);v[i+4>>2]=q;g=v[a+72>>2];v[(e+8|0)+(j<<2)>>2]=(b|0)/256;v[i>>2]=b-(g&k);if(m){j=1;m=0;f=v[e+12>>2];continue}break}b=v[a+32>>2];o=v[a+28>>2]+o|0;j=o>>12;v[c>>2]=v[c>>2]+B(j,v[e+8>>2]);n=b+n|0;b=n>>12;v[c+4>>2]=v[c+4>>2]+B(b,v[e+12>>2]);Ub(e+24|0,e+16|0);if(d){c=c+8|0;b=v[h+16>>2];g=v[e+24>>2];i=v[e+28>>2];continue}break}g=v[e+24>>2];i=v[e+28>>2];l=v[e+44>>2];k=v[e+40>>2];m=v[e+36>>2];f=v[e+32>>2];break a}b=n>>12;j=o>>12}v[a+40>>2]=n;v[a+20>>2]=j;v[a+36>>2]=o;v[a+56>>2]=l;v[a+52>>2]=k;v[a+48>>2]=m;v[a+44>>2]=f;v[a+24>>2]=b;v[a>>2]=g;v[a+4>>2]=i;gb=e+80|0}function Yy(a){a=a|0;var b=0,c=0,d=C(0),e=0;Qb(a+4960|0,0,76);t[a+5044|0]=0;v[a+5036>>2]=0;v[a+5040>>2]=0;b=v[a+4292>>2];d=z[a+4268>>2];v[22656]=0;e=a+4504|0;if(d<C(4294967296)&d>=C(0)){c=~~d>>>0}else{c=0}ha(1838,e|0,67,5,c|0,b|0);b=v[22656];v[22656]=0;a:{if((b|0)==1){break a}b=v[a+4296>>2];v[22656]=0;ha(1838,a+4528|0,62,5,c|0,b|0);b=v[22656];v[22656]=0;if((b|0)==1){break a}b=v[a+4300>>2];v[22656]=0;ha(1838,a+4552|0,53,5,c|0,b|0);b=v[22656];v[22656]=0;if((b|0)==1){break a}b=v[a+4304>>2];v[22656]=0;ha(1838,a+4576|0,43,5,c|0,b|0);b=v[22656];v[22656]=0;if((b|0)==1){break a}b=v[a+4308>>2];v[22656]=0;ha(1838,a+4600|0,32,5,c|0,b|0);b=v[22656];v[22656]=0;if((b|0)==1){break a}b=v[a+4312>>2];v[22656]=0;ha(1838,a+4624|0,22,5,c|0,b|0);b=v[22656];v[22656]=0;if((b|0)==1){break a}b=v[a+4316>>2];v[22656]=0;ha(1838,a+4648|0,75,5,c|0,b|0);b=v[22656];v[22656]=0;if((b|0)==1){break a}b=v[a+4320>>2];v[22656]=0;ha(1838,a+4672|0,69,5,c|0,b|0);b=v[22656];v[22656]=0;if((b|0)==1){break a}b=v[a+4324>>2];v[22656]=0;ha(1838,a+4696|0,60,5,c|0,b|0);b=v[22656];v[22656]=0;if((b|0)==1){break a}b=v[a+4328>>2];v[22656]=0;ha(1838,a+4720|0,48,5,c|0,b|0);b=v[22656];v[22656]=0;if((b|0)==1){break a}b=v[a+4332>>2];v[22656]=0;ha(1838,a+4744|0,36,5,c|0,b|0);b=v[22656];v[22656]=0;if((b|0)==1){break a}b=v[a+4336>>2];v[22656]=0;ha(1838,a+4768|0,25,5,c|0,b|0);b=v[22656];v[22656]=0;if((b|0)==1){break a}v[22656]=0;ha(1838,a+4792|0,0,0,0,0);b=v[22656];v[22656]=0;if((b|0)==1){break a}b=v[a+4344>>2];v[22656]=0;ha(1838,a+4816|0,3,0,c|0,b|0);b=v[22656];v[22656]=0;if((b|0)==1){break a}b=v[a+4348>>2];v[22656]=0;ha(1838,a+4840|0,3,0,c|0,b|0);b=v[22656];v[22656]=0;if((b|0)==1){break a}v[22656]=0;ha(1838,a+4864|0,407,1,c|0,0);b=v[22656];v[22656]=0;if((b|0)==1){break a}v[22656]=0;ha(1838,a+4888|0,400,1,c|0,0);b=v[22656];v[22656]=0;if((b|0)==1){break a}v[22656]=0;ha(1838,a+4912|0,10,0,c|0,-1);b=v[22656];v[22656]=0;if((b|0)==1){break a}v[22656]=0;ha(1838,a+4936|0,10,0,c|0,-1);c=v[22656];v[22656]=0;if((c|0)==1){break a}t[a+5045|0]=1;return}c=V(89116)|0;if((O()|0)==(ea(89116)|0)){Z(c|0)|0;t[a+5045|0]=0;$();return}S(c|0);L()}function Mca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=C(0),f=0,g=C(0),h=0,i=C(0),j=C(0),k=0,l=0,m=0,n=0,o=C(0),p=0,q=0,r=0,s=0,t=0,u=0,x=C(0),y=0,A=0,B=C(0),E=0,F=0,G=0,H=0,I=0,J=0,K=C(0);a:{if(!v[a+4316>>2]){break a}k=a+44|0;if(!mi(k)){break a}p=Nd(k,0);q=Nd(k,1);r=od(k,0);s=od(k,1);H=kb[v[v[a>>2]+192>>2]](a)|0;e=C(kb[v[v[a>>2]+200>>2]](a));B=C(kb[v[v[a>>2]+188>>2]](a));t=kb[v[v[a>>2]+212>>2]](a)|0;b:{if(!d){break b}u=a+4276|0;l=a+4264|0;h=w[a+4260|0];E=h?u:l;F=a+4300|0;G=a+4288|0;x=C(e/C(100));I=t&1;m=v[a+4256>>2];n=v[a+4312>>2];y=d;while(1){j=z[q>>2];i=z[p>>2];f=ro(a,m+n|0);m=ro(a,n);c:{if(h){n=v[a+4328>>2];J=Fe(G,n),K=i,z[J>>2]=K;J=Fe(F,n),K=j,z[J>>2]=K;e=z[Mb(l,f)>>2];J=Mb(l,m),K=C(i+C(x*e)),z[J>>2]=K;e=C(j+C(x*z[Mb(u,f)>>2]));h=u;break c}e=C(C(C(i+j)*C(.5))+C(x*z[Mb(l,f)>>2]));h=l}J=Mb(h,m),K=e,z[J>>2]=K;d:{if(H){g=z[a+4244>>2];e=C(g+z[a+4236>>2]);z[a+4236>>2]=e;g=C(g+z[a+4240>>2]);z[a+4240>>2]=g;if(e>C(1)){e=C(e+C(-2));z[a+4236>>2]=e}if(g>C(1)){z[a+4240>>2]=g+C(-2)}e=C(D(e));e=C(C(e+e)+C(-1));g=C(D(z[a+4240>>2]));g=C(C(g+g)+C(-1));break d}g=z[a+4240>>2];o=z[a+4244>>2];e=C(C(g*o)+z[a+4236>>2]);z[a+4236>>2]=e;g=C(g-C(o*e));z[a+4240>>2]=g}if(w[a+4260|0]){f=(v[a+4328>>2]+2|0)%3|0;i=z[Fe(G,f)>>2];j=z[Fe(F,f)>>2]}o=z[Mb(l,ro(a,v[a+4320>>2]+v[a+4312>>2]|0))>>2];J=r,K=C(i+C(B*C(C(o+C(C(z[Mb(l,ro(a,(v[a+4312>>2]+v[a+4320>>2]|0)+4096|0))>>2]-o)*C(C(v[a+4320>>2]&4095)*C(.000244140625))))-i))),z[J>>2]=K;i=z[Mb(E,ro(a,v[a+4324>>2]+v[a+4312>>2]|0))>>2];J=s,K=C(j+C(B*C(C(i+C(C(z[Mb(E,ro(a,(v[a+4312>>2]+v[a+4324>>2]|0)+4096|0))>>2]-i)*C(C(v[a+4324>>2]&4095)*C(.000244140625))))-j))),z[J>>2]=K;f=v[a+4328>>2];v[a+4328>>2]=((f|0)<=0?f+3|0:f)-1;f=v[a+4312>>2];n=(((f|0)>0?0:v[a+4316>>2]<<12)+f|0)-4096|0;v[a+4312>>2]=n;A=a;m=v[a+4256>>2];f=m;j=z[a+4248>>2];i=C((I?g:e)*j);e:{if(C(D(i))<C(2147483648)){h=~~i;break e}h=-2147483648}v[A+4324>>2]=f+(t>>>0>1?h:0-h|0);f=t>>>0<4;A=a;e=C(e*j);f:{if(C(D(e))<C(2147483648)){h=~~e;break f}h=-2147483648}v[A+4320>>2]=(f?h:0-h|0)+m;y=y-1|0;if(!y){break b}q=q+4|0;p=p+4|0;r=r+4|0;s=s+4|0;h=w[a+4260|0];continue}}Ei(a,b,c,od(k,0),od(k,1),d)}}function NE(a,b,c,d,e,f,g,h,i){var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;j=gb-128|0;gb=j;a:{b:{c:{if(!sn(f,g,h,i,0,0,0,0)){break c}m=f;n=g;l=h;o=i&65535;k=i>>>16&32767;d:{e:{if((k|0)!=32767){p=4;if(k){break e}m=l|m|(n|o)?3:2;break d}p=!(l|m|(n|o))}m=p}if(!m){break c}r=e>>>16|0;o=r&32767;if((o|0)!=32767){break b}}Ed(j+16|0,b,c,d,e,f,g,h,i);e=v[j+16>>2];d=v[j+20>>2];c=v[j+24>>2];b=v[j+28>>2];gF(j,e,d,c,b,e,d,c,b);d=v[j+8>>2];e=v[j+12>>2];h=v[j>>2];i=v[j+4>>2];break a}l=o<<16;p=d;q=l|e&65535;m=q;n=h;q=i>>>16&32767;k=i&65535|q<<16;if((sn(b,c,p,m,f,g,h,k)|0)<=0){if(sn(b,c,p,m,f,g,n,k)){h=b;i=c;break a}Ed(j+112|0,b,c,d,e,0,0,0,0);d=v[j+120>>2];e=v[j+124>>2];h=v[j+112>>2];i=v[j+116>>2];break a}if(o){i=c;h=b}else{Ed(j+96|0,b,c,p,m,0,0,0,1081540608);h=v[j+108>>2];m=h;p=v[j+104>>2];o=(h>>>16|0)-120|0;i=v[j+100>>2];h=v[j+96>>2]}if(!q){Ed(j+80|0,f,g,n,k,0,0,0,1081540608);f=v[j+92>>2];k=f;n=v[j+88>>2];q=(k>>>16|0)-120|0;g=v[j+84>>2];f=v[j+80>>2]}s=k&65535|65536;m=m&65535|65536;if((o|0)>(q|0)){while(1){k=p;l=n;t=k-l|0;l=m-((k>>>0<l>>>0)+s|0)|0;k=(g|0)==(i|0)&f>>>0>h>>>0|g>>>0>i>>>0;l=l-(k>>>0>t>>>0)|0;k=t-k|0;f:{if((l|0)>0|(l|0)>=0){m=h;h=h-f|0;i=i-((f>>>0>m>>>0)+g|0)|0;if(!(h|k|(i|l))){Ed(j+32|0,b,c,d,e,0,0,0,0);d=v[j+40>>2];e=v[j+44>>2];h=v[j+32>>2];i=v[j+36>>2];break a}l=l<<1|k>>>31;p=k<<1|i>>>31;break f}l=m<<1|p>>>31;p=p<<1|i>>>31}m=l;l=i<<1|h>>>31;h=h<<1;i=l;o=o-1|0;if((q|0)<(o|0)){continue}break}o=q}l=p;q=l-n|0;n=m-((l>>>0<n>>>0)+s|0)|0;l=(g|0)==(i|0)&f>>>0>h>>>0|g>>>0>i>>>0;k=n-(l>>>0>q>>>0)|0;n=q-l|0;g:{if((k|0)<0){n=p;k=m;break g}p=h;h=h-f|0;i=i-((f>>>0>p>>>0)+g|0)|0;if(h|n|(i|k)){break g}Ed(j+48|0,b,c,d,e,0,0,0,0);d=v[j+56>>2];e=v[j+60>>2];h=v[j+48>>2];i=v[j+52>>2];break a}if((k|0)==65535|k>>>0<65535){while(1){b=i>>>31|0;o=o-1|0;m=i<<1|h>>>31;h=h<<1;i=m;c=b;b=n;k=k<<1|b>>>31;n=c|b<<1;if(k>>>0<65536){continue}break}}b=r&32768;if((o|0)<=0){Ed(j- -64|0,h,i,n,k&65535|(b|o+120)<<16,0,0,0,1065811968);d=v[j+72>>2];e=v[j+76>>2];h=v[j+64>>2];i=v[j+68>>2];break a}d=n;e=k&65535|(b|o)<<16}v[a>>2]=h;v[a+4>>2]=i;v[a+8>>2]=d;v[a+12>>2]=e;gb=j+128|0}function JL(a,b,c,d,e,f,g,h,i){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0;j=gb-80|0;gb=j;a:{b:{c:{d:{e:{f:{k=Wp(1,28);if(!k){a=ba(4)|0;nm(a);v[22656]=0;U(186,a|0,89116,1928);a=v[22656];v[22656]=0;if((a|0)!=1){break a}break f}v[k+12>>2]=f;v[k+8>>2]=e;v[k+4>>2]=d;v[k>>2]=c?c:1919;d=Cu(j- -64|0);g:{h:{if(!i){break h}c=v[i>>2];if(!c){break h}while(1){i:{e=v[i+4>>2];if(e){v[22656]=0;c=Q(70,j+48|0,c|0)|0;f=v[22656];v[22656]=0;j:{if((f|0)!=1){v[22656]=0;f=Q(1929,d|0,c|0)|0;l=v[22656];v[22656]=0;if((l|0)==1){break j}v[22656]=0;Q(415,f|0,e|0)|0;e=v[22656];v[22656]=0;if((e|0)==1){break j}break i}i=V(0)|0;O()|0;break g}i=V(0)|0;O()|0;vb(c);break g}v[22656]=0;c=Q(70,j+48|0,c|0)|0;e=v[22656];v[22656]=0;k:{if((e|0)!=1){v[22656]=0;R(1930,d|0,c|0);e=v[22656];v[22656]=0;if((e|0)==1){break k}break i}i=V(0)|0;O()|0;break g}i=V(0)|0;O()|0;vb(c);break g}vb(c);c=v[i+8>>2];i=i+8|0;if(c){continue}break}}c=v[a+8>>2];e=v[a+4>>2];f=v[a>>2];v[22656]=0;a=T(1290,80)|0;i=v[22656];v[22656]=0;l:{m:{n:{if((i|0)!=1){v[j+44>>2]=c;v[j+40>>2]=e;v[j+36>>2]=f;v[j+32>>2]=b;v[22656]=0;b=Q(1931,k|0,k+4|0)|0;c=v[22656];v[22656]=0;if((c|0)==1){break n}v[j+48>>2]=b;b=v[jq(j+24|0,j+48|0)>>2];c=v[j+44>>2];v[j+16>>2]=v[j+40>>2];v[j+20>>2]=c;v[22656]=0;c=v[j+36>>2];v[j+8>>2]=v[j+32>>2];v[j+12>>2]=c;da(1932,a|0,j+8|0,b|0,d|0)|0;b=v[22656];v[22656]=0;if((b|0)==1){break m}v[k+24>>2]=a;Dj(j+48|0);Ll(d);i=k;break d}i=V(0)|0;O()|0;break g}i=V(0)|0;O()|0;break l}i=V(0)|0;O()|0;Dj(j+48|0)}Yb(a)}Ll(d);Z(i|0)|0;v[22656]=0;Y(1911,12328,k|0,g|0,h|0);a=v[22656];v[22656]=0;if((a|0)!=1){v[22656]=0;X(20);a=v[22656];v[22656]=0;if((a|0)==1){break f}a=v[k+24>>2];if(a){Yb(Gt(a))}i=0;v[k+24>>2]=0;a=v[k+20>>2];if(a){Yb(a);v[k+20>>2]=0}Yb(k);break d}i=V(0)|0;O()|0;v[22656]=0;X(20);a=v[22656];v[22656]=0;if((a|0)!=1){break e}break b}i=V(0)|0;O()|0}Z(i|0)|0;i=0;v[22656]=0;Y(1911,12328,0,g|0,h|0);a=v[22656];v[22656]=0;if((a|0)==1){break c}$()}gb=j+80|0;return i|0}a=P()|0;O()|0;v[22656]=0;X(20);b=v[22656];v[22656]=0;if((b|0)==1){break b}S(a|0);L()}V(0)|0;O()|0;Bb()}L()}function Jm(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;h=gb-16|0;gb=h;a:{b:{if(cd(a)|y[a+12>>2]<=y[b+4>>2]){break b}c=x[b+8>>1]>=Ji(a)>>>0;g=x[b+8>>1];if(c&(g|0)!=65535){break b}f=g;if((f&65535)==65535){g=Ji(a)-1|0;f=0}d=Yc(a,v[b+4>>2],f&65535);i=w[b+12|0];k=i&4;c:{d:{if(i&2){break d}l=g&65535;if(l>>>0<(f&65535)>>>0){break d}j=w[b+10|0];e=f;c=d;while(1){e:{if(!k){if((j|0)!=w[c+3|0]){break e}break c}if((j|0)==w[c+2|0]){break c}}c=c+6|0;e=e+1|0;if((e&65535)>>>0<=l>>>0){continue}break}}j=g&65535;if(j>>>0>=(f&65535)>>>0){e=f;c=d;while(1){f:{if(!k){if(w[c+3|0]){break f}t[c+3|0]=w[b+10|0];t[c+5|0]=w[b+11|0];break c}if(w[c+2|0]){break f}t[c+2|0]=w[b+10|0];t[c+4|0]=w[b+11|0];break c}c=c+6|0;e=e+1|0;if(j>>>0>=(e&65535)>>>0){continue}break}}g:{if(!(i&1)){break g}i=v[uo(a)+480180>>2]&2;e=w[b+12|0];h:{if(e&4){break h}g=g&65535;if(g>>>0<(f&65535)>>>0){break h}while(1){i:{j:{switch(w[d+3|0]-9|0){case 4:if(!yz(v[uo(a)+8>>2],1)){break i}c=1;t[d+2|0]=1;t[d+4|0]=w[d+5|0];t[d+3|0]=w[b+10|0];t[d+5|0]=w[b+11|0];break a;case 0:break j;default:break i}}c=d;k:{if(i){e=w[d+5|0];if(e>>>0>128){break i}t[d+2|0]=2;t[d+3|0]=w[b+10|0];a=1;break k}t[d+2|0]=2;t[d+3|0]=w[b+10|0];e=w[d+5|0];a=2}t[c+4|0]=a+e>>>a;t[d+5|0]=w[b+11|0];break c}d=d+6|0;f=f+1|0;if(g>>>0>=(f&65535)>>>0){continue}break}e=w[b+12|0]}l:{if(e&4){c=w[b+11|0];d=13;m:{switch(w[b+10|0]-1|0){case 1:c=Bn(B(i?2:4,c));e=w[b+12|0];d=9;break;case 0:break m;default:break l}}t[b+11|0]=c;t[b+10|0]=d;e=e&254;t[b+12|0]=e;break l}f=w[b+11|0];t[h+14|0]=f;d=b;c=w[b+10|0];n:{o:{if(!(!i|(c|0)!=9)){if(f>>>0>128){break n}c=2;f=(f&254)>>>1|0;break o}t[h+15|0]=c;if(!Zt(h+15|0,h+14|0,1)){break n}c=w[h+15|0];if(!c){break n}e=w[b+12|0];f=w[h+14|0]}t[d+11|0]=f;t[b+10|0]=c;t[b+12|0]=e&254}e=w[b+12|0]}c=1;if(e&1){break g}t[b+12|0]=e^4;if(Jm(a,b)){break a}}d=v[b>>2];p:{if((d|0)==1){if(y[a+12>>2]>v[b+4>>2]+1>>>0){v[b+4>>2]=v[b+4>>2]+1;break p}d=v[b>>2]}if((d|0)!=2){break b}c=0;d=v[b+4>>2];if(!d){break a}v[b+4>>2]=d-1}t[b+12|0]=w[b+12|0]|1;c=Jm(a,b);break a}c=1;break a}c=0}gb=h+16|0;return c|0}function Fia(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,w=0,x=0;g=gb-48|0;gb=g;a:{b:{c:{f=v[a+12>>2];h=v[a+8>>2];d:{if((f|0)<=1&h>>>0<=805306368|(f|0)<=0){if((f|0)>=-2&h>>>0>=3489660928|(f|0)>-2){break c}if((f|0)==-2&h>>>0>2147483647|f>>>0>4294967294){break d}break b}if((f|0)==1&h>>>0>2147483648|f>>>0>1){break b}}r=b+196648|0;break a}r=b+131112|0;break a}r=b+262184|0}s=v[a+16>>2];i=v[a+44>>2];v[g+32>>2]=i;m=v[a+48>>2];v[g+36>>2]=m;k=v[a+52>>2];v[g+40>>2]=k;l=v[a+56>>2];v[g+44>>2]=l;n=v[a+40>>2];o=v[a+36>>2];e=v[a+4>>2];j=v[a>>2];v[g+24>>2]=j;v[g+28>>2]=e;v[g+16>>2]=h;v[g+20>>2]=f;e:{if(d){while(1){m=1;b=((((e&2147483647)<<1|j>>>31)&2147483646)<<1)+s|0;e=(j>>>16&65520)+r|0;j=u[e+14>>1];h=u[e+12>>1];l=u[e+10>>1];q=u[e+8>>1];p=u[e+6>>1];t=u[e+4>>1];w=u[e+2>>1];x=u[e>>1];i=0;k=1;f=0;while(1){e=f<<1;v[(g+8|0)+(f<<2)>>2]=(((((((B(u[b+(e|-8)>>1],w)+B(u[b+(e|-12)>>1],x)|0)+B(u[b+(e|-4)>>1],t)|0)+B(u[b+e>>1],p)|0)+B(u[b+(e|4)>>1],q)|0)+B(u[b+(e|8)>>1],l)|0)+B(h,u[b+(e|12)>>1])|0)+B(j,u[b+(e|16)>>1])|0)/32768;e=k&1;k=0;f=1;if(e){continue}break}while(1){k=(g+8|0)+(i<<2)|0;j=v[k>>2];h=v[a+60>>2];l=h;e=(g+32|0)+(i<<3)|0;q=v[e>>2];b=Lb(q,-16777216,16776704);i=v[a+64>>2];f=Lb(v[e+4>>2],-16777216,16776704);p=h>>31;j=j<<8;h=j;h=kqa(l,p,h,h>>31);l=jb;p=h;h=kqa(i,i>>31,b,b>>31);i=p+h|0;b=jb+l|0;b=i>>>0<h>>>0?b+1|0:b;h=i;i=v[a+68>>2];i=kqa(i,i>>31,f,f>>31);f=h+i|0;b=jb+b|0;b=f>>>0<i>>>0?b+1|0:b;f=f+8388608|0;b=f>>>0<8388608?b+1|0:b;b=Jc(f,b,24);v[e+4>>2]=q;f=v[a+72>>2];v[k>>2]=(b|0)/256;v[e>>2]=b-(f&j);i=1;b=m&1;m=0;if(b){continue}break}b=v[a+32>>2];o=v[a+28>>2]+o|0;f=o>>12;v[c>>2]=v[c>>2]+B(f,v[g+8>>2]);n=b+n|0;b=n>>12;v[c+4>>2]=v[c+4>>2]+B(b,v[g+12>>2]);Ub(g+24|0,g+16|0);d=d-1|0;if(d){c=c+8|0;j=v[g+24>>2];e=v[g+28>>2];continue}break}j=v[g+24>>2];e=v[g+28>>2];l=v[g+44>>2];k=v[g+40>>2];m=v[g+36>>2];i=v[g+32>>2];break e}b=n>>12;f=o>>12}v[a+40>>2]=n;v[a+20>>2]=f;v[a+36>>2]=o;v[a+56>>2]=l;v[a+52>>2]=k;v[a+48>>2]=m;v[a+44>>2]=i;v[a+24>>2]=b;v[a>>2]=j;v[a+4>>2]=e;gb=g+48|0}function aia(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,u=0,w=0;e=gb-80|0;gb=e;r=v[a+16>>2];h=Ud(e+48|0);v[h+8>>2]=a+112;v[h+16>>2]=v[a+128>>2];u=h,w=jg(b+327720|0,v[b+20>>2],(v[a+88>>2]&16384)>>>14|0),v[u+12>>2]=w;b=v[h+16>>2];if(b){u=h,w=lg(a+8|0,b),v[u>>2]=w;v[h+4>>2]=jb}f=v[a+44>>2];v[e+32>>2]=f;m=v[a+48>>2];v[e+36>>2]=m;k=v[a+52>>2];v[e+40>>2]=k;l=v[a+56>>2];v[e+44>>2]=l;n=v[a+40>>2];o=v[a+36>>2];i=v[a+4>>2];g=v[a>>2];v[e+24>>2]=g;v[e+28>>2]=i;j=v[a+12>>2];v[e+16>>2]=v[a+8>>2];v[e+20>>2]=j;a:{if(d){while(1){m=0;f=m;j=g;v[e+72>>2]=g;v[e+76>>2]=f;i=(((i&2147483647)<<1|g>>>31)&-2)+r|0;b:{if((b|0)<=0){break b}while(1){g=(f&2147483647)<<1|j>>>31;Id(v[h+8>>2],t[(g|1)+i|0]+t[i+(g&-2)|0]<<5);Hd(v[h+8>>2],4);Ub(e+72|0,h);if((b|0)<2){break b}b=b-1|0;j=v[e+72>>2];f=v[e+76>>2];continue}}b=v[h+8>>2];Ub(b,b+8|0);b=v[h+8>>2];g=v[b+4>>2];if(g){f=b;b=(v[e+76>>2]&2147483647)<<1|v[e+72>>2]>>>31;Id(f,t[(b|1)+i|0]+t[i+(b&-2)|0]<<5);Hd(v[h+8>>2],g);b=v[h+8>>2];g=v[b>>2];v[b>>2]=g;v[b+4>>2]=0}d=d-1|0;f=ig(b,v[h+12>>2]);v[e+12>>2]=f;v[e+8>>2]=f;j=0;m=1;while(1){k=v[a+60>>2];l=k;i=(e+32|0)+(j<<3)|0;q=v[i>>2];b=Lb(q,-16777216,16776704);p=v[a+64>>2];g=Lb(v[i+4>>2],-16777216,16776704);s=k>>31;k=f<<8;f=k;f=kqa(l,s,f,f>>31);l=jb;p=kqa(p,p>>31,b,b>>31);f=p+f|0;b=jb+l|0;b=f>>>0<p>>>0?b+1|0:b;l=f;f=v[a+68>>2];f=kqa(f,f>>31,g,g>>31);g=l+f|0;b=jb+b|0;b=g>>>0<f>>>0?b+1|0:b;g=g+8388608|0;b=g>>>0<8388608?b+1|0:b;b=Jc(g,b,24);v[i+4>>2]=q;g=v[a+72>>2];v[(e+8|0)+(j<<2)>>2]=(b|0)/256;v[i>>2]=b-(g&k);if(m){j=1;m=0;f=v[e+12>>2];continue}break}b=v[a+32>>2];o=v[a+28>>2]+o|0;j=o>>12;v[c>>2]=v[c>>2]+B(j,v[e+8>>2]);n=b+n|0;b=n>>12;v[c+4>>2]=v[c+4>>2]+B(b,v[e+12>>2]);Ub(e+24|0,e+16|0);if(d){c=c+8|0;b=v[h+16>>2];g=v[e+24>>2];i=v[e+28>>2];continue}break}g=v[e+24>>2];i=v[e+28>>2];l=v[e+44>>2];k=v[e+40>>2];m=v[e+36>>2];f=v[e+32>>2];break a}b=n>>12;j=o>>12}v[a+40>>2]=n;v[a+20>>2]=j;v[a+36>>2]=o;v[a+56>>2]=l;v[a+52>>2]=k;v[a+48>>2]=m;v[a+44>>2]=f;v[a+24>>2]=b;v[a>>2]=g;v[a+4>>2]=i;gb=e+80|0}function wha(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,k=0,m=0,p=0,q=0,r=0,s=0,t=0,u=0,w=0,x=0,y=0;d=gb-48|0;gb=d;e=JR(d+32|0,1<<v[b+12>>2]);if(rf(a)){while(1){f=A[ye(a,c)>>3];IR(Tc(e,c),f);c=c+1|0;if(rf(a)>>>0>c>>>0){continue}break}}v[22656]=0;Hz(b,e);c=v[22656];v[22656]=0;a:{if((c|0)==1){break a}w=d,x=Vb(e),v[w>>2]=x;w=d,x=Zb(e),v[w+24>>2]=x;if(Gb(d,d+24|0)){while(1){c=v[d>>2];t=c;f=A[c+8>>3];i=gb-32|0;gb=i;o(+A[c>>3]);c=j(1)|0;g=j(0)|0;o(+f);k=j(1)|0;q=j(0)|0;p=c&2147483647;h=p;k=k&2147483647;r=(h|0)==(k|0)&g>>>0<q>>>0|h>>>0<k>>>0;c=r?g:q;h=r?h:k;r=h;l(0,c|0);l(1,h|0);f=+n();h=h>>>20|0;b:{if((h|0)==2047){break b}u=g;g=(k|0)==(p|0)&g>>>0>q>>>0|k>>>0<p>>>0;l(0,(g?u:q)|0);g=g?p:k;l(1,g|0);m=+n();p=!(c|r);c=g>>>20|0;if(!(p|(c|0)==2047)){if((c-h|0)>=65){f=m+f;break b}c:{if(c>>>0>=1534){f=f*1.90109156629516e-211;m=m*1.90109156629516e-211;s=5.260135901548374e210;break c}s=1;if(h>>>0>572){break c}f=f*5.260135901548374e210;m=m*5.260135901548374e210;s=1.90109156629516e-211}aJ(i+24|0,i+16|0,m);aJ(i+8|0,i,f);f=s*K(A[i>>3]+A[i+16>>3]+A[i+8>>3]+A[i+24>>3]);break b}f=m}gb=i+32|0;IR(t,Tp(f));_o(d);if(Gb(d,d+24|0)){continue}break}}v[22656]=0;Fz(b,e);c=v[22656];v[22656]=0;if((c|0)==1){break a}v[22656]=0;Ez(e);c=v[22656];v[22656]=0;if((c|0)==1){break a}if(uf(e)>>>0>3){c=1;while(1){ZA(Tc(e,c),2);ZA(Tc(e,(uf(e)>>>1|0)+c|0),0);c=c+1|0;if(c>>>0<uf(e)>>>1>>>0){continue}break}}v[22656]=0;Hz(b,e);c=v[22656];v[22656]=0;if((c|0)==1){break a}w=d,x=Vb(e),v[w+24>>2]=x;w=d,x=Zb(e),v[w+16>>2]=x;d:{if(Gb(d+24|0,d+16|0)){while(1){c=v[d+24>>2];v[22656]=0;YA(d,c);g=v[22656];v[22656]=0;if((g|0)==1){break d}g=v[d+4>>2];v[c>>2]=v[d>>2];v[c+4>>2]=g;g=v[d+12>>2];v[c+8>>2]=v[d+8>>2];v[c+12>>2]=g;c=d+24|0;_o(c);if(Gb(c,d+16|0)){continue}break}}v[22656]=0;Fz(b,e);b=v[22656];v[22656]=0;if((b|0)==1){break a}v[22656]=0;Ez(e);b=v[22656];v[22656]=0;if((b|0)==1){break a}if(rf(a)){c=0;while(1){f=A[Tc(e,c)>>3];w=ye(a,c),y=f,A[w>>3]=y;c=c+1|0;if(rf(a)>>>0>c>>>0){continue}break}}Nq(e);gb=d+48|0;return}}a=P()|0;O()|0;Nq(e);S(a|0);L()}function _h(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,z=0,A=0;a:{if(!Jd(a)){break a}xk(a);if(c){c=b;o=gb-16|0;gb=o;g=a;if(Jd(a)){s=c+1298224|0;d=c+1074992|0;c=x[g+34>>1];i=c&4;z=c&2;j=c&16;A=c&8;h=v[g+8>>2];p=v[g+4>>2];f=v[g+16>>2];q=v[g+12>>2];while(1){b:{if((g|0)!=v[d+104>>2]){break b}e=v[d+76>>2];if(!e){break b}m=d;c:{d:{e:{f:{n=v[g>>2];if(!A|(n>>>0<f>>>0|f>>>0<=q>>>0)){break f}l=v[d+88>>2];if(l&2048){break f}v[d+84>>2]=f;v[d+80>>2]=q;e=f;c=j;break e}if(!z|(h>>>0<=p>>>0|h>>>0>n>>>0)){break d}v[d+84>>2]=h;v[d+80>>2]=p;l=v[d+88>>2];e=h;c=i}v[m+76>>2]=e;k=l|2;r=d+88|0;l=(c|0)!=0;c=1;break c}r=d+88|0;k=v[d+88>>2]&-3;l=0;c=0}k=k&-5|(c?l?4:0:0);v[d+88>>2]=k;if(y[d+4>>2]>e>>>0){k=k&-129;v[d+88>>2]=k;m=v[d+80>>2];v[d>>2]=0;v[d+4>>2]=m}if(!l){v[r>>2]=k&-129}if(c){break b}v[d+76>>2]=n}d=d+872|0;if((s|0)!=(d|0)){continue}break}}gb=o+16|0}if((ij(a)|0)==2){d=0;g=gb+-64|0;gb=g;e=fd(a);h=v[a+20>>2];f=h+(B(e,v[a>>2])<<1)|0;while(1){if(e){i=B(d,e);j=B(e,d^-1);c=0;while(1){u[f+(c+i<<1)>>1]=x[f+(c-e<<1)>>1];u[h+(c+j<<1)>>1]=x[h+(c<<1)>>1];c=c+1|0;if((e|0)!=(c|0)){continue}break}}d=d+1|0;if((d|0)!=16){continue}break}d=f+(e<<5)|0;c=x[a+34>>1];if(c&2){i=v[a+8>>2];f=v[a+4>>2];j=g+32|0;Db(j,b+1074312|0,33);xS(g+40|0,d,h+(B(e,f)<<1)|0,i-f|0,e,(c&4)>>>2|0,Cb(j));c=x[a+34>>1]}if(c&8){f=v[a+16>>2];a=v[a+12>>2];i=g+32|0;Db(i,b+1074312|0,33);xS(g+8|0,d+(e<<7)|0,h+(B(a,e)<<1)|0,f-a|0,e,(c&16)>>>4|0,Cb(i))}gb=g- -64|0;return}if((ij(a)|0)!=1){break a}d=0;g=gb+-64|0;gb=g;e=fd(a);h=v[a+20>>2];f=h+B(e,v[a>>2])|0;while(1){if(e){i=B(d,e);j=B(e,d^-1);c=0;while(1){t[f+(c+i|0)|0]=w[f+(c-e|0)|0];t[h+(c+j|0)|0]=w[c+h|0];c=c+1|0;if((e|0)!=(c|0)){continue}break}}d=d+1|0;if((d|0)!=16){continue}break}d=f+(e<<4)|0;c=x[a+34>>1];if(c&2){i=v[a+8>>2];f=v[a+4>>2];j=g+32|0;Db(j,b+1074312|0,33);wS(g+40|0,d,h+B(e,f)|0,i-f|0,e,(c&4)>>>2|0,Cb(j));c=x[a+34>>1]}if(c&8){f=v[a+16>>2];a=v[a+12>>2];i=g+32|0;Db(i,b+1074312|0,33);wS(g+8|0,d+(e<<6)|0,h+B(a,e)|0,f-a|0,e,(c&16)>>>4|0,Cb(i))}gb=g- -64|0}}function Gia(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,w=0,x=0,y=0;f=gb-48|0;gb=f;a:{b:{c:{e=v[a+12>>2];g=v[a+8>>2];d:{if((e|0)<=1&g>>>0<=805306368|(e|0)<=0){if((e|0)>=-2&g>>>0>=3489660928|(e|0)>-2){break c}if((e|0)==-2&g>>>0>2147483647|e>>>0>4294967294){break d}break b}if((e|0)==1&g>>>0>2147483648|e>>>0>1){break b}}r=b+196648|0;break a}r=b+131112|0;break a}r=b+262184|0}s=v[a+16>>2];h=v[a+44>>2];v[f+32>>2]=h;m=v[a+48>>2];v[f+36>>2]=m;k=v[a+52>>2];v[f+40>>2]=k;l=v[a+56>>2];v[f+44>>2]=l;n=v[a+40>>2];o=v[a+36>>2];i=v[a+4>>2];j=v[a>>2];v[f+24>>2]=j;v[f+28>>2]=i;v[f+16>>2]=g;v[f+20>>2]=e;e:{if(d){while(1){i=(((i&2147483647)<<1|j>>>31)&-2)+s|0;b=(j>>>16&65520)+r|0;e=u[b+14>>1];j=u[b+12>>1];g=u[b+10>>1];l=u[b+8>>1];q=u[b+6>>1];p=u[b+4>>1];w=u[b+2>>1];x=u[b>>1];h=0;m=1;k=1;b=0;while(1){v[(f+8|0)+(b<<2)>>2]=(((((((B(t[i+(b|-4)|0],w)+B(t[i+(b|-6)|0],x)|0)+B(t[i+(b|-2)|0],p)|0)+B(t[b+i|0],q)|0)+B(t[i+(b|2)|0],l)|0)+B(t[i+(b|4)|0],g)|0)+B(j,t[i+(b|6)|0])|0)+B(e,t[i+(b|8)|0])<<8)/32768;y=k&1;k=0;b=1;if(y){continue}break}while(1){k=(f+8|0)+(h<<2)|0;j=v[k>>2];g=v[a+60>>2];l=g;i=(f+32|0)+(h<<3)|0;q=v[i>>2];b=Lb(q,-16777216,16776704);h=v[a+64>>2];e=Lb(v[i+4>>2],-16777216,16776704);p=g>>31;j=j<<8;g=j;g=kqa(l,p,g,g>>31);l=jb;p=g;g=kqa(h,h>>31,b,b>>31);h=p+g|0;b=jb+l|0;b=h>>>0<g>>>0?b+1|0:b;g=h;h=v[a+68>>2];h=kqa(h,h>>31,e,e>>31);e=g+h|0;b=jb+b|0;b=e>>>0<h>>>0?b+1|0:b;e=e+8388608|0;b=e>>>0<8388608?b+1|0:b;b=Jc(e,b,24);v[i+4>>2]=q;e=v[a+72>>2];v[k>>2]=(b|0)/256;v[i>>2]=b-(e&j);h=1;b=m&1;m=0;if(b){continue}break}b=v[a+32>>2];o=v[a+28>>2]+o|0;e=o>>12;v[c>>2]=v[c>>2]+B(e,v[f+8>>2]);n=b+n|0;b=n>>12;v[c+4>>2]=v[c+4>>2]+B(b,v[f+12>>2]);Ub(f+24|0,f+16|0);d=d-1|0;if(d){c=c+8|0;j=v[f+24>>2];i=v[f+28>>2];continue}break}j=v[f+24>>2];i=v[f+28>>2];l=v[f+44>>2];k=v[f+40>>2];m=v[f+36>>2];h=v[f+32>>2];break e}b=n>>12;e=o>>12}v[a+40>>2]=n;v[a+20>>2]=e;v[a+36>>2]=o;v[a+56>>2]=l;v[a+52>>2]=k;v[a+48>>2]=m;v[a+44>>2]=h;v[a+24>>2]=b;v[a>>2]=j;v[a+4>>2]=i;gb=f+48|0}function O2(a,b,c,d,e,f,g,h,i){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;a=gb-1072|0;gb=a;v[a+16>>2]=f;v[a+20>>2]=g;v[a+24>>2]=h;v[a+28>>2]=i;j=a+960|0;v[a+956>>2]=j;j=Mx(j,100,8345,a+16|0);v[a+48>>2]=2428;k=a+48|0;o=ge(a+536|0,0,k);v[a+48>>2]=2428;k=ge(a+528|0,0,k);m=a+544|0;a:{b:{c:{if(j>>>0>=100){v[22656]=0;j=ga(2448)|0;m=v[22656];v[22656]=0;if((m|0)==1){break b}v[a>>2]=f;v[a+4>>2]=g;v[22656]=0;v[a+8>>2]=h;v[a+12>>2]=i;j=da(2467,a+956|0,j|0,8345,a|0)|0;f=v[22656];v[22656]=0;if((f|0)==1){break b}if((j|0)==-1){v[22656]=0;X(2429);a=v[22656];v[22656]=0;if((a|0)!=1){break c}break b}Ee(o,v[a+956>>2]);Ee(k,Cd(j<<2));if(wk(k)){v[22656]=0;X(2429);a=v[22656];v[22656]=0;if((a|0)==1){break b}break c}m=v[k>>2]}v[22656]=0;Fc(a+520|0,d);f=v[22656];v[22656]=0;d:{e:{f:{g:{h:{i:{j:{if((f|0)!=1){v[22656]=0;q=T(2452,a+520|0)|0;f=v[22656];v[22656]=0;if((f|0)==1){break j}v[22656]=0;f=v[a+956>>2];Y(2464,q|0,f|0,f+j|0,m|0);f=v[22656];v[22656]=0;if((f|0)==1){break j}p=(j|0)>0?w[v[a+956>>2]]==45:p;h=Kb(a+488|0);f=Kb(a+472|0);g=Kb(a+456|0);v[22656]=0;na(2497,c|0,p|0,a+520|0,a+512|0,a+508|0,a+504|0,h|0,f|0,g|0,a+452|0);c=v[22656];v[22656]=0;if((c|0)==1){break i}v[a+36>>2]=2428;c=ge(a+40|0,0,a+36|0);i=a+48|0;n=v[a+452>>2];k:{if((n|0)<(j|0)){l=((Ab(g)+(j-n<<1)|0)+Ab(f)|0)+1|0;break k}l=(Ab(g)+Ab(f)|0)+2|0}l=l+n|0;if(l>>>0<101){break h}Ee(c,Cd(l<<2));i=v[c>>2];if(i){break h}v[22656]=0;X(2429);b=v[22656];v[22656]=0;if((b|0)!=1){break c}break g}j=P()|0;O()|0;break a}j=P()|0;O()|0;break e}j=P()|0;O()|0;break f}l=v[d+4>>2];v[22656]=0;qa(2498,i|0,a+36|0,a+32|0,l|0,m|0,(j<<2)+m|0,q|0,p|0,a+512|0,v[a+508>>2],v[a+504>>2],h|0,f|0,g|0,n|0);j=v[22656];v[22656]=0;if((j|0)!=1){v[22656]=0;b=la(2477,b|0,i|0,v[a+36>>2],v[a+32>>2],d|0,e|0)|0;d=v[22656];v[22656]=0;if((d|0)!=1){break d}}}j=P()|0;O()|0;Ic(c)}Hc(g);Hc(f);vb(h)}Wb(a+520|0);break a}Ic(c);Hc(g);Hc(f);vb(h);Wb(a+520|0);Ic(k);Ic(o);gb=a+1072|0;return b|0}L()}j=P()|0;O()|0}Ic(k);Ic(o);S(j|0);L()}function Rl(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0;a:{b:{c:{switch(b|0){case 1:b=0;a=Kb(a);d=Ab(c);v[22656]=0;R(60,a|0,d|0);d=v[22656];v[22656]=0;d:{if((d|0)!=1){e:{if(Ab(c)){while(1){d=v[yk(c,b)>>2];f:{if(d>>>0<=127){v[22656]=0;R(61,a|0,d<<24>>24);d=v[22656];v[22656]=0;if((d|0)!=1){break f}break e}v[22656]=0;R(61,a|0,63);d=v[22656];v[22656]=0;if((d|0)==1){break e}}b=b+1|0;if(Ab(c)>>>0>b>>>0){continue}break}}break d}}break a}return;case 2:b=0;a=Kb(a);d=Ab(c);v[22656]=0;R(60,a|0,d|0);d=v[22656];v[22656]=0;g:{if((d|0)!=1){h:{if(Ab(c)){while(1){d=v[yk(c,b)>>2];i:{if(d>>>0<=255){v[22656]=0;R(61,a|0,d<<24>>24);d=v[22656];v[22656]=0;if((d|0)!=1){break i}break h}v[22656]=0;R(61,a|0,63);d=v[22656];v[22656]=0;if((d|0)==1){break h}}b=b+1|0;if(Ab(c)>>>0>b>>>0){continue}break}}break g}}break a}return;case 3:Yq(a,c,20896);return;case 5:Yq(a,c,21920);return;case 4:Yq(a,c,22944);return;case 6:Yq(a,c,23968);return;default:a=ba(8)|0;v[22656]=0;Q(59,a|0,8299)|0;b=v[22656];v[22656]=0;if((b|0)!=1){break b}b=P()|0;O()|0;ca(a|0);S(b|0);L();case 0:break c}}e=gb-16|0;gb=e;f=Kb(a);j:{k:{if(Ab(c)){while(1){a=v[yk(c,h)>>2];l:{if(a>>>0>=2097152){v[22656]=0;R(61,f|0,63);a=v[22656];v[22656]=0;if((a|0)!=1){break l}break k}d=0;m:{n:{while(1){g=a&63;t[(e+10|0)+d|0]=g;if(a>>>0<64){break n}a=a>>>6|0;d=d+1|0;if((d|0)!=6){continue}break}b=7;d=6;break m}o:{if(!d){v[22656]=0;R(61,f|0,t[e+10|0]);break o}b=d+1|0;if((b|0)!=2){break m}d=1;b=2;if((g|0)!=1){break m}v[22656]=0;R(61,f|0,t[e+10|0]|64)}a=v[22656];v[22656]=0;if((a|0)!=1){break l}break k}g=(-1<<b^-1)<<7-d;d=b-1|0;j=d+(e+10|0)|0;a=b;while(1){p:{if((a|0)==(b|0)){a=w[j|0];v[22656]=0;R(61,f|0,(a|g)<<24>>24);i=v[22656];v[22656]=0;a=d;if((i|0)!=1){break p}break k}v[22656]=0;a=a-1|0;R(61,f|0,t[a+(e+10|0)|0]|-128);i=v[22656];v[22656]=0;if((i|0)==1){break k}}if(a){continue}break}}h=h+1|0;if(Ab(c)>>>0>h>>>0){continue}break}}gb=e+16|0;break j}a=P()|0;O()|0;vb(f);S(a|0);L()}return}ia(a|0,89236,24);L()}b=P()|0;O()|0;vb(a);S(b|0);L()}function Ix(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0;e=v[b>>2];a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{if(!d){break l}g=v[d>>2];if(!g){break l}if(!a){d=c;break j}v[d>>2]=0;d=c;break k}m:{if(!v[v[115196]>>2]){if(!a){break m}if(!c){break a}g=c;while(1){d=t[e|0];if(d){v[a>>2]=d&57343;a=a+4|0;e=e+1|0;g=g-1|0;if(g){continue}break a}break}v[a>>2]=0;v[b>>2]=0;return c-g|0}d=c;if(!a){break i}break g}return Nf(e)|0}f=1;break g}f=0;break h}f=1}while(1){if(!f){f=w[e|0]>>>3|0;if((f-16|f+(g>>26))>>>0>7){break f}h=e+1|0;f=h;n:{if(!(g&33554432)){break n}if((w[h|0]&192)!=128){e=e-1|0;break d}h=e+2|0;f=h;if(!(g&524288)){break n}if((w[h|0]&192)!=128){e=e-1|0;break d}f=e+3|0}e=f;d=d-1|0;f=1;continue}while(1){g=w[e|0];o:{if(e&3|g-1>>>0>126){break o}g=v[e>>2];if((g|g-16843009)&-2139062144){break o}while(1){d=d-4|0;g=v[e+4>>2];f=e+4|0;e=f;if(!((g-16843009|g)&-2139062144)){continue}break}e=f}f=g&255;if(f-1>>>0<=126){d=d-1|0;e=e+1|0;continue}break}f=f-194|0;if(f>>>0>50){break e}e=e+1|0;g=v[(f<<2)+76272>>2];f=0;continue}}while(1){if(!f){if(!d){break a}while(1){p:{f=w[e|0];h=f-1|0;q:{r:{if(h>>>0>126){g=f;break r}if(e&3|d>>>0<5){break q}s:{while(1){g=v[e>>2];if((g|g-16843009)&-2139062144){break s}v[a>>2]=g&255;v[a+4>>2]=w[e+1|0];v[a+8>>2]=w[e+2|0];v[a+12>>2]=w[e+3|0];a=a+16|0;e=e+4|0;d=d-4|0;if(d>>>0>4){continue}break}g=w[e|0]}f=g&255;h=f-1|0}if(h>>>0>126){break p}}v[a>>2]=f;a=a+4|0;e=e+1|0;d=d-1|0;if(d){continue}break a}break}f=f-194|0;if(f>>>0>50){break e}e=e+1|0;g=v[(f<<2)+76272>>2];f=1;continue}h=w[e|0];f=h>>>3|0;if((f-16|f+(g>>26))>>>0>7){break f}t:{u:{i=e+1|0;f=h-128|g<<6;h=i;v:{if((f|0)>=0){break v}h=w[i|0]-128|0;if(h>>>0>63){break u}i=e+2|0;f=h|f<<6;h=i;if((f|0)>=0){break v}h=w[i|0]-128|0;if(h>>>0>63){break u}f=h|f<<6;h=e+3|0}e=h;v[a>>2]=f;d=d-1|0;a=a+4|0;break t}v[115137]=25;e=e-1|0;break c}f=0;continue}}e=e-1|0;if(g){break d}g=w[e|0]}if(g&255){break d}if(a){v[a>>2]=0;v[b>>2]=0}return c-d|0}v[115137]=25;if(!a){break b}}v[b>>2]=e}return-1}v[b>>2]=e;return c|0}function lA(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;h=gb-160|0;gb=h;a:{b:{c:{d:{e:{f:{g:{h:{i:{if(!c){break i}d=v[c+4>>2];if(!d&y[c>>2]>=yb(b)>>>0|d){break i}b=ba(8)|0;v[22656]=0;Q(126,b|0,18726)|0;a=v[22656];v[22656]=0;if((a|0)!=1){break h}a=P()|0;O()|0;ca(b|0);break a}if(!v[b>>2]){b=ba(8)|0;v[22656]=0;T(1292,b|0)|0;a=v[22656];v[22656]=0;if((a|0)!=1){break g}a=P()|0;O()|0;ca(b|0);break a}d=v[b+4>>2];g=v[b>>2];v[h>>2]=g;v[h+4>>2]=d;v[h+128>>2]=g;v[h+132>>2]=d;g=gb-16|0;gb=g;d=v[h+4>>2];e=v[h>>2];v[g>>2]=e;v[g+4>>2]=d;v[g+8>>2]=e;v[g+12>>2]=d;d=gb-32|0;gb=d;e=v[g+4>>2];f=v[g>>2];v[d+8>>2]=f;v[d+12>>2]=e;v[d+16>>2]=f;v[d+20>>2]=e;rh(d+24|0,d+8|0);e=v[d+28>>2];v[d>>2]=v[d+24>>2];v[d+4>>2]=e;e=gb-16|0;gb=e;f=v[d+4>>2];i=v[d>>2];v[e>>2]=i;v[e+4>>2]=f;v[e+8>>2]=i;v[e+12>>2]=f;f=gb-16|0;gb=f;i=v[e+4>>2];k=v[e>>2];v[f>>2]=k;v[f+4>>2]=i;v[f+8>>2]=k;v[f+12>>2]=i;i=h+136|0;bG(i,f);gb=f+16|0;gb=e+16|0;v[i+12>>2]=0;gb=d+32|0;gb=g+16|0;j:{k:{if(a&2){d=Kn(h+104|0,i);v[22656]=0;g=Q(1293,d|0,c|0)|0;e=v[22656];v[22656]=0;d=1;if((e|0)==1){break j}if((g|0)==1){break k}e=Kn(h+80|0,i);v[22656]=0;e=Q(1294,e|0,c|0)|0;f=v[22656];v[22656]=0;if((f|0)==1){break f}k=(e|0)==1;if(k){break k}f=Kn(h+56|0,i);v[22656]=0;f=Q(1295,f|0,c|0)|0;j=v[22656];v[22656]=0;if((j|0)==1){break e}l=(f|0)==1;if(l){break k}j=Kn(h+32|0,i);v[22656]=0;j=Q(1296,j|0,c|0)|0;m=v[22656];v[22656]=0;if((m|0)==1){break d}if((j|0)==1){break k}d=(g|0)==-1?-1:0;d=k?d:(e|0)==-1?-1:d;j=(j|0)==-1?-1:l?d:(f|0)==-1?-1:d}if(a&1){a=37824;while(1){d=v[a>>2];if(d){g=Kn(h+8|0,i);v[22656]=0;g=Q(d|0,g|0,c|0)|0;d=v[22656];v[22656]=0;if((d|0)==1){break c}d=1;if((g|0)==1){break k}j=(g|0)==-1?-1:j}a=a+12|0;if((a|0)!=38328){continue}break}}if(c){d=0;if((j|0)!=-1){break k}d=Qc(v[c>>2],v[c+4>>2])>>>0>yb(b)>>>0?-1:0;break k}d=0;if((j|0)!=-1){break k}d=yb(b)>>>0>2047?1:-1}gb=h+160|0;return d}a=P()|0;break b}ia(b|0,89396,24);L()}ia(b|0,89292,24);L()}a=P()|0;break b}a=P()|0;break b}a=P()|0;break b}a=P()|0}O()|0}S(a|0);L()}function S2(a,b,c,d,e,f,g,h,i){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;a=gb-464|0;gb=a;v[a+16>>2]=f;v[a+20>>2]=g;v[a+24>>2]=h;v[a+28>>2]=i;j=a+352|0;v[a+348>>2]=j;j=Mx(j,100,8345,a+16|0);v[a+48>>2]=2428;k=a+48|0;o=ge(a+232|0,0,k);v[a+48>>2]=2428;k=ge(a+224|0,0,k);m=a+240|0;a:{b:{c:{if(j>>>0>=100){v[22656]=0;j=ga(2448)|0;m=v[22656];v[22656]=0;if((m|0)==1){break b}v[a>>2]=f;v[a+4>>2]=g;v[22656]=0;v[a+8>>2]=h;v[a+12>>2]=i;j=da(2467,a+348|0,j|0,8345,a|0)|0;f=v[22656];v[22656]=0;if((f|0)==1){break b}if((j|0)==-1){v[22656]=0;X(2429);a=v[22656];v[22656]=0;if((a|0)!=1){break c}break b}Ee(o,v[a+348>>2]);Ee(k,Cd(j));if(wk(k)){v[22656]=0;X(2429);a=v[22656];v[22656]=0;if((a|0)==1){break b}break c}m=v[k>>2]}v[22656]=0;Fc(a+216|0,d);f=v[22656];v[22656]=0;d:{e:{f:{g:{h:{i:{j:{if((f|0)!=1){v[22656]=0;q=T(21,a+216|0)|0;f=v[22656];v[22656]=0;if((f|0)==1){break j}v[22656]=0;f=v[a+348>>2];Y(2444,q|0,f|0,f+j|0,m|0);f=v[22656];v[22656]=0;if((f|0)==1){break j}p=(j|0)>0?w[v[a+348>>2]]==45:p;h=Kb(a+192|0);f=Kb(a+176|0);g=Kb(a+160|0);v[22656]=0;na(2495,c|0,p|0,a+216|0,a+208|0,a+207|0,a+206|0,h|0,f|0,g|0,a+156|0);c=v[22656];v[22656]=0;if((c|0)==1){break i}v[a+36>>2]=2428;c=ge(a+40|0,0,a+36|0);i=a+48|0;n=v[a+156>>2];k:{if((n|0)<(j|0)){l=((Ab(g)+(j-n<<1)|0)+Ab(f)|0)+1|0;break k}l=(Ab(g)+Ab(f)|0)+2|0}l=l+n|0;if(l>>>0<101){break h}Ee(c,Cd(l));i=v[c>>2];if(i){break h}v[22656]=0;X(2429);b=v[22656];v[22656]=0;if((b|0)!=1){break c}break g}j=P()|0;O()|0;break a}j=P()|0;O()|0;break e}j=P()|0;O()|0;break f}l=v[d+4>>2];v[22656]=0;qa(2496,i|0,a+36|0,a+32|0,l|0,m|0,j+m|0,q|0,p|0,a+208|0,t[a+207|0],t[a+206|0],h|0,f|0,g|0,n|0);j=v[22656];v[22656]=0;if((j|0)!=1){v[22656]=0;b=la(17,b|0,i|0,v[a+36>>2],v[a+32>>2],d|0,e|0)|0;d=v[22656];v[22656]=0;if((d|0)!=1){break d}}}j=P()|0;O()|0;Ic(c)}vb(g);vb(f);vb(h)}Wb(a+216|0);break a}Ic(c);vb(g);vb(f);vb(h);Wb(a+216|0);Ic(k);Ic(o);gb=a+464|0;return b|0}L()}j=P()|0;O()|0}Ic(k);Ic(o);S(j|0);L()}function Fz(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,w=0,x=0,y=0;c=gb-208|0;gb=c;i=1;h=v[a+12>>2];k=1<<h;m=2;g=h;if(g>>>0>=2){f=k;while(1){l=f>>>2|0;if(f>>>0>=4){w=B(i,3);x=i<<1;y=l>>>0>1?l:1;g=0;while(1){e=c+192|0;YN(e,Tc(a,g<<1));f=c+176|0;YN(f,Tc(a,g));Li(c+160|0,f,e);f=g<<m;u=i+f|0;if(f>>>0<u>>>0){while(1){d=Tc(b,f);e=v[d+12>>2];v[c+152>>2]=v[d+8>>2];v[c+156>>2]=e;e=v[d+4>>2];v[c+144>>2]=v[d>>2];v[c+148>>2]=e;n=f+i|0;d=Tc(b,n);e=v[d+12>>2];v[c+136>>2]=v[d+8>>2];v[c+140>>2]=e;e=v[d+4>>2];v[c+128>>2]=v[d>>2];v[c+132>>2]=e;o=f+x|0;d=Tc(b,o);e=v[d+12>>2];v[c+120>>2]=v[d+8>>2];v[c+124>>2]=e;e=v[d+4>>2];v[c+112>>2]=v[d>>2];v[c+116>>2]=e;p=f+w|0;d=Tc(b,p);e=v[d+12>>2];v[c+104>>2]=v[d+8>>2];v[c+108>>2]=e;e=v[d+4>>2];v[c+96>>2]=v[d>>2];v[c+100>>2]=e;q=c+80|0;d=c+144|0;e=c+128|0;Gl(q,d,e);r=c- -64|0;Gj(r,d,e);s=c+48|0;d=c+112|0;e=c+96|0;Gl(s,d,e);j=c+16|0;Gj(j,d,e);t=c+32|0;Li(t,48208,j);Gl(j,q,s);d=Tc(b,f);e=v[c+28>>2];v[d+8>>2]=v[c+24>>2];v[d+12>>2]=e;e=v[c+20>>2];v[d>>2]=v[c+16>>2];v[d+4>>2]=e;Gl(c,r,t);Li(j,c+192|0,c);n=Tc(b,n);d=n;e=v[c+28>>2];v[d+8>>2]=v[c+24>>2];v[d+12>>2]=e;e=v[c+20>>2];v[d>>2]=v[c+16>>2];v[d+4>>2]=e;Gj(c,q,s);Li(j,c+176|0,c);o=Tc(b,o);d=o;e=v[c+28>>2];v[d+8>>2]=v[c+24>>2];v[d+12>>2]=e;e=v[c+20>>2];v[d>>2]=v[c+16>>2];v[d+4>>2]=e;Gj(c,r,t);Li(j,c+160|0,c);p=Tc(b,p);d=p;e=v[c+28>>2];v[d+8>>2]=v[c+24>>2];v[d+12>>2]=e;e=v[c+20>>2];v[d>>2]=v[c+16>>2];v[d+4>>2]=e;f=f+1|0;if((u|0)!=(f|0)){continue}break}}g=g+1|0;if((y|0)!=(g|0)){continue}break}g=v[a+12>>2]}i=i<<2;f=l;m=m+2|0;if(m>>>0<=g>>>0){continue}break}}if(!(!(g&1)|!h)){e=k>>>1|0;l=e>>>0>1?e:1;f=0;while(1){k=e+f|0;h=Tc(b,k);a=v[h+12>>2];v[c+200>>2]=v[h+8>>2];v[c+204>>2]=a;a=v[h+4>>2];v[c+192>>2]=v[h>>2];v[c+196>>2]=a;h=c+192|0;Gj(c+176|0,Tc(b,f),h);g=Tc(b,k);a=v[c+188>>2];v[g+8>>2]=v[c+184>>2];v[g+12>>2]=a;a=v[c+180>>2];v[g>>2]=v[c+176>>2];v[g+4>>2]=a;Gz(Tc(b,f),h);f=f+1|0;if((l|0)!=(f|0)){continue}break}}gb=c+208|0}function Ei(a,b,c,d,e,f){var g=0,h=0,i=0,j=C(0),k=C(0),l=0,m=C(0),n=0,o=C(0),p=C(0),q=0,r=C(0);if(!(kb[v[v[a>>2]+136>>2]](a)|0)){g=w[v[a+20>>2]+25|0]}j=z[v[a+20>>2]+144>>2];k=C(1);if(!(kb[v[v[a>>2]+136>>2]](a)|0)){k=z[v[a+20>>2]+144>>2]}j=C(C(1)-j);a:{if((kb[v[v[a>>2]+152>>2]](a)|0)<=0){break a}if(!FM(v[a+20>>2])){break a}j=C(C(j+j)+C(-1));k=C(-j)}m=z[a+4196>>2];k=C(k*m);j=C(j*m);l=a+44|0;n=Nd(l,0);l=Nd(l,1);b:{c:{switch(g|0){case 4:if(!f){break b}while(1){g=i<<2;h=g+b|0;k=z[h>>2];q=h;r=k;m=z[g+n>>2];h=c+g|0;o=z[h>>2];p=z[g+l>>2];k=C(C(C(C(k+m)+o)+p)*C(.5));z[q>>2]=r-C(C(k+C(k-C(j*z[d+g>>2])))-m);z[h>>2]=o-C(C(k+C(k-C(j*z[e+g>>2])))-p);i=i+1|0;if((i|0)!=(f|0)){continue}break};break b;case 3:if(!f){break b}while(1){g=i<<2;h=g+b|0;z[h>>2]=z[h>>2]-C(z[d+g>>2]-C(j*z[g+n>>2]));h=c+g|0;z[h>>2]=z[h>>2]-C(z[e+g>>2]-C(j*z[g+l>>2]));i=i+1|0;if((i|0)!=(f|0)){continue}break};break b;case 2:if(!f){break b}while(1){g=i<<2;h=g+b|0;z[h>>2]=z[h>>2]+C(z[d+g>>2]-C(k*z[g+n>>2]));h=c+g|0;z[h>>2]=z[h>>2]+C(z[e+g>>2]-C(k*z[g+l>>2]));i=i+1|0;if((i|0)!=(f|0)){continue}break};break b;case 1:if(!f){break b}while(1){g=i<<2;h=g+b|0;z[h>>2]=z[h>>2]+C(z[g+n>>2]-C(j*z[d+g>>2]));h=c+g|0;z[h>>2]=z[h>>2]+C(z[g+l>>2]-C(j*z[e+g>>2]));i=i+1|0;if((i|0)!=(f|0)){continue}break};break b;case 0:if(!f){break b}while(1){g=i<<2;h=g+b|0;z[h>>2]=z[h>>2]+C(C(j*z[d+g>>2])+C(k*z[g+n>>2]));h=c+g|0;z[h>>2]=z[h>>2]+C(C(j*z[e+g>>2])+C(k*z[g+l>>2]));i=i+1|0;if((i|0)!=(f|0)){continue}break};break b;case 5:break c;default:break b}}g=FM(v[a+20>>2]);if(!f){break b}j=g?C(j*C(.5)):j;k=g?C(k*C(.5)):k;while(1){g=i<<2;h=g+b|0;m=C(z[d+g>>2]-z[g+n>>2]);o=C(z[g+l>>2]-z[e+g>>2]);z[h>>2]=z[h>>2]+C(C(j*m)+C(k*o));g=c+g|0;z[g>>2]=z[g>>2]+C(C(k*m)+C(j*o));i=i+1|0;if((i|0)!=(f|0)){continue}break}}d:{if(!((w[v[a+20>>2]+24|0]&4)>>>2|0)){break d}if(kb[v[v[a>>2]+136>>2]](a)|!f){break d}e=0;while(1){a=e<<2;d=a+b|0;z[d>>2]=z[a+n>>2]+z[d>>2];d=a+c|0;z[d>>2]=z[a+l>>2]+z[d>>2];e=e+1|0;if((f|0)!=(e|0)){continue}break}}}function dia(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,w=0;e=gb-80|0;gb=e;p=v[a+16>>2];h=Ud(e+48|0);v[h+8>>2]=a+112;v[h+16>>2]=v[a+128>>2];t=h,w=jg(b+327720|0,v[b+20>>2],(v[a+88>>2]&16384)>>>14|0),v[t+12>>2]=w;b=v[h+16>>2];if(b){t=h,w=lg(a+8|0,b),v[t>>2]=w;v[h+4>>2]=jb}j=v[a+44>>2];v[e+32>>2]=j;f=v[a+48>>2];v[e+36>>2]=f;l=v[a+52>>2];v[e+40>>2]=l;k=v[a+56>>2];v[e+44>>2]=k;q=v[a+24>>2];r=v[a+20>>2];i=v[a+4>>2];g=v[a>>2];v[e+24>>2]=g;v[e+28>>2]=i;m=v[a+12>>2];v[e+16>>2]=v[a+8>>2];v[e+20>>2]=m;if(d){while(1){l=0;j=l;f=g;v[e+72>>2]=g;v[e+76>>2]=j;i=((((i&2147483647)<<1|g>>>31)&2147483646)<<1)+p|0;a:{if((b|0)<=0){break a}while(1){g=(j&2147483647)<<1|f>>>31;Id(v[h+8>>2],(u[(g<<1|2)+i>>1]+u[i+((g&2147483646)<<1)>>1]|0)/8<<16>>16);Hd(v[h+8>>2],4);Ub(e+72|0,h);if((b|0)<2){break a}b=b-1|0;f=v[e+72>>2];j=v[e+76>>2];continue}}b=v[h+8>>2];Ub(b,b+8|0);b=v[h+8>>2];g=v[b+4>>2];if(g){f=b;b=(v[e+76>>2]&2147483647)<<1|v[e+72>>2]>>>31;Id(f,(u[(b<<1|2)+i>>1]+u[i+((b&2147483646)<<1)>>1]|0)/8<<16>>16);Hd(v[h+8>>2],g);b=v[h+8>>2];g=v[b>>2];v[b>>2]=g;v[b+4>>2]=0}d=d-1|0;f=ig(b,v[h+12>>2]);v[e+12>>2]=f;v[e+8>>2]=f;j=0;l=1;while(1){k=v[a+60>>2];m=k;i=(e+32|0)+(j<<3)|0;o=v[i>>2];b=Lb(o,-16777216,16776704);n=v[a+64>>2];g=Lb(v[i+4>>2],-16777216,16776704);s=k>>31;k=f<<8;f=k;f=kqa(m,s,f,f>>31);m=jb;n=kqa(n,n>>31,b,b>>31);f=n+f|0;b=jb+m|0;b=f>>>0<n>>>0?b+1|0:b;m=f;f=v[a+68>>2];f=kqa(f,f>>31,g,g>>31);g=m+f|0;b=jb+b|0;b=g>>>0<f>>>0?b+1|0:b;g=g+8388608|0;b=g>>>0<8388608?b+1|0:b;b=Jc(g,b,24);v[i+4>>2]=o;g=v[a+72>>2];v[(e+8|0)+(j<<2)>>2]=(b|0)/256;v[i>>2]=b-(g&k);if(l){j=1;l=0;f=v[e+12>>2];continue}break}v[c>>2]=v[c>>2]+B(v[e+8>>2],r);v[c+4>>2]=v[c+4>>2]+B(v[e+12>>2],q);Ub(e+24|0,e+16|0);if(d){c=c+8|0;b=v[h+16>>2];g=v[e+24>>2];i=v[e+28>>2];continue}break}g=v[e+24>>2];k=v[e+44>>2];l=v[e+40>>2];f=v[e+36>>2];j=v[e+32>>2];i=v[e+28>>2]}v[a+56>>2]=k;v[a+52>>2]=l;v[a+48>>2]=f;v[a+44>>2]=j;v[a>>2]=g;v[a+4>>2]=i;gb=e+80|0}function $ja(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;d=gb+-64|0;gb=d;u[d+62>>1]=c;zg(d+62|0,32);f=mc(a);v[22656]=0;R(711,f|0,x[d+62>>1]);a=v[22656];v[22656]=0;a:{if((a|0)!=1){b:{if(!x[d+62>>1]){break b}while(1){a=x[b+480190>>1]+1|0;u[d+60>>1]=a;c:{d:{if((a&65535)>>>0<4e3){break d}u[d+24>>1]=1;e:{if(!x[b+480190>>1]){break e}while(1){f:{if(Jd(Bk(b,x[d+24>>1]))){break f}j=d,k=iC(Vb(f),Zb(f),d+24|0),v[j+48>>2]=k;j=d,k=Zb(f),v[j+40>>2]=k;if(Gb(d+48|0,d+40|0)){break f}u[d+60>>1]=x[d+24>>1];c=1;if(!x[b+480192>>1]){break e}while(1){a=v[(((c&65535)<<2)+b|0)+900380>>2];g:{if(!a){break g}a=a+236|0;e=Ou(a);if((a|0)==(e|0)){break g}while(1){if(x[a>>1]==x[d+60>>1]){u[a>>1]=0}a=a+2|0;if((e|0)!=(a|0)){continue}break}}c=c+1|0;if(x[b+480192>>1]>=(c&65535)>>>0){continue}break}break e}a=x[d+24>>1]+1|0;u[d+24>>1]=a;if(x[b+480190>>1]>=(a&65535)>>>0){continue}break}}if(x[d+60>>1]<4e3){break d}c=CB(d+48|0);v[22656]=0;a=Q(977,b|0,c|0)|0;e=v[22656];v[22656]=0;h:{i:{if((e|0)==1){break i}j:{if(a){v[22656]=0;Q(978,b|0,c|0)|0;a=v[22656];v[22656]=0;if((a|0)==1){break i}e=1;if(!x[b+480192>>1]){break j}while(1){a=v[(((e&65535)<<2)+b|0)+900380>>2];k:{if(!a){break k}a=a+236|0;g=Ou(a);if((a|0)==(g|0)){break k}while(1){l:{if(y[c+4>>2]<=x[a>>1]){break l}h=d+40|0;Ce(h,c,x[a>>1]);if(Cb(h)){break l}u[a>>1]=0}a=a+2|0;if((g|0)!=(a|0)){continue}break}}e=e+1|0;if(x[b+480192>>1]>=(e&65535)>>>0){continue}break}break j}Ye(c);break b}a=d+24|0;Ak(a,c);e=d+32|0;xB(e,a,1);a=d+16|0;Vl(a,c);v[22656]=0;t[d+15|0]=0;aT(d+40|0,e,a,d+15|0);a=v[22656];v[22656]=0;if((a|0)!=1){break h}}a=P()|0;O()|0;Ye(c);break a}Ak(d,c);j=d,k=Rj(d+40|0,d),u[j+60>>1]=k;Ye(c);if(x[d+60>>1]>=4e3){break c}}v[22656]=0;R(383,f|0,d+60|0);a=v[22656];v[22656]=0;if((a|0)!=1){if(x[b+480190>>1]>=x[d+60>>1]){break c}u[b+480190>>1]=x[d+60>>1];break c}a=P()|0;O()|0;break a}i=i+1|0;if(x[d+62>>1]>(i&65535)>>>0){continue}break}}gb=d- -64|0;return}a=P()|0;O()|0}Ze(f);S(a|0);L()}function L9(a,b,c,d,e,f,g,h,i){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0;k=gb-48|0;gb=k;a:{b:{c:{j=Wp(1,32);d:{e:{if(!j){a=ba(4)|0;nm(a);v[22656]=0;U(186,a|0,89116,1928);a=v[22656];v[22656]=0;if((a|0)!=1){break a}i=V(0)|0;O()|0;break e}v[j+12>>2]=f;v[j+8>>2]=e;v[j+4>>2]=d;v[j>>2]=c?c:1919;d=Cu(k+32|0);f:{g:{if(!i){break g}c=v[i>>2];if(!c){break g}while(1){h:{e=v[i+4>>2];if(e){v[22656]=0;c=Q(70,k+16|0,c|0)|0;f=v[22656];v[22656]=0;i:{if((f|0)!=1){v[22656]=0;f=Q(1929,d|0,c|0)|0;l=v[22656];v[22656]=0;if((l|0)==1){break i}v[22656]=0;Q(415,f|0,e|0)|0;e=v[22656];v[22656]=0;if((e|0)==1){break i}break h}i=V(0)|0;O()|0;break f}i=V(0)|0;O()|0;vb(c);break f}v[22656]=0;c=Q(70,k+16|0,c|0)|0;e=v[22656];v[22656]=0;j:{if((e|0)!=1){v[22656]=0;R(1930,d|0,c|0);e=v[22656];v[22656]=0;if((e|0)==1){break j}break h}i=V(0)|0;O()|0;break f}i=V(0)|0;O()|0;vb(c);break f}vb(c);c=v[i+8>>2];i=i+8|0;if(c){continue}break}}v[22656]=0;c=T(1290,96)|0;e=v[22656];v[22656]=0;k:{l:{m:{if((e|0)!=1){v[22656]=0;e=Q(1931,j|0,j+4|0)|0;f=v[22656];v[22656]=0;if((f|0)==1){break m}v[k+16>>2]=e;e=v[jq(k+8|0,k+16|0)>>2];v[22656]=0;fa(2006,c|0,a|0,b|0,e|0,d|0)|0;a=v[22656];v[22656]=0;if((a|0)==1){break l}v[j+28>>2]=c;Dj(k+16|0);a=v[j+28>>2];v[j+24>>2]=a?a+8|0:0;Ll(d);break d}i=V(0)|0;O()|0;break f}i=V(0)|0;O()|0;break k}i=V(0)|0;O()|0;Dj(k+16|0)}Yb(c)}Ll(d);Z(i|0)|0;v[22656]=0;Y(1911,2069,j|0,g|0,h|0);a=v[22656];v[22656]=0;if((a|0)!=1){v[22656]=0;X(20);a=v[22656];v[22656]=0;if((a|0)!=1){a=v[j+28>>2];if(a){kb[v[v[a>>2]+4>>2]](a)}v[j+24>>2]=0;v[j+28>>2]=0;a=v[j+20>>2];if(a){Yb(a);v[j+20>>2]=0}Yb(j);j=0;break d}i=V(0)|0;O()|0;break e}i=V(0)|0;O()|0;v[22656]=0;X(20);a=v[22656];v[22656]=0;if((a|0)==1){break b}}Z(i|0)|0;j=0;v[22656]=0;Y(1911,2069,0,g|0,h|0);a=v[22656];v[22656]=0;if((a|0)==1){break c}$()}gb=k+48|0;return j|0}a=P()|0;O()|0;v[22656]=0;X(20);b=v[22656];v[22656]=0;if((b|0)==1){break b}S(a|0);L()}V(0)|0;O()|0;Bb()}L()}function D8(a,b){a=a|0;b=b|0;var c=C(0),d=0,e=C(0),f=C(0),g=0,h=0,i=C(0),k=C(0),m=C(0),n=C(0),o=0;d=gb-16|0;gb=d;a:{b:{c:{d:{switch(b-1|0){case 0:c=z[a+48>>2];a=v[a+48>>2];e:{f:{g:{if(!(a>>>0>=8388608&(a|0)>=0)){f=C(C(-1)/C(c*c));if(!(a&2147483647)){break e}f=C(C(c-c)/C(0));if((a|0)<0){break e}a=(p(C(c*C(33554432))),j(2));b=-152;break g}if(a>>>0>2139095039){break f}b=-127;c=C(0);if((a|0)==1065353216){break f}}a=a+4913933|0;n=C((a>>>23|0)+b|0);c=C((l(2,(a&8388607)+1060439283|0),q())+C(-1));i=C(c*C(c*C(.5)));k=C(c/C(c+C(2)));e=C(k*k);m=C(e*e);f=c;c=(l(2,(p(C(c-i)),j(2))&-4096),q());e=C(C(C(f-c)-i)+C(k*C(i+C(C(e*C(C(m*C(.2849878668785095))+C(.6666666269302368)))+C(m*C(C(m*C(.24279078841209412))+C(.40000972151756287)))))));c=C(C(n*C(.3010292053222656))+C(C(c*C(.434326171875))+C(C(e*C(.434326171875))+C(C(n*C(7.903415166765626e-7))+C(C(e+c)*C(-3168997136526741e-20))))))}f=c}e=C(f*C(2e3));if(!(C(D(e))<C(2147483648))){break c}a=~~e;break b;case 1:a=(B(v[v[a+24>>2]+24604>>2],100)|0)/128|0;break b;case 2:b=gb-16|0;gb=b;h:{i:{j:{k:{a=w[v[a+24>>2]+24648|0];if(a>>>0>=6){d=ba(8)|0;v[22656]=0;b=Q(70,b|0,2219)|0;a=v[22656];v[22656]=0;if((a|0)==1){break k}rc(d,b);v[22656]=0;U(186,d|0,54952,1936);a=v[22656];v[22656]=0;if((a|0)!=1){break i}a=P()|0;O()|0;vb(b);break j}gb=b+16|0;a=v[(a<<24>>24<<2)+59688>>2];break h}a=P()|0;O()|0;ca(d|0)}S(a|0)}L()}break b;case 3:v[d>>2]=0;g=gb-80|0;gb=g;a=v[a+24>>2]+24604|0;v[g+40>>2]=v[a+32>>2];v[g>>2]=v[a+36>>2];b=g+40|0;h=v[Gf(b,g)>>2];o=d;l:{if(v[a+32>>2]==v[Wq(b)+32>>2]){b=-1;if(v[a+36>>2]==v[Wq(g)+36>>2]){break l}}b=0;if((h|0)<=0){break l}b=(h+500>>>0)/1e3|0}v[o>>2]=b;gb=g+80|0;a=v[d>>2];break b;default:break d}}h=ba(8)|0;v[22656]=0;d=Q(70,d|0,7655)|0;a=v[22656];v[22656]=0;m:{if((a|0)!=1){rc(h,d);v[22656]=0;U(186,h|0,54952,1936);a=v[22656];v[22656]=0;if((a|0)!=1){break a}b=P()|0;O()|0;vb(d);break m}b=P()|0;O()|0;ca(h|0)}S(b|0);L()}a=-2147483648}gb=d+16|0;return a|0}L()}function Jia(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,w=0,x=0;f=gb-48|0;gb=f;a:{b:{c:{e=v[a+12>>2];i=v[a+8>>2];d:{if((e|0)<=1&i>>>0<=805306368|(e|0)<=0){if((e|0)>=-2&i>>>0>=3489660928|(e|0)>-2){break c}if((e|0)==-2&i>>>0>2147483647|e>>>0>4294967294){break d}break b}if((e|0)==1&i>>>0>2147483648|e>>>0>1){break b}}p=b+196648|0;break a}p=b+131112|0;break a}p=b+262184|0}q=v[a+16>>2];b=v[a+44>>2];v[f+32>>2]=b;g=v[a+48>>2];v[f+36>>2]=g;k=v[a+52>>2];v[f+40>>2]=k;m=v[a+56>>2];v[f+44>>2]=m;r=v[a+24>>2];s=v[a+20>>2];h=v[a+4>>2];j=v[a>>2];v[f+24>>2]=j;v[f+28>>2]=h;v[f+16>>2]=i;v[f+20>>2]=e;if(d){while(1){m=1;e=((((h&2147483647)<<1|j>>>31)&2147483646)<<1)+q|0;b=(j>>>16&65520)+p|0;j=u[b+14>>1];i=u[b+12>>1];n=u[b+10>>1];l=u[b+8>>1];o=u[b+6>>1];t=u[b+4>>1];w=u[b+2>>1];x=u[b>>1];k=0;b=1;g=0;while(1){h=g<<1;v[(f+8|0)+(g<<2)>>2]=(((((((B(u[e+(h|-8)>>1],w)+B(u[e+(h|-12)>>1],x)|0)+B(u[e+(h|-4)>>1],t)|0)+B(u[e+h>>1],o)|0)+B(u[e+(h|4)>>1],l)|0)+B(u[e+(h|8)>>1],n)|0)+B(u[e+(h|12)>>1],i)|0)+B(j,u[e+(h|16)>>1])|0)/32768;h=b;b=0;g=1;if(h){continue}break}while(1){j=(f+8|0)+(k<<2)|0;g=v[j>>2];i=v[a+60>>2];n=i;h=(f+32|0)+(k<<3)|0;k=v[h>>2];b=Lb(k,-16777216,16776704);l=v[a+64>>2];e=Lb(v[h+4>>2],-16777216,16776704);o=i>>31;i=g<<8;g=i;g=kqa(n,o,g,g>>31);n=jb;l=kqa(l,l>>31,b,b>>31);g=l+g|0;b=jb+n|0;b=g>>>0<l>>>0?b+1|0:b;o=g;g=v[a+68>>2];g=kqa(g,g>>31,e,e>>31);e=o+g|0;b=jb+b|0;b=e>>>0<g>>>0?b+1|0:b;e=e+8388608|0;b=e>>>0<8388608?b+1|0:b;b=Jc(e,b,24);v[h+4>>2]=k;e=v[a+72>>2];v[j>>2]=(b|0)/256;v[h>>2]=b-(e&i);k=1;b=m&1;m=0;if(b){continue}break}v[c>>2]=v[c>>2]+B(v[f+8>>2],s);v[c+4>>2]=v[c+4>>2]+B(v[f+12>>2],r);Ub(f+24|0,f+16|0);d=d-1|0;if(d){c=c+8|0;j=v[f+24>>2];h=v[f+28>>2];continue}break}j=v[f+24>>2];h=v[f+28>>2];m=v[f+44>>2];k=v[f+40>>2];g=v[f+36>>2];b=v[f+32>>2]}v[a+56>>2]=m;v[a+52>>2]=k;v[a+48>>2]=g;v[a+44>>2]=b;v[a>>2]=j;v[a+4>>2]=h;gb=f+48|0}function eia(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,u=0,w=0;e=gb-80|0;gb=e;p=v[a+16>>2];h=Ud(e+48|0);v[h+8>>2]=a+112;v[h+16>>2]=v[a+128>>2];u=h,w=jg(b+327720|0,v[b+20>>2],(v[a+88>>2]&16384)>>>14|0),v[u+12>>2]=w;b=v[h+16>>2];if(b){u=h,w=lg(a+8|0,b),v[u>>2]=w;v[h+4>>2]=jb}j=v[a+44>>2];v[e+32>>2]=j;f=v[a+48>>2];v[e+36>>2]=f;l=v[a+52>>2];v[e+40>>2]=l;k=v[a+56>>2];v[e+44>>2]=k;q=v[a+24>>2];r=v[a+20>>2];i=v[a+4>>2];g=v[a>>2];v[e+24>>2]=g;v[e+28>>2]=i;m=v[a+12>>2];v[e+16>>2]=v[a+8>>2];v[e+20>>2]=m;if(d){while(1){l=0;j=l;f=g;v[e+72>>2]=g;v[e+76>>2]=j;i=(((i&2147483647)<<1|g>>>31)&-2)+p|0;a:{if((b|0)<=0){break a}while(1){g=(j&2147483647)<<1|f>>>31;Id(v[h+8>>2],t[(g|1)+i|0]+t[i+(g&-2)|0]<<5);Hd(v[h+8>>2],4);Ub(e+72|0,h);if((b|0)<2){break a}b=b-1|0;f=v[e+72>>2];j=v[e+76>>2];continue}}b=v[h+8>>2];Ub(b,b+8|0);b=v[h+8>>2];g=v[b+4>>2];if(g){f=b;b=(v[e+76>>2]&2147483647)<<1|v[e+72>>2]>>>31;Id(f,t[(b|1)+i|0]+t[i+(b&-2)|0]<<5);Hd(v[h+8>>2],g);b=v[h+8>>2];g=v[b>>2];v[b>>2]=g;v[b+4>>2]=0}d=d-1|0;f=ig(b,v[h+12>>2]);v[e+12>>2]=f;v[e+8>>2]=f;j=0;l=1;while(1){k=v[a+60>>2];m=k;i=(e+32|0)+(j<<3)|0;o=v[i>>2];b=Lb(o,-16777216,16776704);n=v[a+64>>2];g=Lb(v[i+4>>2],-16777216,16776704);s=k>>31;k=f<<8;f=k;f=kqa(m,s,f,f>>31);m=jb;n=kqa(n,n>>31,b,b>>31);f=n+f|0;b=jb+m|0;b=f>>>0<n>>>0?b+1|0:b;m=f;f=v[a+68>>2];f=kqa(f,f>>31,g,g>>31);g=m+f|0;b=jb+b|0;b=g>>>0<f>>>0?b+1|0:b;g=g+8388608|0;b=g>>>0<8388608?b+1|0:b;b=Jc(g,b,24);v[i+4>>2]=o;g=v[a+72>>2];v[(e+8|0)+(j<<2)>>2]=(b|0)/256;v[i>>2]=b-(g&k);if(l){j=1;l=0;f=v[e+12>>2];continue}break}v[c>>2]=v[c>>2]+B(v[e+8>>2],r);v[c+4>>2]=v[c+4>>2]+B(v[e+12>>2],q);Ub(e+24|0,e+16|0);if(d){c=c+8|0;b=v[h+16>>2];g=v[e+24>>2];i=v[e+28>>2];continue}break}g=v[e+24>>2];k=v[e+44>>2];l=v[e+40>>2];f=v[e+36>>2];j=v[e+32>>2];i=v[e+28>>2]}v[a+56>>2]=k;v[a+52>>2]=l;v[a+48>>2]=f;v[a+44>>2]=j;v[a>>2]=g;v[a+4>>2]=i;gb=e+80|0}function yba(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=C(0),f=0,g=C(0),h=0,i=C(0),j=0,k=0,l=0,m=0,n=0,o=0,p=C(0),q=0,r=0,s=0,t=0,u=C(0),w=0,x=0,y=0,A=0,B=0,D=0,E=0,F=0,G=0,H=0,I=0,J=C(0),K=C(0),L=C(0),M=C(0),N=C(0),O=C(0);m=a+44|0;if(mi(m)){B=Nd(m,0);D=Nd(m,1);E=od(m,0);F=od(m,1);q=v[a+4296>>2];o=v[a+4300>>2];if(d){k=a+4304|0;j=q+1|0;w=j+v[a+4272>>2]&4095;l=k+(w<<4)|0;x=j+v[a+4276>>2]&4095;h=((x<<4)+k|0)+4|0;y=j+v[a+4280>>2]&4095;n=((y<<4)+k|0)+8|0;A=j+v[a+4284>>2]&4095;f=((A<<4)+k|0)+12|0;r=v[a+4288>>2]+o|0;s=v[a+4292>>2]+o|0;H=a+69840|0;I=a+78032|0;G=d;while(1){w=w-1&4095;j=(w<<4)+k|0;e=z[j>>2];r=r&1023;t=(r<<3)+H|0;p=z[t+4>>2];J=z[f>>2];K=z[n>>2];L=z[h>>2];M=z[l>>2];N=z[D>>2];O=z[B>>2];x=x-1&4095;l=(x<<4)+k|0;i=z[l+4>>2];u=z[a+4232>>2];g=C(C(i*C(.6180340051651001))+C(z[t>>2]*u));f=o<<3;h=f+H|0;z[h+4>>2]=i-C(g*C(.6180340051651001));i=e;e=C(C(u*p)-C(e*C(.6180340051651001)));z[h>>2]=i+C(e*C(.6180340051651001));z[j>>2]=g;z[l+4>>2]=e;s=s&1023;t=(s<<3)+I|0;p=z[t+4>>2];y=y-1&4095;n=(y<<4)+k|0;g=z[n+8>>2];A=A-1&4095;h=(A<<4)+k|0;i=z[h+12>>2];u=z[a+4236>>2];e=C(C(i*C(.6180340051651001))+C(z[t>>2]*u));f=f+I|0;z[f+4>>2]=i-C(e*C(.6180340051651001));i=g;g=C(C(u*p)-C(g*C(.6180340051651001)));z[f>>2]=i+C(g*C(.6180340051651001));z[n+8>>2]=e;z[h+12>>2]=g;g=e;e=C(O+C(1.0000000031710769e-30));z[E>>2]=g+C(C(e*z[a+4224>>2])+z[j>>2]);g=C(N+C(1.0000000031710769e-30));z[F>>2]=C(C(g*z[a+4224>>2])+z[l+4>>2])+z[h+12>>2];f=(q<<4)+k|0;i=e;e=z[a+4228>>2];p=C(i*e);z[f>>2]=p+C(C(z[j>>2]*z[a+4240>>2])+C(M*z[a+4244>>2]));e=C(g*e);z[f+4>>2]=e+C(C(z[l+4>>2]*z[a+4248>>2])+C(L*z[a+4252>>2]));z[f+8>>2]=C(C(z[n+8>>2]*z[a+4256>>2])+C(K*z[a+4260>>2]))-e;z[f+12>>2]=p+C(C(z[h+12>>2]*z[a+4264>>2])+C(J*z[a+4268>>2]));f=h+12|0;n=n+8|0;h=l+4|0;F=F+4|0;E=E+4|0;D=D+4|0;B=B+4|0;s=s-1|0;r=r-1|0;o=o-1&1023;q=q-1&4095;l=j;G=G-1|0;if(G){continue}break}}v[a+4300>>2]=o;v[a+4296>>2]=q;Ei(a,b,c,od(m,0),od(m,1),d)}}function Vp(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;if(!a){return Cd(b)}if(b>>>0>=4294967232){v[115137]=48;return 0}e=b>>>0<11?16:b+11&-8;h=a-4|0;i=v[h>>2];c=i&-8;a:{b:{if(!(i&3)){if(e>>>0<256|c>>>0<(e|4)>>>0){break b}if(c-e>>>0<=v[116626]<<1>>>0){break a}break b}g=a-8|0;f=c+g|0;if(c>>>0>=e>>>0){b=c-e|0;if(b>>>0<16){break a}v[h>>2]=i&1|e|2;c=e+g|0;v[c+4>>2]=b|3;v[f+4>>2]=v[f+4>>2]|1;Bs(c,b);return a}if(v[116512]==(f|0)){c=c+v[116509]|0;if(c>>>0<=e>>>0){break b}v[h>>2]=i&1|e|2;b=e+g|0;c=c-e|0;v[b+4>>2]=c|1;v[116509]=c;v[116512]=b;return a}if(v[116511]==(f|0)){c=c+v[116508]|0;if(c>>>0<e>>>0){break b}b=c-e|0;c:{if(b>>>0>=16){v[h>>2]=i&1|e|2;d=e+g|0;v[d+4>>2]=b|1;c=c+g|0;v[c>>2]=b;v[c+4>>2]=v[c+4>>2]&-2;break c}v[h>>2]=c|i&1|2;b=c+g|0;v[b+4>>2]=v[b+4>>2]|1;b=0}v[116511]=d;v[116508]=b;return a}d=v[f+4>>2];if(d&2){break b}j=c+(d&-8)|0;if(j>>>0<e>>>0){break b}l=j-e|0;d:{if(d>>>0<=255){b=v[f+8>>2];d=d>>>3|0;c=v[f+12>>2];if((c|0)==(b|0)){n=466024,o=v[116506]&oqa(-2,d),v[n>>2]=o;break d}v[b+12>>2]=c;v[c+8>>2]=b;break d}k=v[f+24>>2];c=v[f+12>>2];e:{if((f|0)!=(c|0)){b=v[f+8>>2];v[b+12>>2]=c;v[c+8>>2]=b;break e}f:{b=f+20|0;d=v[b>>2];if(d){break f}b=f+16|0;d=v[b>>2];if(d){break f}c=0;break e}while(1){m=b;c=d;b=c+20|0;d=v[b>>2];if(d){continue}b=c+16|0;d=v[c+16>>2];if(d){continue}break}v[m>>2]=0}if(!k){break d}b=v[f+28>>2];d=(b<<2)+466328|0;g:{if(v[d>>2]==(f|0)){v[d>>2]=c;if(c){break g}n=466028,o=v[116507]&oqa(-2,b),v[n>>2]=o;break d}v[(v[k+16>>2]==(f|0)?16:20)+k>>2]=c;if(!c){break d}}v[c+24>>2]=k;b=v[f+16>>2];if(b){v[c+16>>2]=b;v[b+24>>2]=c}b=v[f+20>>2];if(!b){break d}v[c+20>>2]=b;v[b+24>>2]=c}if(l>>>0<=15){v[h>>2]=i&1|j|2;b=g+j|0;v[b+4>>2]=v[b+4>>2]|1;return a}v[h>>2]=i&1|e|2;b=e+g|0;v[b+4>>2]=l|3;c=g+j|0;v[c+4>>2]=v[c+4>>2]|1;Bs(b,l);return a}c=Cd(b);if(!c){return 0}d=v[h>>2];d=(d&3?-4:-8)+(d&-8)|0;hc(c,a,b>>>0>d>>>0?d:b);Yb(a);a=c}return a}function HL(a,b,c,d,e,f,g,h,i){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0;k=gb-48|0;gb=k;a:{b:{c:{d:{e:{f:{j=Wp(1,28);if(!j){a=ba(4)|0;nm(a);v[22656]=0;U(186,a|0,89116,1928);a=v[22656];v[22656]=0;if((a|0)!=1){break a}break f}v[j+12>>2]=f;v[j+8>>2]=e;v[j+4>>2]=d;v[j>>2]=c?c:1919;d=Cu(k+32|0);g:{h:{if(!i){break h}c=v[i>>2];if(!c){break h}while(1){i:{e=v[i+4>>2];if(e){v[22656]=0;c=Q(70,k+16|0,c|0)|0;f=v[22656];v[22656]=0;j:{if((f|0)!=1){v[22656]=0;f=Q(1929,d|0,c|0)|0;l=v[22656];v[22656]=0;if((l|0)==1){break j}v[22656]=0;Q(415,f|0,e|0)|0;e=v[22656];v[22656]=0;if((e|0)==1){break j}break i}i=V(0)|0;O()|0;break g}i=V(0)|0;O()|0;vb(c);break g}v[22656]=0;c=Q(70,k+16|0,c|0)|0;e=v[22656];v[22656]=0;k:{if((e|0)!=1){v[22656]=0;R(1930,d|0,c|0);e=v[22656];v[22656]=0;if((e|0)==1){break k}break i}i=V(0)|0;O()|0;break g}i=V(0)|0;O()|0;vb(c);break g}vb(c);c=v[i+8>>2];i=i+8|0;if(c){continue}break}}v[22656]=0;c=T(1290,80)|0;e=v[22656];v[22656]=0;l:{m:{n:{if((e|0)!=1){v[22656]=0;e=Q(1931,j|0,j+4|0)|0;f=v[22656];v[22656]=0;if((f|0)==1){break n}v[k+16>>2]=e;e=v[jq(k+8|0,k+16|0)>>2];v[22656]=0;fa(1933,c|0,a|0,b|0,e|0,d|0)|0;a=v[22656];v[22656]=0;if((a|0)==1){break m}v[j+24>>2]=c;Dj(k+16|0);Ll(d);i=j;break d}i=V(0)|0;O()|0;break g}i=V(0)|0;O()|0;break l}i=V(0)|0;O()|0;Dj(k+16|0)}Yb(c)}Ll(d);Z(i|0)|0;v[22656]=0;Y(1911,12284,j|0,g|0,h|0);a=v[22656];v[22656]=0;if((a|0)!=1){v[22656]=0;X(20);a=v[22656];v[22656]=0;if((a|0)==1){break f}a=v[j+24>>2];if(a){Yb(Gt(a))}i=0;v[j+24>>2]=0;a=v[j+20>>2];if(a){Yb(a);v[j+20>>2]=0}Yb(j);break d}i=V(0)|0;O()|0;v[22656]=0;X(20);a=v[22656];v[22656]=0;if((a|0)!=1){break e}break b}i=V(0)|0;O()|0}Z(i|0)|0;i=0;v[22656]=0;Y(1911,12284,0,g|0,h|0);a=v[22656];v[22656]=0;if((a|0)==1){break c}$()}gb=k+48|0;return i|0}a=P()|0;O()|0;v[22656]=0;X(20);b=v[22656];v[22656]=0;if((b|0)==1){break b}S(a|0);L()}V(0)|0;O()|0;Bb()}L()}function Kia(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,w=0,x=0,y=0;f=gb-48|0;gb=f;a:{b:{c:{e=v[a+12>>2];h=v[a+8>>2];d:{if((e|0)<=1&h>>>0<=805306368|(e|0)<=0){if((e|0)>=-2&h>>>0>=3489660928|(e|0)>-2){break c}if((e|0)==-2&h>>>0>2147483647|e>>>0>4294967294){break d}break b}if((e|0)==1&h>>>0>2147483648|e>>>0>1){break b}}p=b+196648|0;break a}p=b+131112|0;break a}p=b+262184|0}q=v[a+16>>2];b=v[a+44>>2];v[f+32>>2]=b;i=v[a+48>>2];v[f+36>>2]=i;k=v[a+52>>2];v[f+40>>2]=k;m=v[a+56>>2];v[f+44>>2]=m;r=v[a+24>>2];s=v[a+20>>2];g=v[a+4>>2];j=v[a>>2];v[f+24>>2]=j;v[f+28>>2]=g;v[f+16>>2]=h;v[f+20>>2]=e;if(d){while(1){e=(((g&2147483647)<<1|j>>>31)&-2)+q|0;b=(j>>>16&65520)+p|0;j=u[b+14>>1];h=u[b+12>>1];n=u[b+10>>1];l=u[b+8>>1];o=u[b+6>>1];w=u[b+4>>1];x=u[b+2>>1];y=u[b>>1];k=0;m=1;i=1;b=0;while(1){v[(f+8|0)+(b<<2)>>2]=(((((((B(t[e+(b|-4)|0],x)+B(t[e+(b|-6)|0],y)|0)+B(t[e+(b|-2)|0],w)|0)+B(t[b+e|0],o)|0)+B(t[e+(b|2)|0],l)|0)+B(t[e+(b|4)|0],n)|0)+B(t[e+(b|6)|0],h)|0)+B(j,t[e+(b|8)|0])<<8)/32768;g=i;i=0;b=1;if(g){continue}break}while(1){j=(f+8|0)+(k<<2)|0;e=v[j>>2];h=v[a+60>>2];n=h;i=(f+32|0)+(k<<3)|0;k=v[i>>2];b=Lb(k,-16777216,16776704);l=v[a+64>>2];g=Lb(v[i+4>>2],-16777216,16776704);o=h>>31;h=e<<8;e=h;e=kqa(n,o,e,e>>31);n=jb;l=kqa(l,l>>31,b,b>>31);e=l+e|0;b=jb+n|0;b=e>>>0<l>>>0?b+1|0:b;o=e;e=v[a+68>>2];e=kqa(e,e>>31,g,g>>31);g=o+e|0;b=jb+b|0;b=e>>>0>g>>>0?b+1|0:b;g=g+8388608|0;b=g>>>0<8388608?b+1|0:b;b=Jc(g,b,24);v[i+4>>2]=k;g=v[a+72>>2];v[j>>2]=(b|0)/256;v[i>>2]=b-(g&h);k=1;b=m&1;m=0;if(b){continue}break}v[c>>2]=v[c>>2]+B(v[f+8>>2],s);v[c+4>>2]=v[c+4>>2]+B(v[f+12>>2],r);Ub(f+24|0,f+16|0);d=d-1|0;if(d){c=c+8|0;j=v[f+24>>2];g=v[f+28>>2];continue}break}j=v[f+24>>2];g=v[f+28>>2];m=v[f+44>>2];k=v[f+40>>2];i=v[f+36>>2];b=v[f+32>>2]}v[a+56>>2]=m;v[a+52>>2]=k;v[a+48>>2]=i;v[a+44>>2]=b;v[a>>2]=j;v[a+4>>2]=g;gb=f+48|0}function TS(a){a=a|0;var b=0,c=0,d=0,e=0;Qb(a,0,288);c=a+288|0;vB(c);d=a+800|0;Yo(d);t[a+2|0]=w[11432];b=w[11430]|w[11431]<<8;t[a|0]=b;t[a+1|0]=b>>>8;t[a+34|0]=w[11510];b=w[11508]|w[11509]<<8;t[a+32|0]=b;t[a+33|0]=b>>>8;b=w[2591]|w[2592]<<8|(w[2593]<<16|w[2594]<<24);t[a+99|0]=b;t[a+100|0]=b>>>8;t[a+101|0]=b>>>16;t[a+102|0]=b>>>24;b=w[2588]|w[2589]<<8|(w[2590]<<16|w[2591]<<24);t[a+96|0]=b;t[a+97|0]=b>>>8;t[a+98|0]=b>>>16;t[a+99|0]=b>>>24;b=w[12799]|w[12800]<<8|(w[12801]<<16|w[12802]<<24);t[a+128|0]=b;t[a+129|0]=b>>>8;t[a+130|0]=b>>>16;t[a+131|0]=b>>>24;b=w[12802]|w[12803]<<8|(w[12804]<<16|w[12805]<<24);t[a+131|0]=b;t[a+132|0]=b>>>8;t[a+133|0]=b>>>16;t[a+134|0]=b>>>24;t[a+260|0]=w[6426];b=w[6422]|w[6423]<<8|(w[6424]<<16|w[6425]<<24);t[a+256|0]=b;t[a+257|0]=b>>>8;t[a+258|0]=b>>>16;t[a+259|0]=b>>>24;a=gb-32|0;gb=a;b=Tb(a+16|0,2028);v[22656]=0;R(444,a+8|0,c|0);c=v[22656];v[22656]=0;a:{b:{if((c|0)==1){break b}v[22656]=0;Q(401,a+8|0,b|0)|0;c=v[22656];v[22656]=0;if((c|0)==1){break b}vb(b);gb=a+32|0;break a}a=P()|0;O()|0;vb(b);S(a|0);L()}b=0;a=gb+-64|0;gb=a;c:{d:{e:{while(1){v[a+60>>2]=b<<3;f:{if(b>>>0<=15){Df(a+32|0,1193);v[22656]=0;R(442,a+16|0,a+60|0);c=v[22656];v[22656]=0;g:{h:{i:{j:{if((c|0)!=1){v[22656]=0;U(443,a+48|0,a+32|0,a+16|0);c=v[22656];v[22656]=0;if((c|0)==1){break j}v[22656]=0;R(444,a+8|0,(b<<5)+d|0);c=v[22656];v[22656]=0;if((c|0)==1){break i}v[22656]=0;Q(401,a+8|0,a+48|0)|0;c=v[22656];v[22656]=0;if((c|0)==1){break i}vb(a+48|0);vb(a+16|0);Hb(a+32|0);break f}b=P()|0;O()|0;break g}b=P()|0;O()|0;break h}b=P()|0;O()|0;vb(a+48|0)}vb(a+16|0)}Hb(a+32|0);break d}c=Tb(a+48|0,18726);v[22656]=0;R(444,a+32|0,(b<<5)+d|0);e=v[22656];v[22656]=0;if((e|0)==1){break e}v[22656]=0;Q(401,a+32|0,c|0)|0;e=v[22656];v[22656]=0;if((e|0)==1){break e}vb(c)}b=b+1|0;if((b|0)!=128){continue}break}gb=a- -64|0;break c}b=P()|0;O()|0;vb(c)}S(b|0);L()}}function zk(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;a:{b:{c:{switch(b|0){case 1:b=0;a=Kb(a);d=Ab(c);v[22656]=0;R(62,a|0,d|0);d=v[22656];v[22656]=0;d:{if((d|0)!=1){e:{if(Ab(c)){while(1){d=t[pc(c,b)|0];f:{if((d|0)>=0){v[22656]=0;R(63,a|0,d&255);d=v[22656];v[22656]=0;if((d|0)!=1){break f}break e}v[22656]=0;R(63,a|0,65533);d=v[22656];v[22656]=0;if((d|0)==1){break e}}b=b+1|0;if(Ab(c)>>>0>b>>>0){continue}break}}break d}}break a}return;case 2:b=0;a=Kb(a);d=Ab(c);v[22656]=0;R(62,a|0,d|0);d=v[22656];v[22656]=0;g:{if((d|0)!=1){h:{if(Ab(c)){while(1){d=w[pc(c,b)|0];v[22656]=0;R(63,a|0,d|0);d=v[22656];v[22656]=0;if((d|0)==1){break h}b=b+1|0;if(Ab(c)>>>0>b>>>0){continue}break}}break g}}break a}return;case 3:Xq(a,c,20896);return;case 5:Xq(a,c,21920);return;case 4:Xq(a,c,22944);return;case 6:Xq(a,c,23968);return;default:a=ba(8)|0;v[22656]=0;Q(59,a|0,8299)|0;b=v[22656];v[22656]=0;if((b|0)!=1){break b}b=P()|0;O()|0;ca(a|0);S(b|0);L();case 0:break c}}d=gb-16|0;gb=d;e=Kb(a);f=d,g=zd(c),v[f+8>>2]=g;f=d,g=gf(c),v[f>>2]=g;i:{j:{k:{if(!Gb(d+8|0,d)){break k}c=0;a=0;while(1){b=w[v[d+8>>2]];l:{if(!c){if(!(b&128)){c=0;v[22656]=0;R(63,e|0,b|0);b=v[22656];v[22656]=0;if((b|0)!=1){break l}break j}if((b&224)==192){a=b&31;c=1;break l}if((b&240)==224){a=b&15;c=2;break l}if((b&248)==240){a=b&7;c=3;break l}a=0;v[22656]=0;R(63,e|0,65533);b=v[22656];v[22656]=0;c=0;if((b|0)==1){break j}break l}if((b&192)!=128){v[22656]=0;R(63,e|0,65533);a=v[22656];v[22656]=0;if((a|0)==1){break j}a=b&63;c=-1;break l}b=b&63|a<<6;c=c-1|0;if(c){a=b;break l}a=0;v[22656]=0;R(63,e|0,b|0);b=v[22656];v[22656]=0;c=0;if((b|0)==1){break j}}b=d+8|0;Pe(b);if(Gb(b,d)){continue}break}if(!c){break k}v[22656]=0;R(63,e|0,65533);a=v[22656];v[22656]=0;if((a|0)!=1){break k}break j}gb=d+16|0;break i}a=P()|0;O()|0;Hc(e);S(a|0);L()}return}ia(a|0,89236,24);L()}b=P()|0;O()|0;Hc(a);S(b|0);L()}function oma(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0;f=gb-16|0;gb=f;t[a|0]=0;d=w[b|0];if(d){t[a|0]=d>>>0>96?-1:d+12|0}t[a+1|0]=w[b+1|0];d=a;c=w[b+2|0];e=c-16|0;a:{b:{if((e&255)>>>0<=128){t[a+2|0]=1;c=(e&254)>>>1|0;break b}c:{switch((c+96&240)>>>4|0){case 0:t[a+2|0]=4;c=c&15;break b;case 1:t[a+2|0]=3;c=c&15;break b;case 2:t[a+2|0]=6;c=c&15;break b;case 3:break c;default:break a}}t[a+2|0]=5;c=c&15}t[d+4|0]=c}e=w[b+4|0];c=w[b+5|0];d=w[b+6|0];d:{if(!(d?1:e|c)){break d}e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{if(e>>>0<=28){switch(e|0){case 16:break j;case 15:break k;case 12:break l;case 8:break m;case 4:break n;case 3:break o;case 2:break p;case 1:break q;case 0:break r;default:break d}}s:{switch(e-29|0){case 7:break f;case 5:break g;case 3:break h;case 0:break i;case 1:case 2:case 4:case 6:break d;default:break s}}if((e|0)==128){break e}if((e|0)!=157){break d}t[a+2|0]=15;t[a+3|0]=20;t[a+4|0]=d>>>3;t[f+15|0]=15;h=a,i=w[ac(b+5|0,f+15|0)|0]|208,t[h+5|0]=i;break d}t[a+5|0]=c;t[a+3|0]=d;Of(a);g=w[b+6|0]==15;break d}t[a+3|0]=2;h=a,i=Xi(d<<4|(c&240)>>>4),t[h+5|0]=i;break d}t[a+3|0]=3;h=a,i=Xi(d<<4|(c&240)>>>4),t[h+5|0]=i;break d}t[a+3|0]=4;h=a,i=Xi(d<<4|(c&240)>>>4),t[h+5|0]=i;break d}t[a+3|0]=5;t[a+5|0]=d&240|(c&240)>>>4;break d}if(c){t[a+5|0]=c;t[a+3|0]=9;break d}if((d-1&255)>>>0>1){break d}t[a+5|0]=145;t[a+3|0]=20;break d}t[a+3|0]=13;t[a+5|0]=d>>>1;break d}if(d){t[a+5|0]=d;t[a+3|0]=17;break d}t[a+3|0]=16;t[a+5|0]=c&15;break d}t[a+5|0]=c;t[a+3|0]=d;_u(a,1);g=(w[a+3|0]&254)==16;break d}t[a+5|0]=c;t[a+3|0]=18;break d}t[a+3|0]=31;t[a+5|0]=d>>>1;break d}t[a+3|0]=31;t[a+5|0]=d>>>1&120;break d}t[a+5|0]=159;t[a+3|0]=20;break d}t[a+3|0]=21;t[a+5|0]=d>>>2}b=w[b+3|0];t:{if(!b){break t}if(!w[a+3|0]){t[a+5|0]=b;t[a+3|0]=9;break t}if(w[a+2|0]){break t}t[a+2|0]=2;t[a+4|0]=b>>>2}gb=f+16|0;return g|0}
function Hz(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;c=gb-208|0;gb=c;g=1;d=v[a+12>>2];i=1<<d;if(d&1){j=i>>>1|0;e=j>>>0>1?j:1;d=0;while(1){k=d+j|0;g=Tc(b,k);m=v[g+12>>2];v[c+200>>2]=v[g+8>>2];v[c+204>>2]=m;m=v[g+4>>2];v[c+192>>2]=v[g>>2];v[c+196>>2]=m;m=c+192|0;Gj(c+176|0,Tc(b,d),m);g=Tc(b,k);h=v[c+188>>2];v[g+8>>2]=v[c+184>>2];v[g+12>>2]=h;k=v[c+180>>2];v[g>>2]=v[c+176>>2];v[g+4>>2]=k;Gz(Tc(b,d),m);d=d+1|0;if((e|0)!=(d|0)){continue}break}d=v[a+12>>2];g=2;i=i>>>3|0}else{i=i>>>2|0}k=d&-2;if(k){while(1){if(g){t=B(i,3);u=i<<1;j=0;while(1){d=Tc(a,j<<1);e=v[d+12>>2];v[c+200>>2]=v[d+8>>2];v[c+204>>2]=e;e=v[d+4>>2];v[c+192>>2]=v[d>>2];v[c+196>>2]=e;d=Tc(a,j);e=v[d+12>>2];v[c+184>>2]=v[d+8>>2];v[c+188>>2]=e;e=v[d+4>>2];v[c+176>>2]=v[d>>2];v[c+180>>2]=e;Li(c+160|0,c+176|0,c+192|0);d=j<<k;m=i+d|0;if(d>>>0<m>>>0){while(1){e=Tc(b,d);h=v[e+12>>2];v[c+152>>2]=v[e+8>>2];v[c+156>>2]=h;h=v[e+4>>2];v[c+144>>2]=v[e>>2];v[c+148>>2]=h;h=c+128|0;q=d+i|0;Li(h,c+192|0,Tc(b,q));e=c+112|0;r=d+u|0;Li(e,c+176|0,Tc(b,r));f=c+96|0;s=d+t|0;Li(f,c+160|0,Tc(b,s));n=c+80|0;l=c+144|0;Gl(n,l,e);o=c- -64|0;Gj(o,l,e);l=c+48|0;Gl(l,h,f);e=c+16|0;Vm(e,-A[6026],-A[6027]);Gj(c,h,f);h=c+32|0;Li(h,e,c);Gl(e,n,l);f=Tc(b,d);p=v[c+28>>2];v[f+8>>2]=v[c+24>>2];v[f+12>>2]=p;p=v[c+20>>2];v[f>>2]=v[c+16>>2];v[f+4>>2]=p;Gj(e,n,l);f=Tc(b,q);l=v[c+28>>2];v[f+8>>2]=v[c+24>>2];v[f+12>>2]=l;n=v[c+20>>2];v[f>>2]=v[c+16>>2];v[f+4>>2]=n;Gl(e,o,h);f=Tc(b,r);l=v[c+28>>2];v[f+8>>2]=v[c+24>>2];v[f+12>>2]=l;n=v[c+20>>2];v[f>>2]=v[c+16>>2];v[f+4>>2]=n;Gj(e,o,h);e=Tc(b,s);f=v[c+28>>2];v[e+8>>2]=v[c+24>>2];v[e+12>>2]=f;h=v[c+20>>2];v[e>>2]=v[c+16>>2];v[e+4>>2]=h;d=d+1|0;if((m|0)!=(d|0)){continue}break}}j=j+1|0;if((j|0)!=(g|0)){continue}break}}i=i>>>2|0;g=g<<2;k=k-2|0;if(k){continue}break}}gb=c+208|0}function T7(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0;e=gb-96|0;gb=e;a:{if(gd(c)){break a}f=w[uL(c)|0];if((f|0)==33){d=1}else{if((f|0)!=63){break a}d=0}f=e+80|0;Qs(f,c,0,Ab(c)-1|0);Eb(c,f);vb(f)}f=e+80|0;Ld(f);g=v[e+80>>2];Ld(e+72|0);g=tL(g,v[e+76>>2],c);Ld(f);b:{c:{d:{e:{f:{if((g|0)==v[e+84>>2]){if(qe(c,18726)){a=ba(8)|0;v[22656]=0;b=Q(70,e+80|0,7752)|0;c=v[22656];v[22656]=0;if((c|0)==1){break d}rc(a,b);v[22656]=0;U(186,a|0,54952,1936);a=v[22656];v[22656]=0;if((a|0)!=1){break b}c=P()|0;O()|0;vb(b);break c}if(!d){break f}a=ba(8)|0;v[22656]=0;U(2053,e+80|0,14764,c|0);b=v[22656];v[22656]=0;if((b|0)!=1){rc(a,e+80|0);v[22656]=0;U(186,a|0,54952,1936);a=v[22656];v[22656]=0;if((a|0)!=1){break b}c=P()|0;O()|0;vb(e+80|0);break c}c=P()|0;O()|0;ca(a|0);break c}f=Kb(e+80|0);g:{h:{i:{j:{switch(v[g+4>>2]){case 0:Eg(e- -64|0,c);v[22656]=0;c=v[e+68>>2];v[e+8>>2]=v[e+64>>2];v[e+12>>2]=c;b=W(1996,b|0,e+8|0,d|0)|0;c=v[22656];v[22656]=0;if((c|0)!=1){v[22656]=0;t[e+72|0]=b;R(2056,a|0,e+72|0);a=v[22656];v[22656]=0;if((a|0)!=1){break g}}break i;case 1:Eg(e+56|0,c);v[22656]=0;c=v[e+60>>2];v[e+16>>2]=v[e+56>>2];v[e+20>>2]=c;b=vG(b,e+16|0,d);c=jb;d=v[22656];v[22656]=0;if((d|0)!=1){v[22656]=0;v[e+72>>2]=b;v[e+76>>2]=c;R(2059,a|0,e+72|0);a=v[22656];v[22656]=0;if((a|0)!=1){break g}}break i;case 2:Eg(e+48|0,c);v[22656]=0;c=v[e+52>>2];v[e+24>>2]=v[e+48>>2];v[e+28>>2]=c;h=+oa(1998,b|0,e+24|0,d|0);b=v[22656];v[22656]=0;if((b|0)!=1){v[22656]=0;A[e+72>>3]=h;R(2060,a|0,e+72|0);a=v[22656];v[22656]=0;if((a|0)!=1){break g}}break i;case 3:break j;default:break h}}Eg(e+40|0,c);v[22656]=0;c=v[e+44>>2];v[e+32>>2]=v[e+40>>2];v[e+36>>2]=c;Y(1999,a|0,b|0,e+32|0,d|0);a=v[22656];v[22656]=0;if((a|0)!=1){break g}}c=P()|0;O()|0;vb(f);break c}Dc(a,f)}vb(f);break e}Kb(a)}gb=e+96|0;return}c=P()|0;O()|0;ca(a|0)}S(c|0)}L()}function pia(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,w=0,x=0;g=gb-48|0;gb=g;t=v[a+16>>2];i=v[a+44>>2];v[g+32>>2]=i;n=v[a+48>>2];v[g+36>>2]=n;h=v[a+52>>2];v[g+40>>2]=h;j=v[a+56>>2];v[g+44>>2]=j;o=v[a+40>>2];p=v[a+36>>2];e=v[a+4>>2];k=v[a>>2];v[g+24>>2]=k;v[g+28>>2]=e;f=v[a+12>>2];v[g+16>>2]=v[a+8>>2];v[g+20>>2]=f;a:{if(d){while(1){n=1;e=((((e&2147483647)<<1|k>>>31)&2147483646)<<1)+t|0;f=(((k>>>16|0)+4&131064)<<1)+b|0;k=u[f+38>>1];j=u[f+36>>1];l=u[f+34>>1];q=u[f+32>>1];m=u[f+30>>1];r=u[f+28>>1];w=u[f+26>>1];x=u[f+24>>1];i=0;h=1;f=0;while(1){s=(g+8|0)+(f<<2)|0;f=f<<1;v[s>>2]=(((((B(u[e+(f|8)>>1],l)+B(u[e+(f|4)>>1],q)|0)+B(j,u[e+(f|12)>>1])|0)+B(k,u[e+(f|16)>>1])|0)/2|0)+((((B(u[e+(f|-8)>>1],w)+B(u[e+(f|-12)>>1],x)|0)+B(u[e+(f|-4)>>1],r)|0)+B(u[e+f>>1],m)|0)/2|0)|0)/16384;s=h&1;h=0;f=1;if(s){continue}break}while(1){k=(g+8|0)+(i<<2)|0;h=v[k>>2];j=v[a+60>>2];l=j;f=(g+32|0)+(i<<3)|0;q=v[f>>2];e=Lb(q,-16777216,16776704);m=v[a+64>>2];i=Lb(v[f+4>>2],-16777216,16776704);r=j>>31;j=h<<8;h=j;h=kqa(l,r,h,h>>31);l=jb;m=kqa(m,m>>31,e,e>>31);h=m+h|0;e=jb+l|0;e=h>>>0<m>>>0?e+1|0:e;l=h;h=v[a+68>>2];h=kqa(h,h>>31,i,i>>31);i=l+h|0;e=jb+e|0;e=h>>>0>i>>>0?e+1|0:e;i=i+8388608|0;e=i>>>0<8388608?e+1|0:e;e=Jc(i,e,24);v[f+4>>2]=q;i=v[a+72>>2];v[k>>2]=(e|0)/256;v[f>>2]=e-(i&j);i=1;e=n&1;n=0;if(e){continue}break}e=v[a+32>>2];p=v[a+28>>2]+p|0;f=p>>12;v[c>>2]=v[c>>2]+B(f,v[g+8>>2]);o=e+o|0;l=o>>12;v[c+4>>2]=v[c+4>>2]+B(l,v[g+12>>2]);Ub(g+24|0,g+16|0);d=d-1|0;if(d){c=c+8|0;k=v[g+24>>2];e=v[g+28>>2];continue}break}k=v[g+24>>2];e=v[g+28>>2];j=v[g+44>>2];h=v[g+40>>2];n=v[g+36>>2];i=v[g+32>>2];break a}l=o>>12;f=p>>12}v[a+40>>2]=o;v[a+20>>2]=f;v[a+36>>2]=p;v[a+56>>2]=j;v[a+52>>2]=h;v[a+48>>2]=n;v[a+44>>2]=i;v[a+24>>2]=l;v[a>>2]=k;v[a+4>>2]=e;gb=g+48|0}function Uha(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;d=gb+-64|0;gb=d;u[d+62>>1]=b;e=Ri(a);b=e;f=d+48|0;g=Ig(f);a:{if(!b){break a}v[22656]=0;R(814,f|0,b|0);h=v[22656];v[22656]=0;if((h|0)!=1){v[22656]=0;R(1087,f|0,b|0);b=v[22656];v[22656]=0;if((b|0)!=1){break a}}a=P()|0;O()|0;cs(g);S(a|0);L()}b:{c:{if(!e){break c}b=0;while(1){j=sc(f,b),k=b-c|0,u[j>>1]=k;v[22656]=0;g=Q(1086,a|0,b|0)|0;h=v[22656];v[22656]=0;if((h|0)==1){break b}c=(x[g>>1]==x[d+62>>1])+c|0;b=b+1|0;if((e|0)!=(b|0)){continue}break}if(!(c&65535)){break c}e=Vb(a);c=Zb(a);b=gb-32|0;gb=b;v[b+16>>2]=c;j=b,k=iC(e,c,d+62|0),v[j+24>>2]=k;d:{if(!Gb(b+24|0,b+16|0)){break d}v[b+8>>2]=v[b+24>>2];if(!Gb(of(b+8|0),b+16|0)){break d}while(1){if(x[v[b+8>>2]>>1]!=x[d+62>>1]){c=b+24|0;u[v[c>>2]>>1]=x[v[b+8>>2]>>1];of(c)}if(Gb(of(b+8|0),b+16|0)){continue}break}}gb=b+32|0;v[d+32>>2]=v[b+24>>2];g=d+32|0;b=Fd(d+40|0,g);j=d,k=Zb(a),v[j+16>>2]=k;h=d+16|0;e=Fd(d+24|0,h);b=v[b>>2];c=gb-32|0;gb=c;v[c+16>>2]=v[e>>2];v[c+24>>2]=b;b=a;e=v[b>>2];j=c,k=Vb(b),v[j+8>>2]=k;i=c+24|0;e=e+(sp(i,c+8|0)<<1)|0;if(Gb(i,c+16|0)){yn(b,Rg(e+(sp(c+16|0,c+24|0)<<1)|0,v[b+4>>2],e))}Hg(e);gb=c+32|0;j=d,k=Vb(a),v[j+32>>2]=k;j=d,k=Zb(a),v[j+16>>2]=k;if(Gb(g,h)){while(1){b=x[v[d+32>>2]>>1];c=v[a+24>>2];v[22656]=0;c=me(c+484344|0,b);e=v[22656];v[22656]=0;if((e|0)==1){break b}e:{if(!c){break e}b=_b(v[a+24>>2]+484344|0,b);j=d,k=Vb(b),v[j+8>>2]=k;j=d,k=Zb(b),v[j>>2]=k;if(!Gb(d+8|0,d)){break e}while(1){b=v[d+8>>2];f:{if(w[b+3|0]!=12){break f}c=w[b+5|0];if(tc(f)>>>0<=c>>>0){break f}j=b,k=w[sc(f,w[b+5|0])|0],t[j+5|0]=k}b=d+8|0;bk(b);if(Gb(b,d)){continue}break}}b=d+32|0;of(b);if(Gb(b,d+16|0)){continue}break}}b=x[a+28>>1];if(tc(f)>>>0<=b>>>0){break c}j=a,k=x[sc(f,x[a+28>>1])>>1],u[j+28>>1]=k}Ze(f);gb=d- -64|0;return}a=P()|0;O()|0;Ze(f);S(a|0);L()}function qia(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,w=0,x=0,y=0;g=gb-48|0;gb=g;s=v[a+16>>2];i=v[a+44>>2];v[g+32>>2]=i;n=v[a+48>>2];v[g+36>>2]=n;h=v[a+52>>2];v[g+40>>2]=h;j=v[a+56>>2];v[g+44>>2]=j;o=v[a+40>>2];p=v[a+36>>2];e=v[a+4>>2];k=v[a>>2];v[g+24>>2]=k;v[g+28>>2]=e;f=v[a+12>>2];v[g+16>>2]=v[a+8>>2];v[g+20>>2]=f;a:{if(d){while(1){e=(((e&2147483647)<<1|k>>>31)&-2)+s|0;n=1;f=(((k>>>16|0)+4&131064)<<1)+b|0;k=u[f+38>>1];j=u[f+36>>1];l=u[f+34>>1];q=u[f+32>>1];m=u[f+30>>1];r=u[f+28>>1];w=u[f+26>>1];x=u[f+24>>1];i=0;h=1;f=0;while(1){v[(g+8|0)+(f<<2)>>2]=(((((B(t[e+(f|4)|0],l)+B(t[e+(f|2)|0],q)|0)+B(j,t[e+(f|6)|0])|0)+B(k,t[e+(f|8)|0])<<8)/2|0)+((((B(t[e+(f|-4)|0],w)+B(t[e+(f|-6)|0],x)|0)+B(t[e+(f|-2)|0],r)|0)+B(t[e+f|0],m)<<8)/2|0)|0)/16384;y=h&1;h=0;f=1;if(y){continue}break}while(1){k=(g+8|0)+(i<<2)|0;h=v[k>>2];j=v[a+60>>2];l=j;f=(g+32|0)+(i<<3)|0;q=v[f>>2];e=Lb(q,-16777216,16776704);m=v[a+64>>2];i=Lb(v[f+4>>2],-16777216,16776704);r=j>>31;j=h<<8;h=j;h=kqa(l,r,h,h>>31);l=jb;m=kqa(m,m>>31,e,e>>31);h=m+h|0;e=jb+l|0;e=h>>>0<m>>>0?e+1|0:e;l=h;h=v[a+68>>2];h=kqa(h,h>>31,i,i>>31);i=l+h|0;e=jb+e|0;e=h>>>0>i>>>0?e+1|0:e;i=i+8388608|0;e=i>>>0<8388608?e+1|0:e;e=Jc(i,e,24);v[f+4>>2]=q;i=v[a+72>>2];v[k>>2]=(e|0)/256;v[f>>2]=e-(i&j);i=1;e=n&1;n=0;if(e){continue}break}e=v[a+32>>2];p=v[a+28>>2]+p|0;l=p>>12;v[c>>2]=v[c>>2]+B(l,v[g+8>>2]);o=e+o|0;f=o>>12;v[c+4>>2]=v[c+4>>2]+B(f,v[g+12>>2]);Ub(g+24|0,g+16|0);d=d-1|0;if(d){c=c+8|0;k=v[g+24>>2];e=v[g+28>>2];continue}break}k=v[g+24>>2];e=v[g+28>>2];j=v[g+44>>2];h=v[g+40>>2];n=v[g+36>>2];i=v[g+32>>2];break a}f=o>>12;l=p>>12}v[a+40>>2]=o;v[a+20>>2]=l;v[a+36>>2]=p;v[a+56>>2]=j;v[a+52>>2]=h;v[a+48>>2]=n;v[a+44>>2]=i;v[a+24>>2]=f;v[a>>2]=k;v[a+4>>2]=e;gb=g+48|0}function Wha(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;f=gb-32|0;gb=f;d=b&5;a:{if(!(c&5)){if(!d){break a}j=a,k=Mu(t[a+36|0],t[a+37|0]),v[j+24>>2]=k;u[a+36>>1]=0;if((b|0)!=1){break a}e=kqa(v[a+24>>2],0,8272,0)+4181|0;d=jb;j=a,k=Qc(nqa(e,e>>>0<4181?d+1|0:d,8363,0),jb),v[j+24>>2]=k;break a}if(d){break a}if((c|0)==1){e=kqa(v[a+24>>2],0,8363,0)+4136|0;d=jb;j=a,k=Qc(nqa(e,e>>>0<4136?d+1|0:d,8272,0),jb),v[j+24>>2]=k}e=gb-16|0;gb=e;g=e+8|0;h=g;d=gb-16|0;gb=d;i=v[a+24>>2];b:{if(!i){t[h|0]=0;t[h+1|0]=0;break b}mt(d+8|0,Lb(Ro(Tp(+(i>>>0)*.00011957431543704412)*2215.9795828054475),-16384,16383),128);t[d+7|0]=v[d+8>>2];t[d+6|0]=v[d+12>>2];lB(h,d+7|0,d+6|0)}gb=d+16|0;yc(e,a+36|0);d=e+4|0;yc(d,a+37|0);tS(e,g);tS(d,g+1|0);gb=e+16|0}if(c&3){u[a+38>>1]=0;u[a+40>>1]=0;t[a+36|0]=0;u[a+34>>1]=x[a+34>>1]&65499}if(c&7){u[a+32>>1]=64;d=x[a+34>>1];if(d&8){e=v[a+16>>2];v[a+4>>2]=v[a+12>>2];v[a+8>>2]=e;d=d&16?d|6:d&65529|2}v[a+12>>2]=0;v[a+16>>2]=0;u[a+34>>1]=d&65511}c:{d:{e:{if(c&4){d=x[a+34>>1];if(!(d&32)){u[a+28>>1]=128;u[a+34>>1]=d|32}yf(a+40|0,15);yf(a+41|0,63);if(c&16777248?b&4:0){break e}if(!(b&16777248)){break c}if(w[a+41|0]){break d}break c}if(!(b&4)|!(c&16777248)){break c}if(w[a+41|0]){break d}break c}if(!w[a+41|0]){break c}}e=w[a+40|0];if(!e){break c}b=a;d=w[a+39|0];if(d){g=Bn(Qc(((e<<8|d>>>1)>>>0)/(d>>>0)|0,0))}else{g=255}t[b+39|0]=g}f:{g:{if((c|0)!=4){if((c|0)==16777216){break f}if((c|0)!=32|w[a+38|0]!=2){break g}t[a+38|0]=3;break g}if(w[a+38|0]!=4){break g}t[a+38|0]=0}u[a+34>>1]=x[a+34>>1]&49151}h:{if(!(!(w[a+35|0]&2)|c&16777218)){v[f+24>>2]=0;v[f+8>>2]=0;v[f+16>>2]=0;v[f+20>>2]=0;v[f>>2]=0;v[f+4>>2]=0;So(a,0,f);break h}if(!(w[a+35|0]&2)|(c|0)!=2){break h}a=a+68|0;b=ic(a,8);t[b|0]=w[b|0]&3;a=ic(a,9);t[a|0]=w[a|0]&3}gb=f+32|0}function y3(a,b,c,d,e,f,g,h){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0;i=gb-432|0;gb=i;v[i+424>>2]=37;v[i+428>>2]=0;m=Ps(i+424|1,11170,v[c+4>>2]);v[i+380>>2]=i+384;a=xe();a:{if(m){k=v[c+8>>2];j=i- -64|0;v[j>>2]=g;v[j+4>>2]=h;v[i+56>>2]=e;v[i+60>>2]=f;v[i+48>>2]=k;a=Ff(i+384|0,30,a,i+424|0,i+48|0);break a}v[i+80>>2]=e;v[i+84>>2]=f;v[i+88>>2]=g;v[i+92>>2]=h;a=Ff(i+384|0,30,a,i+424|0,i+80|0)}v[i+128>>2]=2428;k=ge(i+368|0,0,i+128|0);l=i+384|0;j=l;b:{c:{d:{if((a|0)>=30){e:{if(m){v[22656]=0;a=ga(2448)|0;j=v[22656];v[22656]=0;if((j|0)==1){break c}j=v[c+8>>2];v[i+16>>2]=g;v[i+20>>2]=h;v[i>>2]=j;v[22656]=0;v[i+8>>2]=e;v[i+12>>2]=f;a=da(2467,i+380|0,a|0,i+424|0,i|0)|0;e=v[22656];v[22656]=0;if((e|0)!=1){break e}break c}v[22656]=0;a=ga(2448)|0;j=v[22656];v[22656]=0;if((j|0)==1){break c}v[i+32>>2]=e;v[i+36>>2]=f;v[22656]=0;v[i+40>>2]=g;v[i+44>>2]=h;a=da(2467,i+380|0,a|0,i+424|0,i+32|0)|0;e=v[22656];v[22656]=0;if((e|0)==1){break c}}if((a|0)==-1){v[22656]=0;X(2429);a=v[22656];v[22656]=0;if((a|0)==1){break c}break d}Ee(k,v[i+380>>2]);j=v[i+380>>2]}f=a+j|0;g=Tg(j,f,c);v[i+116>>2]=2428;e=ge(i+120|0,0,i+116|0);f:{g:{if(v[i+380>>2]==(i+384|0)){a=i+128|0;break g}a=Cd(a<<3);if(!a){v[22656]=0;X(2429);a=v[22656];v[22656]=0;if((a|0)!=1){break d}c=P()|0;O()|0;break f}Ee(e,a);l=v[i+380>>2]}v[22656]=0;Fc(i+104|0,c);h=v[22656];v[22656]=0;h:{i:{if((h|0)!=1){v[22656]=0;ja(2476,l|0,g|0,f|0,a|0,i+116|0,i+112|0,i+104|0);f=v[22656];v[22656]=0;if((f|0)==1){break i}Wb(i+104|0);v[22656]=0;a=la(2477,b|0,a|0,v[i+116>>2],v[i+112>>2],c|0,d|0)|0;b=v[22656];v[22656]=0;if((b|0)==1){break h}Ic(e);Ic(k);gb=i+432|0;return a|0}c=P()|0;O()|0;break f}c=P()|0;O()|0;Wb(i+104|0);break f}c=P()|0;O()|0}Ic(e);break b}L()}c=P()|0;O()|0}Ic(k);S(c|0);L()}function J3(a,b,c,d,e,f,g,h){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0;i=gb-256|0;gb=i;v[i+248>>2]=37;v[i+252>>2]=0;m=Ps(i+248|1,11170,v[c+4>>2]);v[i+204>>2]=i+208;a=xe();a:{if(m){k=v[c+8>>2];j=i- -64|0;v[j>>2]=g;v[j+4>>2]=h;v[i+56>>2]=e;v[i+60>>2]=f;v[i+48>>2]=k;a=Ff(i+208|0,30,a,i+248|0,i+48|0);break a}v[i+80>>2]=e;v[i+84>>2]=f;v[i+88>>2]=g;v[i+92>>2]=h;a=Ff(i+208|0,30,a,i+248|0,i+80|0)}v[i+128>>2]=2428;k=ge(i+192|0,0,i+128|0);l=i+208|0;j=l;b:{c:{d:{if((a|0)>=30){e:{if(m){v[22656]=0;a=ga(2448)|0;j=v[22656];v[22656]=0;if((j|0)==1){break c}j=v[c+8>>2];v[i+16>>2]=g;v[i+20>>2]=h;v[i>>2]=j;v[22656]=0;v[i+8>>2]=e;v[i+12>>2]=f;a=da(2467,i+204|0,a|0,i+248|0,i|0)|0;e=v[22656];v[22656]=0;if((e|0)!=1){break e}break c}v[22656]=0;a=ga(2448)|0;j=v[22656];v[22656]=0;if((j|0)==1){break c}v[i+32>>2]=e;v[i+36>>2]=f;v[22656]=0;v[i+40>>2]=g;v[i+44>>2]=h;a=da(2467,i+204|0,a|0,i+248|0,i+32|0)|0;e=v[22656];v[22656]=0;if((e|0)==1){break c}}if((a|0)==-1){v[22656]=0;X(2429);a=v[22656];v[22656]=0;if((a|0)==1){break c}break d}Ee(k,v[i+204>>2]);j=v[i+204>>2]}f=a+j|0;g=Tg(j,f,c);v[i+116>>2]=2428;e=ge(i+120|0,0,i+116|0);f:{g:{if(v[i+204>>2]==(i+208|0)){a=i+128|0;break g}a=Cd(a<<1);if(!a){v[22656]=0;X(2429);a=v[22656];v[22656]=0;if((a|0)!=1){break d}c=P()|0;O()|0;break f}Ee(e,a);l=v[i+204>>2]}v[22656]=0;Fc(i+104|0,c);h=v[22656];v[22656]=0;h:{i:{if((h|0)!=1){v[22656]=0;ja(2468,l|0,g|0,f|0,a|0,i+116|0,i+112|0,i+104|0);f=v[22656];v[22656]=0;if((f|0)==1){break i}Wb(i+104|0);v[22656]=0;a=la(17,b|0,a|0,v[i+116>>2],v[i+112>>2],c|0,d|0)|0;b=v[22656];v[22656]=0;if((b|0)==1){break h}Ic(e);Ic(k);gb=i+256|0;return a|0}c=P()|0;O()|0;break f}c=P()|0;O()|0;Wb(i+104|0);break f}c=P()|0;O()|0}Ic(e);break b}L()}c=P()|0;O()|0}Ic(k);S(c|0);L()}function Li(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0,k=0,m=0,p=0,q=0,r=0,s=0,t=0,u=0;e=A[b+8>>3];f=A[c>>3];m=e*f;g=A[b>>3];h=A[c+8>>3];p=g*h;i=m+p;q=g*f;r=e*h;k=q-r;a:{if(!Ni(k)){break a}if(!Ni(i)){break a}b:{if(!$g(g)){b=0;if(!$g(e)){break b}}o(+($g(g)?1:0));b=j(1)|0;d=j(0)|0;o(+g);c=j(1)|0;j(0)|0;l(0,d|0);l(1,b&2147483647|c&-2147483648);g=+n();o(+($g(e)?1:0));b=j(1)|0;d=j(0)|0;o(+e);c=j(1)|0;j(0)|0;l(0,d|0);l(1,b&2147483647|c&-2147483648);e=+n();o(0);b=j(1)|0;d=j(0)|0;o(+f);c=j(1)|0;j(0)|0;l(0,d|0);l(1,b&2147483647|c&-2147483648);f=(s=+n(),t=f,u=Ni(f),u?s:t);o(0);b=j(1)|0;d=j(0)|0;o(+h);c=j(1)|0;j(0)|0;l(0,d|0);l(1,b&2147483647|c&-2147483648);h=(s=+n(),t=h,u=Ni(h),u?s:t);b=1}c:{d:{if(!$g(f)){if(!$g(h)){break d}}o(+($g(f)?1:0));b=j(1)|0;d=j(0)|0;o(+f);c=j(1)|0;j(0)|0;l(0,d|0);l(1,b&2147483647|c&-2147483648);f=+n();o(+($g(h)?1:0));b=j(1)|0;d=j(0)|0;o(+h);c=j(1)|0;j(0)|0;l(0,d|0);l(1,b&2147483647|c&-2147483648);h=+n();o(0);b=j(1)|0;d=j(0)|0;o(+g);c=j(1)|0;j(0)|0;l(0,d|0);l(1,b&2147483647|c&-2147483648);g=(s=+n(),t=g,u=Ni(g),u?s:t);o(0);b=j(1)|0;d=j(0)|0;o(+e);c=j(1)|0;j(0)|0;l(0,d|0);l(1,b&2147483647|c&-2147483648);e=(s=+n(),t=e,u=Ni(e),u?s:t);break c}if(b){break c}e:{if($g(q)){break e}if($g(r)){break e}if($g(p)){break e}if(!$g(m)){break a}}o(0);b=j(1)|0;d=j(0)|0;o(+g);c=j(1)|0;j(0)|0;l(0,d|0);l(1,b&2147483647|c&-2147483648);g=(s=+n(),t=g,u=Ni(g),u?s:t);o(0);b=j(1)|0;d=j(0)|0;o(+e);c=j(1)|0;j(0)|0;l(0,d|0);l(1,b&2147483647|c&-2147483648);e=(s=+n(),t=e,u=Ni(e),u?s:t);o(0);b=j(1)|0;d=j(0)|0;o(+f);c=j(1)|0;j(0)|0;l(0,d|0);l(1,b&2147483647|c&-2147483648);f=(s=+n(),t=f,u=Ni(f),u?s:t);o(0);b=j(1)|0;d=j(0)|0;o(+h);c=j(1)|0;j(0)|0;l(0,d|0);l(1,b&2147483647|c&-2147483648);h=(s=+n(),t=h,u=Ni(h),u?s:t)}i=(f*e+h*g)*N;k=(f*g-h*e)*N}Vm(a,k,i)}function kg(a,b,c,d,e){var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;j=v[a+8>>2]+(B(x[a+14>>1],(w[a+80|0]?c:0)+b|0)>>>1|0)|0;v[a+8>>2]=j;i=w[a+79|0]?x[v[a>>2]+3836>>1]:i;b=x[a+20>>1];l=x[a+22>>1];m=x[a+70>>1];a:{b:{c:{d:{switch(v[a+16>>2]){case 1:c=x[v[a>>2]+3832>>1];f=x[a+26>>1]?x[a+48>>1]>>>x[v[a+52>>2]+((c>>>x[a+44>>1]&7)<<1)>>1]|0:0;g=c;c=x[a+46>>1];f=b+(c?g&c?0:f:f)|0;u[a+20>>1]=f;c=2;h=x[a+28>>1];if((h|0)<=f<<16>>16){break c}break b;case 2:if(w[a+78|0]){break b}case 3:c=0;f=x[v[a>>2]+3832>>1];h=x[a+30>>1]?x[a+60>>1]>>>x[v[a+64>>2]+((f>>>x[a+56>>1]&7)<<1)>>1]|0:0;g=f;f=x[a+58>>1];f=b+(f?g&f?0:h:h)|0;u[a+20>>1]=f;if(f<<16>>16<511){break b}v[a+16>>2]=-1;u[a+20>>1]=511;v[a+72>>2]=0;break a;default:c=0;v[a+72>>2]=0;break a;case 0:break d}}c=1;f=x[v[a>>2]+3832>>1];k=x[a+24>>1]?B((b^-1)<<16>>16,x[a+36>>1]>>>x[v[a+40>>2]+((f>>>x[a+32>>1]&7)<<1)>>1]|0)>>>3|0:0;g=f;f=x[a+34>>1];f=b+(f?g&f?0:k:k)|0;u[a+20>>1]=f;if(f<<16>>16>0){break b}}v[a+16>>2]=c;u[a+20>>1]=h}i=((b+l|0)+m|0)+i<<3;if(e){d=(u[a+74>>1]+u[a+72>>1]>>e)+d|0}d=(j>>>10|0)+d|0;c=d&255;b=d&65535;e:{f:{switch(x[a+12>>1]){case 0:d=(b&512)>>>9|0;b=x[((b&256?c^255:c)<<1)+34704>>1];break e;case 1:d=0;b=x[((b&512?0:b&256?c^255:c)<<1)+34704>>1];break e;case 2:d=0;b=x[((b&256?c^255:c)<<1)+34704>>1];break e;case 3:d=0;b=x[((b&256?0:c)<<1)+34704>>1];break e;case 4:e=0;d=0;if(!(b&512)){e=(c<<1^b<<24>>31)&254;d=(b&256)>>>8|0}b=x[(e<<1)+34704>>1];break e;case 5:d=0;if(b&512){b=0}else{c=c<<1&254;b=b&128?c^255:c}b=x[(b<<1)+34704>>1];break e;case 6:d=(d&512)>>>9|0;b=0;break e;default:break f}}c=d<<3&4088;d=(b&512)>>>9|0;b=d?c^4088:c}u[a+74>>1]=x[a+72>>1];e=a;a=b+i|0;a=(a&65535)>>>0<8191?a:8191;c=0-d^x[((a&255)<<1)+34192>>1]+1024>>>((a&65280)>>>8)<<1;u[e+72>>1]=c}return c<<16>>16}function s6(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;e=gb-16|0;gb=e;g=-2;a:{if(!a){break a}c=v[a+28>>2];if(!c){break a}f=(b|0)==1?2:b;if(f>>>0>4|!(1<<f&21)){break a}h=v[c+11e3>>2];k=v[a+4>>2];v[c+11e3>>2]=0;b:{if(v[c+43780>>2]<0){break b}b=v[c+11004>>2];if((f|0)!=4?b:0){break a}i=v[c+11008>>2]>0?9:8;v[c+11004>>2]=b|(f|0)==4;b=(f|0)!=4;if(!(b|!h)){v[e+12>>2]=v[a+4>>2];v[e+8>>2]=v[a+16>>2];b=v[a+12>>2];h=wJ(c,v[a>>2],e+12|0,b,b,e+8|0,i|4);v[c+43780>>2]=h;b=v[e+12>>2];v[a>>2]=b+v[a>>2];v[a+4>>2]=v[a+4>>2]-b;v[a+8>>2]=b+v[a+8>>2];v[a+48>>2]=v[c+28>>2];b=v[e+8>>2];v[a+12>>2]=b+v[a+12>>2];v[a+16>>2]=v[a+16>>2]-b;v[a+20>>2]=b+v[a+20>>2];g=-3;if((h|0)<0){break a}if(!h){g=1;break a}v[c+43780>>2]=-1;g=-5;break a}h=v[c+10996>>2];if(!h){i=b?i|2:i;j=c+11012|0;d=v[c+10992>>2];h=(f|0)!=4;while(1){b=v[a+4>>2];v[e+8>>2]=32768-d;v[e+12>>2]=b;f=wJ(c,v[a>>2],e+12|0,j,d+j|0,e+8|0,i);v[c+43780>>2]=f;b=v[e+12>>2];v[a>>2]=b+v[a>>2];v[a+4>>2]=v[a+4>>2]-b;v[a+8>>2]=b+v[a+8>>2];v[a+48>>2]=v[c+28>>2];d=v[e+8>>2];v[c+10996>>2]=d;b=v[a+16>>2];d=b>>>0>d>>>0?d:b;hc(v[a+12>>2],v[c+10992>>2]+j|0,d);v[a+12>>2]=d+v[a+12>>2];v[a+16>>2]=v[a+16>>2]-d;v[a+20>>2]=d+v[a+20>>2];b=v[c+10996>>2]-d|0;v[c+10996>>2]=b;d=d+v[c+10992>>2]&32767;v[c+10992>>2]=d;if((f|0)<0){break b}g=-5;if(k?0:(f|0)==1){break a}if(!h){if(!f){g=b?-5:1;break a}if(v[a+16>>2]){continue}break a}if(f){g=0;if(!v[a+4>>2]|!v[a+16>>2]){break a}if(!b){continue}break a}break}g=!b;break a}b=v[a+16>>2];b=b>>>0>h>>>0?h:b;hc(v[a+12>>2],(v[c+10992>>2]+c|0)+11012|0,b);v[a+12>>2]=b+v[a+12>>2];v[a+16>>2]=v[a+16>>2]-b;v[a+20>>2]=b+v[a+20>>2];a=v[c+10996>>2]-b|0;v[c+10996>>2]=a;v[c+10992>>2]=b+v[c+10992>>2]&32767;g=0;if(v[c+43780>>2]){break a}g=!a;break a}g=-3}gb=e+16|0;return g|0}function bka(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;g=gb+-64|0;gb=g;k=c+484344|0;Ag(k,w[b+70|0]|w[b+71|0]<<8);a:{if(w[b+70|0]|w[b+71|0]<<8){while(1){h=v[a+8>>2];d=sg(a);Rb(a,1);b:{if((w[b+58|0]|w[b+59|0]<<8)==258){c=Ae(a)+1|0;break b}c=Og(a)}e=Og(a);Wc(a,d+h|0);d=g+16|0;Td(d,a,e);h=kc(g+40|0,d);xb(d);v[22656]=0;c=W(331,k|0,j&65535,(c?c>>>0<1024?c:1024:64)|0)|0;d=v[22656];v[22656]=0;if((d|0)==1){break a}c:{if(!c|!e){break c}c=_b(k,j);l=g,m=Vb(c),v[l+16>>2]=m;l=g,m=Zb(c),v[l+8>>2]=m;if(!Gb(g+16|0,g+8|0)){break c}while(1){e=v[g+16>>2];v[22656]=0;c=T(374,h|0)|0;d=v[22656];v[22656]=0;d:{e:{f:{if((d|0)!=1){if(!(c&128)){break f}if(c&1){v[22656]=0;d=T(374,h|0)|0;f=v[22656];v[22656]=0;if((f|0)==1){break a}t[e|0]=d}if(c&2){break e}break d}break a}t[e|0]=c;c=255}v[22656]=0;d=T(374,h|0)|0;f=v[22656];v[22656]=0;if((f|0)==1){break a}t[e+1|0]=d}d=0;if(c&4){v[22656]=0;d=T(374,h|0)|0;f=v[22656];v[22656]=0;if((f|0)==1){break a}}if(c&8){v[22656]=0;f=T(374,h|0)|0;i=v[22656];v[22656]=0;if((i|0)==1){break a}t[e+3|0]=f}if(c&16){v[22656]=0;c=T(374,h|0)|0;f=v[22656];v[22656]=0;if((f|0)==1){break a}t[e+5|0]=c}c=e;g:{h:{f=w[e|0];if(!f){break h}i=255;if((f|0)==97){break g}if(f>>>0>96){break h}i=f+12|0;break g}i=0}t[c|0]=i;i:{if(w[e+5|0]|w[e+3|0]){v[22656]=0;Of(e);c=v[22656];v[22656]=0;if((c|0)!=1){break i}break a}t[e+3|0]=0}if(w[e+1|0]==255){t[e+1|0]=0}c=d-16|0;j:{if((c&255)>>>0<=64){t[e+4|0]=c;t[e+2|0]=1;break j}if(d>>>0<96){break j}c=d&15;t[e+4|0]=c;d=d-96>>4;t[e+2|0]=w[d+33439|0];if((d|0)!=6){break j}t[e+4|0]=c<<2}c=g+16|0;bk(c);if(Gb(c,g+8|0)){continue}break}}xb(g+40|0);j=j+1|0;if(j>>>0<(w[b+70|0]|w[b+71|0]<<8)>>>0){continue}break}}gb=g- -64|0;return}a=P()|0;O()|0;xb(g+40|0);S(a|0);L()}function Eka(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;i=gb-32|0;gb=i;o=i,p=ar(b),v[o+16>>2]=p;l=i+24|0;n=l;g=gb-32|0;gb=g;c=b;e=a;b=Yd(e);h=fc(e);a:{b:{if(b){wb(e);c:{while(1){d:{e=b+14|0;e:{if(Ru(c,e)){if(!v[b>>2]){break b}h=b;break e}if(!Ru(e,c)){break c}h=b+4|0;if(!v[b+4>>2]){break d}b=h;h=b}b=v[b>>2];continue}break}v[g+28>>2]=b;b=h;break a}v[g+28>>2]=b;b=h;break a}b=fc(e)}v[g+28>>2]=b}h=b;b=v[b>>2];t[g+27|0]=0;if(!b){k=gb-16|0;gb=k;b=fc(a);e=g+8|0;m=Vj(e,Mc(48,4),Wj(k+8|0,b));b=v[m>>2];j=gb-16|0;gb=j;v[j+8>>2]=v[i+16>>2];c=v[j+8>>2];d=w[c+4|0]|w[c+5|0]<<8|(w[c+6|0]<<16|w[c+7|0]<<24);f=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);t[b+14|0]=f;t[b+15|0]=f>>>8;t[b+16|0]=f>>>16;t[b+17|0]=f>>>24;t[b+18|0]=d;t[b+19|0]=d>>>8;t[b+20|0]=d>>>16;t[b+21|0]=d>>>24;d=w[c+28|0]|w[c+29|0]<<8|(w[c+30|0]<<16|w[c+31|0]<<24);f=w[c+24|0]|w[c+25|0]<<8|(w[c+26|0]<<16|w[c+27|0]<<24);t[b+38|0]=f;t[b+39|0]=f>>>8;t[b+40|0]=f>>>16;t[b+41|0]=f>>>24;t[b+42|0]=d;t[b+43|0]=d>>>8;t[b+44|0]=d>>>16;t[b+45|0]=d>>>24;d=w[c+20|0]|w[c+21|0]<<8|(w[c+22|0]<<16|w[c+23|0]<<24);f=w[c+16|0]|w[c+17|0]<<8|(w[c+18|0]<<16|w[c+19|0]<<24);t[b+30|0]=f;t[b+31|0]=f>>>8;t[b+32|0]=f>>>16;t[b+33|0]=f>>>24;t[b+34|0]=d;t[b+35|0]=d>>>8;t[b+36|0]=d>>>16;t[b+37|0]=d>>>24;d=w[c+12|0]|w[c+13|0]<<8|(w[c+14|0]<<16|w[c+15|0]<<24);c=w[c+8|0]|w[c+9|0]<<8|(w[c+10|0]<<16|w[c+11|0]<<24);t[b+22|0]=c;t[b+23|0]=c>>>8;t[b+24|0]=c>>>16;t[b+25|0]=c>>>24;t[b+26|0]=d;t[b+27|0]=d>>>8;t[b+28|0]=d>>>16;t[b+29|0]=d>>>24;u[b+46>>1]=0;gb=j+16|0;o=fc(m),p=1,t[o+4|0]=p;gb=k+16|0;Hk(a,v[g+28>>2],h,v[e>>2]);b=ce(e);t[g+27|0]=1;a=v[e>>2];v[e>>2]=0;if(a){fc(e);if(a){tT(a)}}}Xj(n,yc(g+8|0,b),g+27|0);gb=g+32|0;a=Yl(l);gb=i+32|0;return a+32|0}function sk(a,b,c,d,e){var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;i=gb-16|0;gb=i;a:{if(!v[c>>2]|!d){break a}j=c;f=v[c>>2]+B(d,20)|0;b:{c:{if(v[a+480180>>2]==64){break c}f=v[c>>2]+((B(d,36318)|0)/1024|0)|0;if(v[a+480180>>2]==512){break c}d:{e:{f:{f=v[a+480208>>2];if(f&16){if(v[a+480180>>2]!=4){break f}f=v[a+480208>>2]}if(f&16){break d}Db(i,a+1074312|0,7);if(!Cb(i)){break d}f=v[c>>2];if((d|0)>=0){break e}g=kqa(f,0,14317456,0);h=jb;f=kqa(f,0,0-d|0,0)+14317456|0;d=jb;f=lP(nqa(g,h,f,f>>>0<14317456?d+1|0:d),jb);break c}k=v[c>>2];f=d>>31;v[i+12>>2]=f+d^f;qc(i+12|0,1020);h=v[i+12>>2];f=c;l=f;g=v[f>>2];m=g;n=g>>31;g:{if((d|0)>0){if(h>>>0<=15){g=gb-16|0;gb=g;f=g+8|0;Db(f,a+1074312|0,7);f=Cb(f);gb=g+16|0;h=v[(h<<2)+(f?43456:43520)>>2];break g}g=gb-16|0;gb=g;f=g+8|0;Db(f,a+1074312|0,7);f=Cb(f);gb=g+16|0;h=v[(h>>>2<<2)+(f?43584:44608)>>2];break g}if(h>>>0<=15){g=gb-16|0;gb=g;f=g+8|0;Db(f,a+1074312|0,7);f=Cb(f);gb=g+16|0;h=v[(h<<2)+(f?43520:43456)>>2];break g}g=gb-16|0;gb=g;f=g+8|0;Db(f,a+1074312|0,7);f=Cb(f);gb=g+16|0;h=v[(h>>>2<<2)+(f?44608:43584)>>2]}h=kqa(m,n,h,h>>31)+32768|0;f=jb;f=Ac(lqa(h,h>>>0<32768?f+1|0:f,65536,0),jb);v[l>>2]=f;if((f|0)!=(k|0)){break b}Db(i,a+1074312|0,7);h=Cb(i);f=v[c>>2];if(!(h^(d|0)>0)){d=(f|0)==2147483647;f=v[c>>2];if(d){break b}f=f+1|0;break c}if((f|0)<2){break b}f=f-1|0;break c}d=kqa(f,f>>31,d,0);h=jb;g=h;if((g|0)>=0&d>>>0>=14317456|(g|0)>0){if(e){v[c>>2]=2147483647;break a}v[c>>2]=0;v[b+696>>2]=0;v[b+88>>2]=v[b+88>>2]|2101248;break a}f=lP(nqa(kqa(f,0,14317456,0),jb,14317456-d|0,0-(g+(d>>>0>14317456)|0)|0),jb);break c}f=v[c>>2]-d|0}v[j>>2]=f}if((f|0)>0){break a}v[c>>2]=1;if(v[a+480180>>2]!=2|e){break a}v[b+696>>2]=0;v[b+88>>2]=v[b+88>>2]|2101248}gb=i+16|0}function Hea(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;c=gb-144|0;gb=c;e=Hm(c+40|0,a);v[22656]=0;d=Q(620,c+24|0,49661)|0;a=v[22656];v[22656]=0;a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{if((a|0)!=1){v[22656]=0;v[c>>2]=19923028;v[c+4>>2]=0;U(621,e|0,d|0,c|0);a=v[22656];v[22656]=0;if((a|0)==1){break n}Hb(d);if(v[e>>2]&1073741824){break e}v[22656]=0;d=Q(620,c+24|0,10683)|0;a=v[22656];v[22656]=0;if((a|0)==1){break m}v[22656]=0;da(1477,e|0,b|0,d|0,1478)|0;a=v[22656];v[22656]=0;if((a|0)==1){break l}Hb(d);v[c+20>>2]=0;v[c+16>>2]=0;v[22656]=0;d=Q(620,c+24|0,13824)|0;a=v[22656];v[22656]=0;if((a|0)==1){break k}v[22656]=0;W(1479,e|0,c+20|0,d|0)|0;a=v[22656];v[22656]=0;if((a|0)==1){break j}Hb(d);v[22656]=0;d=Q(620,c+24|0,13814)|0;a=v[22656];v[22656]=0;if((a|0)==1){break i}v[22656]=0;W(1479,e|0,c+16|0,d|0)|0;a=v[22656];v[22656]=0;if((a|0)==1){break h}Hb(d);a=b;d=v[c+16>>2];f=v[c+20>>2];o:{if(!f){break o}if(d>>>0<f>>>0|f>>>0>y[v[uo(a)+8>>2]+40>>2]){break o}if(d>>>0>y[v[uo(a)+8>>2]+40>>2]){break o}v[a+20>>2]=d;v[a+16>>2]=f}d=Io(c+24|0);v[22656]=0;f=Q(620,c|0,11389)|0;a=v[22656];v[22656]=0;if((a|0)==1){break d}v[22656]=0;U(1480,e|0,d|0,f|0);a=v[22656];v[22656]=0;if((a|0)==1){break g}Hb(f);if(cd(d)){break f}a=v[b+16>>2];v[22656]=0;U(1305,d|0,a|0,16777216);a=v[22656];v[22656]=0;if((a|0)!=1){break f}break c}a=P()|0;O()|0;break a}a=P()|0;O()|0;Hb(d);break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;Hb(d);break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;Hb(d);break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;Hb(d);break a}a=P()|0;O()|0;Hb(f);break b}v[22656]=0;R(1481,b|0,d|0);a=v[22656];v[22656]=0;if((a|0)==1){break c}Nc(d)}gh(e);gb=c+144|0;return}a=P()|0;O()|0;break b}a=P()|0;O()|0}Nc(d)}gh(e);S(a|0);L()}function mha(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;m=gb-16|0;gb=m;n=c;k=d;g=gb-32|0;gb=g;l=g+28|0;f=g+24|0;h=c;e=gb-32|0;gb=e;v[e+24>>2]=b;a:{b:{c:{d:{i=a;if(!Sj(e+24|0,yc(e+16|0,Ch(i)))){j=wb(i);if(!Nl(j,h,ue(e+24|0))){break d}}v[e+16>>2]=b;if(!Sj(e+16|0,yc(e+8|0,zC(i)))){o=wb(i);j=e+16|0;p=j;c=v[j>>2];f=v[c>>2];e:{if(f){c=f;while(1){f=c;c=v[c+4>>2];if(c){continue}break}break e}if(ng(c)){while(1){c=v[c+8>>2];if(ng(c)){continue}break}}f=v[c+8>>2]}v[p>>2]=f;if(!Nl(o,ue(j),h)){break c}}if(!v[b>>2]){v[l>>2]=b;break a}b=v[e+16>>2];v[l>>2]=b;b=b+4|0;break a}if(!Nl(j,ue(e+24|0),h)){break b}c=gb-16|0;gb=c;v[c+8>>2]=b;Uj(c+8|0);gb=c+16|0;c=v[c+8>>2];v[e+16>>2]=c;if(!Sj(e+16|0,yc(e+8|0,Ch(i)))){if(!Nl(j,h,ue(e+16|0))){break c}}if(!v[v[e+24>>2]+4>>2]){v[l>>2]=b;b=b+4|0;break a}v[l>>2]=c;b=c;break a}b=dR(i,l,h);break a}v[l>>2]=b;v[f>>2]=b;b=f}gb=e+32|0;c=b;b=v[b>>2];t[g+23|0]=0;if(!b){i=gb-16|0;gb=i;b=fc(a);h=g+8|0;f=Vj(h,cR(),Wj(i+8|0,b));b=v[f>>2];v[22656]=0;b=b+16|0;e=v[22656];v[22656]=0;f:{if((e|0)!=1){e=v[n+4>>2];v[b>>2]=v[n>>2];v[b+4>>2]=e;wb(k);n=vh(b+8|0);v[b+8>>2]=v[k>>2];v[b+12>>2]=v[k+4>>2];b=wb(k);q=wb(n),r=v[b>>2],v[q>>2]=r;v[b>>2]=0;v[k>>2]=0;v[k+4>>2]=0;q=fc(f),r=1,t[q+4|0]=r;gb=i+16|0;break f}a=P()|0;O()|0;SA(f);S(a|0);L()}Hk(a,v[g+28>>2],c,v[h>>2]);b=ce(h);t[g+23|0]=1;SA(h)}Xj(m,yc(g+8|0,b),g+23|0);gb=g+32|0;a=m;if(!w[fc(a)|0]){c=ue(a)+8|0;b=c;if(v[b>>2]){rf(b);eR(b);tg(b);rf(b);TA(wb(b),v[b>>2],tg(b));q=wb(b),r=0,v[q>>2]=r;v[b>>2]=0;v[b+4>>2]=0}lp(c,d);v[c>>2]=v[d>>2];v[c+4>>2]=v[d+4>>2];b=wb(d);q=wb(c),r=v[b>>2],v[q>>2]=r;v[b>>2]=0;v[d>>2]=0;v[d+4>>2]=0}a=v[yc(m+8|0,v[a>>2])>>2];gb=m+16|0;return a|0}function $na(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;g=gb-32|0;gb=g;v[g+24>>2]=d;k=fg(a,c);se(g,v[a+28>>2]);d=v[g+12>>2];v[g+16>>2]=v[g+8>>2];v[g+20>>2]=d;a:{if(!k){if(nd(a,5)){break a}}j=v[g+24>>2];d=gb-160|0;gb=d;h=Hm(d+56|0,v[a+28>>2]);v[22656]=0;e=Q(620,d+8|0,34111)|0;f=v[22656];v[22656]=0;b:{c:{d:{e:{if((f|0)!=1){v[22656]=0;v[d+48>>2]=19923028;v[d+52>>2]=0;U(621,h|0,e|0,d+48|0);f=v[22656];v[22656]=0;if((f|0)==1){break e}Hb(e);if(!(v[h>>2]&1073741824)){break d}break b}a=P()|0;O()|0;break c}a=P()|0;O()|0;Hb(e);break c}t[d+48|0]=0;t[d+47|0]=0;v[22656]=0;e=Q(620,d+8|0,7364)|0;f=v[22656];v[22656]=0;f:{if((f|0)!=1){v[22656]=0;U(1097,h|0,d+48|0,e|0);f=v[22656];v[22656]=0;if((f|0)==1){break f}Hb(e);if(!w[d+48|0]){break b}yf(d+48|0,50);v[22656]=0;e=Q(620,d+8|0,10564)|0;f=v[22656];v[22656]=0;g:{h:{i:{j:{if((f|0)!=1){v[22656]=0;U(1097,h|0,d+47|0,e|0);f=v[22656];v[22656]=0;if((f|0)==1){break j}Hb(e);e=Pi(b);f=w[d+48|0];if(e>>>0<f>>>0){e=kB(d+8|0,v[b+12>>2]);v[22656]=0;U(1098,b|0,f|0,e|0);f=v[22656];v[22656]=0;if((f|0)==1){break i}Zm(e)}e=0;f=x[Tj(b,0)+28>>1];t[d+7|0]=0;if(w[d+48|0]){while(1){i=e&255;cf(Tj(b,i),f);i=Tj(b,i);v[22656]=0;R(1099,d+8|0,d+7|0);l=v[22656];v[22656]=0;if((l|0)==1){break h}v[22656]=0;Y(1100,h|0,i|0,d+8|0,j|0);i=v[22656];v[22656]=0;if((i|0)==1){break g}Hb(d+8|0);e=e+1|0;t[d+7|0]=e;if(w[d+48|0]>(e&255)>>>0){continue}break}}e=w[d+47|0];j=Pi(b);t[b+16|0]=e>>>0<j>>>0?w[d+47|0]:0;break b}a=P()|0;O()|0;break c}a=P()|0;O()|0;Hb(e);break c}a=P()|0;O()|0;Zm(e);break c}a=P()|0;O()|0;break c}a=P()|0;O()|0;Hb(d+8|0);break c}a=P()|0;O()|0;break c}a=P()|0;O()|0;Hb(e)}gh(h);S(a|0);L()}gh(h);gb=d+160|0}Zf(a,k,c,g+16|0);gb=g+32|0}function Jq(a,b,c,d){var e=0,f=C(0),g=C(0),h=C(0),i=0,j=0,k=0,l=0,m=0,n=0,o=0;e=gb-16|0;gb=e;v[e+12>>2]=u[b+780>>1]+w[b+837|0];v[e+8>>2]=u[b+782>>1]+(w[b+838|0]&127);Zd(e+12|0,0,127);Zd(e+8|0,0,127);l=a+1074312|0;Db(e,l,1);j=Cb(e);i=v[e+12>>2];if(!j){u[b+780>>1]=0;t[b+837|0]=i;j=v[e+8>>2];u[b+782>>1]=0;t[b+838|0]=j}Db(e,l,36);i=B(i,d+256|0);j=(i|0)/256|0;k=Cb(e);m=v[e+8>>2];a:{if(!(m|!k|(i|0)<65024)){j=-1;a=b+788|0;if(!Rd(a)){break a}if(wu(a)|x[b+786>>1]|(v[b>>2]|v[b+4>>2])){break a}a=v[b+88>>2];if(a&8192){break a}v[b+88>>2]=a&-32769;break a}v[b+88>>2]=v[b+88>>2]|32768;f=oe(C(10),C(C(0-m|0)*C(.00937500037252903)));i=gb-16|0;gb=i;g=C(B(v[e+12>>2],d+256|0)>>>0);d=a;b:{if(v[a+480180>>2]!=33554432){h=C(110);g=C(C(g/(w[d+480209|0]&128?C(10240):C(12288)))+C(.25));break b}h=C(125);g=C(C(g*C(6))/C(65024))}n=i,o=Xh(C(h*oe(C(2),g))),v[n+12>>2]=o;Zd(i+12|0,120,2e4);k=v[i+12>>2];d=v[d+24620>>2];gb=i+16|0;Db(e,l,36);g=C(C(((d|0)<k<<1?d>>>1|0:k)>>>0)*C(6.2831854820251465));c:{if(!(!Cb(e)|v[a+480208>>2]&32768)){h=f;f=C(C(y[a+24620>>2])/g);g=C(C(h+C(h*f))+C(-1));z[e>>2]=g;f=C(f*f);break c}h=C(f+f);f=C(g/C(y[a+24620>>2]));z[e>>2]=C(C(1)-h)*f;VP(e,C(2));g=C(C(h-z[e>>2])/f);z[e>>2]=g;f=C(C(1)/C(f*f))}h=C(f+C(g+C(1)));g=C(C(f+C(g+f))/h);f=C(C(-f)/h);h=C(C(1)/h);d:{if(w[b+845|0]==1){n=b,o=Xh(C(C(C(1)-h)*C(16777216))),v[n+60>>2]=o;n=b,o=Xh(C(g*C(16777216))),v[n+64>>2]=o;n=b,o=Xh(C(f*C(16777216))),v[n+68>>2]=o;a=-1;break d}n=b,o=Xh(C(h*C(16777216))),v[n+60>>2]=o;n=b,o=Xh(C(g*C(16777216))),v[n+64>>2]=o;n=b,o=Xh(C(f*C(16777216))),v[n+68>>2]=o;a=0;if(v[b+60>>2]){break d}v[b+60>>2]=1}v[b+72>>2]=a;if(!c){break a}v[b+44>>2]=0;v[b+48>>2]=0;v[b+52>>2]=0;v[b+56>>2]=0}gb=e+16|0;return j}function _2(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0;a=gb-624|0;gb=a;v[a+608>>2]=c;v[a+616>>2]=b;v[a+16>>2]=2479;b=ge(a+200|0,a+208|0,a+16|0);v[22656]=0;Fc(a+192|0,e);h=v[22656];v[22656]=0;a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{if((h|0)!=1){v[22656]=0;h=T(2452,a+192|0)|0;i=v[22656];v[22656]=0;if((i|0)==1){break k}t[a+191|0]=0;e=v[e+4>>2];v[22656]=0;c=ra(2488,a+616|0,c|0,d|0,a+192|0,e|0,f|0,a+191|0,h|0,b|0,a+196|0,a+608|0)|0;d=v[22656];v[22656]=0;if((d|0)==1){break d}if(!c){break e}c=w[11855]|w[11856]<<8|(w[11857]<<16|w[11858]<<24);t[a+183|0]=c;t[a+184|0]=c>>>8;t[a+185|0]=c>>>16;t[a+186|0]=c>>>24;c=w[11852]|w[11853]<<8|(w[11854]<<16|w[11855]<<24);v[a+176>>2]=w[11848]|w[11849]<<8|(w[11850]<<16|w[11851]<<24);v[a+180>>2]=c;v[22656]=0;Y(2464,h|0,a+176|0,a+186|0,a+128|0);c=v[22656];v[22656]=0;if((c|0)==1){break j}v[a+4>>2]=2428;d=ge(a+8|0,0,a+4|0);h=v[a+196>>2];c=h-v[b>>2]|0;e=a+16|0;if((c|0)<393){break h}Ee(d,Cd((c>>>2|0)+2|0));if(v[d>>2]){break i}v[22656]=0;X(2429);c=v[22656];v[22656]=0;if((c|0)==1){break g}break a}e=P()|0;O()|0;break b}e=P()|0;O()|0;break c}e=P()|0;O()|0;break c}e=v[d>>2]}if(w[a+191|0]){t[e|0]=45;e=e+1|0}c=v[b>>2];if(h>>>0>c>>>0){h=a+168|0;while(1){i=a+128|0;j=e,k=w[(a+176|0)+(yx(i,h,c)-i>>2)|0],t[j|0]=k;e=e+1|0;c=c+4|0;if(c>>>0<y[a+196>>2]){continue}break}}t[e|0]=0;v[a>>2]=g;if((MH(a+16|0,a)|0)==1){break f}v[22656]=0;_(2481,5133);c=v[22656];v[22656]=0;if((c|0)!=1){break a}}e=P()|0;O()|0;Ic(d);break c}Ic(d)}v[22656]=0;c=Q(2458,a+616|0,a+608|0)|0;d=v[22656];v[22656]=0;if((d|0)==1){break d}if(c){v[f>>2]=v[f>>2]|2}c=v[a+616>>2];Wb(a+192|0);Ic(b);gb=a+624|0;return c|0}e=P()|0;O()|0}Wb(a+192|0)}Ic(b);S(e|0);L()}L()}function nO(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0,k=0;g=gb-16|0;gb=g;a:{b:{c:{h=B(b,872)+a|0;if(w[h+1075082|0]&2){f=v[a+480180>>2];d:{e:{f:{if(v[a+480208>>2]&4096){if(!(f&16777248)){break f}if(v[a+480180>>2]==64){break e}if(v[a+480208>>2]&4){break d}break c}if((f|0)!=64){break c}break e}if(v[a+480180>>2]!=64){break d}}a=B(b,872)+a|0;b=a+1075811|0;d=w[b|0];if(d&1){v[c>>2]=v[c>>2]+B(w[a+1075816|0],167)}t[b|0]=d+1;break a}break b}if(!(w[h+1075662|0]&2)){break a}a=pu(a,b);if(!a){break a}kb[v[v[a>>2]+88>>2]](a,0,0,b);break a}f=g+8|0;Db(f,a+1074312|0,21);k=1;if(!Cb(f)){break b}f=B(b,872)+a|0;e=f+1075811|0;t[e|0]=w[e|0]+(w[f+1075815|0]<<2)}e=B(b,872)+a|0;i=e+1075814|0;j=e+1075811|0;f=Uz(a,w[i|0],w[j|0]);h=h+1074992|0;g:{if(Mj(h)){z[d>>2]=z[d>>2]+C(C(C(B(w[e+1075816|0],f)|0)*C(.05000000074505806))/C(7680));c=e+1075843|0;d=w[c|0];t[c|0]=d&207|32;if(v[a+1074416>>2]!=(v[a+1074392>>2]+1|0)){break g}t[c|0]=d|48;break g}if((v[a+480208>>2]&2101248)==2101248|(w[a+480209|0]&16?v[a+480180>>2]&67633152:0)){break a}f=v[a+480180>>2]&5?(w[i|0]&3)==1?0-f|0:f:f;d=g+8|0;i=a+1074312|0;Db(d,i,21);d=Cb(d);e=v[a+480208>>2];h:{if(d){d=e&4;f=d?f:0-f|0;d=d?5:6;break h}d=5;i:{if(e&131072){break i}d=8;if(v[a+480180>>2]==1024){break i}d=7;if(v[a+480180>>2]&524304|(w[a+480208|0]&4?0:v[a+480180>>2]&16777248)){break i}d=6}e=g+8|0;Db(e,i,80);if(!Cb(e)){break h}d=w[(B(b,872)+a|0)+1075783|0]==26?d+2|0:d}e=B(b,872)+a|0;d=(0-B(w[e+1075816|0],f)|0)/(1<<d)|0;sk(a,h,c,d,0);c=pu(a,b);if(!c){break g}f=c;e=v[e+1075648>>2];if(e){e=w[e+33|0]}else{e=2}kb[v[v[c>>2]+88>>2]](f,d,e<<24>>24,b)}if(!k){break a}c=g+8|0;Db(c,a+1074312|0,21);if(Cb(c)){break a}t[j|0]=w[j|0]+w[(B(b,872)+a|0)+1075815|0]}gb=g+16|0}function h3(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0;a=gb-288|0;gb=a;v[a+272>>2]=c;v[a+280>>2]=b;v[a+16>>2]=2479;b=ge(a+152|0,a+160|0,a+16|0);v[22656]=0;Fc(a+144|0,e);h=v[22656];v[22656]=0;a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{if((h|0)!=1){v[22656]=0;h=T(21,a+144|0)|0;i=v[22656];v[22656]=0;if((i|0)==1){break k}t[a+143|0]=0;e=v[e+4>>2];v[22656]=0;c=ra(2480,a+280|0,c|0,d|0,a+144|0,e|0,f|0,a+143|0,h|0,b|0,a+148|0,a+260|0)|0;d=v[22656];v[22656]=0;if((d|0)==1){break d}if(!c){break e}c=w[11855]|w[11856]<<8|(w[11857]<<16|w[11858]<<24);t[a+135|0]=c;t[a+136|0]=c>>>8;t[a+137|0]=c>>>16;t[a+138|0]=c>>>24;c=w[11852]|w[11853]<<8|(w[11854]<<16|w[11855]<<24);v[a+128>>2]=w[11848]|w[11849]<<8|(w[11850]<<16|w[11851]<<24);v[a+132>>2]=c;v[22656]=0;Y(2444,h|0,a+128|0,a+138|0,a+118|0);c=v[22656];v[22656]=0;if((c|0)==1){break j}v[a+4>>2]=2428;d=ge(a+8|0,0,a+4|0);h=v[a+148>>2];e=a+16|0;if((h-v[b>>2]|0)<99){break h}Ee(d,Cd((h-v[b>>2]|0)+2|0));if(v[d>>2]){break i}v[22656]=0;X(2429);c=v[22656];v[22656]=0;if((c|0)==1){break g}break a}e=P()|0;O()|0;break b}e=P()|0;O()|0;break c}e=P()|0;O()|0;break c}e=v[d>>2]}if(w[a+143|0]){t[e|0]=45;e=e+1|0}c=v[b>>2];if(h>>>0>c>>>0){h=a+128|0;while(1){j=e,k=w[((Xm(a+118|0,h,c)-a|0)+a|0)+10|0],t[j|0]=k;e=e+1|0;c=c+1|0;if(c>>>0<y[a+148>>2]){continue}break}}t[e|0]=0;v[a>>2]=g;if((MH(a+16|0,a)|0)==1){break f}v[22656]=0;_(2481,5133);c=v[22656];v[22656]=0;if((c|0)!=1){break a}}e=P()|0;O()|0;Ic(d);break c}Ic(d)}v[22656]=0;c=Q(2431,a+280|0,a+272|0)|0;d=v[22656];v[22656]=0;if((d|0)==1){break d}if(c){v[f>>2]=v[f>>2]|2}c=v[a+280>>2];Wb(a+144|0);Ic(b);gb=a+288|0;return c|0}e=P()|0;O()|0}Wb(a+144|0)}Ic(b);S(e|0);L()}L()}function tia(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,w=0,x=0;f=gb-48|0;gb=f;q=v[a+16>>2];e=v[a+44>>2];v[f+32>>2]=e;g=v[a+48>>2];v[f+36>>2]=g;k=v[a+52>>2];v[f+40>>2]=k;n=v[a+56>>2];v[f+44>>2]=n;r=v[a+24>>2];s=v[a+20>>2];h=v[a+4>>2];j=v[a>>2];v[f+24>>2]=j;v[f+28>>2]=h;i=v[a+12>>2];v[f+16>>2]=v[a+8>>2];v[f+20>>2]=i;if(d){while(1){n=1;i=((((h&2147483647)<<1|j>>>31)&2147483646)<<1)+q|0;e=(((j>>>16|0)+4&131064)<<1)+b|0;j=u[e+38>>1];m=u[e+36>>1];o=u[e+34>>1];l=u[e+32>>1];p=u[e+30>>1];t=u[e+28>>1];w=u[e+26>>1];x=u[e+24>>1];k=0;e=1;g=0;while(1){h=g<<1;v[(f+8|0)+(g<<2)>>2]=(((((B(u[i+(h|8)>>1],o)+B(u[i+(h|4)>>1],l)|0)+B(u[i+(h|12)>>1],m)|0)+B(j,u[i+(h|16)>>1])|0)/2|0)+((((B(u[i+(h|-8)>>1],w)+B(u[i+(h|-12)>>1],x)|0)+B(u[i+(h|-4)>>1],t)|0)+B(u[i+h>>1],p)|0)/2|0)|0)/16384;h=e;e=0;g=1;if(h){continue}break}while(1){j=(f+8|0)+(k<<2)|0;g=v[j>>2];m=v[a+60>>2];o=m;h=(f+32|0)+(k<<3)|0;k=v[h>>2];e=Lb(k,-16777216,16776704);l=v[a+64>>2];i=Lb(v[h+4>>2],-16777216,16776704);p=m>>31;m=g<<8;g=m;g=kqa(o,p,g,g>>31);o=jb;l=kqa(l,l>>31,e,e>>31);g=l+g|0;e=jb+o|0;e=g>>>0<l>>>0?e+1|0:e;p=g;g=v[a+68>>2];g=kqa(g,g>>31,i,i>>31);i=p+g|0;e=jb+e|0;e=i>>>0<g>>>0?e+1|0:e;i=i+8388608|0;e=i>>>0<8388608?e+1|0:e;e=Jc(i,e,24);v[h+4>>2]=k;i=v[a+72>>2];v[j>>2]=(e|0)/256;v[h>>2]=e-(i&m);k=1;e=n&1;n=0;if(e){continue}break}v[c>>2]=v[c>>2]+B(v[f+8>>2],s);v[c+4>>2]=v[c+4>>2]+B(v[f+12>>2],r);Ub(f+24|0,f+16|0);d=d-1|0;if(d){c=c+8|0;j=v[f+24>>2];h=v[f+28>>2];continue}break}j=v[f+24>>2];h=v[f+28>>2];n=v[f+44>>2];k=v[f+40>>2];g=v[f+36>>2];e=v[f+32>>2]}v[a+56>>2]=n;v[a+52>>2]=k;v[a+48>>2]=g;v[a+44>>2]=e;v[a>>2]=j;v[a+4>>2]=h;gb=f+48|0}function bN(a,b){var c=0,d=0,e=0,f=0,g=0,h=0;a:{b:{d=b;e=v[b>>2];if(e){if(!v[b+4>>2]){break b}g=v[b+4>>2];c:{if(!g){if(!ng(d)){while(1){d=v[d+8>>2];if(!ng(d)){continue}break}}d=v[d+8>>2];break c}d=SV(g)}e=v[d>>2];if(e){break b}}e=v[d+4>>2];if(e){break b}e=0;g=1;break a}v[e+8>>2]=v[d+8>>2];g=0}d:{e:{if(ng(d)){v[v[d+8>>2]>>2]=e;if((a|0)==(d|0)){a=e;c=0;break d}c=v[d+8>>2]+4|0;break e}v[v[d+8>>2]+4>>2]=e;c=v[d+8>>2]}c=v[c>>2]}h=!w[d+12|0];if((b|0)!=(d|0)){v[d+8>>2]=v[b+8>>2];f:{if(ng(b)){f=v[d+8>>2];break f}f=v[d+8>>2]+4|0}v[f>>2]=d;f=v[b>>2];v[d>>2]=f;gp(f,d);f=v[b+4>>2];v[d+4>>2]=f;if(f){gp(f,d)}t[d+12|0]=w[b+12|0];a=(a|0)==(b|0)?d:a}if(!(h|!a)){if(g){while(1){b=ng(c);d=w[c+12|0];g:{h:{if(!b){if(!d){t[c+12|0]=1;t[v[c+8>>2]+12|0]=0;ur(v[c+8>>2]);b=v[c>>2];a=(b|0)==(a|0)?c:a;c=v[b+4>>2]}b=v[c>>2];i:{if(!(w[b+12|0]?0:b)){b=v[c+4>>2];if(w[b+12|0]?0:b){break i}t[c+12|0]=0;j:{b=v[c+8>>2];if((b|0)!=(a|0)){if(w[b+12|0]){break j}a=b}t[a+12|0]=1;return}if(!ng(b)){break h}b=v[b+8>>2]+4|0;break g}a=v[c+4>>2];if(w[a+12|0]?0:a){break i}t[b+12|0]=1;t[c+12|0]=0;tr(c);c=v[c+8>>2]}t[c+12|0]=w[v[c+8>>2]+12|0];t[v[c+8>>2]+12|0]=1;t[v[c+4>>2]+12|0]=1;ur(v[c+8>>2]);return}if(!d){t[c+12|0]=1;t[v[c+8>>2]+12|0]=0;tr(v[c+8>>2]);b=v[c+4>>2];a=(b|0)==(a|0)?c:a;c=v[b>>2]}d=v[c>>2];k:{if(w[d+12|0]?0:d){break k}b=v[c+4>>2];if(!(w[b+12|0]?0:b)){t[c+12|0]=0;b=v[c+8>>2];if(!((a|0)!=(b|0)?w[b+12|0]:0)){t[b+12|0]=1;return}if(ng(b)){b=v[b+8>>2]+4|0;break g}b=v[b+8>>2];break g}if(w[d+12|0]?0:d){break k}t[b+12|0]=1;t[c+12|0]=0;ur(c);c=v[c+8>>2]}t[c+12|0]=w[v[c+8>>2]+12|0];t[v[c+8>>2]+12|0]=1;t[v[c>>2]+12|0]=1;tr(v[c+8>>2]);return}b=v[b+8>>2]}c=v[b>>2];continue}}t[e+12|0]=1}}function M2(a,b,c,d,e,f,g,h,i,j,k,l,m,n,o){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;l=l|0;m=m|0;n=n|0;o=o|0;var p=0,q=0,r=0,s=0,u=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0;u=gb-16|0;gb=u;v[c>>2]=a;A=d&512;B=h<<2;while(1){a:{b:{switch(t[i+x|0]){case 0:v[b>>2]=v[c>>2];break a;case 1:v[b>>2]=v[c>>2];h=Xs(g,32);p=v[c>>2];v[c>>2]=p+4;v[p>>2]=h;break a;case 3:if(gd(n)){break a}h=v[yk(n,0)>>2];p=v[c>>2];v[c>>2]=p+4;v[p>>2]=h;break a;case 2:if(gd(m)|!A){break a}D=c,E=Vi(zd(m),ui(m),v[c>>2]),v[D>>2]=E;break a;case 4:break b;default:break a}}C=v[c>>2];e=e+B|0;h=e;c:{if(h>>>0>=f>>>0){break c}while(1){if(!kl(g,2048,v[h>>2])){break c}h=h+4|0;if(h>>>0<f>>>0){continue}break}}if((o|0)>0){d:{e:{if(e>>>0>=h>>>0){p=o;break e}q=v[c>>2];p=o;while(1){f:{h=h-4|0;v[q>>2]=v[h>>2];p=p-1|0;q=q+4|0;if(e>>>0>=h>>>0){break f}if(p){continue}}break}v[c>>2]=q;if(p){break e}q=v[c>>2];r=q+4|0;break d}s=Xs(g,48);q=v[c>>2];r=q+4|0;if((p|0)<=0){break d}while(1){v[q>>2]=s;q=r;r=q+4|0;y=p>>>0>1;p=p-1|0;if(y){continue}break}}v[c>>2]=r;v[q>>2]=j}g:{if((e|0)==(h|0)){h=Xs(g,48);p=v[c>>2];r=p+4|0;v[c>>2]=r;v[p>>2]=h;break g}if(gd(l)){s=-1}else{s=t[pc(l,0)|0]}q=0;p=0;while(1){h:{if((p|0)!=(s|0)){break h}p=v[c>>2];v[c>>2]=p+4;v[p>>2]=k;p=0;q=q+1|0;if(Ab(l)>>>0<=q>>>0){break h}if(w[pc(l,q)|0]==127){s=-1;break h}s=t[pc(l,q)|0]}h=h-4|0;y=v[h>>2];z=v[c>>2];r=z+4|0;v[c>>2]=r;v[z>>2]=y;p=p+1|0;if((e|0)!=(h|0)){continue}break}}xx(C,r)}x=x+1|0;if((x|0)!=4){continue}break}if(Ab(n)>>>0>1){D=u,E=zd(n),v[D+8>>2]=E;e=gb-16|0;gb=e;v[e+8>>2]=v[u+8>>2];Qe(e+8|0);gb=e+16|0;D=c,E=Vi(v[e+8>>2],ui(n),v[c>>2]),v[D>>2]=E}d=d&176;if((d|0)!=16){if((d|0)==32){a=v[c>>2]}v[b>>2]=a}gb=u+16|0}function b8(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0;e=gb-32|0;gb=e;g=mc(a);a=b+24|0;f=Sb(v[a>>2]+484360|0);v[22656]=0;h=Ri(f);f=v[22656];v[22656]=0;a:{b:{c:{if((f|0)==1){break c}v[22656]=0;R(1421,g|0,h|0);f=v[22656];v[22656]=0;if((f|0)==1){break c}d:{e:{if(h){f=0;while(1){c=x[sc(Sb(v[a>>2]+484360|0),f)>>1];d=v[a>>2];v[22656]=0;d=dm(d+484344|0,c);i=v[22656];v[22656]=0;if((i|0)==1){break b}f:{if(d){c=_b(v[a>>2]+484344|0,x[sc(Sb(v[a>>2]+484360|0),f)>>1]);v[22656]=0;R(2098,e|0,c|0);c=v[22656];v[22656]=0;g:{h:{i:{if((c|0)!=1){v[22656]=0;U(2092,e+16|0,b|0,e|0);c=v[22656];v[22656]=0;if((c|0)==1){break i}v[22656]=0;R(1423,g|0,e+16|0);c=v[22656];v[22656]=0;if((c|0)==1){break h}vb(e+16|0);vb(e);break f}a=P()|0;O()|0;break a}a=P()|0;O()|0;break g}a=P()|0;O()|0;vb(e+16|0)}vb(e);break a}v[22656]=0;d=v[22656];v[22656]=0;if((d|0)==1){break b}if((c|0)==65534){v[22656]=0;c=Q(70,e+16|0,6397)|0;d=v[22656];v[22656]=0;j:{if((d|0)!=1){v[22656]=0;R(1423,g|0,c|0);d=v[22656];v[22656]=0;if((d|0)==1){break j}vb(c);break f}a=P()|0;O()|0;break a}a=P()|0;O()|0;vb(c);break a}v[22656]=0;d=v[22656];v[22656]=0;if((d|0)==1){break b}if((c|0)==65535){v[22656]=0;c=Q(70,e+16|0,6359)|0;d=v[22656];v[22656]=0;k:{if((d|0)!=1){v[22656]=0;R(1423,g|0,c|0);d=v[22656];v[22656]=0;if((d|0)==1){break k}vb(c);break f}a=P()|0;O()|0;break a}a=P()|0;O()|0;vb(c);break a}v[22656]=0;c=Q(70,e+16|0,11817)|0;d=v[22656];v[22656]=0;if((d|0)==1){break e}v[22656]=0;R(1423,g|0,c|0);d=v[22656];v[22656]=0;if((d|0)==1){break d}vb(c)}f=f+1|0;if((h|0)!=(f|0)){continue}break}}gb=e+32|0;return}a=P()|0;O()|0;break a}a=P()|0;O()|0;vb(c);break a}a=P()|0;O()|0;break a}a=P()|0;O()|0}yd(g);S(a|0);L()}function Bo(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0,j=0;f=gb-16|0;gb=f;v[b+88>>2]=v[b+88>>2]|524288;a:{b:{if(!(v[a+480208>>2]&8)){d=f+8|0;Db(d,a+1074312|0,15);if(Cb(d)){break b}}if(v[a+480180>>2]!=268435456){break a}}c=c?c:w[b+811|0];t[b+812|0]=c;t[b+811|0]=c}if(c){u[b+768>>1]=c}c:{if(Mj(b)){d=x[b+768>>1];if(!d){break c}e=v[b+856>>2];c=b;g=v[a+1074392>>2];i=0-d|0;j=d;d=v[b+708>>2];h=(+(g>>>0)+1)*+(((d|0)<0?i:j)|0)/+y[a+1074416>>2];d:{if(D(h)<2147483648){a=~~h;break d}a=-2147483648}v[c+856>>2]=a;if(w[b+90|0]&16){a=B(v[v[v[b+656>>2]+44>>2]+36>>2]+1|0,a);v[b+856>>2]=a}a=a-(g?e:0)|0;c=a>>31;e=d>>31;if((e+d^e)>>>0<=(c^a+c)>>>0){if(!d){break c}v[b+708>>2]=0;v[b+852>>2]=d+v[b+852>>2];t[b+851|0]=w[b+851|0]|32;break c}v[b+708>>2]=d-a;v[b+852>>2]=a+v[b+852>>2];t[b+851|0]=w[b+851|0]|32;break c}c=1;e:{if(!(t[b+851|0]&1)|v[a+480180>>2]&524352){break e}if(v[a+1074416>>2]==1){d=f+8|0;Db(d,a+1074312|0,6);if(Cb(d)){break e}}c=0;if(v[a+480180>>2]!=8){break e}c=(w[a+480208|0]&2)>>>1|0}d=x[b+768>>1];e=v[a+480180>>2];f:{if(!v[b+700>>2]|!v[b+708>>2]){break f}e=(e|0)==268435456&d>>>0>239;if(!(e?t[b+851|0]&1:c)){break f}c=b+700|0;d=B(v[a+480180>>2]==64?2:4,e?d-240|0:d);d=Hj(a)?d:0-d|0;e=v[b+700>>2];g=v[b+708>>2];if(!(w[b+851|0]&8?0:(e|0)>=(g|0))){sk(a,b,c,d,1);d=v[b+708>>2];if((d|0)>=v[b+700>>2]){break f}v[c>>2]=d;break f}if((e|0)<=(g|0)){break f}sk(a,b,c,0-d|0,1);e=v[b+700>>2];d=v[b+708>>2];g:{if((e|0)<(d|0)){v[c>>2]=d;break g}if((d|0)!=(e|0)){break f}}c=f+8|0;Db(c,a+1074312|0,112);if(!Cb(c)){break f}t[b+851|0]=w[b+851|0]|8}if(v[b+700>>2]!=v[b+708>>2]){break c}c=f+8|0;Db(c,a+1074312|0,25);if(!Cb(c)&v[a+480180>>2]!=1){break c}v[b+708>>2]=0}gb=f+16|0}function z_(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;e=gb-80|0;gb=e;vc(b);ss(a);a:{if(!Ih(b,e+72|0)){break a}if(!AF(e+72|0)){break a}if(!c){j=1;break a}if(!Pb(b,4)){break a}_w(a);p=e,q=Zw(),v[p+48>>2]=q;c=e+48|0;Yw(lj(a)+32|0,c);qs(c);k=v[lj(a)+32>>2];c=lm(b);if(c&1){break a}d=c-4|0;Wc(b,d);g=gb-16|0;gb=g;c=g+8|0;Iw(c,b);f=w[ic(c,0)|0];i=w[ic(c,1)|0];c=w[ic(c,2)|0];gb=g+16|0;g=c|(i<<8|f<<16);if(!g){break a}v[22656]=0;R(271,k|0,g|0);c=v[22656];v[22656]=0;j=1;if((c|0)==1){a=V(89116)|0;if((O()|0)==(ea(89116)|0)){Z(a|0)|0;$();j=0;break a}S(a|0);L()}Wc(b,4);l=e+48|0;zF(l,b);i=v[k>>2];f=gb-32|0;gb=f;b=v[l>>2];t[f+24|0]=w[b|0];t[f+25|0]=w[b+1|0];t[f+26|0]=w[b+2|0];t[f+27|0]=w[b+3|0];c=yF(f+8|0);d=b+d|0;v[c+12>>2]=d-4;v[c+8>>2]=b;fk(c,w[d-1|0]);b=g;while(1){b:{if(!fk(c,1)){v[f+4>>2]=1;while(1){d=fk(c,2);v[f+4>>2]=d+v[f+4>>2];if((d|0)==3){continue}break}qc(f+4|0,b);d=0;if(v[f+4>>2]){while(1){b=b-1|0;p=i+b|0,q=fk(c,8),t[p|0]=q;d=d+1|0;if(d>>>0<y[f+4>>2]){continue}break}}if(!b){break b}}d=fk(c,2);v[f+4>>2]=d+2;c:{if((d|0)==3){d=c;if(fk(c,1)){h=w[ic(f+24|0,3)|0]}else{h=7}m=fk(d,h);while(1){d=fk(c,3);v[f+4>>2]=d+v[f+4>>2];if((d|0)==7){continue}break}break c}m=fk(c,w[ic(f+24|0,d)|0])}qc(f+4|0,b);h=0;n=v[f+4>>2];if(n){while(1){d=0;o=b+m|0;if(g>>>0>o>>>0){d=w[i+o|0]}b=b-1|0;t[i+b|0]=d;h=h+1|0;if((n|0)!=(h|0)){continue}break}}if(b){continue}}break}gb=f+32|0;Vd(e+32|0,k);b=v[e+36>>2];v[e+16>>2]=v[e+32>>2];v[e+20>>2]=b;rh(e+40|0,e+16|0);b=Ud(e+24|0);c=v[e+44>>2];v[e+8>>2]=v[e+40>>2];v[e+12>>2]=c;c=v[b+4>>2];v[e>>2]=v[b>>2];v[e+4>>2]=c;b=ps(l,e+8|0,e);Vc(lj(a)+12|0,b);xb(b)}gb=e+80|0;return j|0}function uia(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,w=0,x=0,y=0;g=gb-48|0;gb=g;q=v[a+16>>2];h=v[a+44>>2];v[g+32>>2]=h;e=v[a+48>>2];v[g+36>>2]=e;k=v[a+52>>2];v[g+40>>2]=k;n=v[a+56>>2];v[g+44>>2]=n;r=v[a+24>>2];s=v[a+20>>2];i=v[a+4>>2];j=v[a>>2];v[g+24>>2]=j;v[g+28>>2]=i;f=v[a+12>>2];v[g+16>>2]=v[a+8>>2];v[g+20>>2]=f;if(d){while(1){f=(((i&2147483647)<<1|j>>>31)&-2)+q|0;n=1;e=(((j>>>16|0)+4&131064)<<1)+b|0;j=u[e+38>>1];m=u[e+36>>1];o=u[e+34>>1];l=u[e+32>>1];p=u[e+30>>1];w=u[e+28>>1];x=u[e+26>>1];y=u[e+24>>1];k=0;e=1;h=0;while(1){v[(g+8|0)+(h<<2)>>2]=(((((B(t[f+(h|4)|0],o)+B(t[f+(h|2)|0],l)|0)+B(t[f+(h|6)|0],m)|0)+B(j,t[f+(h|8)|0])<<8)/2|0)+((((B(t[f+(h|-4)|0],x)+B(t[f+(h|-6)|0],y)|0)+B(t[f+(h|-2)|0],w)|0)+B(t[h+f|0],p)<<8)/2|0)|0)/16384;i=e;e=0;h=1;if(i){continue}break}while(1){j=(g+8|0)+(k<<2)|0;f=v[j>>2];m=v[a+60>>2];o=m;i=(g+32|0)+(k<<3)|0;k=v[i>>2];e=Lb(k,-16777216,16776704);l=v[a+64>>2];h=Lb(v[i+4>>2],-16777216,16776704);p=m>>31;m=f<<8;f=m;f=kqa(o,p,f,f>>31);o=jb;l=kqa(l,l>>31,e,e>>31);f=l+f|0;e=jb+o|0;e=f>>>0<l>>>0?e+1|0:e;l=f;f=v[a+68>>2];f=kqa(f,f>>31,h,h>>31);h=l+f|0;e=jb+e|0;e=h>>>0<f>>>0?e+1|0:e;h=h+8388608|0;e=h>>>0<8388608?e+1|0:e;e=Jc(h,e,24);v[i+4>>2]=k;h=v[a+72>>2];v[j>>2]=(e|0)/256;v[i>>2]=e-(h&m);k=1;e=n&1;n=0;if(e){continue}break}v[c>>2]=v[c>>2]+B(v[g+8>>2],s);v[c+4>>2]=v[c+4>>2]+B(v[g+12>>2],r);Ub(g+24|0,g+16|0);d=d-1|0;if(d){c=c+8|0;j=v[g+24>>2];i=v[g+28>>2];continue}break}j=v[g+24>>2];i=v[g+28>>2];n=v[g+44>>2];k=v[g+40>>2];h=v[g+32>>2];e=v[g+36>>2]}v[a+56>>2]=n;v[a+52>>2]=k;v[a+48>>2]=e;v[a+44>>2]=h;v[a>>2]=j;v[a+4>>2]=i;gb=g+48|0}function Hia(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,w=0,x=0,y=0,z=0,A=0,C=0,D=0,E=0,F=0,G=0;h=gb-16|0;gb=h;a:{b:{c:{f=v[a+12>>2];i=v[a+8>>2];d:{if((f|0)<=1&i>>>0<=805306368|(f|0)<=0){if((f|0)>=-2&i>>>0>=3489660928|(f|0)>-2){break c}if((f|0)==-2&i>>>0>2147483647|f>>>0>4294967294){break d}break b}if((f|0)==1&i>>>0>2147483648|f>>>0>1){break b}}p=b+196648|0;break a}p=b+131112|0;break a}p=b+262184|0}s=v[a+16>>2];g=v[a+48>>2];k=v[a+40>>2];l=v[a+36>>2];m=v[a+44>>2];e=v[a+4>>2];j=v[a>>2];v[h+8>>2]=j;v[h+12>>2]=e;v[h>>2]=i;v[h+4>>2]=f;e:{if(d){while(1){b=(j>>>16&65520)+p|0;f=u[b>>1];e=(e<<1)+s|0;j=u[e-6>>1];i=u[b+2>>1];n=u[e-4>>1];t=u[b+4>>1];w=u[e-2>>1];x=u[b+6>>1];y=u[e>>1];z=u[b+8>>1];A=u[e+2>>1];C=u[b+10>>1];D=u[e+4>>1];E=u[b+12>>1];F=u[e+6>>1];G=u[b+14>>1];e=u[e+8>>1];r=v[a+60>>2];b=Lb(m,-16777216,16776704);o=v[a+64>>2];g=Lb(g,-16777216,16776704);b=kqa(o,o>>31,b,b>>31);o=jb;q=b;j=(((((((B(i,n)+B(f,j)|0)+B(t,w)|0)+B(x,y)|0)+B(z,A)|0)+B(C,D)|0)+B(E,F)|0)+B(e,G)|0)/32768<<8;b=j;f=kqa(r,r>>31,b,b>>31);e=q+f|0;b=jb+o|0;b=e>>>0<f>>>0?b+1|0:b;q=e;e=v[a+68>>2];e=kqa(e,e>>31,g,g>>31);g=q+e|0;b=jb+b|0;b=e>>>0>g>>>0?b+1|0:b;g=g+8388608|0;b=g>>>0<8388608?b+1|0:b;b=Jc(g,b,24);g=v[a+72>>2];e=v[a+32>>2];l=v[a+28>>2]+l|0;f=l>>12;n=(b|0)/256|0;v[c>>2]=v[c>>2]+B(f,n);k=e+k|0;i=k>>12;v[c+4>>2]=v[c+4>>2]+B(n,i);b=b-(g&j)|0;Ub(h+8|0,h);d=d-1|0;if(d){c=c+8|0;j=v[h+8>>2];e=v[h+12>>2];g=m;m=b;continue}break}j=v[h+8>>2];e=v[h+12>>2];g=m;break e}i=k>>12;f=l>>12;b=m}v[a+40>>2]=k;v[a+20>>2]=f;v[a+36>>2]=l;v[a+48>>2]=g;v[a+44>>2]=b;v[a+24>>2]=i;v[a>>2]=j;v[a+4>>2]=e;gb=h+16|0}function Iia(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,w=0,x=0,y=0,z=0,A=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0;h=gb-16|0;gb=h;a:{b:{c:{f=v[a+12>>2];i=v[a+8>>2];d:{if((f|0)<=1&i>>>0<=805306368|(f|0)<=0){if((f|0)>=-2&i>>>0>=3489660928|(f|0)>-2){break c}if((f|0)==-2&i>>>0>2147483647|f>>>0>4294967294){break d}break b}if((f|0)==1&i>>>0>2147483648|f>>>0>1){break b}}p=b+196648|0;break a}p=b+131112|0;break a}p=b+262184|0}r=v[a+16>>2];g=v[a+48>>2];k=v[a+40>>2];l=v[a+36>>2];m=v[a+44>>2];e=v[a+4>>2];j=v[a>>2];v[h+8>>2]=j;v[h+12>>2]=e;v[h>>2]=i;v[h+4>>2]=f;e:{if(d){while(1){b=e+r|0;f=t[b+4|0];e=(j>>>16&65520)+p|0;j=u[e+14>>1];i=t[b+3|0];o=u[e+12>>1];s=t[b+2|0];w=u[e+10>>1];x=t[b+1|0];y=u[e+8>>1];z=t[b|0];A=u[e+6>>1];C=t[b-1|0];D=u[e+4>>1];E=t[b-2|0];F=u[e+2>>1];G=t[b-3|0];e=u[e>>1];b=v[a+60>>2];H=b;I=b>>31;b=Lb(m,-16777216,16776704);n=v[a+64>>2];g=Lb(g,-16777216,16776704);b=kqa(n,n>>31,b,b>>31);n=jb;J=b;b=v[a+68>>2];q=kqa(b,b>>31,g,g>>31);g=J+q|0;b=jb+n|0;b=g>>>0<q>>>0?b+1|0:b;e=(((((((B(E,F)+B(e,G)|0)+B(C,D)|0)+B(z,A)|0)+B(x,y)|0)+B(s,w)|0)+B(i,o)|0)+B(f,j)<<8)/32768<<8;f=kqa(H,I,e,e>>31);g=g+f|0;b=jb+b|0;b=g>>>0<f>>>0?b+1|0:b;g=g+8388608|0;b=g>>>0<8388608?b+1|0:b;b=Jc(g,b,24);g=v[a+72>>2];j=v[a+32>>2];l=v[a+28>>2]+l|0;f=l>>12;o=(b|0)/256|0;v[c>>2]=v[c>>2]+B(f,o);k=j+k|0;i=k>>12;v[c+4>>2]=v[c+4>>2]+B(o,i);b=b-(g&e)|0;Ub(h+8|0,h);d=d-1|0;if(d){c=c+8|0;j=v[h+8>>2];e=v[h+12>>2];g=m;m=b;continue}break}j=v[h+8>>2];e=v[h+12>>2];g=m;break e}i=k>>12;f=l>>12;b=m}v[a+40>>2]=k;v[a+20>>2]=f;v[a+36>>2]=l;v[a+48>>2]=g;v[a+44>>2]=b;v[a+24>>2]=i;v[a>>2]=j;v[a+4>>2]=e;gb=h+16|0}function Q2(a,b,c,d,e,f,g,h,i,j,k,l,m,n,o){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;l=l|0;m=m|0;n=n|0;o=o|0;var p=0,q=0,r=0,s=0,u=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0;u=gb-16|0;gb=u;v[c>>2]=a;A=d&512;while(1){a:{b:{switch(t[i+x|0]){case 0:v[b>>2]=v[c>>2];break a;case 1:v[b>>2]=v[c>>2];p=qn(g,32);q=v[c>>2];v[c>>2]=q+1;t[q|0]=p;break a;case 3:if(gd(n)){break a}p=w[pc(n,0)|0];q=v[c>>2];v[c>>2]=q+1;t[q|0]=p;break a;case 2:if(gd(m)|!A){break a}C=c,D=Vi(zd(m),gf(m),v[c>>2]),v[C>>2]=D;break a;case 4:break b;default:break a}}B=v[c>>2];e=e+h|0;r=e;c:{if(e>>>0>=f>>>0){break c}while(1){if(!nh(g,2048,t[r|0])){break c}r=r+1|0;if(r>>>0<f>>>0){continue}break}}if((o|0)>0){p=o;d:{e:{if(e>>>0>=r>>>0){break e}while(1){f:{r=r-1|0;q=w[r|0];s=v[c>>2];v[c>>2]=s+1;t[s|0]=q;p=p-1|0;if(e>>>0>=r>>>0){break f}if(p){continue}}break}if(p){break e}p=0;s=0;break d}s=qn(g,48)}q=v[c>>2];v[c>>2]=q+1;if((p|0)>0){while(1){t[q|0]=s;q=v[c>>2];v[c>>2]=q+1;y=p>>>0>1;p=p-1|0;if(y){continue}break}}t[q|0]=j}g:{if((e|0)==(r|0)){p=qn(g,48);q=v[c>>2];v[c>>2]=q+1;t[q|0]=p;break g}if(gd(l)){q=-1}else{q=t[pc(l,0)|0]}s=0;p=0;while(1){h:{if((p|0)!=(q|0)){break h}p=v[c>>2];v[c>>2]=p+1;t[p|0]=k;p=0;s=s+1|0;if(Ab(l)>>>0<=s>>>0){break h}if(w[pc(l,s)|0]==127){q=-1;break h}q=t[pc(l,s)|0]}r=r-1|0;y=w[r|0];z=v[c>>2];v[c>>2]=z+1;t[z|0]=y;p=p+1|0;if((e|0)!=(r|0)){continue}break}}qm(B,v[c>>2])}x=x+1|0;if((x|0)!=4){continue}break}if(Ab(n)>>>0>1){C=u,D=zd(n),v[C+8>>2]=D;e=gb-16|0;gb=e;v[e+8>>2]=v[u+8>>2];v[e+8>>2]=v[e+8>>2]+1;gb=e+16|0;C=c,D=Vi(v[e+8>>2],gf(n),v[c>>2]),v[C>>2]=D}d=d&176;if((d|0)!=16){if((d|0)==32){a=v[c>>2]}v[b>>2]=a}gb=u+16|0}function Ts(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,u=0;i=gb-128|0;gb=i;v[i+120>>2]=b;k=Pp(c,d);v[i+4>>2]=2428;n=yH(i+8|0,i+4|0);j=i+16|0;a:{b:{if(k>>>0>=101){j=Cd(k);if(!j){v[22656]=0;X(2429);a=v[22656];v[22656]=0;if((a|0)!=1){break a}break b}Ee(n,j)}m=(c|0)==(d|0);if(!m){b=c;h=j;while(1){c:{if(!gd(b)){t[h|0]=1;break c}t[h|0]=2;l=l+1|0;k=k-1|0}h=h+1|0;b=b+12|0;if((d|0)!=(b|0)){continue}break}}while(1){r=o;v[22656]=0;h=Q(2430,a|0,i+120|0)|0;b=v[22656];v[22656]=0;d:{if((b|0)!=1){if(h&(k|0)!=0){break d}v[22656]=0;b=Q(2431,a|0,i+120|0)|0;a=v[22656];v[22656]=0;if((a|0)==1){break b}if(b){v[f>>2]=v[f>>2]|2}e:{if(!m){while(1){if(w[j|0]==2){d=c;break e}j=j+1|0;c=c+12|0;if((d|0)!=(c|0)){continue}break}}v[f>>2]=v[f>>2]|4}Ic(n);gb=i+128|0;return d|0}break b}v[22656]=0;p=T(2432,a|0)|0;b=v[22656];v[22656]=0;f:{if((b|0)!=1){if(g){break f}v[22656]=0;p=Q(2433,e|0,p|0)|0;b=v[22656];v[22656]=0;if((b|0)!=1){break f}}break b}o=r+1|0;if(m){continue}s=0;h=c;b=j;while(1){g:{if(w[b|0]!=1){break g}q=t[pc(h,r)|0];h:{if(g){break h}v[22656]=0;q=Q(2433,e|0,q<<24>>24)|0;u=v[22656];v[22656]=0;if((u|0)!=1){break h}break b}i:{if((p&255)==(q&255)){s=1;if((Ab(h)|0)!=(o|0)){break g}t[b|0]=2;l=l+1|0;break i}t[b|0]=0}k=k-1|0}b=b+1|0;h=h+12|0;if((h|0)!=(d|0)){continue}break}if(!s){continue}v[22656]=0;T(2434,a|0)|0;b=v[22656];v[22656]=0;if((b|0)!=1){if(k+l>>>0<2){continue}h=c;b=j;if(m){continue}while(1){j:{if(w[b|0]!=2){break j}if((Ab(h)|0)==(o|0)){break j}t[b|0]=0;l=l-1|0}b=b+1|0;h=h+12|0;if((h|0)!=(d|0)){continue}break}continue}break}}a=P()|0;O()|0;Ic(n);S(a|0)}L()}function Via(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;b=gb-48|0;gb=b;r=v[a+16>>2];h=v[a+44>>2];v[b+32>>2]=h;m=v[a+48>>2];v[b+36>>2]=m;g=v[a+52>>2];v[b+40>>2]=g;i=v[a+56>>2];v[b+44>>2]=i;n=v[a+40>>2];o=v[a+36>>2];e=v[a+4>>2];j=v[a>>2];v[b+24>>2]=j;v[b+28>>2]=e;f=v[a+12>>2];v[b+16>>2]=v[a+8>>2];v[b+20>>2]=f;a:{if(d){while(1){m=1;e=((((e&2147483647)<<1|j>>>31)&2147483646)<<1)+r|0;h=j>>>21&2040;j=u[h+46166>>1];i=u[h+46164>>1];k=u[h+46162>>1];p=u[h+46160>>1];h=0;g=1;f=0;while(1){q=(b+8|0)+(f<<2)|0;f=f<<1;v[q>>2]=(((B(u[f+e>>1],k)+B(u[e+(f|-4)>>1],p)|0)+B(i,u[e+(f|4)>>1])|0)+B(j,u[e+(f|8)>>1])|0)/16384;l=g&1;g=0;f=1;if(l){continue}break}while(1){j=(b+8|0)+(h<<2)|0;g=v[j>>2];i=v[a+60>>2];k=i;h=(b+32|0)+(h<<3)|0;p=v[h>>2];e=Lb(p,-16777216,16776704);l=v[a+64>>2];f=Lb(v[h+4>>2],-16777216,16776704);q=i>>31;i=g<<8;g=i;g=kqa(k,q,g,g>>31);k=jb;l=kqa(l,l>>31,e,e>>31);g=l+g|0;e=jb+k|0;e=g>>>0<l>>>0?e+1|0:e;k=g;g=v[a+68>>2];g=kqa(g,g>>31,f,f>>31);f=k+g|0;e=jb+e|0;e=f>>>0<g>>>0?e+1|0:e;f=f+8388608|0;e=f>>>0<8388608?e+1|0:e;e=Jc(f,e,24);v[h+4>>2]=p;f=v[a+72>>2];v[j>>2]=(e|0)/256;v[h>>2]=e-(f&i);h=1;e=m&1;m=0;if(e){continue}break}e=v[a+32>>2];o=v[a+28>>2]+o|0;f=o>>12;v[c>>2]=v[c>>2]+B(f,v[b+8>>2]);n=e+n|0;k=n>>12;v[c+4>>2]=v[c+4>>2]+B(k,v[b+12>>2]);Ub(b+24|0,b+16|0);d=d-1|0;if(d){c=c+8|0;j=v[b+24>>2];e=v[b+28>>2];continue}break}j=v[b+24>>2];e=v[b+28>>2];i=v[b+44>>2];g=v[b+40>>2];m=v[b+36>>2];h=v[b+32>>2];break a}k=n>>12;f=o>>12}v[a+40>>2]=n;v[a+20>>2]=f;v[a+36>>2]=o;v[a+56>>2]=i;v[a+52>>2]=g;v[a+48>>2]=m;v[a+44>>2]=h;v[a+24>>2]=k;v[a>>2]=j;v[a+4>>2]=e;gb=b+48|0}function rfa(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0;g=gb-48|0;gb=g;h=Ki(b)^-1;a:{if(Nb(d)>>>0<=h>>>0){bu(a);break a}Ki(b);c=c+4|0;if((w[c|0]|w[c+1|0]<<8)>>>0>=60){Rb(b,4)}k=g,l=Ki(b),v[k+44>>2]=l;Rb(b,4);i=Ki(b);j=Ki(b);if(!((i|0)>0&(j|0)>36)){bu(a);break a}b:{if(!f){break b}if(!xr(Ad(e,v[Mb(d,h)>>2]),f)){break b}bu(a);break a}Ww(g,b,j,i);b=kc(g+24|0,g);xb(g);v[22656]=0;d=T(275,b|0)|0;e=v[22656];v[22656]=0;c:{if((e|0)==1){break c}d:{e:{if(!d){v[22656]=0;T(1427,a|0)|0;a=v[22656];v[22656]=0;if((a|0)!=1){break e}break c}if((w[c|0]|w[c+1|0]<<8)>>>0<=39){v[22656]=0;Q(318,b|0,8)|0;d=v[22656];v[22656]=0;if((d|0)==1){break c}}if((w[c|0]|w[c+1|0]<<8)>>>0<=59){v[22656]=0;Q(318,b|0,16)|0;d=v[22656];v[22656]=0;if((d|0)==1){break c}}v[22656]=0;T(1419,b|0)|0;d=v[22656];v[22656]=0;if((d|0)==1){break c}f:{if((w[c|0]|w[c+1|0]<<8)>>>0>=120){v[22656]=0;T(1419,b|0)|0;c=v[22656];v[22656]=0;if((c|0)==1){break c}v[22656]=0;Q(318,b|0,8)|0;break f}if((w[c|0]|w[c+1|0]<<8)>>>0>=100){v[22656]=0;Q(318,b|0,4)|0;c=v[22656];v[22656]=0;if((c|0)==1){break c}v[22656]=0;T(1419,b|0)|0;c=v[22656];v[22656]=0;if((c|0)==1){break c}v[22656]=0;Q(318,b|0,4)|0;break f}if((w[c|0]|w[c+1|0]<<8)>>>0>=62){v[22656]=0;T(1419,b|0)|0;c=v[22656];v[22656]=0;if((c|0)==1){break c}v[22656]=0;Q(318,b|0,4)|0;break f}v[22656]=0;T(1419,b|0)|0}c=v[22656];v[22656]=0;if((c|0)==1){break c}v[22656]=0;c=T(1419,b|0)|0;d=v[22656];v[22656]=0;if((d|0)==1){break d}v[22656]=0;U(288,g|0,b|0,c|0);c=v[22656];v[22656]=0;if((c|0)==1){break d}kc(a,g);v[a+20>>2]=v[g+44>>2];xb(g)}xb(b);break a}}a=P()|0;O()|0;xb(b);S(a|0);L()}gb=g+48|0}function oB(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;f=gb-32|0;gb=f;d=c&4;a:{if(!(b&4)){if(!d){break a}t[a+15|0]=w[a+16|0];b=w[a+12|0];t[a+12|0]=b&247;d=!(b&2);b=w[a+14|0];if(d|b>>>0<=w[a+13|0]){break a}if(Nb(a)>>>0<=b>>>0){break a}while(1){d=Cc(a,b);u[d>>1]=x[d>>1]+1;b=b+1|0;if(Nb(a)>>>0>b>>>0){continue}break}break a}if(d){break a}b=w[a+14|0];b:{if(b>>>0>=w[a+15|0]){break b}d=w[a+12|0];if(!(d&2)){break b}t[a+12|0]=d&251}if(!(w[a+12|0]&2)|b>>>0<=w[a+13|0]){break a}if(Nb(a)>>>0<=b>>>0){break a}d=x[Cc(a,w[a+14|0])>>1];e=Cc(a,w[a+14|0]-1|0);b=w[a+14|0];if(x[e>>1]<(d-1|0)){b=x[Cc(a,b)>>1]-1&65535;d=Vq(a,b,64,64);q=f,r=Vb(a),v[q+8>>2]=r;q=f,r=$o(f+8|0,w[a+14|0]),v[q+16>>2]=r;e=Fd(f+24|0,f+16|0);h=qr(f,b,d&255);g=gb-32|0;gb=g;v[g+24>>2]=v[e>>2];b=a;d=v[a>>2];q=g,r=Vb(a),v[q>>2]=r;d=d+(rv(g+24|0,g)<<2)|0;c:{d:{if(y[a+4>>2]<y[wb(a)>>2]){i=v[b+4>>2];if((i|0)!=(d|0)){break d}qW(b,h);break c}e=wb(b);e=Ap(g,fh(b,Nb(b)+1|0),d-v[b>>2]>>2,e);v[22656]=0;R(1080,e|0,h|0);l=v[22656];v[22656]=0;e:{if((l|0)==1){break e}v[22656]=0;d=W(1081,b|0,e|0,d|0)|0;b=v[22656];v[22656]=0;if((b|0)==1){break e}gj(e);break c}a=P()|0;O()|0;gj(e);S(a|0);L()}m=gb-16|0;gb=m;l=d;o=b;p=v[b+4>>2];b=(p-(d+4|0)|0)+d|0;j=Fg(m,o,i-b>>2);f:{g:{if(b>>>0<i>>>0){k=v[j+4>>2];e=b;while(1){n=wb(o);v[22656]=0;hn(n,k,e);n=v[22656];v[22656]=0;if((n|0)==1){break g}k=k+4|0;v[j+4>>2]=k;e=e+4|0;if(i>>>0>e>>>0){continue}break}}$b(j);zr(l,b,p);gb=m+16|0;break f}a=P()|0;O()|0;$b(j);S(a|0);L()}u[d>>1]=x[h>>1];t[d+2|0]=w[h+2|0]}Hg(d);gb=g+32|0;break a}t[a+14|0]=b-1}if((c|0)!=16777216){t[a+17|0]=255}gb=f+32|0}function Rs(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,u=0;i=gb-128|0;gb=i;v[i+120>>2]=b;k=Pp(c,d);v[i+4>>2]=2428;n=yH(i+8|0,i+4|0);j=i+16|0;a:{b:{if(k>>>0>=101){j=Cd(k);if(!j){v[22656]=0;X(2429);a=v[22656];v[22656]=0;if((a|0)!=1){break a}break b}Ee(n,j)}m=(c|0)==(d|0);if(!m){b=c;h=j;while(1){c:{if(!gd(b)){t[h|0]=1;break c}t[h|0]=2;l=l+1|0;k=k-1|0}h=h+1|0;b=b+12|0;if((d|0)!=(b|0)){continue}break}}while(1){r=o;v[22656]=0;h=Q(2457,a|0,i+120|0)|0;b=v[22656];v[22656]=0;d:{if((b|0)!=1){if(h&(k|0)!=0){break d}v[22656]=0;b=Q(2458,a|0,i+120|0)|0;a=v[22656];v[22656]=0;if((a|0)==1){break b}if(b){v[f>>2]=v[f>>2]|2}e:{if(!m){while(1){if(w[j|0]==2){d=c;break e}j=j+1|0;c=c+12|0;if((d|0)!=(c|0)){continue}break}}v[f>>2]=v[f>>2]|4}Ic(n);gb=i+128|0;return d|0}break b}v[22656]=0;p=T(2459,a|0)|0;b=v[22656];v[22656]=0;f:{if((b|0)!=1){if(g){break f}v[22656]=0;p=Q(2460,e|0,p|0)|0;b=v[22656];v[22656]=0;if((b|0)!=1){break f}}break b}o=r+1|0;if(m){continue}s=0;h=c;b=j;while(1){g:{if(w[b|0]!=1){break g}q=v[yk(h,r)>>2];h:{if(g){break h}v[22656]=0;q=Q(2460,e|0,q|0)|0;u=v[22656];v[22656]=0;if((u|0)!=1){break h}break b}i:{if((p|0)==(q|0)){s=1;if((Ab(h)|0)!=(o|0)){break g}t[b|0]=2;l=l+1|0;break i}t[b|0]=0}k=k-1|0}b=b+1|0;h=h+12|0;if((h|0)!=(d|0)){continue}break}if(!s){continue}v[22656]=0;T(2461,a|0)|0;b=v[22656];v[22656]=0;if((b|0)!=1){if(k+l>>>0<2){continue}h=c;b=j;if(m){continue}while(1){j:{if(w[b|0]!=2){break j}if((Ab(h)|0)==(o|0)){break j}t[b|0]=0;l=l-1|0}b=b+1|0;h=h+12|0;if((h|0)!=(d|0)){continue}break}continue}break}}a=P()|0;O()|0;Ic(n);S(a|0)}L()}function f8(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0;c=gb+-64|0;gb=c;f=mc(a);a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{if(Bj(b)){zh(c+56|0);break n}v[22656]=0;R(2096,c+40|0,b|0);a=v[22656];v[22656]=0;if((a|0)==1){break m}v[22656]=0;a=T(2084,c+40|0)|0;e=v[22656];v[22656]=0;if((e|0)==1){break l}v[c+56>>2]=a;Yf(c+40|0)}if(Bj(b)){a=b+36|0}else{a=v[c+56>>2]}e=ko(a);v[22656]=0;R(1421,f|0,e|0);e=v[22656];v[22656]=0;if((e|0)==1){break k}h=c,i=Vb(a),v[h+32>>2]=i;h=c,i=Zb(a),v[h+24>>2]=i;if(Gb(c+32|0,c+24|0)){a=b+24|0;while(1){e=v[c+32>>2];b=Tj(v[a>>2]+484360|0,w[e+16|0]);v[22656]=0;R(2097,c+8|0,b|0);d=v[22656];v[22656]=0;if((d|0)==1){break j}v[22656]=0;R(2039,c+40|0,c+8|0);d=v[22656];v[22656]=0;if((d|0)==1){break i}v[22656]=0;R(1423,f|0,c+40|0);d=v[22656];v[22656]=0;if((d|0)==1){break h}vb(c+40|0);vb(c+8|0);o:{if(!gd(LK(f))){break o}d=w[e+12|0];v[22656]=0;d=Q(472,b|0,d|0)|0;g=v[22656];v[22656]=0;if((g|0)==1){break c}if(!d){break o}d=v[a>>2];v[22656]=0;d=Kk(d);g=v[22656];v[22656]=0;if((g|0)==1){break f}b=_b(v[a>>2]+484344|0,x[sc(b,v[e+12>>2])>>1]);v[22656]=0;R(2098,c+8|0,b|0);b=v[22656];v[22656]=0;if((b|0)==1){break e}v[22656]=0;Y(360,c+40|0,0,d|0,c+8|0);b=v[22656];v[22656]=0;if((b|0)==1){break d}b=c+40|0;Eb(LK(f),b);vb(b);vb(c+8|0)}b=c+32|0;eL(b);if(Gb(b,c+24|0)){continue}break}}xl(c+56|0);gb=c- -64|0;return}b=P()|0;O()|0;break a}b=P()|0;O()|0;Yf(c+40|0);break a}b=P()|0;O()|0;break b}b=P()|0;O()|0;break b}b=P()|0;O()|0;break g}b=P()|0;O()|0;vb(c+40|0)}vb(c+8|0);break b}b=P()|0;O()|0;break b}b=P()|0;O()|0;break b}b=P()|0;O()|0;vb(c+8|0);break b}b=P()|0;O()|0}xl(c+56|0)}yd(f);S(b|0);L()}function Sha(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;e=gb-32|0;gb=e;u[e+28>>1]=c;u[e+30>>1]=b;u[e+26>>1]=d;d=0;l=x[v[v[a+24>>2]+8>>2]+12>>1];a:{if(l>>>0<=b>>>0){break a}if(!c|Ri(a)>>>0>=l>>>0){break a}zg(e+28|0,l-b&65535);s=e,t=am(a),u[s+8>>1]=t;b=Le(e+30|0,e+8|0);dW(a,x[e+28>>1]+x[b>>1]|0);b=x[e+30>>1];if(tc(a)>>>0<b>>>0){Af(a,x[e+30>>1])}s=e,t=Vb(a),v[s>>2]=t;c=x[e+30>>1];b=gb-16|0;gb=b;v[b+8>>2]=v[e>>2];v[b+8>>2]=v[b+8>>2]+(c<<1);gb=b+16|0;v[e+8>>2]=v[b+8>>2];b=v[Fd(e+16|0,e+8|0)>>2];f=x[e+28>>1];i=e+26|0;j=gb-32|0;gb=j;v[j+24>>2]=b;c=a;b=v[c>>2];s=j,t=Vb(c),v[s>>2]=t;d=b+(sp(j+24|0,j)<<1)|0;b:{c:{d:{if(!f){break d}b=v[wb(c)>>2];g=v[c+4>>2];if(f>>>0<=b-g>>1>>>0){b=f;k=g-d|0;h=k>>1;if(b>>>0>h>>>0){up(c,f-h|0,i);b=h;if(!k){break d}}p=gb-16|0;gb=p;k=c;m=g;n=d;r=v[c+4>>2];h=(r-((f<<1)+d|0)|0)+d|0;q=li(p,c,g-h>>1);if(g>>>0>h>>>0){o=v[q+4>>2];g=h;while(1){wb(k);To(o,g);o=o+2|0;v[q+4>>2]=o;g=g+2|0;if(m>>>0>g>>>0){continue}break}}$b(q);zr(n,h,r);gb=p+16|0;pv(d,b,i+((d>>>0<=i>>>0?i>>>0<y[c+4>>2]?f:0:0)<<1)|0);break d}b=wb(c);g=Gn(j,Vk(c,tc(c)+f|0),d-v[c>>2]>>1,b);v[22656]=0;U(312,g|0,f|0,i|0);b=v[22656];v[22656]=0;if((b|0)==1){break c}b=c;Fp(c);f=g;k=v[f+4>>2];h=d;n=f+4|0;Dk(wb(c),v[c>>2],d,n);wb(c);i=f+8|0;m=i;d=v[c+4>>2];if((h|0)!=(d|0)){c=v[m>>2];while(1){To(c,h);c=v[m>>2]+2|0;v[m>>2]=c;h=h+2|0;if((d|0)!=(h|0)){continue}break}}xc(b,n);xc(b+4|0,i);xc(wb(b),dc(f));v[f>>2]=v[f+4>>2];$r(b,tc(b));d=k;Hh(g)}Hg(d);gb=j+32|0;break b}a=P()|0;O()|0;Hh(g);S(a|0);L()}if(tc(a)>>>0>l>>>0){Af(a,l)}d=x[e+28>>1]}gb=e+32|0;return d&65535}function Wia(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;b=gb-48|0;gb=b;q=v[a+16>>2];h=v[a+44>>2];v[b+32>>2]=h;m=v[a+48>>2];v[b+36>>2]=m;f=v[a+52>>2];v[b+40>>2]=f;i=v[a+56>>2];v[b+44>>2]=i;n=v[a+40>>2];o=v[a+36>>2];e=v[a+4>>2];j=v[a>>2];v[b+24>>2]=j;v[b+28>>2]=e;g=v[a+12>>2];v[b+16>>2]=v[a+8>>2];v[b+20>>2]=g;a:{if(d){while(1){e=(((e&2147483647)<<1|j>>>31)&-2)+q|0;g=j>>>21&2040;j=u[g+46166>>1];i=u[g+46164>>1];k=u[g+46162>>1];p=u[g+46160>>1];h=0;m=1;f=1;g=0;while(1){v[(b+8|0)+(g<<2)>>2]=(((B(t[e+g|0],k)+B(t[e+(g|-2)|0],p)|0)+B(i,t[e+(g|2)|0])|0)+B(j,t[e+(g|4)|0])<<8)/16384;l=f&1;f=0;g=1;if(l){continue}break}while(1){j=(b+8|0)+(h<<2)|0;f=v[j>>2];i=v[a+60>>2];k=i;g=(b+32|0)+(h<<3)|0;p=v[g>>2];e=Lb(p,-16777216,16776704);l=v[a+64>>2];h=Lb(v[g+4>>2],-16777216,16776704);r=i>>31;i=f<<8;f=i;f=kqa(k,r,f,f>>31);k=jb;l=kqa(l,l>>31,e,e>>31);f=l+f|0;e=jb+k|0;e=f>>>0<l>>>0?e+1|0:e;k=f;f=v[a+68>>2];f=kqa(f,f>>31,h,h>>31);h=k+f|0;e=jb+e|0;e=f>>>0>h>>>0?e+1|0:e;h=h+8388608|0;e=h>>>0<8388608?e+1|0:e;e=Jc(h,e,24);v[g+4>>2]=p;h=v[a+72>>2];v[j>>2]=(e|0)/256;v[g>>2]=e-(h&i);h=1;e=m&1;m=0;if(e){continue}break}e=v[a+32>>2];o=v[a+28>>2]+o|0;k=o>>12;v[c>>2]=v[c>>2]+B(k,v[b+8>>2]);n=e+n|0;g=n>>12;v[c+4>>2]=v[c+4>>2]+B(g,v[b+12>>2]);Ub(b+24|0,b+16|0);d=d-1|0;if(d){c=c+8|0;j=v[b+24>>2];e=v[b+28>>2];continue}break}j=v[b+24>>2];e=v[b+28>>2];i=v[b+44>>2];f=v[b+40>>2];m=v[b+36>>2];h=v[b+32>>2];break a}g=n>>12;k=o>>12}v[a+40>>2]=n;v[a+20>>2]=k;v[a+36>>2]=o;v[a+56>>2]=i;v[a+52>>2]=f;v[a+48>>2]=m;v[a+44>>2]=h;v[a+24>>2]=g;v[a>>2]=j;v[a+4>>2]=e;gb=b+48|0}function Zt(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0;e=gb-16|0;gb=e;a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{d=w[a|0];switch(d|0){case 1:case 6:case 7:case 8:case 10:case 12:case 14:case 15:case 16:case 17:case 18:case 19:break a;case 2:break j;case 13:break k;case 0:break l;case 5:break c;case 9:break e;case 11:break f;case 20:break g;case 4:break h;case 3:break i;default:break d}}t[a|0]=0;break b}f=1;t[a|0]=1;t[e+15|0]=64;h=b,i=w[ac(b,e+15|0)|0],t[h|0]=i;break a}d=c;c=w[b|0];if(!(c&3|c>>>0>223?d:1)){break a}t[b|0]=(c&252)>>>2;t[a|0]=12;break b}d=c;c=w[b|0];if(!(c&3|c>>>0>223?d:1)){break a}t[b|0]=(c&252)>>>2;t[a|0]=13;break b}g=w[b|0];if(g>>>0<240){d=0;while(1){f=w[d+39104|0];m:{n:{if(c){if(f>>>0>=g>>>0){break n}break m}if((f|0)!=(g|0)){break m}}t[a|0]=11;t[b|0]=d;break b}f=0;d=d+1|0;if((d|0)!=10){continue}break}break a}t[a|0]=11;t[b|0]=9;break b}o:{p:{q:{d=w[b|0]>>>4|0;switch(d|0){case 3:case 4:case 5:case 6:case 7:break a;case 8:break o;case 0:case 1:case 2:break p;default:break q}}if((d|0)!=15){break a}}if(!c){break a}t[b|0]=0;t[a|0]=0;break b}t[a|0]=2;t[b|0]=w[b|0]<<2&60|2;break b}c=w[b|0];if(!c){break a}d=c&15;if(!d){t[b|0]=c>>>4;t[a|0]=3;break b}g=c&240;if(!g){t[a|0]=4;break b}if((d|0)==15){t[b|0]=c>>>4;t[a|0]=5;break b}if((g|0)!=240){break a}t[b|0]=d;t[a|0]=6;break b}c=b;b=w[b|0];t[c|0]=(b|0)==255?64:b>>>2|0;t[a|0]=2;break b}if((d|0)!=26){break a}r:{if(c){t[b|0]=0;break r}if(w[b|0]){break a}}t[a|0]=8;break b}s:{if(c){t[e+14|0]=w[b|0]&15;t[e+13|0]=9;d=w[ac(e+14|0,e+13|0)|0];break s}d=w[b|0];if((d&14)>>>0>9|d&240){break a}}t[b|0]=d&15;t[a|0]=8}f=1}gb=e+16|0;return f}function U3(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0;a=gb-352|0;gb=a;v[a+336>>2]=c;v[a+344>>2]=b;h=Kb(a+208|0);v[22656]=0;Fc(a+16|0,d);b=v[22656];v[22656]=0;a:{b:{c:{d:{if((b|0)!=1){v[22656]=0;b=T(2452,a+16|0)|0;c=v[22656];v[22656]=0;if((c|0)==1){break d}v[22656]=0;Y(2464,b|0,81024,81050,a+224|0);b=v[22656];v[22656]=0;if((b|0)==1){break d}Wb(a+16|0);c=Kb(a+192|0);b=Kc(c);v[22656]=0;R(76,c|0,b|0);b=v[22656];v[22656]=0;if((b|0)==1){break b}b=pc(c,0);v[a+188>>2]=b;v[a+12>>2]=a+16;v[a+8>>2]=0;while(1){e:{v[22656]=0;d=Q(2457,a+344|0,a+336|0)|0;g=v[22656];v[22656]=0;if((g|0)==1){break e}if(!d){break c}if(v[a+188>>2]==(Ab(c)+b|0)){d=Ab(c);b=Ab(c);v[22656]=0;R(76,c|0,b<<1);b=v[22656];v[22656]=0;if((b|0)==1){break b}b=Kc(c);v[22656]=0;R(76,c|0,b|0);b=v[22656];v[22656]=0;if((b|0)==1){break b}b=pc(c,0);v[a+188>>2]=d+b}v[22656]=0;d=T(2459,a+344|0)|0;g=v[22656];v[22656]=0;if((g|0)==1){break e}if(rm(d,16,b,a+188|0,a+8|0,0,h,a+16|0,a+12|0,a+224|0)){break c}v[22656]=0;T(2461,a+344|0)|0;d=v[22656];v[22656]=0;if((d|0)!=1){continue}}break}break b}b=P()|0;O()|0;break a}b=P()|0;O()|0;Wb(a+16|0);break a}v[22656]=0;R(76,c|0,v[a+188>>2]-b|0);b=v[22656];v[22656]=0;f:{if((b|0)==1){break f}b=Jb(c);v[22656]=0;d=ga(2448)|0;g=v[22656];v[22656]=0;if((g|0)==1){break f}v[a>>2]=f;v[22656]=0;b=da(2449,b|0,d|0,a|0,a|0)|0;d=v[22656];v[22656]=0;if((d|0)==1){break f}if((b|0)!=1){v[e>>2]=4}v[22656]=0;b=Q(2458,a+344|0,a+336|0)|0;d=v[22656];v[22656]=0;if((d|0)==1){break f}if(b){v[e>>2]=v[e>>2]|2}b=v[a+344>>2];vb(c);vb(h);gb=a+352|0;return b|0}}b=P()|0;O()|0;vb(c)}vb(h);S(b|0);L()}function f4(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0;a=gb-272|0;gb=a;v[a+256>>2]=c;v[a+264>>2]=b;h=Kb(a+208|0);v[22656]=0;Fc(a+16|0,d);b=v[22656];v[22656]=0;a:{b:{c:{d:{if((b|0)!=1){v[22656]=0;b=T(21,a+16|0)|0;c=v[22656];v[22656]=0;if((c|0)==1){break d}v[22656]=0;Y(2444,b|0,81024,81050,a+224|0);b=v[22656];v[22656]=0;if((b|0)==1){break d}Wb(a+16|0);c=Kb(a+192|0);b=Kc(c);v[22656]=0;R(76,c|0,b|0);b=v[22656];v[22656]=0;if((b|0)==1){break b}b=pc(c,0);v[a+188>>2]=b;v[a+12>>2]=a+16;v[a+8>>2]=0;while(1){e:{v[22656]=0;d=Q(2430,a+264|0,a+256|0)|0;g=v[22656];v[22656]=0;if((g|0)==1){break e}if(!d){break c}if(v[a+188>>2]==(Ab(c)+b|0)){d=Ab(c);b=Ab(c);v[22656]=0;R(76,c|0,b<<1);b=v[22656];v[22656]=0;if((b|0)==1){break b}b=Kc(c);v[22656]=0;R(76,c|0,b|0);b=v[22656];v[22656]=0;if((b|0)==1){break b}b=pc(c,0);v[a+188>>2]=d+b}v[22656]=0;d=T(2432,a+264|0)|0;g=v[22656];v[22656]=0;if((g|0)==1){break e}if(tm(d,16,b,a+188|0,a+8|0,0,h,a+16|0,a+12|0,a+224|0)){break c}v[22656]=0;T(2434,a+264|0)|0;d=v[22656];v[22656]=0;if((d|0)!=1){continue}}break}break b}b=P()|0;O()|0;break a}b=P()|0;O()|0;Wb(a+16|0);break a}v[22656]=0;R(76,c|0,v[a+188>>2]-b|0);b=v[22656];v[22656]=0;f:{if((b|0)==1){break f}b=Jb(c);v[22656]=0;d=ga(2448)|0;g=v[22656];v[22656]=0;if((g|0)==1){break f}v[a>>2]=f;v[22656]=0;b=da(2449,b|0,d|0,a|0,a|0)|0;d=v[22656];v[22656]=0;if((d|0)==1){break f}if((b|0)!=1){v[e>>2]=4}v[22656]=0;b=Q(2431,a+264|0,a+256|0)|0;d=v[22656];v[22656]=0;if((d|0)==1){break f}if(b){v[e>>2]=v[e>>2]|2}b=v[a+264>>2];vb(c);vb(h);gb=a+272|0;return b|0}}b=P()|0;O()|0;vb(c)}vb(h);S(b|0);L()}function iha(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0;e=gb-48|0;gb=e;ud(b,2);d=e+16|0;Mk(d,2,a+1|0);f=e+32|0;Bc(f,d);v[22656]=0;Q(303,b+43|0,f|0)|0;d=v[22656];v[22656]=0;if((d|0)!=1){vb(e+32|0);a:{if(!(w[a|0]?w[a|0]!=1:0)){if(w[a|0]==1){d=a+16|0;v[b>>2]=w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24);d=a+20|0;v[e+32>>2]=w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24);v[e+16>>2]=v[b>>2]-1;f=e+32|0;h=b,i=v[Fb(f,e+16|0)>>2],v[h+4>>2]=i;d=a+24|0;v[e+32>>2]=w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24);h=b,i=v[Fb(f,b)>>2],v[h+8>>2]=i;u[b+34>>1]=x[b+34>>1]&65533|w[a+31|0]<<1&2}d=v[b+8>>2];if(d>>>0>=2&d>>>0>y[b+4>>2]){break a}u[b+34>>1]=0;v[b+4>>2]=0;v[b+8>>2]=0;break a}if(w[a|0]!=2){break a}f=e+16|0;zi(f,a+16|0);d=e+32|0;g=v[f>>2];g=w[g|0]|w[g+1|0]<<8|(w[g+2|0]<<16|w[g+3|0]<<24);t[d|0]=g;t[d+1|0]=g>>>8;t[d+2|0]=g>>>16;t[d+3|0]=g>>>24;zi(f,a+20|0);g=v[e+16>>2];g=w[g|0]|w[g+1|0]<<8|(w[g+2|0]<<16|w[g+3|0]<<24);t[d+4|0]=g;t[d+5|0]=g>>>8;t[d+6|0]=g>>>16;t[d+7|0]=g>>>24;zi(f,a+24|0);f=v[e+16>>2];f=w[f|0]|w[f+1|0]<<8|(w[f+2|0]<<16|w[f+3|0]<<24);t[d+8|0]=f;t[d+9|0]=f>>>8;t[d+10|0]=f>>>16;t[d+11|0]=f>>>24;v[e+8>>2]=v[e+40>>2];d=v[e+36>>2];v[e>>2]=v[e+32>>2];v[e+4>>2]=d;So(b,1,e)}t[e+32|0]=w[a+28|0];t[e+16|0]=64;h=b,i=w[ac(e+32|0,e+16|0)|0]<<2,u[h+30>>1]=i;d=a+32|0;d=w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24);v[b+24>>2]=d;b=b+24|0;b:{if(!c){break b}if(w[a|0]==2){d=x[b>>1];v[b>>2]=d;break b}a=b;if(y[b>>2]>=65536){v[a>>2]=65535}d=v[b>>2]}c:{d:{if(!d){a=8363;break d}a=1024;if(d>>>0>1023){break c}}v[b>>2]=a}gb=e+48|0;return}a=P()|0;O()|0;vb(e+32|0);S(a|0);L()}function cha(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,x=0,y=0;f=gb+-64|0;gb=f;a:{b:{c:{d:{e:{f:{g:{if(!a){break g}l=e<<2;if(l>>>0>d>>>0){break g}x=l-4|0;n=B(b,e);o=n-8|0;while(1){v[22656]=0;b=Q(191,c|0,l|0)|0;g=v[22656];v[22656]=0;if((g|0)==1){break b}if(!(b&m>>>0<n>>>0)){break g}v[22656]=0;U(288,f+16|0,c|0,d|0);b=v[22656];v[22656]=0;if((b|0)==1){break c}g=f+40|0;b=f+16|0;p=kc(g,b);xb(b);v[22656]=0;R(757,b|0,g|0);b=v[22656];v[22656]=0;if((b|0)==1){break e}v[22656]=0;y=Sd(f+16|0);b=v[22656];v[22656]=0;if((b|0)==1){break f}q=v[f+16>>2];if(e){r=q-4|0;g=0;while(1){v[22656]=0;b=T(746,p|0)|0;i=v[22656];v[22656]=0;h:{if((i|0)!=1){v[f+12>>2]=b;v[22656]=0;b=T(374,p|0)|0;i=v[22656];v[22656]=0;if((i|0)==1){break f}v[f+8>>2]=b;Zd(f+8|0,0,89);v[22656]=0;Q(318,f+40|0,1)|0;b=v[22656];v[22656]=0;if((b|0)==1){break f}i=g+m|0;if(o>>>0<i>>>0){break h}k=0;b=e+g<<2;if(r>>>0<b>>>0){break h}while(1){j=zb(w[b+y|0]);s=k&1;j=s?j>>>4|0:j&15;h=v[f+8>>2];v[f+8>>2]=t[(j&7)+36568|0]+h;h=u[(h<<1)+36576>>1];h=(((0-(j&1)&h>>2)+(h>>3)|0)+(j<<30>>31&h>>1)|0)+(h&j<<29>>31)|0;v[f+12>>2]=v[f+12>>2]+(j&8?0-h|0:h);Zd(f+8|0,0,88);Zd(f+12|0,-32768,32767);u[(i<<1)+a>>1]=v[f+12>>2];i=e+i|0;b=b+s|0;k=k+1|0;if((k|0)!=8){continue}if(i>>>0>o>>>0){break h}k=0;b=b+x|0;if(r>>>0>=b>>>0){continue}break}break h}break f}g=g+1|0;if((g|0)!=(e|0)){continue}break}}m=(q-l<<1)+m|0;zc(f+16|0);xb(f+40|0);continue}}xb(c);gb=f- -64|0;return}b=P()|0;O()|0;zc(f+16|0);break d}b=P()|0;O()|0}xb(f+40|0);break a}b=P()|0;O()|0;break a}b=P()|0;O()|0}xb(c);S(b|0);L()}function bia(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;f=gb-48|0;gb=f;p=v[a+16>>2];i=Ud(f+16|0);v[i+8>>2]=a+112;v[i+16>>2]=v[a+128>>2];q=i,r=jg(b+327720|0,v[b+20>>2],(v[a+88>>2]&16384)>>>14|0),v[q+12>>2]=r;b=v[i+16>>2];if(b){q=i,r=lg(a+8|0,b),v[q>>2]=r;v[i+4>>2]=jb}g=v[a+48>>2];m=v[a+40>>2];n=v[a+36>>2];o=v[a+44>>2];h=v[a+4>>2];j=v[a>>2];v[f+8>>2]=j;v[f+12>>2]=h;e=v[a+12>>2];v[f>>2]=v[a+8>>2];v[f+4>>2]=e;a:{if(d){while(1){l=0;e=l;v[f+40>>2]=j;v[f+44>>2]=e;h=(h<<1)+p|0;b:{if((b|0)<=0){break b}while(1){Id(v[i+8>>2],u[(e<<1)+h>>1]/4<<16>>16);Hd(v[i+8>>2],4);Ub(f+40|0,i);if((b|0)<2){break b}b=b-1|0;e=v[f+44>>2];continue}}d=d-1|0;b=v[i+8>>2];Ub(b,b+8|0);b=v[i+8>>2];e=v[b+4>>2];if(e){Id(b,u[h+(v[f+44>>2]<<1)>>1]/4<<16>>16);Hd(v[i+8>>2],e);b=v[i+8>>2];h=v[b>>2];v[b>>2]=h;v[b+4>>2]=0}e=ig(b,v[i+12>>2]);h=v[a+60>>2];j=h;b=Lb(o,-16777216,16776704);k=v[a+64>>2];g=Lb(g,-16777216,16776704);l=h>>31;h=e<<8;e=h;e=kqa(j,l,e,e>>31);j=jb;k=kqa(k,k>>31,b,b>>31);e=k+e|0;b=jb+j|0;b=e>>>0<k>>>0?b+1|0:b;l=e;e=v[a+68>>2];e=kqa(e,e>>31,g,g>>31);g=l+e|0;b=jb+b|0;b=e>>>0>g>>>0?b+1|0:b;g=g+8388608|0;b=g>>>0<8388608?b+1|0:b;g=Jc(g,b,24);e=v[a+72>>2];j=v[a+32>>2];n=v[a+28>>2]+n|0;b=n>>12;l=(g|0)/256|0;v[c>>2]=v[c>>2]+B(b,l);m=j+m|0;k=m>>12;v[c+4>>2]=v[c+4>>2]+B(l,k);e=g-(e&h)|0;Ub(f+8|0,f);if(d){c=c+8|0;b=v[i+16>>2];j=v[f+8>>2];h=v[f+12>>2];g=o;o=e;continue}break}j=v[f+8>>2];h=v[f+12>>2];g=o;break a}k=m>>12;b=n>>12;e=o}v[a+40>>2]=m;v[a+20>>2]=b;v[a+36>>2]=n;v[a+48>>2]=g;v[a+44>>2]=e;v[a+24>>2]=k;v[a>>2]=j;v[a+4>>2]=h;gb=f+48|0}
function Tfa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;d=gb+-64|0;gb=d;c=x[a+480190>>1];t[d+48|0]=0;vR(b,c+1|0,d+48|0);if(x[a+480192>>1]){i=mc(d+48|0);c=a+484344|0;l=d,m=Vb(c),v[l+40>>2]=m;l=d,m=Zb(c),v[l+32>>2]=m;if(Gb(d+40|0,d+32|0)){while(1){a:{h=v[d+40>>2];if(!hi(h)){break a}c=x[a+480188>>1];v[22656]=0;t[d+8|0]=0;U(1130,i|0,c|0,d+8|0);c=v[22656];v[22656]=0;if((c|0)!=1){b:{l=d,m=Vb(h),v[l+24>>2]=m;j=0;if(!v[h+12>>2]){break a}while(1){f=0;c:{if(!x[a+480188>>1]){break c}while(1){d:{c=v[d+24>>2];v[22656]=0;c=Rd(c);e=v[22656];v[22656]=0;if((e|0)==1){break d}e:{if(!c){break e}c=w[v[d+24>>2]+1|0];t[d+23|0]=c;if(!w[v[d+24>>2]+1|0]){c=w[lc(i,f)|0];t[d+23|0]=c}if(c&255){u[d+8>>1]=0;f:{if(x[d+8>>1]>w[d+23|0]){break f}e=v[((w[v[d+24>>2]+1|0]<<2)+a|0)+900380>>2];if(!e){break f}e=x[vd(e+236|0,w[v[d+24>>2]]-1|0)>>1];if(e>>>0>x[a+480190>>1]){break f}g=d+8|0;Ce(g,b,e);Uf(g,1)}l=lc(i,f),m=c,t[l|0]=m;break e}c=x[a+480192>>1];if(!c){break e}e=c;while(1){g=v[((c<<2)+a|0)+900380>>2];g:{if(!g){break g}g=x[vd(g+236|0,w[v[d+24>>2]]-1|0)>>1];if(g>>>0>x[a+480190>>1]){break g}k=d+8|0;Ce(k,b,g);Uf(k,1)}c=c-1|0;e=e-1|0;if(e&65535){continue}break}}bk(d+24|0);f=f+1|0;if(f>>>0<x[a+480188>>1]){continue}break c}break}break b}j=j+1|0;if(j>>>0<y[h+12>>2]){continue}break}break a}}a=P()|0;O()|0;gc(i);S(a|0);L()}c=d+40|0;VO(c);if(Gb(c,d+32|0)){continue}break}}c=x[a+480190>>1];h:{if(!c){f=0;break h}f=0;e=c;while(1){h=d+8|0;Ce(h,b,c);if(!Cb(h)){f=Jd((B(c,104)+a|0)+484380|0)+f|0}c=c-1|0;e=e-1|0;if(e&65535){continue}break}}gc(i)}gb=d- -64|0;return f&65535}function A3(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=+e;var f=0,g=0,h=0,i=0,j=0,k=0,l=0;f=gb-384|0;gb=f;v[f+376>>2]=37;v[f+380>>2]=0;h=Ps(f+376|1,18726,v[c+4>>2]);v[f+332>>2]=f+336;a=xe();a:{if(h){i=v[c+8>>2];A[f+40>>3]=e;v[f+32>>2]=i;a=Ff(f+336|0,30,a,f+376|0,f+32|0);break a}A[f+48>>3]=e;a=Ff(f+336|0,30,a,f+376|0,f+48|0)}v[f+80>>2]=2428;i=ge(f+320|0,0,f+80|0);j=f+336|0;g=j;b:{c:{d:{if((a|0)>=30){e:{if(h){v[22656]=0;a=ga(2448)|0;g=v[22656];v[22656]=0;if((g|0)==1){break c}v[f>>2]=v[c+8>>2];v[22656]=0;A[f+8>>3]=e;a=da(2467,f+332|0,a|0,f+376|0,f|0)|0;g=v[22656];v[22656]=0;if((g|0)!=1){break e}break c}v[22656]=0;a=ga(2448)|0;g=v[22656];v[22656]=0;if((g|0)==1){break c}A[f+16>>3]=e;v[22656]=0;a=da(2467,f+332|0,a|0,f+376|0,f+16|0)|0;g=v[22656];v[22656]=0;if((g|0)==1){break c}}if((a|0)==-1){v[22656]=0;X(2429);a=v[22656];v[22656]=0;if((a|0)==1){break c}break d}Ee(i,v[f+332>>2]);g=v[f+332>>2]}h=a+g|0;k=Tg(g,h,c);v[f+68>>2]=2428;g=ge(f+72|0,0,f+68|0);f:{g:{if(v[f+332>>2]==(f+336|0)){a=f+80|0;break g}a=Cd(a<<3);if(!a){v[22656]=0;X(2429);a=v[22656];v[22656]=0;if((a|0)!=1){break d}c=P()|0;O()|0;break f}Ee(g,a);j=v[f+332>>2]}v[22656]=0;Fc(f+56|0,c);l=v[22656];v[22656]=0;h:{i:{if((l|0)!=1){v[22656]=0;ja(2476,j|0,k|0,h|0,a|0,f+68|0,f- -64|0,f+56|0);h=v[22656];v[22656]=0;if((h|0)==1){break i}Wb(f+56|0);v[22656]=0;a=la(2477,b|0,a|0,v[f+68>>2],v[f+64>>2],c|0,d|0)|0;b=v[22656];v[22656]=0;if((b|0)==1){break h}Ic(g);Ic(i);gb=f+384|0;return a|0}c=P()|0;O()|0;break f}c=P()|0;O()|0;Wb(f+56|0);break f}c=P()|0;O()|0}Ic(g);break b}L()}c=P()|0;O()|0}Ic(i);S(c|0);L()}function M3(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=+e;var f=0,g=0,h=0,i=0,j=0,k=0,l=0;f=gb-208|0;gb=f;v[f+200>>2]=37;v[f+204>>2]=0;h=Ps(f+200|1,18726,v[c+4>>2]);v[f+156>>2]=f+160;a=xe();a:{if(h){i=v[c+8>>2];A[f+40>>3]=e;v[f+32>>2]=i;a=Ff(f+160|0,30,a,f+200|0,f+32|0);break a}A[f+48>>3]=e;a=Ff(f+160|0,30,a,f+200|0,f+48|0)}v[f+80>>2]=2428;i=ge(f+144|0,0,f+80|0);j=f+160|0;g=j;b:{c:{d:{if((a|0)>=30){e:{if(h){v[22656]=0;a=ga(2448)|0;g=v[22656];v[22656]=0;if((g|0)==1){break c}v[f>>2]=v[c+8>>2];v[22656]=0;A[f+8>>3]=e;a=da(2467,f+156|0,a|0,f+200|0,f|0)|0;g=v[22656];v[22656]=0;if((g|0)!=1){break e}break c}v[22656]=0;a=ga(2448)|0;g=v[22656];v[22656]=0;if((g|0)==1){break c}A[f+16>>3]=e;v[22656]=0;a=da(2467,f+156|0,a|0,f+200|0,f+16|0)|0;g=v[22656];v[22656]=0;if((g|0)==1){break c}}if((a|0)==-1){v[22656]=0;X(2429);a=v[22656];v[22656]=0;if((a|0)==1){break c}break d}Ee(i,v[f+156>>2]);g=v[f+156>>2]}h=a+g|0;k=Tg(g,h,c);v[f+68>>2]=2428;g=ge(f+72|0,0,f+68|0);f:{g:{if(v[f+156>>2]==(f+160|0)){a=f+80|0;break g}a=Cd(a<<1);if(!a){v[22656]=0;X(2429);a=v[22656];v[22656]=0;if((a|0)!=1){break d}c=P()|0;O()|0;break f}Ee(g,a);j=v[f+156>>2]}v[22656]=0;Fc(f+56|0,c);l=v[22656];v[22656]=0;h:{i:{if((l|0)!=1){v[22656]=0;ja(2468,j|0,k|0,h|0,a|0,f+68|0,f- -64|0,f+56|0);h=v[22656];v[22656]=0;if((h|0)==1){break i}Wb(f+56|0);v[22656]=0;a=la(17,b|0,a|0,v[f+68>>2],v[f+64>>2],c|0,d|0)|0;b=v[22656];v[22656]=0;if((b|0)==1){break h}Ic(g);Ic(i);gb=f+208|0;return a|0}c=P()|0;O()|0;break f}c=P()|0;O()|0;Wb(f+56|0);break f}c=P()|0;O()|0}Ic(g);break b}L()}c=P()|0;O()|0}Ic(i);S(c|0);L()}function mM(a){var b=C(0),c=0,d=0,e=0,f=0,g=0,h=C(0),i=C(0),k=0,l=C(0);d=gb-16|0;gb=d;k=d,l=C(Zy(z[a+4216>>2])/C(wf(v[a+16>>2])>>>0)),z[k+12>>2]=l;v[d+8>>2]=1056964608;b=Qp(C(z[Gm(d+12|0,d+8|0)>>2]*C(6.2831854820251465)));b=C(K(C(C(C(b+b)+C(3))/C(5))));z[a+4236>>2]=b;z[a+4240>>2]=K(C(C(1)-C(b*b)));f=a;b=C(C(z[a+4212>>2]*C(29))+C(2));a:{if(b<C(4294967296)&b>=C(0)){c=~~b>>>0;break a}c=0}t[f+4272|0]=c;f=a;e=2;b:{if(c>>>0<4){break b}e=3;if(c>>>0<8){break b}e=c>>>0<16?4:5}t[f+4273|0]=e;h=oe(C(10),C(C(C(z[a+4208>>2]*C(60))+C(-60))/C(20)));k=d,l=C(Zy(z[a+4220>>2])/C(wf(v[a+16>>2])>>>0)),z[k+12>>2]=l;v[d+8>>2]=1056964608;i=z[Gm(d+12|0,d+8|0)>>2];k=d,l=C(Zy(z[a+4224>>2])/C(wf(v[a+16>>2])>>>0)),z[k+12>>2]=l;v[d+8>>2]=1056964608;b=C(C(z[Gm(d+12|0,d+8|0)>>2]*C(6.2831854820251465))*C(.5));e=gb-16|0;gb=e;f=(p(b),j(2));c=f&2147483647;c:{if(c>>>0<=1061752794){if(c>>>0<964689920){break c}b=bo(+b,0);break c}if(c>>>0<=1081824209){g=+b;if(c>>>0<=1075235811){b=bo(((f|0)>=0?-1.5707963267948966:1.5707963267948966)+g,1);break c}b=bo(((f|0)>=0?-3.141592653589793:3.141592653589793)+g,0);break c}if(c>>>0<=1088565717){g=+b;if(c>>>0<=1085271519){b=bo(((f|0)>=0?-4.71238898038469:4.71238898038469)+g,1);break c}b=bo(((f|0)>=0?-6.283185307179586:6.283185307179586)+g,0);break c}if(c>>>0>=2139095040){b=C(b-b);break c}c=hy(b,e+8|0);b=bo(A[e+8>>3],c&1)}gb=e+16|0;z[a+4268>>2]=C(C(1)-b)/C(b+C(1));b=Qp(C(i*C(6.2831854820251465)));z[a+4264>>2]=-b;h=C(h*C(K(C(C(1)-C(b*b)))));b=z[a+4268>>2];z[a+4260>>2]=C(h*C(K(C(C(1)-C(b*b)))))*z[(w[a+4272|0]<<2)+51664>>2];gb=d+16|0}function BL(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=C(0);d=gb-48|0;gb=d;a:{b:{c:{d:{e:{switch(b-1|0){case 1:b=(c<<7)/100|0;a=a+24|0;if((b|0)==v[v[a>>2]+24604>>2]){break d}c=d+8|0;hc(c,v[a>>2]+24604|0,40);v[d+8>>2]=b;$z(v[a>>2],c);break d;case 2:f=a+24|0;a=v[f>>2];b=a+24664|0;e=v[b+4>>2];v[d+24>>2]=v[b>>2];v[d+28>>2]=e;b=a+24656|0;e=v[b+4>>2];v[d+16>>2]=v[b>>2];v[d+20>>2]=e;b=v[a+24652>>2];v[d+8>>2]=v[a+24648>>2];v[d+12>>2]=b;e=d;g=gb-16|0;gb=g;b=3;f:{g:{h:{a=c;if(!a|(a|0)>7){break h}b=2;if((a|0)>2){break h}b=1;if((a|0)==2){break h}b=0;if((a|0)>0){break h}b=ba(8)|0;v[22656]=0;c=Q(70,g|0,8063)|0;a=v[22656];v[22656]=0;i:{if((a|0)!=1){rc(b,c);v[22656]=0;U(186,b|0,54952,1936);a=v[22656];v[22656]=0;if((a|0)!=1){break g}a=P()|0;O()|0;vb(c);break i}a=P()|0;O()|0;ca(b|0)}S(a|0);L()}gb=g+16|0;break f}L()}t[e+8|0]=b;if(!Qy(d+8|0,v[f>>2]+24648|0)){break d}_z(v[f>>2],d+8|0);break d;case 3:b=d+8|0;a=a+24|0;hc(b,v[a>>2]+24604|0,40);e=gb-48|0;gb=e;j:{if((c|0)==-1){Jt(b,v[Wq(e+8|0)+32>>2]);Mo(b,v[Wq(e+8|0)+36>>2]);break j}if((c|0)<=0){Jt(b,0);Mo(b,0);break j}c=B(c,1e3);Jt(b,c);Mo(b,c)}gb=e+48|0;if(v[v[a>>2]+24636>>2]==v[d+40>>2]&v[v[a>>2]+24640>>2]==v[d+44>>2]){break d}$z(v[a>>2],d+8|0);break d;default:a=ba(8)|0;v[22656]=0;b=Q(70,d+8|0,7655)|0;c=v[22656];v[22656]=0;if((c|0)==1){break c}rc(a,b);v[22656]=0;U(186,a|0,54952,1936);a=v[22656];v[22656]=0;if((a|0)!=1){break a}c=P()|0;O()|0;vb(b);break b;case 0:break e}}h=a,i=oe(C(10),C(C(C(c|0)*C(.0010000000474974513))*C(.5))),z[h+48>>2]=i}gb=d+48|0;return}c=P()|0;O()|0;ca(a|0)}S(c|0)}L()}function cia(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;f=gb-48|0;gb=f;p=v[a+16>>2];i=Ud(f+16|0);v[i+8>>2]=a+112;v[i+16>>2]=v[a+128>>2];q=i,r=jg(b+327720|0,v[b+20>>2],(v[a+88>>2]&16384)>>>14|0),v[q+12>>2]=r;b=v[i+16>>2];if(b){q=i,r=lg(a+8|0,b),v[q>>2]=r;v[i+4>>2]=jb}g=v[a+48>>2];m=v[a+40>>2];n=v[a+36>>2];o=v[a+44>>2];h=v[a+4>>2];j=v[a>>2];v[f+8>>2]=j;v[f+12>>2]=h;e=v[a+12>>2];v[f>>2]=v[a+8>>2];v[f+4>>2]=e;a:{if(d){while(1){l=0;e=l;v[f+40>>2]=j;v[f+44>>2]=e;h=h+p|0;b:{if((b|0)<=0){break b}while(1){Id(v[i+8>>2],t[e+h|0]<<6);Hd(v[i+8>>2],4);Ub(f+40|0,i);if((b|0)<2){break b}b=b-1|0;e=v[f+44>>2];continue}}d=d-1|0;b=v[i+8>>2];Ub(b,b+8|0);b=v[i+8>>2];e=v[b+4>>2];if(e){Id(b,t[h+v[f+44>>2]|0]<<6);Hd(v[i+8>>2],e);b=v[i+8>>2];h=v[b>>2];v[b>>2]=h;v[b+4>>2]=0}e=ig(b,v[i+12>>2]);h=v[a+60>>2];j=h;b=Lb(o,-16777216,16776704);k=v[a+64>>2];g=Lb(g,-16777216,16776704);l=h>>31;h=e<<8;e=h;e=kqa(j,l,e,e>>31);j=jb;k=kqa(k,k>>31,b,b>>31);e=k+e|0;b=jb+j|0;b=e>>>0<k>>>0?b+1|0:b;l=e;e=v[a+68>>2];e=kqa(e,e>>31,g,g>>31);g=l+e|0;b=jb+b|0;b=e>>>0>g>>>0?b+1|0:b;g=g+8388608|0;b=g>>>0<8388608?b+1|0:b;g=Jc(g,b,24);e=v[a+72>>2];j=v[a+32>>2];n=v[a+28>>2]+n|0;b=n>>12;l=(g|0)/256|0;v[c>>2]=v[c>>2]+B(b,l);m=j+m|0;k=m>>12;v[c+4>>2]=v[c+4>>2]+B(l,k);e=g-(e&h)|0;Ub(f+8|0,f);if(d){c=c+8|0;b=v[i+16>>2];j=v[f+8>>2];h=v[f+12>>2];g=o;o=e;continue}break}j=v[f+8>>2];h=v[f+12>>2];g=o;break a}k=m>>12;b=n>>12;e=o}v[a+40>>2]=m;v[a+20>>2]=b;v[a+36>>2]=n;v[a+48>>2]=g;v[a+44>>2]=e;v[a+24>>2]=k;v[a>>2]=j;v[a+4>>2]=h;gb=f+48|0}function $pa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;f=Kb(a);j=Ab(b);v[22656]=0;R(456,f|0,j|0);a=v[22656];v[22656]=0;a:{b:{c:{d:{e:{if((a|0)!=1){if(!j){break d}a=0;break e}e=P()|0;O()|0;break b}f:{while(1){g:{d=t[pc(b,e)|0];h=d&255;h:{i:{switch(a+1|0){case 1:a=1;j:{switch(h-123|0){case 2:a=3;break h;case 0:break h;default:break j}}a=0;v[22656]=0;W(457,f|0,1,d|0)|0;d=v[22656];v[22656]=0;if((d|0)!=1){break h}break g;case 2:k:{switch(h-123|0){case 0:a=0;v[22656]=0;W(457,f|0,1,123)|0;d=v[22656];v[22656]=0;if((d|0)==1){break g}break h;case 2:l=1;d=g+1|0;a=0;if(ws(c)>>>0<=g>>>0){g=d;break h}g=Ad(c,g);v[22656]=0;Q(458,f|0,g|0)|0;h=v[22656];v[22656]=0;g=d;if((h|0)!=1){break h}e=P()|0;O()|0;break b;default:break k}}a=-1;d=d-48|0;if((d&255)>>>0>9){break h}k=1;a=2;i=d;break h;case 3:a=-1;l:{switch(h-123|0){case 2:a=0;if(ws(c)>>>0<=i>>>0){break h}d=Ad(c,i);v[22656]=0;Q(458,f|0,d|0)|0;d=v[22656];v[22656]=0;if((d|0)!=1){break h}e=P()|0;O()|0;break b;case 0:break h;default:break l}}if((d-48&255)>>>0>9){break h}i=(d+B(i,10)|0)-48|0;k=1;a=2;break h;case 4:a=-1;if((d|0)!=125){break h}a=0;v[22656]=0;W(457,f|0,1,125)|0;d=v[22656];v[22656]=0;if((d|0)==1){break g}break h;case 0:break i;default:break h}}a=-1}e=e+1|0;if((j|0)!=(e|0)){continue}break f}break}e=P()|0;O()|0;break b}if(k&l|a){break c}}return}a=ba(8)|0;v[22656]=0;T(185,a|0)|0;b=v[22656];v[22656]=0;if((b|0)!=1){v[22656]=0;U(186,a|0,27304,24);a=v[22656];v[22656]=0;if((a|0)!=1){break a}e=P()|0;O()|0;break b}e=P()|0;O()|0;ca(a|0)}vb(f);S(e|0)}L()}function m$(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;f=Kb(a);j=Ab(b);v[22656]=0;R(182,f|0,j|0);a=v[22656];v[22656]=0;a:{b:{c:{d:{e:{if((a|0)!=1){if(!j){break d}a=0;break e}e=P()|0;O()|0;break b}f:{while(1){g:{d=t[pc(b,e)|0];h=d&255;h:{i:{switch(a+1|0){case 1:a=1;j:{switch(h-123|0){case 2:a=3;break h;case 0:break h;default:break j}}a=0;v[22656]=0;W(183,f|0,1,d|0)|0;d=v[22656];v[22656]=0;if((d|0)!=1){break h}break g;case 2:k:{switch(h-123|0){case 0:a=0;v[22656]=0;W(183,f|0,1,123)|0;d=v[22656];v[22656]=0;if((d|0)==1){break g}break h;case 2:l=1;d=g+1|0;a=0;if(ws(c)>>>0<=g>>>0){g=d;break h}g=Ad(c,g);v[22656]=0;Q(184,f|0,g|0)|0;h=v[22656];v[22656]=0;g=d;if((h|0)!=1){break h}e=P()|0;O()|0;break b;default:break k}}a=-1;d=d-48|0;if((d&255)>>>0>9){break h}k=1;a=2;i=d;break h;case 3:a=-1;l:{switch(h-123|0){case 2:a=0;if(ws(c)>>>0<=i>>>0){break h}d=Ad(c,i);v[22656]=0;Q(184,f|0,d|0)|0;d=v[22656];v[22656]=0;if((d|0)!=1){break h}e=P()|0;O()|0;break b;case 0:break h;default:break l}}if((d-48&255)>>>0>9){break h}i=(d+B(i,10)|0)-48|0;k=1;a=2;break h;case 4:a=-1;if((d|0)!=125){break h}a=0;v[22656]=0;W(183,f|0,1,125)|0;d=v[22656];v[22656]=0;if((d|0)==1){break g}break h;case 0:break i;default:break h}}a=-1}e=e+1|0;if((j|0)!=(e|0)){continue}break f}break}e=P()|0;O()|0;break b}if(k&l|a){break c}}return}a=ba(8)|0;v[22656]=0;T(185,a|0)|0;b=v[22656];v[22656]=0;if((b|0)!=1){v[22656]=0;U(186,a|0,27304,24);a=v[22656];v[22656]=0;if((a|0)!=1){break a}e=P()|0;O()|0;break b}e=P()|0;O()|0;ca(a|0)}vb(f);S(e|0)}L()}function IH(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;g=gb-272|0;gb=g;i=v[b>>2];v[g+12>>2]=i;m=a?a:g+16|0;e=0;a:{b:{c:{d=a?d:256;if(!i|!d){break c}f=c>>>0>=d>>>0;j=f;if(!(f|c>>>0>32)){break b}while(1){j=j?d:c;c=c-j|0;i=0;n=gb-16|0;gb=n;d:{e:{f:{g:{f=m;if(f){if(j>>>0>=4){break g}h=j;break f}j=0;f=v[g+12>>2];h=v[f>>2];if(!h){break d}while(1){l=1;if(h>>>0>=128){i=-1;l=ql(n+12|0,h,0);if((l|0)==-1){break d}}h=v[f+4>>2];f=f+4|0;j=j+l|0;i=j;if(h){continue}break}break d}l=v[g+12>>2];h=j;while(1){k=v[l>>2];h:{if(k-1>>>0>=127){if(!k){t[f|0]=0;v[g+12>>2]=0;break e}i=-1;k=ql(f,k,0);if((k|0)==-1){break d}h=h-k|0;f=f+k|0;break h}t[f|0]=k;h=h-1|0;l=v[g+12>>2];f=f+1|0}l=l+4|0;v[g+12>>2]=l;if(h>>>0>3){continue}break}}if(h){l=v[g+12>>2];while(1){k=v[l>>2];i:{if(k-1>>>0>=127){if(!k){t[f|0]=0;v[g+12>>2]=0;break e}i=-1;k=ql(n+12|0,k,0);if((k|0)==-1){break d}if(h>>>0<k>>>0){break e}ql(f,v[l>>2],0);h=h-k|0;f=f+k|0;break i}t[f|0]=k;h=h-1|0;l=v[g+12>>2];f=f+1|0}l=l+4|0;v[g+12>>2]=l;if(h){continue}break}}i=j;break d}i=j-h|0}gb=n+16|0;if((i|0)==-1){d=0;i=v[g+12>>2];e=-1;break c}f=(g+16|0)==(m|0)?0:i;m=f+m|0;e=e+i|0;i=v[g+12>>2];d=d-f|0;if(!i|!d){break c}f=c>>>0>=d>>>0;j=f;if(f|c>>>0>32){continue}break}break b}if(!i){break a}}if(!d|!c){break a}j=e;while(1){j:{f=ql(m,v[i>>2],0);k:{if(f+1>>>0<=1){e=-1;if(f){break a}v[g+12>>2]=0;break k}i=v[g+12>>2]+4|0;v[g+12>>2]=i;j=f+j|0;d=d-f|0;if(d){break j}}e=j;break a}m=f+m|0;e=j;c=c-1|0;if(c){continue}break}}if(a){v[b>>2]=v[g+12>>2]}gb=g+272|0;return e|0}function mA(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0;h=89;i=88;j=92;k=91;l=85;m=84;n=83;o=5;p=113;q=111;r=107;s=106;t=96;u=82;v=80;w=78;x=79;y=77;z=57;A=47;d=10;e=8;f=7;c=sA(a);a:{b:{c:{d:{switch(b-1|0){default:a=(b|0)==16777216;if(!a&(b|0)!=32){break c}Ob(c,0,1);Ob(c,7,1);Ob(c,8,1);Ob(c,9,1);Ob(c,10,1);Ob(c,11,1);Ob(c,12,1);Ob(c,13,1);Ob(c,14,1);Ob(c,15,1);Ob(c,16,1);Ob(c,17,1);Ob(c,18,1);Ob(c,19,1);Ob(c,20,1);Ob(c,21,1);Ob(c,22,1);Ob(c,23,1);Ob(c,24,1);Ob(c,25,1);Ob(c,26,1);Ob(c,27,1);Ob(c,28,1);Ob(c,29,1);Ob(c,30,1);Ob(c,31,1);Ob(c,32,1);Ob(c,33,1);Ob(c,34,1);Ob(c,35,1);Ob(c,36,1);Ob(c,37,1);Ob(c,38,1);Ob(c,39,1);Ob(c,40,1);Ob(c,41,1);Ob(c,42,1);Ob(c,43,1);Ob(c,44,1);Ob(c,45,1);Ob(c,46,1);Ob(c,47,1);Ob(c,48,1);Ob(c,103,1);Ob(c,50,1);Ob(c,87,1);Ob(c,88,1);Ob(c,100,1);Ob(c,102,1);Ob(c,104,1);Ob(c,115,1);if(!a){break a}d=111;e=105;f=99;break b;case 3:Ob(c,0,1);Ob(c,4,1);Ob(c,8,1);Ob(c,9,1);Ob(c,10,1);Ob(c,17,1);Ob(c,40,1);Ob(c,51,1);Ob(c,52,1);Ob(c,53,1);Ob(c,54,1);Ob(c,55,1);Ob(c,56,1);Ob(c,57,1);Ob(c,58,1);Ob(c,59,1);Ob(c,60,1);Ob(c,61,1);Ob(c,62,1);Ob(c,63,1);Ob(c,64,1);Ob(c,65,1);Ob(c,66,1);Ob(c,67,1);p=112;q=98;r=93;s=90;t=89;u=86;v=76;w=75;x=74;y=73;z=72;A=71;d=70;e=69;g=68;case 1:Ob(c,g,1);Ob(c,e,1);Ob(c,d,1);Ob(c,A,1);Ob(c,z,1);Ob(c,y,1);Ob(c,x,1);Ob(c,w,1);m=88;o=v;n=u;l=t;k=s;j=r;i=q;h=p;break;case 2:break c;case 0:break d}}Ob(c,o,1);Ob(c,n,1);Ob(c,m,1);Ob(c,l,1);g=k;f=j;e=i;d=h}Ob(c,g,1)}Ob(c,f,1);Ob(c,e,1);Ob(c,d,1)}}function Lia(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,w=0,x=0,y=0,z=0,A=0,C=0,D=0,E=0,F=0,G=0;h=gb-16|0;gb=h;a:{b:{c:{f=v[a+12>>2];j=v[a+8>>2];d:{if((f|0)<=1&j>>>0<=805306368|(f|0)<=0){if((f|0)>=-2&j>>>0>=3489660928|(f|0)>-2){break c}if((f|0)==-2&j>>>0>2147483647|f>>>0>4294967294){break d}break b}if((f|0)==1&j>>>0>2147483648|f>>>0>1){break b}}m=b+196648|0;break a}m=b+131112|0;break a}m=b+262184|0}p=v[a+16>>2];g=v[a+48>>2];q=v[a+24>>2];r=v[a+20>>2];k=v[a+44>>2];e=v[a+4>>2];i=v[a>>2];v[h+8>>2]=i;v[h+12>>2]=e;v[h>>2]=j;v[h+4>>2]=f;e:{if(!d){b=k;k=g;break e}while(1){b=(i>>>16&65520)+m|0;f=u[b>>1];e=(e<<1)+p|0;i=u[e-6>>1];j=u[b+2>>1];s=u[e-4>>1];t=u[b+4>>1];w=u[e-2>>1];x=u[b+6>>1];y=u[e>>1];z=u[b+8>>1];A=u[e+2>>1];C=u[b+10>>1];D=u[e+4>>1];E=u[b+12>>1];F=u[e+6>>1];G=u[b+14>>1];e=u[e+8>>1];o=v[a+60>>2];b=Lb(k,-16777216,16776704);l=v[a+64>>2];g=Lb(g,-16777216,16776704);b=kqa(l,l>>31,b,b>>31);l=jb;n=b;i=(((((((B(j,s)+B(f,i)|0)+B(t,w)|0)+B(x,y)|0)+B(z,A)|0)+B(C,D)|0)+B(E,F)|0)+B(e,G)|0)/32768<<8;b=i;f=kqa(o,o>>31,b,b>>31);e=n+f|0;b=jb+l|0;b=e>>>0<f>>>0?b+1|0:b;n=e;e=v[a+68>>2];e=kqa(e,e>>31,g,g>>31);g=n+e|0;b=jb+b|0;b=e>>>0>g>>>0?b+1|0:b;g=g+8388608|0;b=g>>>0<8388608?b+1|0:b;b=Jc(g,b,24);g=v[a+72>>2];e=(b|0)/256|0;v[c>>2]=v[c>>2]+B(e,r);v[c+4>>2]=v[c+4>>2]+B(e,q);b=b-(g&i)|0;Ub(h+8|0,h);d=d-1|0;if(d){c=c+8|0;i=v[h+8>>2];e=v[h+12>>2];g=k;k=b;continue}break}i=v[h+8>>2];e=v[h+12>>2]}v[a+48>>2]=k;v[a+44>>2]=b;v[a>>2]=i;v[a+4>>2]=e;gb=h+16|0}function jja(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;b=gb-48|0;gb=b;q=v[a+16>>2];l=v[a+44>>2];v[b+32>>2]=l;j=v[a+48>>2];v[b+36>>2]=j;k=v[a+52>>2];v[b+40>>2]=k;i=v[a+56>>2];v[b+44>>2]=i;m=v[a+40>>2];n=v[a+36>>2];e=v[a+4>>2];h=v[a>>2];v[b+24>>2]=h;v[b+28>>2]=e;g=v[a+12>>2];v[b+16>>2]=v[a+8>>2];v[b+20>>2]=g;a:{if(d){while(1){j=h>>>18|0;l=1;e=((((e&2147483647)<<1|h>>>31)&2147483646)<<1)+q|0;g=0;k=1;f=0;while(1){i=f<<1;h=u[i+e>>1];v[(b+8|0)+(f<<2)>>2]=h+((B(j,u[e+(i|4)>>1]-h|0)|0)/16384|0);h=k&1;k=0;f=1;if(h){continue}break}while(1){k=(b+8|0)+(g<<2)|0;f=v[k>>2];j=v[a+60>>2];i=j;h=(b+32|0)+(g<<3)|0;p=v[h>>2];e=Lb(p,-16777216,16776704);o=v[a+64>>2];g=Lb(v[h+4>>2],-16777216,16776704);r=j>>31;j=f<<8;f=j;f=kqa(i,r,f,f>>31);i=jb;o=kqa(o,o>>31,e,e>>31);f=o+f|0;e=jb+i|0;e=f>>>0<o>>>0?e+1|0:e;i=f;f=v[a+68>>2];f=kqa(f,f>>31,g,g>>31);g=i+f|0;e=jb+e|0;e=f>>>0>g>>>0?e+1|0:e;g=g+8388608|0;e=g>>>0<8388608?e+1|0:e;e=Jc(g,e,24);v[h+4>>2]=p;g=v[a+72>>2];v[k>>2]=(e|0)/256;v[h>>2]=e-(g&j);g=1;e=l&1;l=0;if(e){continue}break}e=v[a+32>>2];n=v[a+28>>2]+n|0;f=n>>12;v[c>>2]=v[c>>2]+B(f,v[b+8>>2]);m=e+m|0;g=m>>12;v[c+4>>2]=v[c+4>>2]+B(g,v[b+12>>2]);Ub(b+24|0,b+16|0);d=d-1|0;if(d){c=c+8|0;h=v[b+24>>2];e=v[b+28>>2];continue}break}h=v[b+24>>2];e=v[b+28>>2];i=v[b+44>>2];k=v[b+40>>2];j=v[b+36>>2];l=v[b+32>>2];break a}g=m>>12;f=n>>12}v[a+40>>2]=m;v[a+20>>2]=f;v[a+36>>2]=n;v[a+56>>2]=i;v[a+52>>2]=k;v[a+48>>2]=j;v[a+44>>2]=l;v[a+24>>2]=g;v[a>>2]=h;v[a+4>>2]=e;gb=b+48|0}function Mia(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,w=0,x=0,y=0,z=0,A=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0;h=gb-16|0;gb=h;a:{b:{c:{f=v[a+12>>2];i=v[a+8>>2];d:{if((f|0)<=1&i>>>0<=805306368|(f|0)<=0){if((f|0)>=-2&i>>>0>=3489660928|(f|0)>-2){break c}if((f|0)==-2&i>>>0>2147483647|f>>>0>4294967294){break d}break b}if((f|0)==1&i>>>0>2147483648|f>>>0>1){break b}}m=b+196648|0;break a}m=b+131112|0;break a}m=b+262184|0}o=v[a+16>>2];g=v[a+48>>2];p=v[a+24>>2];q=v[a+20>>2];k=v[a+44>>2];e=v[a+4>>2];j=v[a>>2];v[h+8>>2]=j;v[h+12>>2]=e;v[h>>2]=i;v[h+4>>2]=f;e:{if(!d){b=k;k=g;break e}while(1){b=e+o|0;f=t[b+4|0];e=(j>>>16&65520)+m|0;j=u[e+14>>1];i=t[b+3|0];r=u[e+12>>1];s=t[b+2|0];w=u[e+10>>1];x=t[b+1|0];y=u[e+8>>1];z=t[b|0];A=u[e+6>>1];C=t[b-1|0];D=u[e+4>>1];E=t[b-2|0];F=u[e+2>>1];G=t[b-3|0];e=u[e>>1];b=v[a+60>>2];H=b;I=b>>31;b=Lb(k,-16777216,16776704);l=v[a+64>>2];g=Lb(g,-16777216,16776704);b=kqa(l,l>>31,b,b>>31);l=jb;J=b;b=v[a+68>>2];n=kqa(b,b>>31,g,g>>31);g=J+n|0;b=jb+l|0;b=g>>>0<n>>>0?b+1|0:b;e=(((((((B(E,F)+B(e,G)|0)+B(C,D)|0)+B(z,A)|0)+B(x,y)|0)+B(s,w)|0)+B(i,r)|0)+B(f,j)<<8)/32768<<8;f=kqa(H,I,e,e>>31);g=g+f|0;b=jb+b|0;b=g>>>0<f>>>0?b+1|0:b;g=g+8388608|0;b=g>>>0<8388608?b+1|0:b;b=Jc(g,b,24);g=v[a+72>>2];f=(b|0)/256|0;v[c>>2]=v[c>>2]+B(f,q);v[c+4>>2]=v[c+4>>2]+B(f,p);b=b-(g&e)|0;Ub(h+8|0,h);d=d-1|0;if(d){c=c+8|0;j=v[h+8>>2];e=v[h+12>>2];g=k;k=b;continue}break}j=v[h+8>>2];e=v[h+12>>2]}v[a+48>>2]=k;v[a+44>>2]=b;v[a>>2]=j;v[a+4>>2]=e;gb=h+16|0}function kja(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;b=gb-48|0;gb=b;r=v[a+16>>2];j=v[a+44>>2];v[b+32>>2]=j;l=v[a+48>>2];v[b+36>>2]=l;k=v[a+52>>2];v[b+40>>2]=k;h=v[a+56>>2];v[b+44>>2]=h;m=v[a+40>>2];n=v[a+36>>2];e=v[a+4>>2];i=v[a>>2];v[b+24>>2]=i;v[b+28>>2]=e;f=v[a+12>>2];v[b+16>>2]=v[a+8>>2];v[b+20>>2]=f;a:{if(d){while(1){j=i>>>10&4194048;e=(((e&2147483647)<<1|i>>>31)&-2)+r|0;g=0;l=1;k=1;f=0;while(1){i=t[e+f|0];v[(b+8|0)+(f<<2)>>2]=((B(j,t[e+(f|2)|0]-i|0)|0)/16384|0)+(i<<8);i=k&1;k=0;f=1;if(i){continue}break}while(1){k=(b+8|0)+(g<<2)|0;j=v[k>>2];h=v[a+60>>2];o=h;i=(b+32|0)+(g<<3)|0;q=v[i>>2];e=Lb(q,-16777216,16776704);g=v[a+64>>2];f=Lb(v[i+4>>2],-16777216,16776704);p=h>>31;j=j<<8;h=j;h=kqa(o,p,h,h>>31);o=jb;p=h;h=kqa(g,g>>31,e,e>>31);g=p+h|0;e=jb+o|0;e=g>>>0<h>>>0?e+1|0:e;h=g;g=v[a+68>>2];g=kqa(g,g>>31,f,f>>31);f=h+g|0;e=jb+e|0;e=f>>>0<g>>>0?e+1|0:e;f=f+8388608|0;e=f>>>0<8388608?e+1|0:e;e=Jc(f,e,24);v[i+4>>2]=q;f=v[a+72>>2];v[k>>2]=(e|0)/256;v[i>>2]=e-(f&j);g=1;e=l&1;l=0;if(e){continue}break}e=v[a+32>>2];n=v[a+28>>2]+n|0;g=n>>12;v[c>>2]=v[c>>2]+B(g,v[b+8>>2]);m=e+m|0;f=m>>12;v[c+4>>2]=v[c+4>>2]+B(f,v[b+12>>2]);Ub(b+24|0,b+16|0);d=d-1|0;if(d){c=c+8|0;i=v[b+24>>2];e=v[b+28>>2];continue}break}i=v[b+24>>2];e=v[b+28>>2];h=v[b+44>>2];k=v[b+40>>2];l=v[b+36>>2];j=v[b+32>>2];break a}f=m>>12;g=n>>12}v[a+40>>2]=m;v[a+20>>2]=g;v[a+36>>2]=n;v[a+56>>2]=h;v[a+52>>2]=k;v[a+48>>2]=l;v[a+44>>2]=j;v[a+24>>2]=f;v[a>>2]=i;v[a+4>>2]=e;gb=b+48|0}function nfa(a,b){a=a|0;b=b|0;var c=0,d=0;c=gb-112|0;gb=c;d=c+88|0;Tm(d,b,1413829443);v[22656]=0;b=T(275,d|0)|0;d=v[22656];v[22656]=0;a:{b:{c:{if((d|0)==1){break c}if(!b){v[22656]=0;U(1430,c- -64|0,a+140|0,1413894985);a=v[22656];v[22656]=0;d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{if((a|0)!=1){v[22656]=0;a=Q(1435,c- -64|0,10951)|0;b=v[22656];v[22656]=0;if((b|0)==1){break e}b=28591;if(a){b=Kb(c+48|0);v[22656]=0;a=T(467,c- -64|0)|0;d=v[22656];v[22656]=0;if((d|0)==1){break m}v[22656]=0;W(413,c- -64|0,b|0,a|0)|0;a=v[22656];v[22656]=0;if((a|0)==1){break m}v[22656]=0;d=Q(69,c+16|0,b|0)|0;a=v[22656];v[22656]=0;if((a|0)==1){break l}v[22656]=0;_(1436,c|0);a=v[22656];v[22656]=0;if((a|0)==1){break k}v[22656]=0;U(1437,c+32|0,d|0,c|0);a=v[22656];v[22656]=0;if((a|0)==1){break j}a=c+32|0;Eb(b,a);vb(a);vb(c);vb(d);v[22656]=0;U(13,a|0,2,b|0);a=v[22656];v[22656]=0;if((a|0)==1){break h}v[22656]=0;a=T(972,c+32|0)|0;d=v[22656];v[22656]=0;if((d|0)==1){break g}vb(c+32|0);vb(b);b=a-1>>>0<19398657?1252:28591}xb(c- -64|0);break a}a=P()|0;O()|0;break b}a=P()|0;O()|0;break f}a=P()|0;O()|0;break f}a=P()|0;O()|0;break i}a=P()|0;O()|0;vb(c)}vb(d);break f}a=P()|0;O()|0;break f}a=P()|0;O()|0;vb(c+32|0)}vb(b);break d}a=P()|0;O()|0}xb(c- -64|0);break b}v[22656]=0;a=Q(191,c+88|0,2)|0;b=v[22656];v[22656]=0;if((b|0)==1){break c}b=28591;if(!a){break a}v[22656]=0;b=T(287,c+88|0)|0;a=v[22656];v[22656]=0;if((a|0)!=1){break a}a=P()|0;O()|0;break b}a=P()|0;O()|0}xb(c+88|0);S(a|0);L()}xb(c+88|0);gb=c+112|0;return b|0}function Zia(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;e=gb-48|0;gb=e;o=v[a+16>>2];b=v[a+44>>2];v[e+32>>2]=b;g=v[a+48>>2];v[e+36>>2]=g;f=v[a+52>>2];v[e+40>>2]=f;l=v[a+56>>2];v[e+44>>2]=l;p=v[a+24>>2];q=v[a+20>>2];h=v[a+4>>2];k=v[a>>2];v[e+24>>2]=k;v[e+28>>2]=h;i=v[a+12>>2];v[e+16>>2]=v[a+8>>2];v[e+20>>2]=i;if(d){while(1){l=1;i=((((h&2147483647)<<1|k>>>31)&2147483646)<<1)+o|0;b=k>>>21&2040;k=u[b+46166>>1];j=u[b+46164>>1];m=u[b+46162>>1];n=u[b+46160>>1];f=0;b=1;g=0;while(1){h=g<<1;v[(e+8|0)+(g<<2)>>2]=(((B(u[h+i>>1],m)+B(u[i+(h|-4)>>1],n)|0)+B(u[i+(h|4)>>1],j)|0)+B(k,u[i+(h|8)>>1])|0)/16384;h=b;b=0;g=1;if(h){continue}break}while(1){k=(e+8|0)+(f<<2)|0;i=v[k>>2];j=v[a+60>>2];m=j;h=(e+32|0)+(f<<3)|0;n=v[h>>2];b=Lb(n,-16777216,16776704);f=v[a+64>>2];g=Lb(v[h+4>>2],-16777216,16776704);j=j>>31;i=i<<8;j=kqa(m,j,i,i>>31);m=jb;r=j;j=kqa(f,f>>31,b,b>>31);f=r+j|0;b=jb+m|0;b=f>>>0<j>>>0?b+1|0:b;j=f;f=v[a+68>>2];f=kqa(f,f>>31,g,g>>31);g=j+f|0;b=jb+b|0;b=g>>>0<f>>>0?b+1|0:b;g=g+8388608|0;b=g>>>0<8388608?b+1|0:b;b=Jc(g,b,24);v[h+4>>2]=n;g=v[a+72>>2];v[k>>2]=(b|0)/256;v[h>>2]=b-(g&i);f=1;b=l&1;l=0;if(b){continue}break}v[c>>2]=v[c>>2]+B(v[e+8>>2],q);v[c+4>>2]=v[c+4>>2]+B(v[e+12>>2],p);Ub(e+24|0,e+16|0);d=d-1|0;if(d){c=c+8|0;k=v[e+24>>2];h=v[e+28>>2];continue}break}k=v[e+24>>2];h=v[e+28>>2];l=v[e+44>>2];f=v[e+40>>2];g=v[e+36>>2];b=v[e+32>>2]}v[a+56>>2]=l;v[a+52>>2]=f;v[a+48>>2]=g;v[a+44>>2]=b;v[a>>2]=k;v[a+4>>2]=h;gb=e+48|0}function V3(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0;a=gb-384|0;gb=a;v[a+368>>2]=c;v[a+376>>2]=b;Ax(a+216|0,d,a+240|0,a+236|0,a+232|0);d=Kb(a+200|0);b=Kc(d);v[22656]=0;R(76,d|0,b|0);b=v[22656];v[22656]=0;a:{b:{c:{if((b|0)!=1){c=pc(d,0);v[a+196>>2]=c;v[a+28>>2]=a+32;v[a+24>>2]=0;t[a+23|0]=1;t[a+22|0]=69;b=v[a+232>>2];h=v[a+236>>2];while(1){d:{v[22656]=0;g=Q(2457,a+376|0,a+368|0)|0;i=v[22656];v[22656]=0;if((i|0)==1){break d}if(!g){break c}if(v[a+196>>2]==(Ab(d)+c|0)){g=Ab(d);c=Ab(d);v[22656]=0;R(76,d|0,c<<1);c=v[22656];v[22656]=0;if((c|0)==1){break b}c=Kc(d);v[22656]=0;R(76,d|0,c|0);c=v[22656];v[22656]=0;if((c|0)==1){break b}c=pc(d,0);v[a+196>>2]=g+c}v[22656]=0;g=T(2459,a+376|0)|0;i=v[22656];v[22656]=0;if((i|0)==1){break d}if(zx(g,a+23|0,a+22|0,c,a+196|0,h,b,a+216|0,a+32|0,a+28|0,a+24|0,a+240|0)){break c}v[22656]=0;T(2461,a+376|0)|0;g=v[22656];v[22656]=0;if((g|0)!=1){continue}}break}break b}break b}e:{if(!Ab(a+216|0)|!w[a+23|0]){break e}b=v[a+28>>2];if((b-(a+32|0)|0)>159){break e}v[a+28>>2]=b+4;v[b>>2]=v[a+24>>2]}v[22656]=0;Y(2447,a|0,c|0,v[a+196>>2],e|0);b=v[22656];v[22656]=0;f:{if((b|0)==1){break f}b=v[a+8>>2];c=v[a+12>>2];h=v[a+4>>2];v[f>>2]=v[a>>2];v[f+4>>2]=h;v[f+8>>2]=b;v[f+12>>2]=c;jf(a+216|0,a+32|0,v[a+28>>2],e);v[22656]=0;b=Q(2458,a+376|0,a+368|0)|0;c=v[22656];v[22656]=0;if((c|0)==1){break f}if(b){v[e>>2]=v[e>>2]|2}b=v[a+376>>2];vb(d);vb(a+216|0);gb=a+384|0;break a}}b=P()|0;O()|0;vb(d);vb(a+216|0);S(b|0);L()}return b|0}function h4(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0;a=gb-288|0;gb=a;v[a+272>>2]=c;v[a+280>>2]=b;Dx(a+224|0,d,a+240|0,a+239|0,a+238|0);d=Kb(a+208|0);b=Kc(d);v[22656]=0;R(76,d|0,b|0);b=v[22656];v[22656]=0;a:{b:{c:{if((b|0)!=1){c=pc(d,0);v[a+204>>2]=c;v[a+28>>2]=a+32;v[a+24>>2]=0;t[a+23|0]=1;t[a+22|0]=69;b=t[a+238|0];h=t[a+239|0];while(1){d:{v[22656]=0;g=Q(2430,a+280|0,a+272|0)|0;i=v[22656];v[22656]=0;if((i|0)==1){break d}if(!g){break c}if(v[a+204>>2]==(Ab(d)+c|0)){g=Ab(d);c=Ab(d);v[22656]=0;R(76,d|0,c<<1);c=v[22656];v[22656]=0;if((c|0)==1){break b}c=Kc(d);v[22656]=0;R(76,d|0,c|0);c=v[22656];v[22656]=0;if((c|0)==1){break b}c=pc(d,0);v[a+204>>2]=g+c}v[22656]=0;g=T(2432,a+280|0)|0;i=v[22656];v[22656]=0;if((i|0)==1){break d}if(Cx(g,a+23|0,a+22|0,c,a+204|0,h,b,a+224|0,a+32|0,a+28|0,a+24|0,a+240|0)){break c}v[22656]=0;T(2434,a+280|0)|0;g=v[22656];v[22656]=0;if((g|0)!=1){continue}}break}break b}break b}e:{if(!Ab(a+224|0)|!w[a+23|0]){break e}b=v[a+28>>2];if((b-(a+32|0)|0)>159){break e}v[a+28>>2]=b+4;v[b>>2]=v[a+24>>2]}v[22656]=0;Y(2447,a|0,c|0,v[a+204>>2],e|0);b=v[22656];v[22656]=0;f:{if((b|0)==1){break f}b=v[a+8>>2];c=v[a+12>>2];h=v[a+4>>2];v[f>>2]=v[a>>2];v[f+4>>2]=h;v[f+8>>2]=b;v[f+12>>2]=c;jf(a+224|0,a+32|0,v[a+28>>2],e);v[22656]=0;b=Q(2431,a+280|0,a+272|0)|0;c=v[22656];v[22656]=0;if((c|0)==1){break f}if(b){v[e>>2]=v[e>>2]|2}b=v[a+280>>2];vb(d);vb(a+224|0);gb=a+288|0;break a}}b=P()|0;O()|0;vb(d);vb(a+224|0);S(b|0);L()}return b|0}function SU(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;f=gb-16|0;gb=f;a:{if((b|0)==(c|0)){break a}v[f+12>>2]=-1953789045;ZB(b,c,f+12|0);c=c-b>>2;v[f+8>>2]=c;e=1;j=Nb(a);h=j+1|0;v[f+4>>2]=h;k=v[Lc(f+4|0,f+8|0)>>2];g=v[((v[f+8>>2]<<2)+b|0)-4>>2];i=c;d=11;b:{if(c>>>0>622){break b}d=7;if(c>>>0>67){break b}d=5;if(c>>>0>38){break b}d=3;if(c>>>0>6){break b}d=c-1>>>1|0}l=i-d>>>1|0;c=(l<<2)+b|0;i=B(cv(g^(v[c>>2]^v[b>>2])),1664525);v[c>>2]=i+v[c>>2];m=d+l|0;c=(m<<2)+b|0;d=c;g=v[c>>2];c=j+i|0;v[d>>2]=g+c;v[b>>2]=c;c=v[f+8>>2];if(j){while(1){g=e-1|0;d=((e+l>>>0)%(c>>>0)<<2)+b|0;n=(e>>>0)%(c>>>0)|0;o=(n<<2)+b|0;i=B(cv(v[((g>>>0)%(c>>>0)<<2)+b>>2]^(v[d>>2]^v[o>>2])),1664525);v[d>>2]=i+v[d>>2];d=Mb(a,g);c=v[f+8>>2];g=((e+m>>>0)%(c>>>0)<<2)+b|0;d=v[d>>2]+(i+n|0)|0;v[g>>2]=d+v[g>>2];v[o>>2]=d;e=e+1|0;if(j>>>0>=e>>>0){continue}break}}if(h>>>0<k>>>0){while(1){a=((h+l>>>0)%(c>>>0)<<2)+b|0;d=(h>>>0)%(c>>>0)|0;j=(d<<2)+b|0;e=B(cv(v[((h-1>>>0)%(c>>>0)<<2)+b>>2]^(v[a>>2]^v[j>>2])),1664525);v[a>>2]=e+v[a>>2];c=v[f+8>>2];a=((h+m>>>0)%(c>>>0)<<2)+b|0;i=a;g=v[a>>2];a=e+d|0;v[i>>2]=g+a;v[j>>2]=a;h=h+1|0;if((k|0)!=(h|0)){continue}break}}if(c+k>>>0<=k>>>0){break a}e=k;while(1){a=((e+l>>>0)%(c>>>0)<<2)+b|0;d=(e>>>0)%(c>>>0)|0;j=(d<<2)+b|0;h=B(cv(v[((e-1>>>0)%(c>>>0)<<2)+b>>2]+(v[a>>2]+v[j>>2]|0)|0),1566083941);v[a>>2]=h^v[a>>2];c=v[f+8>>2];a=((e+m>>>0)%(c>>>0)<<2)+b|0;i=a;g=v[a>>2];a=h-d|0;v[i>>2]=g^a;v[j>>2]=a;e=e+1|0;if(e>>>0<c+k>>>0){continue}break}}gb=f+16|0}function _ia(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;e=gb-48|0;gb=e;o=v[a+16>>2];f=v[a+44>>2];v[e+32>>2]=f;b=v[a+48>>2];v[e+36>>2]=b;g=v[a+52>>2];v[e+40>>2]=g;l=v[a+56>>2];v[e+44>>2]=l;p=v[a+24>>2];q=v[a+20>>2];j=v[a+4>>2];k=v[a>>2];v[e+24>>2]=k;v[e+28>>2]=j;h=v[a+12>>2];v[e+16>>2]=v[a+8>>2];v[e+20>>2]=h;if(d){while(1){h=(((j&2147483647)<<1|k>>>31)&-2)+o|0;b=k>>>21&2040;k=u[b+46166>>1];i=u[b+46164>>1];m=u[b+46162>>1];n=u[b+46160>>1];g=0;l=1;b=1;f=0;while(1){v[(e+8|0)+(f<<2)>>2]=(((B(t[f+h|0],m)+B(t[h+(f|-2)|0],n)|0)+B(t[h+(f|2)|0],i)|0)+B(k,t[h+(f|4)|0])<<8)/16384;j=b;b=0;f=1;if(j){continue}break}while(1){k=(e+8|0)+(g<<2)|0;h=v[k>>2];i=v[a+60>>2];m=i;j=(e+32|0)+(g<<3)|0;n=v[j>>2];b=Lb(n,-16777216,16776704);g=v[a+64>>2];f=Lb(v[j+4>>2],-16777216,16776704);i=i>>31;h=h<<8;i=kqa(m,i,h,h>>31);m=jb;r=i;i=kqa(g,g>>31,b,b>>31);g=r+i|0;b=jb+m|0;b=g>>>0<i>>>0?b+1|0:b;i=g;g=v[a+68>>2];g=kqa(g,g>>31,f,f>>31);f=i+g|0;b=jb+b|0;b=f>>>0<g>>>0?b+1|0:b;f=f+8388608|0;b=f>>>0<8388608?b+1|0:b;b=Jc(f,b,24);v[j+4>>2]=n;f=v[a+72>>2];v[k>>2]=(b|0)/256;v[j>>2]=b-(f&h);g=1;b=l&1;l=0;if(b){continue}break}v[c>>2]=v[c>>2]+B(v[e+8>>2],q);v[c+4>>2]=v[c+4>>2]+B(v[e+12>>2],p);Ub(e+24|0,e+16|0);d=d-1|0;if(d){c=c+8|0;k=v[e+24>>2];j=v[e+28>>2];continue}break}k=v[e+24>>2];j=v[e+28>>2];l=v[e+44>>2];g=v[e+40>>2];f=v[e+32>>2];b=v[e+36>>2]}v[a+56>>2]=l;v[a+52>>2]=g;v[a+48>>2]=b;v[a+44>>2]=f;v[a>>2]=k;v[a+4>>2]=j;gb=e+48|0}function fia(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;f=gb-48|0;gb=f;m=v[a+16>>2];h=Ud(f+16|0);v[h+8>>2]=a+112;v[h+16>>2]=v[a+128>>2];q=h,r=jg(b+327720|0,v[b+20>>2],(v[a+88>>2]&16384)>>>14|0),v[q+12>>2]=r;b=v[h+16>>2];if(b){q=h,r=lg(a+8|0,b),v[q>>2]=r;v[h+4>>2]=jb}i=v[a+48>>2];n=v[a+24>>2];o=v[a+20>>2];k=v[a+44>>2];g=v[a+4>>2];j=v[a>>2];v[f+8>>2]=j;v[f+12>>2]=g;e=v[a+12>>2];v[f>>2]=v[a+8>>2];v[f+4>>2]=e;a:{if(!d){e=k;k=i;break a}while(1){e=0;v[f+40>>2]=j;v[f+44>>2]=e;g=(g<<1)+m|0;b:{if((b|0)<=0){break b}while(1){Id(v[h+8>>2],u[(e<<1)+g>>1]/4<<16>>16);Hd(v[h+8>>2],4);Ub(f+40|0,h);if((b|0)<2){break b}b=b-1|0;e=v[f+44>>2];continue}}d=d-1|0;b=v[h+8>>2];Ub(b,b+8|0);b=v[h+8>>2];e=v[b+4>>2];if(e){Id(b,u[g+(v[f+44>>2]<<1)>>1]/4<<16>>16);Hd(v[h+8>>2],e);b=v[h+8>>2];g=v[b>>2];v[b>>2]=g;v[b+4>>2]=0}e=ig(b,v[h+12>>2]);g=v[a+60>>2];j=g;b=Lb(k,-16777216,16776704);l=v[a+64>>2];i=Lb(i,-16777216,16776704);p=g>>31;g=e<<8;e=g;e=kqa(j,p,e,e>>31);j=jb;l=kqa(l,l>>31,b,b>>31);e=l+e|0;b=jb+j|0;b=e>>>0<l>>>0?b+1|0:b;j=e;e=v[a+68>>2];e=kqa(e,e>>31,i,i>>31);i=j+e|0;b=jb+b|0;b=e>>>0>i>>>0?b+1|0:b;i=i+8388608|0;b=i>>>0<8388608?b+1|0:b;b=Jc(i,b,24);i=v[a+72>>2];e=(b|0)/256|0;v[c>>2]=v[c>>2]+B(e,o);v[c+4>>2]=v[c+4>>2]+B(e,n);e=b-(g&i)|0;Ub(f+8|0,f);if(d){c=c+8|0;b=v[h+16>>2];j=v[f+8>>2];g=v[f+12>>2];i=k;k=e;continue}break}j=v[f+8>>2];g=v[f+12>>2]}v[a+48>>2]=k;v[a+44>>2]=e;v[a>>2]=j;v[a+4>>2]=g;gb=f+48|0}function Koa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;f=gb-32|0;gb=f;t[f+24|0]=44;v[f+16>>2]=-1;v[f+20>>2]=0;v[f+8>>2]=1042;v[f+12>>2]=2;n=a;o=b;c=gb+-64|0;gb=c;p=c;j=f+8|0;b=v[j>>2]&2?16:10;g=gb-32|0;gb=g;d=He(g+16|0,1,0);a:{b:{c:{while(1){i=g+8|0;k=Jb(d);l=Jb(d)+Ab(d)|0;h=x[o>>1];e=b;d:{if((e|0)!=10){a=l;while(1){e:{if((a|0)==(k|0)){a=k;break e}m=h&65535;h=(m|0)/(e|0)|0;a=a-1|0;t[a|0]=w[(m-B(e,h)|0)+1991|0];if(h&65535){continue}}break}f:{if(!(h&65535)){e=l-a|0;if(e){break f}}v[i+4>>2]=61;v[i>>2]=l;break d}a=yh(k,a,e);v[i+4>>2]=0;v[i>>2]=a+e;break d}AA(i,k,l,h)}if(!v[g+12>>2]){break c}a=Ab(d);v[22656]=0;v[g+4>>2]=a;e=xf(g+4|0);a=v[22656];v[22656]=0;if((a|0)!=1){v[22656]=0;U(75,d|0,e|0,0);a=v[22656];v[22656]=0;if((a|0)!=1){continue}}break}break b}b=v[g+8>>2];a=Jb(d);v[22656]=0;R(76,d|0,b-a|0);a=v[22656];v[22656]=0;g:{if((a|0)!=1){v[22656]=0;R(86,p|0,d|0);a=v[22656];v[22656]=0;if((a|0)!=1){break g}break b}break b}vb(d);gb=g+32|0;break a}a=P()|0;O()|0;vb(d);S(a|0);L()}a=c+16|0;Ml(a,c,j);v[22656]=0;U(93,c+32|0,a|0,j|0);a=v[22656];v[22656]=0;h:{i:{j:{k:{l:{if((a|0)!=1){v[22656]=0;U(94,c+48|0,c+32|0,j|0);a=v[22656];v[22656]=0;if((a|0)==1){break l}v[22656]=0;R(85,n|0,c+48|0);a=v[22656];v[22656]=0;if((a|0)==1){break k}vb(c+48|0);vb(c+32|0);vb(c+16|0);vb(c);gb=c- -64|0;break h}a=P()|0;O()|0;break i}a=P()|0;O()|0;break j}a=P()|0;O()|0;vb(c+48|0)}vb(c+32|0)}vb(c+16|0);vb(c);S(a|0);L()}gb=f+32|0}function Xz(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;j=gb-16|0;gb=j;k=j;a:{if(!Mj(c)){h=b;i=v[c+704>>2];g=gb-16|0;gb=g;v[g+12>>2]=d;f=0;b:{if(!d){break b}if(v[h+480180>>2]&20){e=h+1074312|0;Db(g,e,73);d=Cb(g)?d&65535:d;if(w[h+480208|0]&16){Db(g,e,73);e=Cb(g)?14-((9983-d>>>0)/768|0)&31:((d>>>0)/768|0)+2|0;f=v[((d>>>0)%768<<2)+40384>>2]<<6>>>e|0;break b}if(!d){v[g+12>>2]=1;d=1}f=229079296/(d>>>0)|0;break b}f=227001280/(d>>>0)|0;if(_l(h)){break b}f=(d+i<<4)-133808|0;if(v[h+480180>>2]==64){break b}d=v[h+480180>>2];qc(g+12|0,16777215);if(d&17408){f=Qc(nqa(kqa(i?i:8363,0,3506176,0),jb,(v[g+12>>2]<<8)+e|0,0),jb);break b}if(Hj(h)){f=e>>31;d=v[g+12>>2];h=d>>>24|0;i=d<<8;e=i+e|0;d=h+f|0;d=e>>>0<i>>>0?d+1|0:d;f=(d&15)<<28|e>>>4;break b}if(w[h+480208|0]&16){f=Qc(nqa(kqa(i?i:8363,0,7012352,0),jb,(v[g+12>>2]<<8)+e|0,0),jb);break b}f=Qc(nqa(-1485242368,13,(v[g+12>>2]<<8)+e|0,0),jb)}gb=g+16|0;e=f;break a}e=v[c+700>>2]}v[k+12>>2]=e;d=v[c+656>>2];c=u[c+774>>1];c:{if(!c){break c}c=d?B(t[d+33|0],c):c;if(!c){break c}e=Ah(Ek(+(c|0)/393216)*+(e>>>0));v[j+12>>2]=e}d:{if(!d){break d}c=v[d+40>>2];if(!c){break d}d=(c|0)/2|0;f=v[b+1074420>>2];f=kqa(f,f>>31,e,e>>31);e=d+f|0;d=jb+(d>>31)|0;l=j,m=Ac(lqa(e,e>>>0<f>>>0?d+1|0:d,c,c>>31),jb),v[l+12>>2]=m}qc(j+12|0,2147483647);c=j;l=c,m=lqa(0,v[c+12>>2],v[b+24620>>2]<<4,0),v[l>>2]=m;v[c+4>>2]=jb;b=v[c+4>>2];v[a>>2]=v[c>>2];v[a+4>>2]=b;v[a+8>>2]=v[c+12>>2];gb=c+16|0}function zla(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;if(v[a+4>>2]!=v[wb(a)>>2]){c=gb-16|0;gb=c;v[c>>2]=a;a=v[a+4>>2];v[c+4>>2]=a;v[c+8>>2]=a+56;a=c;d=v[a+4>>2];v[22656]=0;R(866,d|0,b|0);b=v[22656];v[22656]=0;a:{if((b|0)!=1){v[a+4>>2]=v[a+4>>2]+56;$b(a);gb=c+16|0;break a}b=P()|0;O()|0;$b(a);S(b|0);L()}return}l=gb-32|0;gb=l;j=a;e=wb(a);f=l+8|0;g=a;d=dr(a)+1|0;h=gb-16|0;gb=h;v[h+12>>2]=d;i=gb-16|0;gb=i;v[i+12>>2]=76695844;v[22656]=0;v[i+8>>2]=2147483647;k=Fb(i+12|0,i+8|0);c=v[22656];v[22656]=0;b:{if((c|0)!=1){gb=i+16|0;c=v[k>>2];break b}V(0)|0;O()|0;Bb();L()}c:{if(c>>>0>=d>>>0){d=HU(g);if(d>>>0<c>>>1>>>0){v[h+8>>2]=d<<1;c=v[Lc(h+8|0,h+12|0)>>2]}gb=h+16|0;break c}Sc();L()}d=dr(a);a=0;g=gb-16|0;gb=g;v[g+12>>2]=0;kf(f+12|0,e);if(c){a=c;if(a>>>0>=76695845){rd(8445);L()}a=Mc(B(a,56),4)}v[f>>2]=a;d=B(d,56)+a|0;v[f+8>>2]=d;v[f+4>>2]=d;m=dc(f),n=B(c,56)+a|0,v[m>>2]=n;gb=g+16|0;a=f;c=v[a+8>>2];v[22656]=0;R(866,c|0,b|0);b=v[22656];v[22656]=0;d:{if((b|0)!=1){v[a+8>>2]=v[a+8>>2]+56;b=a;f=a+4|0;k=f;c=v[j+4>>2];g=v[j>>2];if((c|0)!=(g|0)){d=v[k>>2];while(1){e=d-56|0;c=c-56|0;$u(e,c);$u(e+12|0,c+12|0);YB(e+24|0,c+24|0);u[e+52>>1]=x[c+52>>1];d=v[c+48>>2];v[e+44>>2]=v[c+44>>2];v[e+48>>2]=d;d=v[c+40>>2];v[e+36>>2]=v[c+36>>2];v[e+40>>2]=d;d=v[k>>2]-56|0;v[k>>2]=d;if((c|0)!=(g|0)){continue}break}}wc(j,f);wc(j+4|0,b+8|0);wc(wb(j),dc(b));v[b>>2]=v[b+4>>2];GU(a);gb=l+32|0;break d}b=P()|0;O()|0;GU(a);S(b|0);L()}}function MZ(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0;g=gb-32|0;gb=g;vc(c);a:{if(!Pb(c,3)){break a}while(1){e=g+24|0;Vr(e,c);f=qd(e);i=Ve(e);if(y[a+12>>2]<=w[e|0]){break a}h=Yc(a,w[e|0],b);e=w[f|0];b:{if(e>>>0<=126){if(!(e|w[i|0])){t[h|0]=254;break b}t[h|0]=e+1;if(w[i|0]==255){break b}t[h+2|0]=1;t[h+4|0]=w[i|0];break b}c:{switch(e-127|0){case 1:t[h+1|0]=w[i|0]+1;break b;case 0:break b;default:break c}}d=t[i|0];t[g+23|0]=d;i=0;e=e&127;if(e>>>0<=23){i=w[e+28432|0]}e=g;d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{j=w[f|0];switch((j&127)-2|0){case 21:break h;case 18:break i;case 17:break j;case 16:case 20:break k;case 15:break l;case 2:break m;case 1:break n;case 0:case 8:case 9:break o;default:break e}}if((d|0)>=0){break g}f=0-d&15;break f}t[g+16|0]=64;d=w[ac(g+23|0,g+16|0)|0];if(w[h+2|0]>1){break e}t[h+4|0]=d;t[h+2|0]=1;break b}f=3;if((d|0)>=0){break d}f=0-d&127;break f}if(!d){break b}f=0-d|-16;if((d|0)<0){break f}f=d<<4|15;break f}if(!d){break b}e=(d|0)>=0;if(!e){d=0-d&15;t[g+23|0]=d;j=w[f|0]}f=e?3:2;d=((j|0)==22?-32:-16)|d;t[g+23|0]=d;break d}f=d&15|-48;break f}f=d&15|-64;break f}f=164;if((d|0)==100){break f}v[g+16>>2]=d- -64;v[g+12>>2]=0;v[g+8>>2]=128;d=v[dj(g+16|0,g+12|0,g+8|0)>>2];if(!w[h+3|0]){break e}p:{switch(w[h+2|0]){case 0:case 2:break p;default:break b}}t[h+2|0]=2;t[h+4|0]=(d&254)>>>1;break b}f=d<<4}d=f;t[e+23|0]=d}f=i;if(!i){break b}}t[h+5|0]=d;t[h+3|0]=f}if(Pb(c,3)){continue}break}}gb=g+32|0}function Rma(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;e=gb-16|0;gb=e;a:{if((c|0)!=4){g=b+236|0;h=b+108|0;while(1){f=(d<<2)+a|0;i=w[f+4|0];j=ic(h,d),k=i+1|0,t[j|0]=k;f=f+6|0;f=w[f|0]|w[f+1|0]<<8;j=vd(g,d),k=f+1|0,u[j>>1]=k;d=d+1|0;if((d|0)!=120){continue}break}break a}g=b+236|0;while(1){h=((d<<2)+a|0)+6|0;h=w[h|0]|w[h+1|0]<<8;j=vd(g,d+12|0),k=h+1|0,u[j>>1]=k;d=d+1|0;if((d|0)!=96){continue}break}}nC(a+484|0,b+48|0,0);nC(a+590|0,b+68|0,0);nC(a+696|0,b+88|0,5);d=a+806|0;v[b>>2]=w[d|0]|w[d+1|0]<<8;d=a+808|0;g=w[d|0];b:{if(t[d|0]<0){t[b+34|0]=g-127;break b}if(!(!(t[a|0]&1)|g>>>0>16)){t[b+31|0]=w[d|0]+1;break b}if(!w[d|0]|w[d|0]>16){break b}t[b+31|0]=w[d|0]+1}if(w[b+31|0]){c:{d:{if((c|0)==4){d=a+810|0;break d}d=a+809|0;if(t[d|0]>=0){u[b+28>>1]=w[d|0]+1}d=a+810|0;if(t[d|0]<0){break c}}t[b+30|0]=w[d|0]+1}t[b+33|0]=w[a+811|0]}if((c|0)==32){t[e+15|0]=w[a+812|0];t[e+14|0]=128;j=b,k=w[ac(e+15|0,e+14|0)|0]>>>1|0,v[j+4>>2]=k}c=a+813|0;if((w[c|0]|w[c+1|0]<<8)>>>0<=256){v[b+8>>2]=w[c|0]|w[c+1|0]<<8;t[b+15|0]=w[b+15|0]|1}t[b+16|0]=w[a+815|0];t[b+26|0]=w[a+816|0];t[b+27|0]=w[a+817|0];t[b+17|0]=w[a+818|0];t[b+18|0]=w[a+819|0];c=a+820|0;u[e+12>>1]=w[c|0]|w[c+1|0]<<8;u[e+10>>1]=100;j=b,k=w[Pc(e+12|0,e+10|0)|0],t[j+20|0]=k;c=a+822|0;u[e+8>>1]=w[c|0]|w[c+1|0]<<8;u[e+6>>1]=256;j=b,k=x[Pc(e+8|0,e+6|0)>>1]>>>2|0,t[j+19|0]=k;c=a+824|0;hm(b,w[c|0]&127,w[c|0]>>>7|0);a=a+825|0;gm(b,w[a|0]&127,w[a|0]>>>7|0);gb=e+16|0}function jO(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;c=gb-16|0;gb=c;d=B(b,872)+a|0;a:{if(v[d+1075080>>2]&134218752){break a}if(!tk(d+1074992|0)){break a}h=v[(B(b,872)+a|0)+1075648>>2];if(w[h+15|0]&2){break a}d=Lm(a,b,2,1);if((d-1&255)>>>0>249){break a}g=v[(B(d,160)+a|0)+906140>>2];if(!g){break a}e=B(b,872)+a|0;d=w[e+1075780|0];b:{if(w[e+1075782|0]==1){t[c+8|0]=64;f=w[ac(e+1075784|0,c+8|0)|0];break b}f=255;if(w[e+1075783|0]!=13){break b}t[c+8|0]=64;f=w[ac((B(b,872)+a|0)+1075785|0,c+8|0)|0]}e=c+8|0;j=a+1074312|0;Db(e,j,2);if(Cb(e)){if(d){e=a;f=b;if(ve(d)){d=w[ic(h+108|0,d-1|0)|0]}Mm(e,f,d,x[(B(b,872)+a|0)+1075680>>1]);break a}if((f|0)==255){break a}kb[v[v[g>>2]+76>>2]](g,39,f,b);break a}k=v[h+4>>2];if(d){e=w[h+35|0]?k<<2:v[(B(b,872)+a|0)+1075680>>2];i=u[(B(b,872)+a|0)+1075768>>1];l=c+8|0;Db(l,j,28);m=c,n=e+(Cb(l)?i<<2:i)|0,v[m+4>>2]=n;Zd(c+4|0,0,256);e=d;i=b;if(ve(d)){e=w[ic(h+108|0,d-1|0)|0]}Mm(a,i,e&255,x[c+4>>1])}e=w[h+35|0];a=c+8|0;Db(a,j,101);i=(f|0)!=255;if(Cb(a)){a=(d|0)!=0}else{a=ve(d)}if(!(a?0:i)&(!a|(e|0)!=1)){break a}c:{switch(w[h+36|0]){case 1:if((f|0)!=255){GM(g,f<<1);break a}GM(g,k<<1);break a;case 0:break c;default:break a}}if((f|0)!=255){t[c+8|0]=127;t[c+4|0]=f<<1;n=g,o=7,p=w[ac(c+8|0,c+4|0)|0],q=b,m=v[v[g>>2]+76>>2],kb[m](n|0,o|0,p|0,q|0);break a}v[c+8>>2]=127;v[c+4>>2]=k<<1;q=g,p=7,o=w[Fb(c+8|0,c+4|0)|0],n=b,m=v[v[g>>2]+76>>2],kb[m](q|0,p|0,o|0,n|0)}gb=c+16|0}function gia(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;f=gb-48|0;gb=f;m=v[a+16>>2];h=Ud(f+16|0);v[h+8>>2]=a+112;v[h+16>>2]=v[a+128>>2];q=h,r=jg(b+327720|0,v[b+20>>2],(v[a+88>>2]&16384)>>>14|0),v[q+12>>2]=r;b=v[h+16>>2];if(b){q=h,r=lg(a+8|0,b),v[q>>2]=r;v[h+4>>2]=jb}i=v[a+48>>2];n=v[a+24>>2];o=v[a+20>>2];k=v[a+44>>2];g=v[a+4>>2];j=v[a>>2];v[f+8>>2]=j;v[f+12>>2]=g;e=v[a+12>>2];v[f>>2]=v[a+8>>2];v[f+4>>2]=e;a:{if(!d){e=k;k=i;break a}while(1){e=0;v[f+40>>2]=j;v[f+44>>2]=e;g=g+m|0;b:{if((b|0)<=0){break b}while(1){Id(v[h+8>>2],t[e+g|0]<<6);Hd(v[h+8>>2],4);Ub(f+40|0,h);if((b|0)<2){break b}b=b-1|0;e=v[f+44>>2];continue}}d=d-1|0;b=v[h+8>>2];Ub(b,b+8|0);b=v[h+8>>2];e=v[b+4>>2];if(e){Id(b,t[g+v[f+44>>2]|0]<<6);Hd(v[h+8>>2],e);b=v[h+8>>2];g=v[b>>2];v[b>>2]=g;v[b+4>>2]=0}e=ig(b,v[h+12>>2]);g=v[a+60>>2];j=g;b=Lb(k,-16777216,16776704);l=v[a+64>>2];i=Lb(i,-16777216,16776704);p=g>>31;g=e<<8;e=g;e=kqa(j,p,e,e>>31);j=jb;l=kqa(l,l>>31,b,b>>31);e=l+e|0;b=jb+j|0;b=e>>>0<l>>>0?b+1|0:b;j=e;e=v[a+68>>2];e=kqa(e,e>>31,i,i>>31);i=j+e|0;b=jb+b|0;b=e>>>0>i>>>0?b+1|0:b;i=i+8388608|0;b=i>>>0<8388608?b+1|0:b;b=Jc(i,b,24);i=v[a+72>>2];e=(b|0)/256|0;v[c>>2]=v[c>>2]+B(e,o);v[c+4>>2]=v[c+4>>2]+B(e,n);e=b-(g&i)|0;Ub(f+8|0,f);if(d){c=c+8|0;b=v[h+16>>2];j=v[f+8>>2];g=v[f+12>>2];i=k;k=e;continue}break}j=v[f+8>>2];g=v[f+12>>2]}v[a+48>>2]=k;v[a+44>>2]=e;v[a>>2]=j;v[a+4>>2]=g;gb=f+48|0}function zJ(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=+d;e=+e;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;i=gb-16|0;gb=i;a:{b:{c:{g=a+8|0;d:{if(wl(g)){f=wl(g);break d}f=hq(g)}if(!((f|0)>(b|0)&(b|0)>=0)){c=ba(8)|0;v[22656]=0;b=Q(70,i|0,3092)|0;a=v[22656];v[22656]=0;if((a|0)==1){break c}rc(c,b);v[22656]=0;U(186,c|0,54952,1936);a=v[22656];v[22656]=0;if((a|0)!=1){break a}a=P()|0;O()|0;vb(b);break b}if(c>>>0>=120){c=ba(8)|0;v[22656]=0;b=Q(70,i|0,8608)|0;a=v[22656];v[22656]=0;if((a|0)!=1){rc(c,b);v[22656]=0;U(186,c|0,54952,1936);a=v[22656];v[22656]=0;if((a|0)!=1){break a}a=P()|0;O()|0;vb(b);break b}a=P()|0;O()|0;ca(c|0);break b}h=a+32|0;a=wA(v[h>>2],65535);j=(a|0)==65535?255:a;u[i>>1]=j;f=v[h>>2]+B(j,872)|0;g=f+1074992|0;$m(g,7,v[h>>2],65535,1024);a=c+1|0;t[f+1075794|0]=a;t[f+1075791|0]=a;u[f+1075778>>1]=0;Nm(g);Fo(v[h>>2],g,b+1|0,0,1,1);v[f+1075688>>2]=65536;tu(v[h>>2],g,a,0,1,1,65535);m=f+1075684|0,n=Ro(GA(e*128,-128,128)+128),v[m>>2]=n;m=f+1075680|0,n=Ro(GA(d*256,0,256)),v[m>>2]=n;a=v[h>>2]+1074478|0;k=a;f=(x[v[h>>2]+480212>>1]<<1)+a|0;l=f;g=i;c=g;b=f;e:{if((b|0)==(a|0)){break e}c=x[c>>1];while(1){if((c|0)==x[a>>1]){break e}a=a+2|0;if((b|0)!=(a|0)){continue}break}a=b}b=a;f:{if((l|0)==(a|0)){break f}c=b+2|0;if((f|0)==(c|0)){break f}while(1){if(x[c>>1]!=x[g>>1]){u[b>>1]=x[c>>1];b=b+2|0}c=c+2|0;if((f|0)!=(c|0)){continue}break}}a=$q(k,b);u[v[h>>2]+480212>>1]=a;gb=i+16|0;return j|0}a=P()|0;O()|0;ca(c|0)}S(a|0)}L()}function ria(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,w=0,x=0,y=0,z=0,A=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0;h=gb-16|0;gb=h;f=v[a+48>>2];k=v[a+40>>2];l=v[a+36>>2];m=v[a+44>>2];r=v[a+16>>2];e=v[a+4>>2];g=e;i=v[a>>2];v[h+8>>2]=i;v[h+12>>2]=e;e=v[a+12>>2];v[h>>2]=v[a+8>>2];v[h+4>>2]=e;a:{if(d){while(1){e=(g<<1)+r|0;n=u[e-6>>1];g=(((i>>>16|0)+4&131064)<<1)+b|0;i=u[g+24>>1];o=u[e-4>>1];p=u[g+26>>1];s=u[e-2>>1];t=u[g+28>>1];w=u[e>>1];x=u[g+30>>1];y=u[e+2>>1];z=u[g+32>>1];A=u[e+4>>1];C=u[g+34>>1];D=u[e+6>>1];E=u[g+36>>1];F=u[e+8>>1];g=u[g+38>>1];e=v[a+60>>2];G=e;H=e>>31;e=Lb(m,-16777216,16776704);j=v[a+64>>2];f=Lb(f,-16777216,16776704);e=kqa(j,j>>31,e,e>>31);j=jb;I=e;e=v[a+68>>2];q=kqa(e,e>>31,f,f>>31);e=I+q|0;f=jb+j|0;f=e>>>0<q>>>0?f+1|0:f;j=e;g=(((((B(A,C)+B(y,z)|0)+B(D,E)|0)+B(g,F)|0)/2|0)+((((B(o,p)+B(i,n)|0)+B(s,t)|0)+B(w,x)|0)/2|0)|0)/16384<<8;e=g;i=kqa(G,H,e,e>>31);e=j+i|0;f=jb+f|0;f=e>>>0<i>>>0?f+1|0:f;e=e+8388608|0;f=e>>>0<8388608?f+1|0:f;f=Jc(e,f,24);e=v[a+72>>2];i=v[a+32>>2];l=v[a+28>>2]+l|0;n=l>>12;p=(f|0)/256|0;v[c>>2]=v[c>>2]+B(n,p);k=i+k|0;o=k>>12;v[c+4>>2]=v[c+4>>2]+B(p,o);e=f-(e&g)|0;Ub(h+8|0,h);d=d-1|0;if(d){c=c+8|0;i=v[h+8>>2];g=v[h+12>>2];f=m;m=e;continue}break}i=v[h+8>>2];g=v[h+12>>2];f=m;break a}o=k>>12;n=l>>12;e=m}v[a+40>>2]=k;v[a+20>>2]=n;v[a+36>>2]=l;v[a+48>>2]=f;v[a+44>>2]=e;v[a+24>>2]=o;v[a>>2]=i;v[a+4>>2]=g;gb=h+16|0}function nJ(a){var b=0,c=0,d=0,e=0;he(a,v[a+20>>2]);if(v[a+24>>2]>0){while(1){he(a,v[v[a+28>>2]+(b<<2)>>2]);b=b+1|0;if((b|0)<v[a+24>>2]){continue}break}}he(a,v[a+28>>2]);a:{b=v[a+396>>2];if(!b|v[a+264>>2]<=0){break a}while(1){c=B(e,24)+b|0;b=v[c+16>>2];if(b){d=a;if(v[(v[a+124>>2]+B(w[c+13|0],2096)|0)+4>>2]>0){he(a,v[b>>2]);b=1;if(v[(v[a+124>>2]+B(w[c+13|0],2096)|0)+4>>2]>=2){while(1){he(a,v[v[c+16>>2]+(b<<2)>>2]);b=b+1|0;if((b|0)<v[(v[a+124>>2]+B(w[c+13|0],2096)|0)+4>>2]){continue}break}}b=v[c+16>>2]}he(d,b)}he(a,v[c+20>>2]);e=e+1|0;if((e|0)>=v[a+264>>2]){break a}b=v[a+396>>2];continue}}b=v[a+124>>2];if(b){d=a;if(v[a+120>>2]>0){c=0;while(1){b=B(c,2096)+b|0;he(a,v[b+8>>2]);he(a,v[b+28>>2]);he(a,v[b+32>>2]);he(a,v[b+2084>>2]);b=v[b+2088>>2];he(a,b?b-4|0:0);c=c+1|0;if((c|0)<v[a+120>>2]){b=v[a+124>>2];continue}break}b=v[a+124>>2]}he(d,b)}he(a,v[a+260>>2]);he(a,v[a+396>>2]);d=v[a+404>>2];if(d){b=1;c=a;if(v[a+400>>2]>0){he(a,v[d+4>>2]);if(v[a+400>>2]>=2){while(1){he(a,v[(v[a+404>>2]+B(b,40)|0)+4>>2]);b=b+1|0;if((b|0)<v[a+400>>2]){continue}break}}d=v[a+404>>2]}he(c,d)}c=1;b:{if(v[a+4>>2]<=0){break b}b=0;while(1){d=(b<<2)+a|0;he(a,v[d+800>>2]);he(a,v[d+928>>2]);he(a,v[d+996>>2]);if(b>>>0>14){break b}b=b+1|0;if((b|0)<v[a+4>>2]){continue}break}}b=0;while(1){b=(b<<2)+a|0;he(a,v[b+1068>>2]);he(a,v[b+1076>>2]);he(a,v[b+1084>>2]);he(a,v[b+1092>>2]);he(a,v[b+1100>>2]);b=1;d=c&1;c=0;if(d){continue}break}}function sM(a){var b=C(0),c=0,d=C(0),e=0,f=C(0),g=0,h=C(0),i=C(0),k=C(0),m=0,n=C(0),o=0,r=C(0);e=gb-16|0;gb=e;c=wf(v[a+16>>2]);o=a,r=oe(C(10),C(C(C(z[a+4208>>2]*C(120))+C(-60))/C(20))),z[o+4232>>2]=r;f=C(C(c>>>0)/C(1e3));o=a,r=oe(C(10),C(C(-1)/C(f*C(C(z[a+4212>>2]*C(499.989990234375))+C(.009999999776482582))))),z[o+4236>>2]=r;o=a,r=oe(C(10),C(C(-1)/C(f*C(C(z[a+4216>>2]*C(2950))+C(50))))),z[o+4240>>2]=r;v[e+12>>2]=1325400064;g=e;b=C(oe(C(10),C(C(C(z[a+4220>>2]*C(60))+C(-60))/C(20)))*C(2147483648));c=(p(b),j(2));a:{b:{c:{if(!(c>>>0>=8388608&(c|0)>=0)){d=C(C(-1)/C(b*b));if(!(c&2147483647)){break a}d=C(C(b-b)/C(0));if((c|0)<0){break a}c=(p(C(b*C(33554432))),j(2));m=-152;break c}if(c>>>0>2139095039){break b}m=-127;b=C(0);if((c|0)==1065353216){break b}}c=c+4913933|0;n=C((c>>>23|0)+m|0);b=C((l(2,(c&8388607)+1060439283|0),q())+C(-1));h=C(b/C(b+C(2)));i=C(h*h);k=C(i*i);d=b;b=C(b*C(b*C(.5)));b=C(C(n*C(.6931381225585938))+C(d+C(C(C(n*C(905800061445916e-20))+C(h*C(b+C(C(i*C(C(k*C(.2849878668785095))+C(.6666666269302368)))+C(k*C(C(k*C(.24279078841209412))+C(.40000972151756287)))))))-b)))}d=b}z[g+8>>2]=C(C(d*C(67108864))/C(.6931471824645996))+C(67108864);o=a,r=C(z[Gm(e+12|0,e+8|0)>>2]*C(4.656612873077393e-10)),z[o+4244>>2]=r;z[a+4248>>2]=C(C(-1)/C(C(z[a+4224>>2]*C(99))+C(1)))+C(1);g=a;b=C(C(f*C(z[a+4228>>2]*C(4)))+C(2));d:{if(C(D(b))<C(2147483648)){a=~~b;break d}a=-2147483648}v[g+4252>>2]=a;gb=e+16|0}function bda(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;i=gb-16|0;gb=i;d=b+1298264|0;if(!Dd(d)){e=i;f=gb-16|0;gb=f;c=sf(12);v[22656]=0;h=T(1644,c|0)|0;g=v[22656];v[22656]=0;a:{if((g|0)!=1){c=gb-16|0;gb=c;v[c+12>>2]=h;xq(f+8|0,c+12|0);gb=c+16|0;gb=f+16|0;c=v[f+8>>2];break a}a=P()|0;O()|0;Yb(c);S(a|0);L()}v[e+8>>2]=c;e=i+8|0;YO(d,ce(e));lu(e)}e=v[d>>2];f=0;c=gb-48|0;gb=c;d=c+16|0;TO(d,a);v[22656]=0;U(9,c+32|0,0,d|0);d=v[22656];v[22656]=0;b:{c:{d:{e:{f:{if((d|0)!=1){vb(c+16|0);k=c,l=Vb(e),v[k+8>>2]=l;k=c,l=Zb(e),v[k>>2]=l;g:{if(Gb(c+8|0,c)){e=0;while(1){h=0;d=v[c+8>>2];if(v[v[d>>2]+32>>2]==(w[a+16|0]|w[a+17|0]<<8|(w[a+18|0]<<16|w[a+19|0]<<24))){h=v[v[d>>2]+36>>2]==(w[a+20|0]|w[a+21|0]<<8|(w[a+22|0]<<16|w[a+23|0]<<24))}g=v[d>>2];v[22656]=0;R(1645,c+16|0,g+8|0);g=v[22656];v[22656]=0;if((g|0)==1){break g}v[22656]=0;g=NS(c+16|0,c+32|0);j=v[22656];v[22656]=0;h:{i:{if((j|0)!=1){vb(c+16|0);g=!g;if(!(g&h)){break i}f=v[d>>2];e=3;break h}e=P()|0;O()|0;vb(c+16|0);break d}if((e|0)<2&h){f=v[d>>2];e=2;break h}h=v[d>>2];d=g&(e|0)<=0;f=d?h:f;e=d?1:e}d=c+8|0;Qe(d);if(Gb(d,c)){continue}break}break f}e=0;break e}e=P()|0;O()|0;break d}e=P()|0;O()|0;vb(c+16|0);break c}e=0;if(!f){break e}d=v[f+4>>2];if(!d){break e}v[22656]=0;a=W(d|0,f|0,b|0,a|0)|0;b=v[22656];v[22656]=0;if((b|0)!=1){e=(a|0)!=0;break e}e=P()|0;O()|0;break d}vb(c+32|0);gb=c+48|0;break b}vb(c+32|0)}S(e|0);L()}gb=i+16|0;return e|0}function y1(a,b,c,d,e,f,g,h){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0;k=gb-16|0;gb=k;i=c;j=(c|0)==(d|0);a:{if(j){break a}while(1){if(!v[i>>2]){break a}i=i+4|0;if((i|0)!=(d|0)){continue}break}i=d}v[h>>2]=f;v[e>>2]=c;b:{c:{if(j|(f|0)==(g|0)){break c}m=1;while(1){j=v[b+4>>2];v[k+8>>2]=v[b>>2];v[k+12>>2]=j;l=gb-16|0;gb=l;v[l+12>>2]=v[a+8>>2];n=vi(l+8|0,l+12|0);v[22656]=0;j=IH(f,e,i-c>>2,g-f|0,b);o=v[22656];v[22656]=0;d:{if((o|0)!=1){hf(n);gb=l+16|0;break d}a=P()|0;O()|0;hf(n);S(a|0);L()}e:{f:{g:{h:{i:{j:{switch(j+1|0){case 0:v[h>>2]=f;k:{if(v[e>>2]==(c|0)){break k}while(1){b=sx(f,v[c>>2],k+8|0,v[a+8>>2]);if((b|0)==-1){break k}f=b+v[h>>2]|0;v[h>>2]=f;c=c+4|0;if((c|0)!=v[e>>2]){continue}break}}v[e>>2]=c;break i;case 1:break b;default:break j}}f=j+v[h>>2]|0;v[h>>2]=f;if((f|0)==(g|0)){break g}if((d|0)==(i|0)){c=v[e>>2];i=d;break e}j=sx(k+4|0,0,b,v[a+8>>2]);if((j|0)!=-1){break h}}m=2;break b}f=v[h>>2];if(j>>>0>g-f>>>0){break b}if(!j){break f}c=w[k+4|0];v[h>>2]=f+1;t[f|0]=c;i=k+4|0;c=j-1|0;if(!c){break f}while(1){j=w[i+1|0];f=v[h>>2];v[h>>2]=f+1;t[f|0]=j;i=i+1|0;c=c-1|0;if(c){continue}break}break f}c=v[e>>2];break c}c=v[e>>2]+4|0;v[e>>2]=c;f=c;i=d;l:{if((d|0)==(f|0)){break l}while(1){i=f;if(!v[f>>2]){break l}f=f+4|0;if((f|0)!=(d|0)){continue}break}i=d}f=v[h>>2]}if((c|0)==(d|0)){break c}if((f|0)!=(g|0)){continue}break}}m=(c|0)!=(d|0)}gb=k+16|0;return m|0}function sia(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,w=0,x=0,y=0,z=0,A=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0;h=gb-16|0;gb=h;f=v[a+48>>2];k=v[a+40>>2];l=v[a+36>>2];m=v[a+44>>2];r=v[a+16>>2];e=v[a+4>>2];g=e;i=v[a>>2];v[h+8>>2]=i;v[h+12>>2]=e;e=v[a+12>>2];v[h>>2]=v[a+8>>2];v[h+4>>2]=e;a:{if(d){while(1){e=g+r|0;n=t[e-3|0];g=(((i>>>16|0)+4&131064)<<1)+b|0;i=u[g+24>>1];o=t[e-2|0];p=u[g+26>>1];s=t[e-1|0];w=u[g+28>>1];x=t[e|0];y=u[g+30>>1];z=t[e+1|0];A=u[g+32>>1];C=t[e+2|0];D=u[g+34>>1];E=t[e+3|0];F=u[g+36>>1];G=t[e+4|0];g=u[g+38>>1];e=v[a+60>>2];H=e;I=e>>31;e=Lb(m,-16777216,16776704);j=v[a+64>>2];f=Lb(f,-16777216,16776704);e=kqa(j,j>>31,e,e>>31);j=jb;J=e;e=v[a+68>>2];q=kqa(e,e>>31,f,f>>31);e=J+q|0;f=jb+j|0;f=e>>>0<q>>>0?f+1|0:f;j=e;g=(((((B(C,D)+B(z,A)|0)+B(E,F)|0)+B(g,G)<<8)/2|0)+((((B(o,p)+B(i,n)|0)+B(s,w)|0)+B(x,y)<<8)/2|0)|0)/16384<<8;e=g;i=kqa(H,I,e,e>>31);e=j+i|0;f=jb+f|0;f=e>>>0<i>>>0?f+1|0:f;e=e+8388608|0;f=e>>>0<8388608?f+1|0:f;f=Jc(e,f,24);e=v[a+72>>2];i=v[a+32>>2];l=v[a+28>>2]+l|0;n=l>>12;p=(f|0)/256|0;v[c>>2]=v[c>>2]+B(n,p);k=i+k|0;o=k>>12;v[c+4>>2]=v[c+4>>2]+B(p,o);e=f-(e&g)|0;Ub(h+8|0,h);d=d-1|0;if(d){c=c+8|0;i=v[h+8>>2];g=v[h+12>>2];f=m;m=e;continue}break}i=v[h+8>>2];g=v[h+12>>2];f=m;break a}o=k>>12;n=l>>12;e=m}v[a+40>>2]=k;v[a+20>>2]=n;v[a+36>>2]=l;v[a+48>>2]=f;v[a+44>>2]=e;v[a+24>>2]=o;v[a>>2]=i;v[a+4>>2]=g;gb=h+16|0}function Aja(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;b=gb-48|0;gb=b;q=v[a+16>>2];h=v[a+44>>2];v[b+32>>2]=h;l=v[a+48>>2];v[b+36>>2]=l;i=v[a+52>>2];v[b+40>>2]=i;f=v[a+56>>2];v[b+44>>2]=f;m=v[a+40>>2];n=v[a+36>>2];e=v[a+4>>2];g=v[a>>2];v[b+24>>2]=g;v[b+28>>2]=e;j=v[a+12>>2];v[b+16>>2]=v[a+8>>2];v[b+20>>2]=j;a:{if(d){while(1){e=((((e&2147483647)<<1|g>>>31)&2147483646)<<1)+q|0;f=u[e>>1];v[b+8>>2]=f;v[b+12>>2]=u[e+2>>1];j=0;l=1;while(1){i=v[a+60>>2];k=i;g=(b+32|0)+(j<<3)|0;p=v[g>>2];e=Lb(p,-16777216,16776704);o=v[a+64>>2];h=Lb(v[g+4>>2],-16777216,16776704);r=i>>31;i=f<<8;f=i;f=kqa(k,r,f,f>>31);k=jb;o=kqa(o,o>>31,e,e>>31);f=o+f|0;e=jb+k|0;e=f>>>0<o>>>0?e+1|0:e;k=f;f=v[a+68>>2];h=kqa(f,f>>31,h,h>>31);f=k+h|0;e=jb+e|0;e=f>>>0<h>>>0?e+1|0:e;f=f+8388608|0;e=f>>>0<8388608?e+1|0:e;e=Jc(f,e,24);v[g+4>>2]=p;f=v[a+72>>2];v[(b+8|0)+(j<<2)>>2]=(e|0)/256;v[g>>2]=e-(f&i);if(l){j=1;l=0;f=v[b+12>>2];continue}break}e=v[a+32>>2];n=v[a+28>>2]+n|0;j=n>>12;v[c>>2]=v[c>>2]+B(j,v[b+8>>2]);m=e+m|0;k=m>>12;v[c+4>>2]=v[c+4>>2]+B(k,v[b+12>>2]);Ub(b+24|0,b+16|0);d=d-1|0;if(d){c=c+8|0;g=v[b+24>>2];e=v[b+28>>2];continue}break}g=v[b+24>>2];e=v[b+28>>2];f=v[b+44>>2];i=v[b+40>>2];l=v[b+36>>2];h=v[b+32>>2];break a}k=m>>12;j=n>>12}v[a+40>>2]=m;v[a+20>>2]=j;v[a+36>>2]=n;v[a+56>>2]=f;v[a+52>>2]=i;v[a+48>>2]=l;v[a+44>>2]=h;v[a+24>>2]=k;v[a>>2]=g;v[a+4>>2]=e;gb=b+48|0}function X3(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=C(0);a=gb-368|0;gb=a;v[a+352>>2]=c;v[a+360>>2]=b;Ax(a+200|0,d,a+224|0,a+220|0,a+216|0);d=Kb(a+184|0);b=Kc(d);v[22656]=0;R(76,d|0,b|0);b=v[22656];v[22656]=0;a:{b:{c:{if((b|0)!=1){c=pc(d,0);v[a+180>>2]=c;v[a+12>>2]=a+16;v[a+8>>2]=0;t[a+7|0]=1;t[a+6|0]=69;b=v[a+216>>2];i=v[a+220>>2];while(1){d:{v[22656]=0;g=Q(2457,a+360|0,a+352|0)|0;h=v[22656];v[22656]=0;if((h|0)==1){break d}if(!g){break c}if(v[a+180>>2]==(Ab(d)+c|0)){g=Ab(d);c=Ab(d);v[22656]=0;R(76,d|0,c<<1);c=v[22656];v[22656]=0;if((c|0)==1){break b}c=Kc(d);v[22656]=0;R(76,d|0,c|0);c=v[22656];v[22656]=0;if((c|0)==1){break b}c=pc(d,0);v[a+180>>2]=g+c}v[22656]=0;g=T(2459,a+360|0)|0;h=v[22656];v[22656]=0;if((h|0)==1){break d}if(zx(g,a+7|0,a+6|0,c,a+180|0,i,b,a+200|0,a+16|0,a+12|0,a+8|0,a+224|0)){break c}v[22656]=0;T(2461,a+360|0)|0;g=v[22656];v[22656]=0;if((g|0)!=1){continue}}break}break b}break b}e:{if(!Ab(a+200|0)|!w[a+7|0]){break e}b=v[a+12>>2];if((b-(a+16|0)|0)>159){break e}v[a+12>>2]=b+4;v[b>>2]=v[a+8>>2]}v[22656]=0;j=C(ya(2443,c|0,v[a+180>>2],e|0));b=v[22656];v[22656]=0;f:{if((b|0)==1){break f}z[f>>2]=j;jf(a+200|0,a+16|0,v[a+12>>2],e);v[22656]=0;b=Q(2458,a+360|0,a+352|0)|0;c=v[22656];v[22656]=0;if((c|0)==1){break f}if(b){v[e>>2]=v[e>>2]|2}b=v[a+360>>2];vb(d);vb(a+200|0);gb=a+368|0;break a}}b=P()|0;O()|0;vb(d);vb(a+200|0);S(b|0);L()}return b|0}function l4(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=C(0);a=gb-272|0;gb=a;v[a+256>>2]=c;v[a+264>>2]=b;Dx(a+208|0,d,a+224|0,a+223|0,a+222|0);d=Kb(a+192|0);b=Kc(d);v[22656]=0;R(76,d|0,b|0);b=v[22656];v[22656]=0;a:{b:{c:{if((b|0)!=1){c=pc(d,0);v[a+188>>2]=c;v[a+12>>2]=a+16;v[a+8>>2]=0;t[a+7|0]=1;t[a+6|0]=69;b=t[a+222|0];i=t[a+223|0];while(1){d:{v[22656]=0;g=Q(2430,a+264|0,a+256|0)|0;h=v[22656];v[22656]=0;if((h|0)==1){break d}if(!g){break c}if(v[a+188>>2]==(Ab(d)+c|0)){g=Ab(d);c=Ab(d);v[22656]=0;R(76,d|0,c<<1);c=v[22656];v[22656]=0;if((c|0)==1){break b}c=Kc(d);v[22656]=0;R(76,d|0,c|0);c=v[22656];v[22656]=0;if((c|0)==1){break b}c=pc(d,0);v[a+188>>2]=g+c}v[22656]=0;g=T(2432,a+264|0)|0;h=v[22656];v[22656]=0;if((h|0)==1){break d}if(Cx(g,a+7|0,a+6|0,c,a+188|0,i,b,a+208|0,a+16|0,a+12|0,a+8|0,a+224|0)){break c}v[22656]=0;T(2434,a+264|0)|0;g=v[22656];v[22656]=0;if((g|0)!=1){continue}}break}break b}break b}e:{if(!Ab(a+208|0)|!w[a+7|0]){break e}b=v[a+12>>2];if((b-(a+16|0)|0)>159){break e}v[a+12>>2]=b+4;v[b>>2]=v[a+8>>2]}v[22656]=0;j=C(ya(2443,c|0,v[a+188>>2],e|0));b=v[22656];v[22656]=0;f:{if((b|0)==1){break f}z[f>>2]=j;jf(a+208|0,a+16|0,v[a+12>>2],e);v[22656]=0;b=Q(2431,a+264|0,a+256|0)|0;c=v[22656];v[22656]=0;if((c|0)==1){break f}if(b){v[e>>2]=v[e>>2]|2}b=v[a+264>>2];vb(d);vb(a+208|0);gb=a+272|0;break a}}b=P()|0;O()|0;vb(d);vb(a+208|0);S(b|0);L()}return b|0}function aoa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;g=gb-32|0;gb=g;j=fg(a,c);se(g+8|0,v[a+28>>2]);d=v[g+20>>2];v[g+24>>2]=v[g+16>>2];v[g+28>>2]=d;a:{if(!j){if(nd(a,5)){break a}}d=gb-144|0;gb=d;h=Hm(d+40|0,v[a+28>>2]);v[22656]=0;f=Q(620,d+24|0,49666)|0;e=v[22656];v[22656]=0;b:{c:{d:{e:{if((e|0)!=1){v[22656]=0;v[d+16>>2]=19923028;v[d+20>>2]=0;U(621,h|0,f|0,d+16|0);e=v[22656];v[22656]=0;if((e|0)==1){break e}Hb(f);if(!(v[h>>2]&1073741824)){break d}break b}e=P()|0;O()|0;break c}e=P()|0;O()|0;Hb(f);break c}k=d,l=Te(b),u[k+16>>1]=l;u[d+14>>1]=65535;v[22656]=0;f=Q(620,d+24|0,7375)|0;e=v[22656];v[22656]=0;f:{if((e|0)!=1){v[22656]=0;e=W(1094,h|0,d+14|0,f|0)|0;i=v[22656];v[22656]=0;if((i|0)==1){break f}Hb(f);if((e|0)!=1){u[d+16>>1]=x[d+14>>1]}zg(d+16|0,4e3);g:{if(x[d+16>>1]<=Te(b)>>>0){break g}v[22656]=0;R(330,b|0,x[d+16>>1]);e=v[22656];v[22656]=0;if((e|0)!=1){break g}e=P()|0;O()|0;break c}e=0;u[d+12>>1]=0;if(!x[d+16>>1]){break b}h:{while(1){i:{f=_b(b,e&65535);v[22656]=0;R(1493,d+24|0,d+12|0);i=v[22656];v[22656]=0;if((i|0)==1){break i}v[22656]=0;da(1477,h|0,f|0,d+24|0,1494)|0;f=v[22656];v[22656]=0;if((f|0)==1){break h}Hb(d+24|0);e=e+1|0;u[d+12>>1]=e;if(x[d+16>>1]>(e&65535)>>>0){continue}break b}break}e=P()|0;O()|0;break c}e=P()|0;O()|0;Hb(d+24|0);break c}e=P()|0;O()|0;break c}e=P()|0;O()|0;Hb(f)}gh(h);S(e|0);L()}gh(h);gb=d+144|0}Zf(a,j,c,g+24|0);gb=g+32|0}function XH(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=gb-96|0;gb=c;a:{b:{c:{d:{e:{f:{g:{h:{i:{b=v[b>>2];j:{if(!b){Tb(a,6892);break j}if(!(b&65535)){d=gb-16|0;gb=d;e=Tb(d,1508);Dc(c+80|0,e);vb(e);gb=d+16|0;v[22656]=0;v[c+24>>2]=b>>>24;R(134,c- -64|0,c+24|0);d=v[22656];v[22656]=0;k:{l:{m:{n:{if((d|0)!=1){v[22656]=0;v[c+8>>2]=b>>>16&255;R(135,c+48|0,c+8|0);b=v[22656];v[22656]=0;if((b|0)==1){break n}v[22656]=0;Y(136,a|0,c+80|0,c- -64|0,c+48|0);a=v[22656];v[22656]=0;if((a|0)==1){break m}vb(c+48|0);vb(c- -64|0);Hb(c+80|0);break j}b=P()|0;O()|0;break k}b=P()|0;O()|0;break l}b=P()|0;O()|0;vb(c+48|0)}vb(c- -64|0)}break a}d=gb-16|0;gb=d;e=Tb(d,1232);Dc(c+80|0,e);vb(e);gb=d+16|0;v[22656]=0;v[c+44>>2]=b>>>24;R(134,c- -64|0,c+44|0);d=v[22656];v[22656]=0;if((d|0)==1){break i}v[22656]=0;v[c+40>>2]=b>>>16&255;R(135,c+48|0,c+40|0);d=v[22656];v[22656]=0;if((d|0)==1){break h}v[22656]=0;v[c+20>>2]=b>>>8&255;R(135,c+24|0,c+20|0);d=v[22656];v[22656]=0;if((d|0)==1){break g}v[22656]=0;v[c+4>>2]=b&255;R(135,c+8|0,c+4|0);b=v[22656];v[22656]=0;if((b|0)==1){break f}v[22656]=0;ka(137,a|0,c+80|0,c- -64|0,c+48|0,c+24|0,c+8|0);a=v[22656];v[22656]=0;if((a|0)==1){break e}vb(c+8|0);vb(c+24|0);vb(c+48|0);vb(c- -64|0);Hb(c+80|0)}gb=c+96|0;return}b=P()|0;O()|0;break a}b=P()|0;O()|0;break b}b=P()|0;O()|0;break c}b=P()|0;O()|0;break d}b=P()|0;O()|0;vb(c+8|0)}vb(c+24|0)}vb(c+48|0)}vb(c- -64|0)}Hb(c+80|0);S(b|0);L()}function W3(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0;a=gb-368|0;gb=a;v[a+352>>2]=c;v[a+360>>2]=b;Ax(a+200|0,d,a+224|0,a+220|0,a+216|0);d=Kb(a+184|0);b=Kc(d);v[22656]=0;R(76,d|0,b|0);b=v[22656];v[22656]=0;a:{b:{c:{if((b|0)!=1){c=pc(d,0);v[a+180>>2]=c;v[a+12>>2]=a+16;v[a+8>>2]=0;t[a+7|0]=1;t[a+6|0]=69;b=v[a+216>>2];i=v[a+220>>2];while(1){d:{v[22656]=0;g=Q(2457,a+360|0,a+352|0)|0;h=v[22656];v[22656]=0;if((h|0)==1){break d}if(!g){break c}if(v[a+180>>2]==(Ab(d)+c|0)){g=Ab(d);c=Ab(d);v[22656]=0;R(76,d|0,c<<1);c=v[22656];v[22656]=0;if((c|0)==1){break b}c=Kc(d);v[22656]=0;R(76,d|0,c|0);c=v[22656];v[22656]=0;if((c|0)==1){break b}c=pc(d,0);v[a+180>>2]=g+c}v[22656]=0;g=T(2459,a+360|0)|0;h=v[22656];v[22656]=0;if((h|0)==1){break d}if(zx(g,a+7|0,a+6|0,c,a+180|0,i,b,a+200|0,a+16|0,a+12|0,a+8|0,a+224|0)){break c}v[22656]=0;T(2461,a+360|0)|0;g=v[22656];v[22656]=0;if((g|0)!=1){continue}}break}break b}break b}e:{if(!Ab(a+200|0)|!w[a+7|0]){break e}b=v[a+12>>2];if((b-(a+16|0)|0)>159){break e}v[a+12>>2]=b+4;v[b>>2]=v[a+8>>2]}v[22656]=0;j=+oa(2446,c|0,v[a+180>>2],e|0);b=v[22656];v[22656]=0;f:{if((b|0)==1){break f}A[f>>3]=j;jf(a+200|0,a+16|0,v[a+12>>2],e);v[22656]=0;b=Q(2458,a+360|0,a+352|0)|0;c=v[22656];v[22656]=0;if((c|0)==1){break f}if(b){v[e>>2]=v[e>>2]|2}b=v[a+360>>2];vb(d);vb(a+200|0);gb=a+368|0;break a}}b=P()|0;O()|0;vb(d);vb(a+200|0);S(b|0);L()}return b|0}function Bja(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;b=gb-48|0;gb=b;q=v[a+16>>2];h=v[a+44>>2];v[b+32>>2]=h;l=v[a+48>>2];v[b+36>>2]=l;i=v[a+52>>2];v[b+40>>2]=i;f=v[a+56>>2];v[b+44>>2]=f;m=v[a+40>>2];n=v[a+36>>2];e=v[a+4>>2];g=v[a>>2];v[b+24>>2]=g;v[b+28>>2]=e;j=v[a+12>>2];v[b+16>>2]=v[a+8>>2];v[b+20>>2]=j;a:{if(d){while(1){e=(((e&2147483647)<<1|g>>>31)&-2)+q|0;f=t[e|0]<<8;v[b+8>>2]=f;v[b+12>>2]=t[e+1|0]<<8;j=0;l=1;while(1){i=v[a+60>>2];k=i;g=(b+32|0)+(j<<3)|0;p=v[g>>2];e=Lb(p,-16777216,16776704);o=v[a+64>>2];h=Lb(v[g+4>>2],-16777216,16776704);r=i>>31;i=f<<8;f=i;f=kqa(k,r,f,f>>31);k=jb;o=kqa(o,o>>31,e,e>>31);f=o+f|0;e=jb+k|0;e=f>>>0<o>>>0?e+1|0:e;k=f;f=v[a+68>>2];h=kqa(f,f>>31,h,h>>31);f=k+h|0;e=jb+e|0;e=f>>>0<h>>>0?e+1|0:e;f=f+8388608|0;e=f>>>0<8388608?e+1|0:e;e=Jc(f,e,24);v[g+4>>2]=p;f=v[a+72>>2];v[(b+8|0)+(j<<2)>>2]=(e|0)/256;v[g>>2]=e-(f&i);if(l){j=1;l=0;f=v[b+12>>2];continue}break}e=v[a+32>>2];n=v[a+28>>2]+n|0;j=n>>12;v[c>>2]=v[c>>2]+B(j,v[b+8>>2]);m=e+m|0;k=m>>12;v[c+4>>2]=v[c+4>>2]+B(k,v[b+12>>2]);Ub(b+24|0,b+16|0);d=d-1|0;if(d){c=c+8|0;g=v[b+24>>2];e=v[b+28>>2];continue}break}g=v[b+24>>2];e=v[b+28>>2];f=v[b+44>>2];i=v[b+40>>2];l=v[b+36>>2];h=v[b+32>>2];break a}k=m>>12;j=n>>12}v[a+40>>2]=m;v[a+20>>2]=j;v[a+36>>2]=n;v[a+56>>2]=f;v[a+52>>2]=i;v[a+48>>2]=l;v[a+44>>2]=h;v[a+24>>2]=k;v[a>>2]=g;v[a+4>>2]=e;gb=b+48|0}function j4(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0;a=gb-272|0;gb=a;v[a+256>>2]=c;v[a+264>>2]=b;Dx(a+208|0,d,a+224|0,a+223|0,a+222|0);d=Kb(a+192|0);b=Kc(d);v[22656]=0;R(76,d|0,b|0);b=v[22656];v[22656]=0;a:{b:{c:{if((b|0)!=1){c=pc(d,0);v[a+188>>2]=c;v[a+12>>2]=a+16;v[a+8>>2]=0;t[a+7|0]=1;t[a+6|0]=69;b=t[a+222|0];i=t[a+223|0];while(1){d:{v[22656]=0;g=Q(2430,a+264|0,a+256|0)|0;h=v[22656];v[22656]=0;if((h|0)==1){break d}if(!g){break c}if(v[a+188>>2]==(Ab(d)+c|0)){g=Ab(d);c=Ab(d);v[22656]=0;R(76,d|0,c<<1);c=v[22656];v[22656]=0;if((c|0)==1){break b}c=Kc(d);v[22656]=0;R(76,d|0,c|0);c=v[22656];v[22656]=0;if((c|0)==1){break b}c=pc(d,0);v[a+188>>2]=g+c}v[22656]=0;g=T(2432,a+264|0)|0;h=v[22656];v[22656]=0;if((h|0)==1){break d}if(Cx(g,a+7|0,a+6|0,c,a+188|0,i,b,a+208|0,a+16|0,a+12|0,a+8|0,a+224|0)){break c}v[22656]=0;T(2434,a+264|0)|0;g=v[22656];v[22656]=0;if((g|0)!=1){continue}}break}break b}break b}e:{if(!Ab(a+208|0)|!w[a+7|0]){break e}b=v[a+12>>2];if((b-(a+16|0)|0)>159){break e}v[a+12>>2]=b+4;v[b>>2]=v[a+8>>2]}v[22656]=0;j=+oa(2446,c|0,v[a+188>>2],e|0);b=v[22656];v[22656]=0;f:{if((b|0)==1){break f}A[f>>3]=j;jf(a+208|0,a+16|0,v[a+12>>2],e);v[22656]=0;b=Q(2431,a+264|0,a+256|0)|0;c=v[22656];v[22656]=0;if((c|0)==1){break f}if(b){v[e>>2]=v[e>>2]|2}b=v[a+264>>2];vb(d);vb(a+208|0);gb=a+272|0;break a}}b=P()|0;O()|0;vb(d);vb(a+208|0);S(b|0);L()}return b|0}function oja(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;e=gb-48|0;gb=e;p=v[a+16>>2];f=v[a+44>>2];v[e+32>>2]=f;j=v[a+48>>2];v[e+36>>2]=j;k=v[a+52>>2];v[e+40>>2]=k;g=v[a+56>>2];v[e+44>>2]=g;q=v[a+24>>2];r=v[a+20>>2];b=v[a+4>>2];i=v[a>>2];v[e+24>>2]=i;v[e+28>>2]=b;h=v[a+12>>2];v[e+16>>2]=v[a+8>>2];v[e+20>>2]=h;s=a;if(d){while(1){l=i>>>18|0;k=1;g=((((b&2147483647)<<1|i>>>31)&2147483646)<<1)+p|0;f=0;b=1;j=0;while(1){h=j<<1;i=u[h+g>>1];v[(e+8|0)+(j<<2)>>2]=i+((B(l,u[g+(h|4)>>1]-i|0)|0)/16384|0);i=b;b=0;j=1;if(i){continue}break}while(1){j=(e+8|0)+(f<<2)|0;l=v[j>>2];h=v[a+60>>2];m=h;i=(e+32|0)+(f<<3)|0;o=v[i>>2];b=Lb(o,-16777216,16776704);f=v[a+64>>2];g=Lb(v[i+4>>2],-16777216,16776704);n=h>>31;l=l<<8;h=l;h=kqa(m,n,h,h>>31);m=jb;n=h;h=kqa(f,f>>31,b,b>>31);f=n+h|0;b=jb+m|0;b=f>>>0<h>>>0?b+1|0:b;h=f;f=v[a+68>>2];f=kqa(f,f>>31,g,g>>31);g=h+f|0;b=jb+b|0;b=f>>>0>g>>>0?b+1|0:b;g=g+8388608|0;b=g>>>0<8388608?b+1|0:b;b=Jc(g,b,24);v[i+4>>2]=o;g=v[a+72>>2];v[j>>2]=(b|0)/256;v[i>>2]=b-(g&l);f=1;b=k&1;k=0;if(b){continue}break}v[c>>2]=v[c>>2]+B(v[e+8>>2],r);v[c+4>>2]=v[c+4>>2]+B(v[e+12>>2],q);Ub(e+24|0,e+16|0);d=d-1|0;if(d){c=c+8|0;i=v[e+24>>2];b=v[e+28>>2];continue}break}i=v[e+24>>2];b=v[e+28>>2];k=v[e+40>>2];j=v[e+36>>2];f=v[e+32>>2];g=v[e+44>>2]}v[s+56>>2]=g;v[a+52>>2]=k;v[a+48>>2]=j;v[a+44>>2]=f;v[a>>2]=i;v[a+4>>2]=b;gb=e+48|0}function f5(){var a=0,b=0,c=0;a=gb-16|0;gb=a;et(463616);v[115914]=463672;v[115912]=90312;v[115904]=75864;v[115916]=-1;t[463668]=0;b=a+8|0;_s(b,463616);c=v[v[115904]+8>>2];v[22656]=0;R(c|0,463616,b|0);b=v[22656];v[22656]=0;a:{if((b|0)!=1){Wb(a+8|0);gb=a+16|0;break a}b=P()|0;O()|0;Wb(a+8|0);Am(463616);S(b|0);L()}ju(462944);v[115736]=74656;v[115734]=74636;v[115735]=0;v[22656]=0;R(2396,462944,463616);a=v[22656];v[22656]=0;if((a|0)==1){a=P()|0;O()|0;oh(462944);S(a|0);L()}a=gb-16|0;gb=a;AI(463680);v[115930]=463736;v[115928]=90312;v[115920]=75964;v[115932]=-1;t[463732]=0;b=a+8|0;_s(b,463680);c=v[v[115920]+8>>2];v[22656]=0;R(c|0,463680,b|0);b=v[22656];v[22656]=0;b:{if((b|0)!=1){Wb(a+8|0);gb=a+16|0;break b}b=P()|0;O()|0;Wb(a+8|0);bq(463680);S(b|0);L()}_H(463032);v[115758]=74704;v[115756]=74684;v[115757]=0;v[22656]=0;R(2397,463032,463680);a=v[22656];v[22656]=0;if((a|0)==1){a=P()|0;O()|0;oh(463032);S(a|0);L()}dI(463744,90456,463792);Rx(463112,463744);cI(463800,90456,463848);Qx(463196,463800);dI(463856,90160,463904);Rx(463280,463856);Rx(463448,v[(v[v[115820]-12>>2]+463280|0)+24>>2]);cI(463912,90160,463960);Qx(463364,463912);Qx(463532,v[(v[v[115841]-12>>2]+463364|0)+24>>2]);aI(v[v[115734]-12>>2]+462936|0);$H(v[v[115756]-12>>2]+463024|0);ZN(v[v[115820]-12>>2]+463280|0);ZN(v[v[115841]-12>>2]+463364|0);aI(v[v[115820]-12>>2]+463280|0);$H(v[v[115841]-12>>2]+463364|0)}function n8(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;b=gb-176|0;gb=b;d=Tb(b+8|0,8890);v[22656]=0;Q(70,b+20|0,8238)|0;e=v[22656];v[22656]=0;c=1;a:{b:{if((e|0)==1){break b}v[22656]=0;Q(70,b+32|0,8720)|0;c=v[22656];v[22656]=0;if((c|0)==1){c=2;break b}v[22656]=0;Q(70,b+44|0,8230)|0;c=v[22656];v[22656]=0;if((c|0)==1){c=3;break b}v[22656]=0;Q(70,b+56|0,5376)|0;c=v[22656];v[22656]=0;if((c|0)==1){c=4;break b}v[22656]=0;Q(70,b+68|0,8215)|0;c=v[22656];v[22656]=0;if((c|0)==1){c=5;break b}v[22656]=0;Q(70,b+80|0,5442)|0;c=v[22656];v[22656]=0;if((c|0)==1){c=6;break b}v[22656]=0;Q(70,b+92|0,2712)|0;c=v[22656];v[22656]=0;if((c|0)==1){c=7;break b}v[22656]=0;Q(70,b+104|0,9258)|0;c=v[22656];v[22656]=0;if((c|0)==1){c=8;break b}v[22656]=0;Q(70,b+116|0,8663)|0;c=v[22656];v[22656]=0;if((c|0)==1){c=9;break b}v[22656]=0;Q(70,b+128|0,9459)|0;c=v[22656];v[22656]=0;if((c|0)==1){c=10;break b}v[22656]=0;Q(70,b+140|0,2564)|0;c=v[22656];v[22656]=0;if((c|0)==1){c=11;break b}v[22656]=0;Q(70,b+152|0,4379)|0;c=v[22656];v[22656]=0;if((c|0)==1){c=12;break b}v[b+172>>2]=13;v[b+168>>2]=d;v[22656]=0;c=v[b+172>>2];v[b>>2]=v[b+168>>2];v[b+4>>2]=c;Q(2086,a|0,b|0)|0;a=v[22656];v[22656]=0;if((a|0)!=1){a=b+164|0;while(1){a=vb(a-12|0);if((d|0)!=(a|0)){continue}break}gb=b+176|0;return}a=b+164|0;break a}a=(b+8|0)+B(c,12)|0}b=P()|0;O()|0;while(1){a=vb(a-12|0);if((d|0)!=(a|0)){continue}break}S(b|0);L()}function Yba(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=C(0),o=C(0),p=0,q=0,r=C(0),s=0;g=gb-16|0;gb=g;m=a+44|0;if(mi(m)){j=Nd(m,0);k=Nd(m,1);h=od(m,0);i=od(m,1);r=z[a+4212>>2];v[g+12>>2]=d;if(d){e=v[a+4224>>2];while(1){s=a;f=v[a+4220>>2];a:{if(f>>>0>e>>>0){v[g+8>>2]=f-e;f=v[Fb(g+12|0,g+8|0)>>2];b:{if(!(r<C(1))){e=0;if(!f){break b}while(1){z[h>>2]=z[j>>2];z[i>>2]=z[k>>2];i=i+4|0;k=k+4|0;h=h+4|0;j=j+4|0;e=e+1|0;if((f|0)!=(e|0)){continue}break}break b}e=v[a+4224>>2];l=f+e|0;if(e>>>0>=l>>>0){break b}n=C(C(1)/C(y[a+4220>>2]));while(1){o=C(e>>>0);z[h>>2]=n*C(z[j>>2]*o);z[i>>2]=n*C(z[k>>2]*o);i=i+4|0;k=k+4|0;h=h+4|0;j=j+4|0;e=e+1|0;if((l|0)!=(e|0)){continue}break}}l=v[g+12>>2]-f|0;v[g+12>>2]=l;e=f+v[a+4224>>2]|0;break a}v[g+4>>2]=v[a+4216>>2]-e;f=v[Fb(g+12|0,g+4|0)>>2];c:{d:{e:{if(!(r<C(1))){e=0;if(f){break e}break d}p=v[a+4216>>2];q=v[a+4224>>2];e=p-q|0;l=e-f|0;if(e>>>0<=l>>>0){break c}n=C(C(1)/C(y[a+4220>>2]));while(1){o=C(e>>>0);z[h>>2]=n*C(z[j>>2]*o);z[i>>2]=n*C(z[k>>2]*o);i=i+4|0;k=k+4|0;h=h+4|0;j=j+4|0;e=e-1|0;if(l>>>0<e>>>0){continue}break}break c}while(1){v[h>>2]=0;v[i>>2]=0;i=i+4|0;h=h+4|0;e=e+1|0;if((f|0)!=(e|0)){continue}break}}e=f<<2;k=e+k|0;j=e+j|0;p=v[a+4216>>2];q=v[a+4224>>2]}l=v[g+12>>2]-f|0;v[g+12>>2]=l;e=f+q|0;e=e>>>0<p>>>0?e:0}v[s+4224>>2]=e;if(l){continue}break}}Ei(a,b,c,od(m,0),od(m,1),d)}gb=g+16|0}function pja(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;e=gb-48|0;gb=e;o=v[a+16>>2];f=v[a+44>>2];v[e+32>>2]=f;i=v[a+48>>2];v[e+36>>2]=i;b=v[a+52>>2];v[e+40>>2]=b;j=v[a+56>>2];v[e+44>>2]=j;p=v[a+24>>2];q=v[a+20>>2];h=v[a+4>>2];g=v[a>>2];v[e+24>>2]=g;v[e+28>>2]=h;k=v[a+12>>2];v[e+16>>2]=v[a+8>>2];v[e+20>>2]=k;if(d){while(1){k=g>>>10&4194048;g=(((h&2147483647)<<1|g>>>31)&-2)+o|0;i=0;j=1;b=1;f=0;while(1){h=t[f+g|0];v[(e+8|0)+(f<<2)>>2]=((B(k,t[g+(f|2)|0]-h|0)|0)/16384|0)+(h<<8);h=b;b=0;f=1;if(h){continue}break}while(1){k=(e+8|0)+(i<<2)|0;f=v[k>>2];l=v[a+60>>2];m=l;h=(e+32|0)+(i<<3)|0;i=v[h>>2];b=Lb(i,-16777216,16776704);n=v[a+64>>2];g=Lb(v[h+4>>2],-16777216,16776704);r=l>>31;l=f<<8;f=l;f=kqa(m,r,f,f>>31);m=jb;n=kqa(n,n>>31,b,b>>31);f=n+f|0;b=jb+m|0;b=f>>>0<n>>>0?b+1|0:b;m=f;f=v[a+68>>2];f=kqa(f,f>>31,g,g>>31);g=m+f|0;b=jb+b|0;b=f>>>0>g>>>0?b+1|0:b;g=g+8388608|0;b=g>>>0<8388608?b+1|0:b;b=Jc(g,b,24);v[h+4>>2]=i;g=v[a+72>>2];v[k>>2]=(b|0)/256;v[h>>2]=b-(g&l);i=1;b=j&1;j=0;if(b){continue}break}v[c>>2]=v[c>>2]+B(v[e+8>>2],q);v[c+4>>2]=v[c+4>>2]+B(v[e+12>>2],p);Ub(e+24|0,e+16|0);d=d-1|0;if(d){c=c+8|0;g=v[e+24>>2];h=v[e+28>>2];continue}break}g=v[e+24>>2];h=v[e+28>>2];j=v[e+44>>2];i=v[e+36>>2];f=v[e+32>>2];b=v[e+40>>2]}v[a+56>>2]=j;v[a+52>>2]=b;v[a+48>>2]=i;v[a+44>>2]=f;v[a>>2]=g;v[a+4>>2]=h;gb=e+48|0}function Yh(a,b,c){var d=0,e=0,f=0,g=0;if((b|0)==189){t[a+3843|0]=c>>>7;t[a+3844|0]=c>>>6&1;return}d=b&224;a:{if(!d){if((b|0)!=8){if((b|0)!=260){break a}d=1;b=0;while(1){e=B(b>>>0<3?b:b+6|0,44)+a|0;f=e+148|0;e=e+16|0;g=c&d;b:{if(g){Mo(e,f);break b}Mo(e,0)}t[f+40|0]=!g;d=d<<1&510;b=b+1|0;if((b|0)!=6){continue}break}break a}t[a+3842|0]=c>>>6&1;b=0;while(1){eB((B(b,44)+a|0)+16|0);b=b+1|0;if((b|0)!=18){continue}break}break a}if((d-160&65535)>>>0<=32){d=b&15;if(d>>>0>8){break a}a=(B(b&256?d+9|0:d,44)+a|0)+16|0;d=v[a+36>>2];c:{b=b&240;if((b|0)!=160){if((b|0)==192){break c}if((b|0)!=176){break a}b=c&32;ZR(a,b>>>5|0);f=c>>>2&7;YR(a,f);e=a;a=c&3;XR(e,a);if(!d){break a}ZR(d,(b|0)!=0);YR(d,f);XR(d,a);return}WR(a,c);if(!d){break a}WR(d,c);return}t[a+42|0]=(c&32)>>>5;t[a+41|0]=(c&16)>>>4;b=c>>>1&7;u[a+30>>1]=b?9-b|0:0;u[a+32>>1]=c&1;return}if((d|0)!=224&d>>>0>=129|-4144960>>>b&1){break a}e=a;a=t[(b&31)+35296|0];a=(e+B(b&256?a+18|0:a,84)|0)+808|0;d:{switch(d-32>>>5|0){case 0:t[a+79|0]=c>>>7;t[a+80|0]=(c&64)>>>6;t[a+78|0]=(c&32)>>>5;t[a+77|0]=(c&16)>>>4;No(a);u[a+14>>1]=x[((c&15)<<1)+35328>>1];return;case 1:u[a+68>>1]=w[(c>>>6|0)+18711|0];VR(a);u[a+22>>1]=(c&63)<<2;return;case 2:u[a+24>>1]=c>>>4;No(a);u[a+26>>1]=c&15;No(a);return;case 3:b=c>>>4|0;u[a+28>>1]=b>>>0<15?b<<4:496;u[a+30>>1]=c&15;No(a);return;case 6:break d;default:break a}}u[a+12>>1]=c&7}}function TR(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;e=gb-16|0;gb=e;v[e+12>>2]=b;a:{if(wk(a)){h=gb-16|0;gb=h;j=h+8|0;f=sf(3848);k=v[e+12>>2];c=f+808|0;b=f+16|0;while(1){v[b+16>>2]=0;v[b+20>>2]=0;v[b+36>>2]=0;t[b+42|0]=1;u[b+40>>1]=257;v[b+24>>2]=0;v[b+28>>2]=0;u[b+32>>1]=0;b=b+44|0;if((c|0)!=(b|0)){continue}break}c=f+3832|0;b=f+808|0;while(1){v[b>>2]=0;v[b+4>>2]=0;v[b+68>>2]=0;v[b+72>>2]=0;v[b+24>>2]=0;v[b+28>>2]=0;u[b+20>>1]=511;v[b+16>>2]=-1;u[b+14>>1]=1;u[b+6>>1]=0;u[b+8>>1]=0;u[b+10>>1]=0;u[b+12>>1]=0;t[b+73|0]=0;t[b+74|0]=0;t[b+75|0]=0;t[b+76|0]=0;t[b+77|0]=0;t[b+78|0]=0;t[b+79|0]=0;t[b+80|0]=0;b=b+84|0;if((c|0)!=(b|0)){continue}break}b=f;v[b+3832>>2]=0;v[b+3836>>2]=0;c=b+3837|0;t[c|0]=0;t[c+1|0]=0;t[c+2|0]=0;t[c+3|0]=0;t[c+4|0]=0;t[c+5|0]=0;t[c+6|0]=0;t[c+7|0]=0;while(1){ef((b+B(g,84)|0)+808|0,b);g=g+1|0;if((g|0)!=36){continue}break}while(1){v[(b+B(d,44)|0)+32>>2]=b;d=d+1|0;if((d|0)!=18){continue}break}d=0;while(1){c=(b+B(d,44)|0)+16|0;g=v[(d<<2)+35216>>2];b:{if(!(!(1<<d&3591)|d>>>0>11)){i=c;c=b+B(g,84)|0;$R(i,c+808|0,c+1060|0,c+1312|0,c+1564|0);break b}i=c;c=b+B(g,84)|0;$R(i,c+808|0,c+1060|0,0,0)}d=d+1|0;if((d|0)!=18){continue}break}d=0;while(1){No((b+B(d,84)|0)+808|0);d=d+1|0;if((d|0)!=36){continue}break}_R(b,k);b=v[Wi(j,f)>>2];gb=h+16|0;v[e+8>>2]=b;b=e+8|0;_C(a,b);ln(b);break a}_R(v[a>>2],b)}cB(a);gb=e+16|0}function Moa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=gb-80|0;gb=d;b=b&4095;u[d+78>>1]=b;a:{b:{c:{d:{if(b>>>0>=81){e=gb-16|0;gb=e;f=Tb(e,1547);Dc(d- -64|0,f);vb(f);gb=e+16|0;v[22656]=0;e=((b|0)==4095?c:b-80|0)+734016|0;c=kqa(e,e>>31,1e4,0)+14780|0;b=jb;b=lqa(c,c>>>0<14780?b+1|0:b,3652425,0);c=(((((b|0)/-4|0)+e|0)+B(b,-365)|0)+((b|0)/100|0)|0)+((b|0)/-400|0)|0;if((c|0)<0){b=b-1|0;c=(((e+((b|0)/-4|0)|0)+B(b,-365)|0)+((b|0)/100|0)|0)+((b|0)/-400|0)|0}g=b;b=(B(c,100)+52|0)/3060|0;e=b+2|0;f=(e|0)/12|0;v[d+44>>2]=g+f;R(112,d+48|0,d+44|0);g=v[22656];v[22656]=0;e:{f:{g:{h:{i:{j:{if((g|0)!=1){v[22656]=0;v[d+28>>2]=(e-B(f,12)|0)+1;R(114,d+32|0,d+28|0);e=v[22656];v[22656]=0;if((e|0)==1){break j}v[22656]=0;v[d+12>>2]=(((B(b,306)+5|0)/-10|0)+c|0)+1;R(114,d+16|0,d+12|0);b=v[22656];v[22656]=0;if((b|0)==1){break i}v[22656]=0;ha(556,a|0,d- -64|0,d+48|0,d+32|0,d+16|0);a=v[22656];v[22656]=0;if((a|0)==1){break h}vb(d+16|0);vb(d+32|0);break d}b=P()|0;O()|0;break e}b=P()|0;O()|0;break f}b=P()|0;O()|0;break g}b=P()|0;O()|0;vb(d+16|0)}vb(d+32|0)}vb(d+48|0)}break a}Df(d- -64|0,1527);v[22656]=0;R(557,d+48|0,d+78|0);b=v[22656];v[22656]=0;if((b|0)==1){break c}v[22656]=0;U(167,a|0,d- -64|0,d+48|0);a=v[22656];v[22656]=0;if((a|0)==1){break b}}vb(d+48|0);Hb(d- -64|0);gb=d+80|0;return}b=P()|0;O()|0;break a}b=P()|0;O()|0;vb(d+48|0)}Hb(d- -64|0);S(b|0);L()}function a4(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0;a=gb-352|0;gb=a;v[a+336>>2]=c;v[a+344>>2]=b;b=Mh(d);g=Wn(d,a+224|0);Vn(a+208|0,d,a+332|0);d=Kb(a+192|0);c=Kc(d);v[22656]=0;R(76,d|0,c|0);c=v[22656];v[22656]=0;a:{b:{c:{if((c|0)!=1){c=pc(d,0);v[a+188>>2]=c;v[a+12>>2]=a+16;v[a+8>>2]=0;j=v[a+332>>2];while(1){d:{v[22656]=0;h=Q(2457,a+344|0,a+336|0)|0;i=v[22656];v[22656]=0;if((i|0)==1){break d}if(!h){break c}if(v[a+188>>2]==(Ab(d)+c|0)){h=Ab(d);c=Ab(d);v[22656]=0;R(76,d|0,c<<1);c=v[22656];v[22656]=0;if((c|0)==1){break b}c=Kc(d);v[22656]=0;R(76,d|0,c|0);c=v[22656];v[22656]=0;if((c|0)==1){break b}c=pc(d,0);v[a+188>>2]=h+c}v[22656]=0;h=T(2459,a+344|0)|0;i=v[22656];v[22656]=0;if((i|0)==1){break d}if(rm(h,b,c,a+188|0,a+8|0,j,a+208|0,a+16|0,a+12|0,g)){break c}v[22656]=0;T(2461,a+344|0)|0;h=v[22656];v[22656]=0;if((h|0)!=1){continue}}break}break b}break b}e:{if(!Ab(a+208|0)){break e}g=v[a+12>>2];if((g-(a+16|0)|0)>159){break e}v[a+12>>2]=g+4;v[g>>2]=v[a+8>>2]}v[22656]=0;b=As(2438,c,v[a+188>>2],e,b);c=jb;g=v[22656];v[22656]=0;f:{if((g|0)==1){break f}v[f>>2]=b;v[f+4>>2]=c;jf(a+208|0,a+16|0,v[a+12>>2],e);v[22656]=0;b=Q(2458,a+344|0,a+336|0)|0;c=v[22656];v[22656]=0;if((c|0)==1){break f}if(b){v[e>>2]=v[e>>2]|2}b=v[a+344>>2];vb(d);vb(a+208|0);gb=a+352|0;break a}}b=P()|0;O()|0;vb(d);vb(a+208|0);S(b|0);L()}return b|0}function Y3(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0;a=gb-352|0;gb=a;v[a+336>>2]=c;v[a+344>>2]=b;b=Mh(d);g=Wn(d,a+224|0);Vn(a+208|0,d,a+332|0);d=Kb(a+192|0);c=Kc(d);v[22656]=0;R(76,d|0,c|0);c=v[22656];v[22656]=0;a:{b:{c:{if((c|0)!=1){c=pc(d,0);v[a+188>>2]=c;v[a+12>>2]=a+16;v[a+8>>2]=0;j=v[a+332>>2];while(1){d:{v[22656]=0;h=Q(2457,a+344|0,a+336|0)|0;i=v[22656];v[22656]=0;if((i|0)==1){break d}if(!h){break c}if(v[a+188>>2]==(Ab(d)+c|0)){h=Ab(d);c=Ab(d);v[22656]=0;R(76,d|0,c<<1);c=v[22656];v[22656]=0;if((c|0)==1){break b}c=Kc(d);v[22656]=0;R(76,d|0,c|0);c=v[22656];v[22656]=0;if((c|0)==1){break b}c=pc(d,0);v[a+188>>2]=h+c}v[22656]=0;h=T(2459,a+344|0)|0;i=v[22656];v[22656]=0;if((i|0)==1){break d}if(rm(h,b,c,a+188|0,a+8|0,j,a+208|0,a+16|0,a+12|0,g)){break c}v[22656]=0;T(2461,a+344|0)|0;h=v[22656];v[22656]=0;if((h|0)!=1){continue}}break}break b}break b}e:{if(!Ab(a+208|0)){break e}g=v[a+12>>2];if((g-(a+16|0)|0)>159){break e}v[a+12>>2]=g+4;v[g>>2]=v[a+8>>2]}v[22656]=0;b=As(2442,c,v[a+188>>2],e,b);c=jb;g=v[22656];v[22656]=0;f:{if((g|0)==1){break f}v[f>>2]=b;v[f+4>>2]=c;jf(a+208|0,a+16|0,v[a+12>>2],e);v[22656]=0;b=Q(2458,a+344|0,a+336|0)|0;c=v[22656];v[22656]=0;if((c|0)==1){break f}if(b){v[e>>2]=v[e>>2]|2}b=v[a+344>>2];vb(d);vb(a+208|0);gb=a+352|0;break a}}b=P()|0;O()|0;vb(d);vb(a+208|0);S(b|0);L()}return b|0}function Sz(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;g=gb-16|0;gb=g;i=mO(b,c);a:{if(!v[b+656>>2]|!(t[i+6|0]&1)){break a}e=v[i>>2];f=g+8|0;j=a+1074312|0;Db(f,j,31);f=Cb(f);d=pw(v[b+656>>2],c);if(cd(d)){break a}f=e+(f^1)|0;e=g+8|0;Db(e,j,31);h=Cb(e);e=w[d+12|0];b:{c:{if(!h){d:{if(!(e&2)){break d}e=x[Mb(d,w[d+14|0])>>1]+!(v[a+480180>>2]&1048580)|0;if(!(!(w[b+89|0]&8)|(!(w[d+12|0]&4)|w[d+14|0]!=w[d+16|0]))){h=g+8|0;Db(h,j,70);k=Cb(h)}if((e|0)!=(f|0)|k){break d}f=x[Mb(d,w[d+13|0])>>1]}if(!(!(w[d+12|0]&4)|w[b+89|0]&8)){if((x[Mb(d,w[d+16|0])>>1]+1|0)!=(f|0)){break b}f=x[Mb(d,w[d+15|0])>>1];a=g+8|0;Db(a,j,93);if(!Cb(a)|(c|0)!=1|v[b+88>>2]&2048){break b}t[i+6|0]=w[i+6|0]&254;break b}k=1;e=x[wo(d)>>1];if(f>>>0>e>>>0){break c}break b}e:{f:{if(!(!(e&4)|w[b+669|0]&8)){if(x[i+4>>1]==65535){break f}e=g+8|0;Db(e,j,97);if(Cb(e)){break f}e=w[d+12|0]}if(e&2){e=x[Mb(d,w[d+13|0])>>1];h=x[Mb(d,w[d+14|0])>>1]+1|0;break e}e=x[wo(d)>>1];k=f>>>0>e>>>0;h=e;break e}e=x[Mb(d,w[d+15|0])>>1];h=x[Mb(d,w[d+16|0])>>1]+1|0}e=f>>>0<h>>>0?f:e}g:{if(!k|c){break g}if(!(!(v[a+480180>>2]&16777248)&(!(w[b+89|0]&8)|v[a+480180>>2]==16384))){v[b+88>>2]=v[b+88>>2]|4096}if(w[wo(d)+2|0]|!(v[a+480180>>2]&16777248?1:x[b+786>>1])){break g}v[b+696>>2]=0;v[b+720>>2]=0;v[b+680>>2]=0;v[b+88>>2]=v[b+88>>2]|4096}f=e}a=g+8|0;Db(a,j,31);l=i,m=Cb(a)+f|0,v[l>>2]=m}gb=g+16|0}function b4(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0;a=gb-352|0;gb=a;v[a+336>>2]=c;v[a+344>>2]=b;b=Mh(d);h=Wn(d,a+224|0);Vn(a+208|0,d,a+332|0);d=Kb(a+192|0);c=Kc(d);v[22656]=0;R(76,d|0,c|0);c=v[22656];v[22656]=0;a:{b:{c:{if((c|0)!=1){c=pc(d,0);v[a+188>>2]=c;v[a+12>>2]=a+16;v[a+8>>2]=0;j=v[a+332>>2];while(1){d:{v[22656]=0;g=Q(2457,a+344|0,a+336|0)|0;i=v[22656];v[22656]=0;if((i|0)==1){break d}if(!g){break c}if(v[a+188>>2]==(Ab(d)+c|0)){g=Ab(d);c=Ab(d);v[22656]=0;R(76,d|0,c<<1);c=v[22656];v[22656]=0;if((c|0)==1){break b}c=Kc(d);v[22656]=0;R(76,d|0,c|0);c=v[22656];v[22656]=0;if((c|0)==1){break b}c=pc(d,0);v[a+188>>2]=g+c}v[22656]=0;g=T(2459,a+344|0)|0;i=v[22656];v[22656]=0;if((i|0)==1){break d}if(rm(g,b,c,a+188|0,a+8|0,j,a+208|0,a+16|0,a+12|0,h)){break c}v[22656]=0;T(2461,a+344|0)|0;g=v[22656];v[22656]=0;if((g|0)!=1){continue}}break}break b}break b}e:{if(!Ab(a+208|0)){break e}h=v[a+12>>2];if((h-(a+16|0)|0)>159){break e}v[a+12>>2]=h+4;v[h>>2]=v[a+8>>2]}v[22656]=0;b=da(2435,c|0,v[a+188>>2],e|0,b|0)|0;c=v[22656];v[22656]=0;f:{if((c|0)==1){break f}v[f>>2]=b;jf(a+208|0,a+16|0,v[a+12>>2],e);v[22656]=0;b=Q(2458,a+344|0,a+336|0)|0;c=v[22656];v[22656]=0;if((c|0)==1){break f}if(b){v[e>>2]=v[e>>2]|2}b=v[a+344>>2];vb(d);vb(a+208|0);gb=a+352|0;break a}}b=P()|0;O()|0;vb(d);vb(a+208|0);S(b|0);L()}return b|0}function _3(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0;a=gb-352|0;gb=a;v[a+336>>2]=c;v[a+344>>2]=b;b=Mh(d);h=Wn(d,a+224|0);Vn(a+208|0,d,a+332|0);d=Kb(a+192|0);c=Kc(d);v[22656]=0;R(76,d|0,c|0);c=v[22656];v[22656]=0;a:{b:{c:{if((c|0)!=1){c=pc(d,0);v[a+188>>2]=c;v[a+12>>2]=a+16;v[a+8>>2]=0;j=v[a+332>>2];while(1){d:{v[22656]=0;g=Q(2457,a+344|0,a+336|0)|0;i=v[22656];v[22656]=0;if((i|0)==1){break d}if(!g){break c}if(v[a+188>>2]==(Ab(d)+c|0)){g=Ab(d);c=Ab(d);v[22656]=0;R(76,d|0,c<<1);c=v[22656];v[22656]=0;if((c|0)==1){break b}c=Kc(d);v[22656]=0;R(76,d|0,c|0);c=v[22656];v[22656]=0;if((c|0)==1){break b}c=pc(d,0);v[a+188>>2]=g+c}v[22656]=0;g=T(2459,a+344|0)|0;i=v[22656];v[22656]=0;if((i|0)==1){break d}if(rm(g,b,c,a+188|0,a+8|0,j,a+208|0,a+16|0,a+12|0,h)){break c}v[22656]=0;T(2461,a+344|0)|0;g=v[22656];v[22656]=0;if((g|0)!=1){continue}}break}break b}break b}e:{if(!Ab(a+208|0)){break e}h=v[a+12>>2];if((h-(a+16|0)|0)>159){break e}v[a+12>>2]=h+4;v[h>>2]=v[a+8>>2]}v[22656]=0;b=da(2440,c|0,v[a+188>>2],e|0,b|0)|0;c=v[22656];v[22656]=0;f:{if((c|0)==1){break f}v[f>>2]=b;jf(a+208|0,a+16|0,v[a+12>>2],e);v[22656]=0;b=Q(2458,a+344|0,a+336|0)|0;c=v[22656];v[22656]=0;if((c|0)==1){break f}if(b){v[e>>2]=v[e>>2]|2}b=v[a+344>>2];vb(d);vb(a+208|0);gb=a+352|0;break a}}b=P()|0;O()|0;vb(d);vb(a+208|0);S(b|0);L()}return b|0}function Z3(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0;a=gb-352|0;gb=a;v[a+336>>2]=c;v[a+344>>2]=b;b=Mh(d);h=Wn(d,a+224|0);Vn(a+208|0,d,a+332|0);d=Kb(a+192|0);c=Kc(d);v[22656]=0;R(76,d|0,c|0);c=v[22656];v[22656]=0;a:{b:{c:{if((c|0)!=1){c=pc(d,0);v[a+188>>2]=c;v[a+12>>2]=a+16;v[a+8>>2]=0;j=v[a+332>>2];while(1){d:{v[22656]=0;g=Q(2457,a+344|0,a+336|0)|0;i=v[22656];v[22656]=0;if((i|0)==1){break d}if(!g){break c}if(v[a+188>>2]==(Ab(d)+c|0)){g=Ab(d);c=Ab(d);v[22656]=0;R(76,d|0,c<<1);c=v[22656];v[22656]=0;if((c|0)==1){break b}c=Kc(d);v[22656]=0;R(76,d|0,c|0);c=v[22656];v[22656]=0;if((c|0)==1){break b}c=pc(d,0);v[a+188>>2]=g+c}v[22656]=0;g=T(2459,a+344|0)|0;i=v[22656];v[22656]=0;if((i|0)==1){break d}if(rm(g,b,c,a+188|0,a+8|0,j,a+208|0,a+16|0,a+12|0,h)){break c}v[22656]=0;T(2461,a+344|0)|0;g=v[22656];v[22656]=0;if((g|0)!=1){continue}}break}break b}break b}e:{if(!Ab(a+208|0)){break e}h=v[a+12>>2];if((h-(a+16|0)|0)>159){break e}v[a+12>>2]=h+4;v[h>>2]=v[a+8>>2]}v[22656]=0;b=da(2441,c|0,v[a+188>>2],e|0,b|0)|0;c=v[22656];v[22656]=0;f:{if((c|0)==1){break f}v[f>>2]=b;jf(a+208|0,a+16|0,v[a+12>>2],e);v[22656]=0;b=Q(2458,a+344|0,a+336|0)|0;c=v[22656];v[22656]=0;if((c|0)==1){break f}if(b){v[e>>2]=v[e>>2]|2}b=v[a+344>>2];vb(d);vb(a+208|0);gb=a+352|0;break a}}b=P()|0;O()|0;vb(d);vb(a+208|0);S(b|0);L()}return b|0}function $3(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0;a=gb-352|0;gb=a;v[a+336>>2]=c;v[a+344>>2]=b;b=Mh(d);h=Wn(d,a+224|0);Vn(a+208|0,d,a+332|0);d=Kb(a+192|0);c=Kc(d);v[22656]=0;R(76,d|0,c|0);c=v[22656];v[22656]=0;a:{b:{c:{if((c|0)!=1){c=pc(d,0);v[a+188>>2]=c;v[a+12>>2]=a+16;v[a+8>>2]=0;j=v[a+332>>2];while(1){d:{v[22656]=0;g=Q(2457,a+344|0,a+336|0)|0;i=v[22656];v[22656]=0;if((i|0)==1){break d}if(!g){break c}if(v[a+188>>2]==(Ab(d)+c|0)){g=Ab(d);c=Ab(d);v[22656]=0;R(76,d|0,c<<1);c=v[22656];v[22656]=0;if((c|0)==1){break b}c=Kc(d);v[22656]=0;R(76,d|0,c|0);c=v[22656];v[22656]=0;if((c|0)==1){break b}c=pc(d,0);v[a+188>>2]=g+c}v[22656]=0;g=T(2459,a+344|0)|0;i=v[22656];v[22656]=0;if((i|0)==1){break d}if(rm(g,b,c,a+188|0,a+8|0,j,a+208|0,a+16|0,a+12|0,h)){break c}v[22656]=0;T(2461,a+344|0)|0;g=v[22656];v[22656]=0;if((g|0)!=1){continue}}break}break b}break b}e:{if(!Ab(a+208|0)){break e}h=v[a+12>>2];if((h-(a+16|0)|0)>159){break e}v[a+12>>2]=h+4;v[h>>2]=v[a+8>>2]}v[22656]=0;b=da(2439,c|0,v[a+188>>2],e|0,b|0)|0;c=v[22656];v[22656]=0;f:{if((c|0)==1){break f}u[f>>1]=b;jf(a+208|0,a+16|0,v[a+12>>2],e);v[22656]=0;b=Q(2458,a+344|0,a+336|0)|0;c=v[22656];v[22656]=0;if((c|0)==1){break f}if(b){v[e>>2]=v[e>>2]|2}b=v[a+344>>2];vb(d);vb(a+208|0);gb=a+352|0;break a}}b=P()|0;O()|0;vb(d);vb(a+208|0);S(b|0);L()}return b|0}function u4(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0;a=gb-240|0;gb=a;v[a+224>>2]=c;v[a+232>>2]=b;b=Mh(d);Xn(a+208|0,d,a+223|0);d=Kb(a+192|0);c=Kc(d);v[22656]=0;R(76,d|0,c|0);c=v[22656];v[22656]=0;a:{b:{c:{if((c|0)!=1){c=pc(d,0);v[a+188>>2]=c;v[a+12>>2]=a+16;v[a+8>>2]=0;g=t[a+223|0];while(1){d:{v[22656]=0;h=Q(2430,a+232|0,a+224|0)|0;i=v[22656];v[22656]=0;if((i|0)==1){break d}if(!h){break c}if(v[a+188>>2]==(Ab(d)+c|0)){h=Ab(d);c=Ab(d);v[22656]=0;R(76,d|0,c<<1);c=v[22656];v[22656]=0;if((c|0)==1){break b}c=Kc(d);v[22656]=0;R(76,d|0,c|0);c=v[22656];v[22656]=0;if((c|0)==1){break b}c=pc(d,0);v[a+188>>2]=h+c}v[22656]=0;h=T(2432,a+232|0)|0;i=v[22656];v[22656]=0;if((i|0)==1){break d}if(tm(h,b,c,a+188|0,a+8|0,g,a+208|0,a+16|0,a+12|0,81024)){break c}v[22656]=0;T(2434,a+232|0)|0;h=v[22656];v[22656]=0;if((h|0)!=1){continue}}break}break b}break b}e:{if(!Ab(a+208|0)){break e}g=v[a+12>>2];if((g-(a+16|0)|0)>159){break e}v[a+12>>2]=g+4;v[g>>2]=v[a+8>>2]}v[22656]=0;b=As(2438,c,v[a+188>>2],e,b);c=jb;g=v[22656];v[22656]=0;f:{if((g|0)==1){break f}v[f>>2]=b;v[f+4>>2]=c;jf(a+208|0,a+16|0,v[a+12>>2],e);v[22656]=0;b=Q(2431,a+232|0,a+224|0)|0;c=v[22656];v[22656]=0;if((c|0)==1){break f}if(b){v[e>>2]=v[e>>2]|2}b=v[a+232>>2];vb(d);vb(a+208|0);gb=a+240|0;break a}}b=P()|0;O()|0;vb(d);vb(a+208|0);S(b|0);L()}return b|0}function n4(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0;a=gb-240|0;gb=a;v[a+224>>2]=c;v[a+232>>2]=b;b=Mh(d);Xn(a+208|0,d,a+223|0);d=Kb(a+192|0);c=Kc(d);v[22656]=0;R(76,d|0,c|0);c=v[22656];v[22656]=0;a:{b:{c:{if((c|0)!=1){c=pc(d,0);v[a+188>>2]=c;v[a+12>>2]=a+16;v[a+8>>2]=0;g=t[a+223|0];while(1){d:{v[22656]=0;h=Q(2430,a+232|0,a+224|0)|0;i=v[22656];v[22656]=0;if((i|0)==1){break d}if(!h){break c}if(v[a+188>>2]==(Ab(d)+c|0)){h=Ab(d);c=Ab(d);v[22656]=0;R(76,d|0,c<<1);c=v[22656];v[22656]=0;if((c|0)==1){break b}c=Kc(d);v[22656]=0;R(76,d|0,c|0);c=v[22656];v[22656]=0;if((c|0)==1){break b}c=pc(d,0);v[a+188>>2]=h+c}v[22656]=0;h=T(2432,a+232|0)|0;i=v[22656];v[22656]=0;if((i|0)==1){break d}if(tm(h,b,c,a+188|0,a+8|0,g,a+208|0,a+16|0,a+12|0,81024)){break c}v[22656]=0;T(2434,a+232|0)|0;h=v[22656];v[22656]=0;if((h|0)!=1){continue}}break}break b}break b}e:{if(!Ab(a+208|0)){break e}g=v[a+12>>2];if((g-(a+16|0)|0)>159){break e}v[a+12>>2]=g+4;v[g>>2]=v[a+8>>2]}v[22656]=0;b=As(2442,c,v[a+188>>2],e,b);c=jb;g=v[22656];v[22656]=0;f:{if((g|0)==1){break f}v[f>>2]=b;v[f+4>>2]=c;jf(a+208|0,a+16|0,v[a+12>>2],e);v[22656]=0;b=Q(2431,a+232|0,a+224|0)|0;c=v[22656];v[22656]=0;if((c|0)==1){break f}if(b){v[e>>2]=v[e>>2]|2}b=v[a+232>>2];vb(d);vb(a+208|0);gb=a+240|0;break a}}b=P()|0;O()|0;vb(d);vb(a+208|0);S(b|0);L()}return b|0}function E3(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;k=gb-16|0;gb=k;m=Xx(g);g=Bx(g);Ug(k,g);a:{b:{c:{d:{if(gd(k)){v[22656]=0;Y(2464,m|0,a|0,c|0,d|0);g=v[22656];v[22656]=0;if((g|0)==1){break d}g=(c-a<<2)+d|0;v[f>>2]=g;break a}v[f>>2]=d;e:{f:{j=a;h=w[j|0];switch(h-43|0){case 0:case 2:break f;default:break e}}v[22656]=0;j=Q(2474,m|0,h<<24>>24)|0;h=v[22656];v[22656]=0;if((h|0)==1){break d}h=v[f>>2];v[f>>2]=h+4;v[h>>2]=j;j=a+1|0}if(!(w[j|0]!=48|(c-j|0)<2|(w[j+1|0]|32)!=120)){v[22656]=0;h=Q(2474,m|0,48)|0;i=v[22656];v[22656]=0;if((i|0)==1){break d}i=v[f>>2];v[f>>2]=i+4;v[i>>2]=h;h=t[j+1|0];v[22656]=0;h=Q(2474,m|0,h|0)|0;i=v[22656];v[22656]=0;if((i|0)==1){break d}i=v[f>>2];v[f>>2]=i+4;v[i>>2]=h;j=j+2|0}qm(j,c);v[22656]=0;n=T(2462,g|0)|0;g=v[22656];v[22656]=0;g:{if((g|0)!=1){if(c>>>0>j>>>0){break g}g=v[f>>2];break b}break d}o=(c-j|0)+j|0;g=j;h=0;i=0;while(1){h:{if(!w[pc(k,h)|0]){break h}if(t[pc(k,h)|0]!=(i|0)){break h}i=v[f>>2];v[f>>2]=i+4;v[i>>2]=n;h=(Ab(k)-1>>>0>h>>>0)+h|0;i=0}l=t[g|0];v[22656]=0;p=Q(2474,m|0,l|0)|0;l=v[22656];v[22656]=0;if((l|0)!=1){l=v[f>>2];v[f>>2]=l+4;v[l>>2]=p;i=i+1|0;g=g+1|0;if((o|0)==(g|0)){break c}continue}break}}a=P()|0;O()|0;vb(k);S(a|0);L()}g=l+4|0}xx((j-a<<2)+d|0,g);g=v[f>>2]}v[e>>2]=(b|0)==(c|0)?g:(b-a<<2)+d|0;vb(k);gb=k+16|0}function hia(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;e=gb-48|0;gb=e;m=v[a+16>>2];f=Ud(e+16|0);v[f+8>>2]=a+112;v[f+16>>2]=v[a+128>>2];o=f,p=jg(b+327720|0,v[b+20>>2],(v[a+88>>2]&16384)>>>14|0),v[o+12>>2]=p;b=v[f+16>>2];if(b){o=f,p=lg(a+8|0,b),v[o>>2]=p;v[f+4>>2]=jb}k=v[a+40>>2];l=v[a+36>>2];h=v[a+4>>2];g=v[a>>2];v[e+8>>2]=g;v[e+12>>2]=h;i=v[a+12>>2];v[e>>2]=v[a+8>>2];v[e+4>>2]=i;a:{if(d){while(1){i=0;j=g;v[e+40>>2]=g;v[e+44>>2]=n;h=((((h&2147483647)<<1|g>>>31)&2147483646)<<1)+m|0;b:{if((b|0)<=0){break b}while(1){g=(i&2147483647)<<1|j>>>31;Id(v[f+8>>2],(u[(g<<1|2)+h>>1]+u[h+((g&2147483646)<<1)>>1]|0)/8<<16>>16);Hd(v[f+8>>2],4);Ub(e+40|0,f);if((b|0)<2){break b}b=b-1|0;j=v[e+40>>2];i=v[e+44>>2];continue}}d=d-1|0;b=v[f+8>>2];Ub(b,b+8|0);b=v[f+8>>2];g=v[b+4>>2];if(g){j=b;b=(v[e+44>>2]&2147483647)<<1|v[e+40>>2]>>>31;Id(j,(u[(b<<1|2)+h>>1]+u[h+((b&2147483646)<<1)>>1]|0)/8<<16>>16);Hd(v[f+8>>2],g);b=v[f+8>>2];g=v[b>>2];v[b>>2]=g;v[b+4>>2]=0}b=ig(b,v[f+12>>2]);h=v[a+32>>2];l=v[a+28>>2]+l|0;i=l>>12;v[c>>2]=v[c>>2]+B(b,i);k=h+k|0;j=k>>12;v[c+4>>2]=v[c+4>>2]+B(b,j);Ub(e+8|0,e);if(d){c=c+8|0;b=v[f+16>>2];g=v[e+8>>2];h=v[e+12>>2];continue}break}g=v[e+8>>2];h=v[e+12>>2];break a}j=k>>12;i=l>>12}v[a+40>>2]=k;v[a+20>>2]=i;v[a+36>>2]=l;v[a+24>>2]=j;v[a>>2]=g;v[a+4>>2]=h;gb=e+48|0}function p1(a,b,c,d,e,f,g,h){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0;a=gb-16|0;gb=a;v[a+12>>2]=c;v[a+8>>2]=f;v[a+12>>2]=c;v[a+8>>2]=f;b=v[a+12>>2];a:{if(d>>>0<=b>>>0){break a}b:{while(1){if(f>>>0>=g>>>0){break b}j=t[b|0];c=j&255;l=a;c:{if((j|0)>=0){u[f>>1]=c;b=b+1|0;break c}j=2;if(c>>>0<194){break a}if(c>>>0<=223){if((d-b|0)<2){break b}i=w[b+1|0];if((i&192)!=128){break a}u[f>>1]=i&63|c<<6&1984;b=b+2|0;break c}if(c>>>0<=239){if((d-b|0)<3){break b}k=w[b+2|0];i=w[b+1|0];d:{e:{if((c|0)!=237){if((c|0)!=224){break e}if((i&224)==160){break d}break a}if((i&224)==128){break d}break a}if((i&192)!=128){break a}}if((k&192)!=128){break a}u[f>>1]=k&63|((i&63)<<6|c<<12);b=b+3|0;break c}if(c>>>0>244){break a}if((d-b|0)<4){break b}k=w[b+3|0];i=w[b+2|0];b=w[b+1|0];f:{g:{switch(c-240|0){case 0:if((b+112&255)>>>0<48){break f}break a;case 4:if((b&240)==128){break f}break a;default:break g}}if((b&192)!=128){break a}}if((i&192)!=128|(k&192)!=128){break a}if((g-f|0)<4){break b}c=c&7;if((b<<12&196608|c<<18)>>>0>1114111){break a}b=b<<2;u[f>>1]=(i>>>4&3|(b&192|c<<8|b&60))+16320|55296;v[a+8>>2]=f+2;u[f+2>>1]=i<<6&960|k&63|56320;b=v[a+12>>2]+4|0}v[l+12>>2]=b;f=v[a+8>>2]+2|0;v[a+8>>2]=f;b=v[a+12>>2];if(d>>>0>b>>>0){continue}break}j=0;break a}j=1}v[e>>2]=v[a+12>>2];v[h>>2]=v[a+8>>2];gb=a+16|0;return j|0}function Nia(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;g=gb-32|0;gb=g;a:{b:{c:{e=v[a+12>>2];h=v[a+8>>2];d:{if((e|0)<=1&h>>>0<=805306368|(e|0)<=0){if((e|0)>=-2&h>>>0>=3489660928|(e|0)>-2){break c}if((e|0)==-2&h>>>0>2147483647|e>>>0>4294967294){break d}break b}if((e|0)==1&h>>>0>2147483648|e>>>0>1){break b}}l=b+196648|0;break a}l=b+131112|0;break a}l=b+262184|0}m=v[a+16>>2];j=v[a+40>>2];k=v[a+36>>2];f=v[a+4>>2];i=v[a>>2];v[g+24>>2]=i;v[g+28>>2]=f;v[g+16>>2]=h;v[g+20>>2]=e;e:{if(d){while(1){e=((((f&2147483647)<<1|i>>>31)&2147483646)<<1)+m|0;b=(i>>>16&65520)+l|0;i=u[b+14>>1];n=u[b+12>>1];o=u[b+10>>1];p=u[b+8>>1];q=u[b+6>>1];r=u[b+4>>1];s=u[b+2>>1];t=u[b>>1];h=0;b=1;while(1){f=h<<1;v[(g+8|0)+(h<<2)>>2]=(((((((B(u[(f|-8)+e>>1],s)+B(u[(f|-12)+e>>1],t)|0)+B(u[(f|-4)+e>>1],r)|0)+B(u[e+f>>1],q)|0)+B(u[(f|4)+e>>1],p)|0)+B(u[(f|8)+e>>1],o)|0)+B(u[(f|12)+e>>1],n)|0)+B(u[(f|16)+e>>1],i)|0)/32768;f=b;b=0;h=1;if(f){continue}break}b=v[a+32>>2];k=v[a+28>>2]+k|0;h=k>>12;v[c>>2]=v[c>>2]+B(h,v[g+8>>2]);j=b+j|0;b=j>>12;v[c+4>>2]=v[c+4>>2]+B(b,v[g+12>>2]);Ub(g+24|0,g+16|0);d=d-1|0;if(d){c=c+8|0;i=v[g+24>>2];f=v[g+28>>2];continue}break}i=v[g+24>>2];f=v[g+28>>2];break e}b=j>>12;h=k>>12}v[a+40>>2]=j;v[a+20>>2]=h;v[a+36>>2]=k;v[a+24>>2]=b;v[a>>2]=i;v[a+4>>2]=f;gb=g+32|0}function w4(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0;a=gb-240|0;gb=a;v[a+224>>2]=c;v[a+232>>2]=b;b=Mh(d);Xn(a+208|0,d,a+223|0);d=Kb(a+192|0);c=Kc(d);v[22656]=0;R(76,d|0,c|0);c=v[22656];v[22656]=0;a:{b:{c:{if((c|0)!=1){c=pc(d,0);v[a+188>>2]=c;v[a+12>>2]=a+16;v[a+8>>2]=0;h=t[a+223|0];while(1){d:{v[22656]=0;g=Q(2430,a+232|0,a+224|0)|0;i=v[22656];v[22656]=0;if((i|0)==1){break d}if(!g){break c}if(v[a+188>>2]==(Ab(d)+c|0)){g=Ab(d);c=Ab(d);v[22656]=0;R(76,d|0,c<<1);c=v[22656];v[22656]=0;if((c|0)==1){break b}c=Kc(d);v[22656]=0;R(76,d|0,c|0);c=v[22656];v[22656]=0;if((c|0)==1){break b}c=pc(d,0);v[a+188>>2]=g+c}v[22656]=0;g=T(2432,a+232|0)|0;i=v[22656];v[22656]=0;if((i|0)==1){break d}if(tm(g,b,c,a+188|0,a+8|0,h,a+208|0,a+16|0,a+12|0,81024)){break c}v[22656]=0;T(2434,a+232|0)|0;g=v[22656];v[22656]=0;if((g|0)!=1){continue}}break}break b}break b}e:{if(!Ab(a+208|0)){break e}h=v[a+12>>2];if((h-(a+16|0)|0)>159){break e}v[a+12>>2]=h+4;v[h>>2]=v[a+8>>2]}v[22656]=0;b=da(2435,c|0,v[a+188>>2],e|0,b|0)|0;c=v[22656];v[22656]=0;f:{if((c|0)==1){break f}v[f>>2]=b;jf(a+208|0,a+16|0,v[a+12>>2],e);v[22656]=0;b=Q(2431,a+232|0,a+224|0)|0;c=v[22656];v[22656]=0;if((c|0)==1){break f}if(b){v[e>>2]=v[e>>2]|2}b=v[a+232>>2];vb(d);vb(a+208|0);gb=a+240|0;break a}}b=P()|0;O()|0;vb(d);vb(a+208|0);S(b|0);L()}return b|0}function s4(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0;a=gb-240|0;gb=a;v[a+224>>2]=c;v[a+232>>2]=b;b=Mh(d);Xn(a+208|0,d,a+223|0);d=Kb(a+192|0);c=Kc(d);v[22656]=0;R(76,d|0,c|0);c=v[22656];v[22656]=0;a:{b:{c:{if((c|0)!=1){c=pc(d,0);v[a+188>>2]=c;v[a+12>>2]=a+16;v[a+8>>2]=0;h=t[a+223|0];while(1){d:{v[22656]=0;g=Q(2430,a+232|0,a+224|0)|0;i=v[22656];v[22656]=0;if((i|0)==1){break d}if(!g){break c}if(v[a+188>>2]==(Ab(d)+c|0)){g=Ab(d);c=Ab(d);v[22656]=0;R(76,d|0,c<<1);c=v[22656];v[22656]=0;if((c|0)==1){break b}c=Kc(d);v[22656]=0;R(76,d|0,c|0);c=v[22656];v[22656]=0;if((c|0)==1){break b}c=pc(d,0);v[a+188>>2]=g+c}v[22656]=0;g=T(2432,a+232|0)|0;i=v[22656];v[22656]=0;if((i|0)==1){break d}if(tm(g,b,c,a+188|0,a+8|0,h,a+208|0,a+16|0,a+12|0,81024)){break c}v[22656]=0;T(2434,a+232|0)|0;g=v[22656];v[22656]=0;if((g|0)!=1){continue}}break}break b}break b}e:{if(!Ab(a+208|0)){break e}h=v[a+12>>2];if((h-(a+16|0)|0)>159){break e}v[a+12>>2]=h+4;v[h>>2]=v[a+8>>2]}v[22656]=0;b=da(2439,c|0,v[a+188>>2],e|0,b|0)|0;c=v[22656];v[22656]=0;f:{if((c|0)==1){break f}u[f>>1]=b;jf(a+208|0,a+16|0,v[a+12>>2],e);v[22656]=0;b=Q(2431,a+232|0,a+224|0)|0;c=v[22656];v[22656]=0;if((c|0)==1){break f}if(b){v[e>>2]=v[e>>2]|2}b=v[a+232>>2];vb(d);vb(a+208|0);gb=a+240|0;break a}}b=P()|0;O()|0;vb(d);vb(a+208|0);S(b|0);L()}return b|0}function q4(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0;a=gb-240|0;gb=a;v[a+224>>2]=c;v[a+232>>2]=b;b=Mh(d);Xn(a+208|0,d,a+223|0);d=Kb(a+192|0);c=Kc(d);v[22656]=0;R(76,d|0,c|0);c=v[22656];v[22656]=0;a:{b:{c:{if((c|0)!=1){c=pc(d,0);v[a+188>>2]=c;v[a+12>>2]=a+16;v[a+8>>2]=0;h=t[a+223|0];while(1){d:{v[22656]=0;g=Q(2430,a+232|0,a+224|0)|0;i=v[22656];v[22656]=0;if((i|0)==1){break d}if(!g){break c}if(v[a+188>>2]==(Ab(d)+c|0)){g=Ab(d);c=Ab(d);v[22656]=0;R(76,d|0,c<<1);c=v[22656];v[22656]=0;if((c|0)==1){break b}c=Kc(d);v[22656]=0;R(76,d|0,c|0);c=v[22656];v[22656]=0;if((c|0)==1){break b}c=pc(d,0);v[a+188>>2]=g+c}v[22656]=0;g=T(2432,a+232|0)|0;i=v[22656];v[22656]=0;if((i|0)==1){break d}if(tm(g,b,c,a+188|0,a+8|0,h,a+208|0,a+16|0,a+12|0,81024)){break c}v[22656]=0;T(2434,a+232|0)|0;g=v[22656];v[22656]=0;if((g|0)!=1){continue}}break}break b}break b}e:{if(!Ab(a+208|0)){break e}h=v[a+12>>2];if((h-(a+16|0)|0)>159){break e}v[a+12>>2]=h+4;v[h>>2]=v[a+8>>2]}v[22656]=0;b=da(2440,c|0,v[a+188>>2],e|0,b|0)|0;c=v[22656];v[22656]=0;f:{if((c|0)==1){break f}v[f>>2]=b;jf(a+208|0,a+16|0,v[a+12>>2],e);v[22656]=0;b=Q(2431,a+232|0,a+224|0)|0;c=v[22656];v[22656]=0;if((c|0)==1){break f}if(b){v[e>>2]=v[e>>2]|2}b=v[a+232>>2];vb(d);vb(a+208|0);gb=a+240|0;break a}}b=P()|0;O()|0;vb(d);vb(a+208|0);S(b|0);L()}return b|0}function o4(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0;a=gb-240|0;gb=a;v[a+224>>2]=c;v[a+232>>2]=b;b=Mh(d);Xn(a+208|0,d,a+223|0);d=Kb(a+192|0);c=Kc(d);v[22656]=0;R(76,d|0,c|0);c=v[22656];v[22656]=0;a:{b:{c:{if((c|0)!=1){c=pc(d,0);v[a+188>>2]=c;v[a+12>>2]=a+16;v[a+8>>2]=0;h=t[a+223|0];while(1){d:{v[22656]=0;g=Q(2430,a+232|0,a+224|0)|0;i=v[22656];v[22656]=0;if((i|0)==1){break d}if(!g){break c}if(v[a+188>>2]==(Ab(d)+c|0)){g=Ab(d);c=Ab(d);v[22656]=0;R(76,d|0,c<<1);c=v[22656];v[22656]=0;if((c|0)==1){break b}c=Kc(d);v[22656]=0;R(76,d|0,c|0);c=v[22656];v[22656]=0;if((c|0)==1){break b}c=pc(d,0);v[a+188>>2]=g+c}v[22656]=0;g=T(2432,a+232|0)|0;i=v[22656];v[22656]=0;if((i|0)==1){break d}if(tm(g,b,c,a+188|0,a+8|0,h,a+208|0,a+16|0,a+12|0,81024)){break c}v[22656]=0;T(2434,a+232|0)|0;g=v[22656];v[22656]=0;if((g|0)!=1){continue}}break}break b}break b}e:{if(!Ab(a+208|0)){break e}h=v[a+12>>2];if((h-(a+16|0)|0)>159){break e}v[a+12>>2]=h+4;v[h>>2]=v[a+8>>2]}v[22656]=0;b=da(2441,c|0,v[a+188>>2],e|0,b|0)|0;c=v[22656];v[22656]=0;f:{if((c|0)==1){break f}v[f>>2]=b;jf(a+208|0,a+16|0,v[a+12>>2],e);v[22656]=0;b=Q(2431,a+232|0,a+224|0)|0;c=v[22656];v[22656]=0;if((c|0)==1){break f}if(b){v[e>>2]=v[e>>2]|2}b=v[a+232>>2];vb(d);vb(a+208|0);gb=a+240|0;break a}}b=P()|0;O()|0;vb(d);vb(a+208|0);S(b|0);L()}return b|0}function ppa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;e=gb-1072|0;gb=e;v[e+1068>>2]=c;n=e,o=Ae(b),t[n+8|0]=o;t[e+4|0]=1;d=e+8|0;c=w[df(d,e+4|0)|0];i=sD(d,b);v[22656]=0;m=nn(i);d=v[22656];v[22656]=0;a:{b:{c:{d:{if((d|0)==1){break d}v[22656]=0;d=T(467,b|0)|0;f=v[22656];v[22656]=0;if((f|0)==1){break b}v[e+4>>2]=d;v[22656]=0;v[e>>2]=536870911;d=Fb(e+4|0,e);f=v[22656];v[22656]=0;if((f|0)==1){break c}qc(e+1068|0,v[d>>2]<<3);v[22656]=0;l=Q(514,a|0,v[e+1068>>2])|0;a=v[22656];v[22656]=0;if((a|0)==1){break d}v[22656]=0;f=8;g=Q(200,i|0,8)|0;d=v[22656];v[22656]=0;a=1;e:{f:{if((d|0)==1){break f}d=zb(g&255);n=lc(l,0),o=d,t[n|0]=o;g:{if(y[e+1068>>2]<2){break g}d=c;while(1){v[22656]=0;k=f&255;h=Q(200,i|0,k|0)|0;j=v[22656];v[22656]=0;h:{i:{j:{k:{if((j|0)!=1){if(h){break k}if(k>>>0>8){break g}f=f+1|0;break j}break f}j=g;g=h>>>1|0;g=j+(h&1?0-g|0:g)|0;j=zb(g&255);n=lc(l,a),o=j,t[n|0]=o;a=a+1|0;if(!(h>>>k-1|0)){break i}}d=c;break h}d=d-1|0;h=d&255;f=f-(!h&k>>>0>1)|0;d=h?d:c}if(y[e+1068>>2]>a>>>0){continue}break}}v[22656]=0;a=nn(i);c=v[22656];v[22656]=0;if((c|0)==1){break f}v[22656]=0;Q(190,b|0,((a-m|0)+3&-4)+m|0)|0;a=v[22656];v[22656]=0;if((a|0)!=1){break e}}c=P()|0;O()|0;gc(l);break a}xb(i);gb=e+1072|0;return}c=P()|0;O()|0;break a}c=P()|0;O()|0;break a}c=P()|0;O()|0}xb(i);S(c|0);L()}function hla(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;k=gb-144|0;gb=k;XB(a);a:{b:{if(!Wf(a,64)){break b}c:{d:{if(!Wl(a,60)){break d}if(!pU(a,11407)){break d}h=15;e=450;break c}XB(a);if(!Wf(a,128)){break b}b=0;if(!Wl(a,124)){break a}if(!pU(a,12505)){break a}h=31;e=930}XB(a);b=0;while(1){j=0;f=gb-16|0;gb=f;c=gb-32|0;gb=c;d=c+24|0;zi(d,f+8|0);g=yb(d);d=v[c+28>>2];i=v[c+24>>2];v[c+8>>2]=i;v[c+12>>2]=d;v[c>>2]=i;v[c+4>>2]=d;d=a;i=c+16|0;hd(i,a,c);i=yb(i);if((i|0)==(g|0)){bd(d,yb(c+24|0))}gb=c+32|0;if((g|0)==(i|0)){d=f+8|0;j=Xb(w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24))}gb=f+16|0;if(j>>>0>131072){break a}l=l+1|0;if((l&65535)>>>0<h>>>0){continue}break}bd(a,4);if(!Wf(a,2)){break b}h=0;f=gb-16|0;gb=f;c=gb-32|0;gb=c;d=c+24|0;Cn(d,f+8|0);j=yb(d);d=v[c+28>>2];g=v[c+24>>2];v[c+8>>2]=g;v[c+12>>2]=d;v[c>>2]=g;v[c+4>>2]=d;d=a;g=c+16|0;hd(g,a,c);g=yb(g);if((g|0)==(j|0)){bd(d,yb(c+24|0))}gb=c+32|0;if((g|0)==(j|0)){d=f+8|0;h=Ib(w[d|0]|w[d+1|0]<<8)}gb=f+16|0;if(h>>>0<178){break a}b=-1;if(!Wf(a,e)){break a}bd(a,e);e=gb-32|0;gb=e;d=e+24|0;h=k+8|0;mV(d,h);d=yb(d);c=v[e+28>>2];f=v[e+24>>2];v[e+8>>2]=f;v[e+12>>2]=c;v[e>>2]=f;v[e+4>>2]=c;c=e+16|0;hd(c,a,e);c=yb(c);if((c|0)==(d|0)){bd(a,yb(e+24|0))}gb=e+32|0;a=(c|0)==(d|0);if(!a){cC(h)}if(!a){break a}b=oU(k+8|0);break a}b=-1}gb=k+144|0;return b|0}function j_(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=gb-32|0;gb=d;a:{if((w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24))==1397771593){ud(b,32);ki(d,1,a+4|0);c=d+16|0;Bc(c,d);v[22656]=0;Q(303,b+43|0,c|0)|0;c=v[22656];v[22656]=0;if((c|0)==1){break a}vb(d+16|0);u[b+30>>1]=w[a+19|0]<<2;zg(b+30|0,256);u[b+32>>1]=w[a+17|0];zg(b+32|0,64);c=a+47|0;u[b+28>>1]=(w[c|0]&127)<<2;zg(b+28|0,256);if(t[c|0]<0){u[b+34>>1]=x[b+34>>1]|32}c=a+18|0;if(w[c|0]&16){u[b+34>>1]=x[b+34>>1]|2}if(w[c|0]&32){u[b+34>>1]=x[b+34>>1]|8}if(w[c|0]&64){u[b+34>>1]=x[b+34>>1]|4}if(t[c|0]<0){u[b+34>>1]=x[b+34>>1]|16}c=a+60|0;c=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);c=c?c:8363;v[b+24>>2]=c>>>0>256?c:256;c=a+48|0;v[b>>2]=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);c=a+52|0;v[b+4>>2]=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);c=a+56|0;v[b+8>>2]=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);c=a- -64|0;v[b+12>>2]=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);c=a+68|0;v[b+16>>2]=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);xk(b);t[b+38|0]=w[(w[a+79|0]&7)+46144|0];t[b+41|0]=w[a+76|0];t[b+40|0]=w[a+77|0]&127;t[b+39|0]=w[a+78|0];c=512;e=a+46|0;b:{if(w[e|0]!=64){c=16384;if(w[e|0]!=128){break b}}u[b+34>>1]=x[b+34>>1]|c}a=a+72|0;c=w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24)}gb=d+32|0;return c|0}a=P()|0;O()|0;vb(d+16|0);S(a|0);L()}function r_(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0;e=gb-1088|0;gb=e;Jh(a);Qb(a+20|0,0,1040);i=a;v[a+1064>>2]=0;v[a+1068>>2]=0;v[a+1060>>2]=c;g=a+1072|0;v[g>>2]=0;v[g+4>>2]=0;v[a+1080>>2]=0;t[a+1084|0]=d;a:{if(fd(c)){g=a+1064|0;while(1){v[a+1064>>2]=0;v[a+1068>>2]=0;b:{if(!v[c>>2]){break b}while(1){v[22656]=0;d=Q(191,b|0,2)|0;f=v[22656];v[22656]=0;c:{d:{e:{if((f|0)!=1){if(!d){break b}v[22656]=0;d=T(287,b|0)|0;f=v[22656];v[22656]=0;if((f|0)==1){break e}if(!d){break c}v[22656]=0;U(288,e|0,b|0,d|0);d=v[22656];v[22656]=0;f:{g:{if((d|0)!=1){v[22656]=0;d=Lp(e+24|0,e);f=v[22656];v[22656]=0;if((f|0)==1){break g}Vc(i,d);hc(i+20|0,d+20|0,1040);xb(e+24|0);xb(e);v[a+1076>>2]=0;v[a+1080>>2]=0;f=ij(v[a+1060>>2]);d=v[a+1060>>2];if(f>>>0<2){break f}d=v[d+20>>2];v[22656]=0;R(289,a|0,d+(h<<1)|0);d=v[22656];v[22656]=0;if((d|0)!=1){break c}break d}d=P()|0;O()|0;break a}d=P()|0;O()|0;xb(e);break a}d=v[d+20>>2];v[22656]=0;R(290,a|0,d+h|0);d=v[22656];v[22656]=0;if((d|0)==1){break d}break c}d=P()|0;O()|0;break a}d=P()|0;O()|0;break a}d=V(27364)|0;if((O()|0)!=(ea(27364)|0)){break a}Z(d|0)|0;v[22656]=0;X(20);d=v[22656];v[22656]=0;if((d|0)!=1){break c}d=P()|0;O()|0;break a}if(y[g>>2]<y[c>>2]){continue}break}}h=h+1|0;if(fd(v[a+1060>>2])>>>0>h>>>0){continue}break}}gb=e+1088|0;return a|0}xb(a);S(d|0);L()}function iJ(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0,j=C(0),k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=C(0);d=(b<<2)+a|0;g=d+1068|0;l=c<<1&-4;q=g,r=$d(a,l),v[q>>2]=r;i=d+1076|0;q=i,r=$d(a,l),v[q>>2]=r;k=$d(a,c&-4);v[d+1084>>2]=k;a:{g=v[g>>2];if(!g){break a}i=v[i>>2];if(!i|!k){break a}d=c;b:{if((d|0)<4){break b}j=C(d|0);p=d>>>2|0;while(1){m=e<<2;f=+C(C(C(h<<2)*C(3.1415927410125732))/j);q=m+g|0,s=C(Me(f)),z[q>>2]=s;n=e|1;o=n<<2;q=o+g|0,s=C(-C(ri(f))),z[q>>2]=s;f=+C(C(C(C(n|0)*C(3.1415927410125732))/j)*C(.5));q=i+m|0,s=C(C(Me(f))*C(.5)),z[q>>2]=s;q=i+o|0,s=C(C(ri(f))*C(.5)),z[q>>2]=s;e=e+2|0;h=h+1|0;if((p|0)!=(h|0)){continue}break}if((d|0)<8){break b}d=d>>3;d=(d|0)>1?d:1;e=0;h=0;while(1){g=e|1;f=+C(C(C(g<<1)*C(3.1415927410125732))/j);q=k+(e<<2)|0,s=C(Me(f)),z[q>>2]=s;q=k+(g<<2)|0,s=C(-C(ri(f))),z[q>>2]=s;e=e+2|0;h=h+1|0;if((d|0)!=(h|0)){continue}break}}e=(b<<2)+a|0;d=$d(a,l);v[e+1092>>2]=d;if(!d){break a}b=c;if((b|0)>=2){b=b>>1;f=+(b|0);h=(b|0)>1?b:1;b=0;while(1){j=C(ri((+(b|0)+.5)/f*.5*3.1415927410125732));q=d+(b<<2)|0,s=C(ri(+C(j*j)*1.5707963705062866)),z[q>>2]=s;b=b+1|0;if((h|0)!=(b|0)){continue}break}}b=$d(a,c>>2&-2);v[e+1100>>2]=b;if(!b){break a}a=c;d=Dm(a);if((a|0)>=8){c=36-d|0;d=a>>>3|0;a=0;while(1){q=b+(a<<1)|0,r=Bm(a)>>>c<<2,u[q>>1]=r;a=a+1|0;if((d|0)!=(a|0)){continue}break}}return 1}ec(a,3);return 0}function Lea(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;i=gb-32|0;gb=i;v[i+24>>2]=b;b=v[a>>2];p=i,q=Vb(a),v[p>>2]=q;b=b+B(Yt(i+24|0,i),6)|0;a:{b:{if(!c){break b}e=v[wb(a)>>2];f=v[a+4>>2];if((e-f|0)/6>>>0>=c>>>0){g=c;h=f-b|0;e=(h|0)/6|0;if(e>>>0<c>>>0){XC(a,c-e|0,d);g=e;if(!h){break b}}l=gb-16|0;gb=l;j=a;e=b;o=f;n=v[a+4>>2];h=B((n-(B(c,6)+e|0)|0)/6|0,6)+e|0;m=Br(l,a,(f-h|0)/6|0);if(f>>>0>h>>>0){k=v[m+4>>2];f=h;while(1){wb(j);CN(k,f);k=k+6|0;v[m+4>>2]=k;f=f+6|0;if(o>>>0>f>>>0){continue}break}}$b(m);f=h-e|0;if(f){yh(n+B((f|0)/-6|0,6)|0,e,f)}gb=l+16|0;a=B(b>>>0<=d>>>0?y[a+4>>2]>d>>>0?c:0:0,6)+d|0;if(g){while(1){c=w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24);t[e|0]=c;t[e+1|0]=c>>>8;t[e+2|0]=c>>>16;t[e+3|0]=c>>>24;c=w[a+4|0]|w[a+5|0]<<8;t[e+4|0]=c;t[e+5|0]=c>>>8;e=e+6|0;g=g-1|0;if(g){continue}break}}break b}g=wb(a);g=KW(i,IC(a,Kg(a)+c|0),(b-v[a>>2]|0)/6|0,g);v[22656]=0;U(643,g|0,c|0,d|0);c=v[22656];v[22656]=0;if((c|0)==1){break a}VC(a);c=v[g+4>>2];f=g+4|0;IW(wb(a),v[a>>2],b,f);wb(a);h=g+8|0;d=h;j=v[a+4>>2];if((j|0)!=(b|0)){e=v[d>>2];while(1){CN(e,b);e=v[d>>2]+6|0;v[d>>2]=e;b=b+6|0;if((j|0)!=(b|0)){continue}break}}xc(a,f);xc(a+4|0,h);xc(wb(a),dc(g));v[g>>2]=v[g+4>>2];KC(a,Kg(a));b=c;uv(g)}Hg(b);gb=i+32|0;return}a=P()|0;O()|0;uv(g);S(a|0);L()}function Oia(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,w=0;f=gb-32|0;gb=f;a:{b:{c:{e=v[a+12>>2];g=v[a+8>>2];d:{if((e|0)<=1&g>>>0<=805306368|(e|0)<=0){if((e|0)>=-2&g>>>0>=3489660928|(e|0)>-2){break c}if((e|0)==-2&g>>>0>2147483647|e>>>0>4294967294){break d}break b}if((e|0)==1&g>>>0>2147483648|e>>>0>1){break b}}l=b+196648|0;break a}l=b+131112|0;break a}l=b+262184|0}m=v[a+16>>2];j=v[a+40>>2];k=v[a+36>>2];i=v[a+4>>2];h=v[a>>2];v[f+24>>2]=h;v[f+28>>2]=i;v[f+16>>2]=g;v[f+20>>2]=e;e:{if(d){while(1){g=(((i&2147483647)<<1|h>>>31)&-2)+m|0;b=(h>>>16&65520)+l|0;h=u[b+14>>1];n=u[b+12>>1];o=u[b+10>>1];p=u[b+8>>1];q=u[b+6>>1];r=u[b+4>>1];s=u[b+2>>1];w=u[b>>1];b=0;e=1;while(1){v[(f+8|0)+(b<<2)>>2]=(((((((B(t[(b|-4)+g|0],s)+B(t[(b|-6)+g|0],w)|0)+B(t[(b|-2)+g|0],r)|0)+B(t[b+g|0],q)|0)+B(t[(b|2)+g|0],p)|0)+B(t[(b|4)+g|0],o)|0)+B(t[(b|6)+g|0],n)|0)+B(t[(b|8)+g|0],h)<<8)/32768;i=e;e=0;b=1;if(i){continue}break}b=v[a+32>>2];k=v[a+28>>2]+k|0;e=k>>12;v[c>>2]=v[c>>2]+B(e,v[f+8>>2]);j=b+j|0;b=j>>12;v[c+4>>2]=v[c+4>>2]+B(b,v[f+12>>2]);Ub(f+24|0,f+16|0);d=d-1|0;if(d){c=c+8|0;h=v[f+24>>2];i=v[f+28>>2];continue}break}h=v[f+24>>2];i=v[f+28>>2];break e}b=j>>12;e=k>>12}v[a+40>>2]=j;v[a+20>>2]=e;v[a+36>>2]=k;v[a+24>>2]=b;v[a>>2]=h;v[a+4>>2]=i;gb=f+32|0}function V2(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0;a=gb-448|0;gb=a;v[a+432>>2]=c;v[a+440>>2]=b;v[a+20>>2]=2479;h=ge(a+24|0,a+32|0,a+20|0);v[22656]=0;Fc(a+16|0,e);b=v[22656];v[22656]=0;a:{b:{c:{d:{if((b|0)!=1){v[22656]=0;i=T(2452,a+16|0)|0;b=v[22656];v[22656]=0;if((b|0)==1){break b}t[a+15|0]=0;b=v[e+4>>2];v[22656]=0;b=ra(2488,a+440|0,c|0,d|0,a+16|0,b|0,f|0,a+15|0,i|0,h|0,a+20|0,a+432|0)|0;c=v[22656];v[22656]=0;if((c|0)==1){break b}if(!b){break c}c=gb-16|0;gb=c;b=g;e:{if(De(b)){d=v[b>>2];v[c+12>>2]=0;Ge(d,c+12|0);de(b,0);break e}v[c+8>>2]=0;Ge(b,c+8|0);_e(b,0)}gb=c+16|0;if(!w[a+15|0]){break d}v[22656]=0;b=Q(2474,i|0,45)|0;c=v[22656];v[22656]=0;if((c|0)==1){break b}v[22656]=0;R(63,g|0,b|0);b=v[22656];v[22656]=0;if((b|0)!=1){break d}break b}e=P()|0;O()|0;break a}v[22656]=0;b=Q(2474,i|0,48)|0;c=v[22656];v[22656]=0;if((c|0)==1){break b}e=v[h>>2];c=v[a+20>>2];d=c-4|0;f:{if(e>>>0>=d>>>0){break f}while(1){if((b|0)!=v[e>>2]){break f}e=e+4|0;if(d>>>0>e>>>0){continue}break}}v[22656]=0;U(2493,g|0,e|0,c|0);b=v[22656];v[22656]=0;if((b|0)!=1){break c}break b}v[22656]=0;b=Q(2458,a+440|0,a+432|0)|0;c=v[22656];v[22656]=0;if((c|0)==1){break b}if(b){v[f>>2]=v[f>>2]|2}b=v[a+440>>2];Wb(a+16|0);Ic(h);gb=a+448|0;return b|0}e=P()|0;O()|0;Wb(a+16|0)}Ic(h);S(e|0);L()}function via(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,w=0,x=0,y=0,z=0,A=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0;i=gb-16|0;gb=i;f=v[a+48>>2];m=v[a+24>>2];n=v[a+20>>2];k=v[a+44>>2];o=v[a+16>>2];g=v[a+4>>2];h=v[a>>2];v[i+8>>2]=h;v[i+12>>2]=g;e=v[a+12>>2];v[i>>2]=v[a+8>>2];v[i+4>>2]=e;a:{if(!d){e=k;k=f;break a}while(1){e=(g<<1)+o|0;p=u[e-6>>1];g=(((h>>>16|0)+4&131064)<<1)+b|0;h=u[g+24>>1];q=u[e-4>>1];r=u[g+26>>1];s=u[e-2>>1];t=u[g+28>>1];w=u[e>>1];x=u[g+30>>1];y=u[e+2>>1];z=u[g+32>>1];A=u[e+4>>1];C=u[g+34>>1];D=u[e+6>>1];E=u[g+36>>1];F=u[e+8>>1];g=u[g+38>>1];e=v[a+60>>2];G=e;H=e>>31;e=Lb(k,-16777216,16776704);j=v[a+64>>2];f=Lb(f,-16777216,16776704);e=kqa(j,j>>31,e,e>>31);j=jb;I=e;e=v[a+68>>2];l=kqa(e,e>>31,f,f>>31);e=I+l|0;f=jb+j|0;f=e>>>0<l>>>0?f+1|0:f;j=e;g=(((((B(A,C)+B(y,z)|0)+B(D,E)|0)+B(g,F)|0)/2|0)+((((B(q,r)+B(h,p)|0)+B(s,t)|0)+B(w,x)|0)/2|0)|0)/16384<<8;e=g;h=kqa(G,H,e,e>>31);e=j+h|0;f=jb+f|0;f=e>>>0<h>>>0?f+1|0:f;e=e+8388608|0;f=e>>>0<8388608?f+1|0:f;f=Jc(e,f,24);e=v[a+72>>2];h=(f|0)/256|0;v[c>>2]=v[c>>2]+B(h,n);v[c+4>>2]=v[c+4>>2]+B(h,m);e=f-(e&g)|0;Ub(i+8|0,i);d=d-1|0;if(d){c=c+8|0;h=v[i+8>>2];g=v[i+12>>2];f=k;k=e;continue}break}h=v[i+8>>2];g=v[i+12>>2]}v[a+48>>2]=k;v[a+44>>2]=e;v[a>>2]=h;v[a+4>>2]=g;gb=i+16|0}function q1(a,b,c,d,e,f,g,h){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0;a=gb-16|0;gb=a;v[a+12>>2]=c;v[a+8>>2]=f;v[a+12>>2]=c;v[a+8>>2]=f;a:{b:{c=v[a+12>>2];if(d>>>0>c>>>0){while(1){b=x[c>>1];c:{if(b>>>0<=127){f=1;c=v[a+8>>2];if((g-c|0)<=0){break a}v[a+8>>2]=c+1;t[c|0]=b;break c}if(b>>>0<=2047){c=v[a+8>>2];if((g-c|0)<2){break b}v[a+8>>2]=c+1;t[c|0]=b>>>6|192;c=v[a+8>>2];v[a+8>>2]=c+1;t[c|0]=b&63|128;break c}if(b>>>0<=55295){c=v[a+8>>2];if((g-c|0)<3){break b}v[a+8>>2]=c+1;t[c|0]=b>>>12|224;c=v[a+8>>2];v[a+8>>2]=c+1;t[c|0]=b>>>6&63|128;c=v[a+8>>2];v[a+8>>2]=c+1;t[c|0]=b&63|128;break c}d:{e:{if(b>>>0<=56319){f=1;if((d-c|0)<4){break a}i=x[c+2>>1];if((i&64512)!=56320){break e}if((g-v[a+8>>2]|0)<4){break a}v[a+12>>2]=c+2;c=v[a+8>>2];v[a+8>>2]=c+1;f=c;c=(b>>>6&15)+1|0;t[f|0]=c>>>2|240;f=v[a+8>>2];v[a+8>>2]=f+1;t[f|0]=c<<4&48|b>>>2&15|128;c=v[a+8>>2];v[a+8>>2]=c+1;t[c|0]=i>>>6&15|b<<4&48|128;b=v[a+8>>2];v[a+8>>2]=b+1;t[b|0]=i&63|128;break c}if(b>>>0>=57344){break d}}f=2;break a}c=v[a+8>>2];if((g-c|0)<3){break b}v[a+8>>2]=c+1;t[c|0]=b>>>12|224;c=v[a+8>>2];v[a+8>>2]=c+1;t[c|0]=b>>>6&63|128;c=v[a+8>>2];v[a+8>>2]=c+1;t[c|0]=b&63|128}c=v[a+12>>2]+2|0;v[a+12>>2]=c;if(c>>>0<d>>>0){continue}break}}f=0;break a}f=1}v[e>>2]=v[a+12>>2];v[h>>2]=v[a+8>>2];gb=a+16|0;return f|0}function Q3(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;k=gb-16|0;gb=k;l=ED(g);g=Fx(g);Ug(k,g);a:{b:{if(gd(k)){v[22656]=0;Y(2444,l|0,a|0,c|0,d|0);g=v[22656];v[22656]=0;if((g|0)==1){break a}g=(c-a|0)+d|0;v[f>>2]=g;break b}v[f>>2]=d;c:{d:{j=a;h=w[j|0];switch(h-43|0){case 0:case 2:break d;default:break c}}v[22656]=0;j=Q(22,l|0,h<<24>>24)|0;h=v[22656];v[22656]=0;if((h|0)==1){break a}h=v[f>>2];v[f>>2]=h+1;t[h|0]=j;j=a+1|0}if(!(w[j|0]!=48|(c-j|0)<2|(w[j+1|0]|32)!=120)){v[22656]=0;h=Q(22,l|0,48)|0;i=v[22656];v[22656]=0;if((i|0)==1){break a}i=v[f>>2];v[f>>2]=i+1;t[i|0]=h;h=t[j+1|0];v[22656]=0;h=Q(22,l|0,h|0)|0;i=v[22656];v[22656]=0;if((i|0)==1){break a}i=v[f>>2];v[f>>2]=i+1;t[i|0]=h;j=j+2|0}qm(j,c);v[22656]=0;o=T(2436,g|0)|0;g=v[22656];v[22656]=0;if((g|0)==1){break a}if(c>>>0>j>>>0){p=(c-j|0)+j|0;g=j;h=0;i=0;while(1){e:{if(!w[pc(k,h)|0]){break e}if(t[pc(k,h)|0]!=(i|0)){break e}i=v[f>>2];v[f>>2]=i+1;t[i|0]=o;h=(Ab(k)-1>>>0>h>>>0)+h|0;i=0}n=t[g|0];v[22656]=0;n=Q(22,l|0,n|0)|0;m=v[22656];v[22656]=0;if((m|0)==1){break a}m=v[f>>2];v[f>>2]=m+1;t[m|0]=n;i=i+1|0;g=g+1|0;if((p|0)!=(g|0)){continue}break}}qm((j-a|0)+d|0,v[f>>2]);g=v[f>>2]}v[e>>2]=(b|0)==(c|0)?g:(b-a|0)+d|0;vb(k);gb=k+16|0;return}a=P()|0;O()|0;vb(k);S(a|0);L()}function Gu(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;a:{f=a;d=b;b:{c:{i=a+58|0;h=ic(i,b);b=t[h|0];if((b|0)==-1){break c}if((b|0)>=0){break b}b=b&127;e=vd(f+22|0,b);g=x[e>>1];if((g|0)!=65535&(d|0)!=(g|0)){break c}u[e>>1]=d;t[h|0]=b;break b}m=f+4|0;j=f+22|0;g=255;b=0;e=255;while(1){k=vd(j,b);l=x[k>>1];if((l|0)==65535){u[k>>1]=d;t[h|0]=b;break b}if(!(w[ic(m,b)|0]&32)){g=t[ic(i,l)|0]>=0?g:b;e=b}b=b+1|0;if((b|0)!=18){continue}break}if((e&255)!=255){b=(g&255)==255?e:g;e=vd(j,b&255);n=ic(i,x[e>>1]),o=255,t[n|0]=o;u[e>>1]=d;t[h|0]=b}b=Ol(f,d)}e=b&255;if((e|0)==255){break a}if(wk(a)){break a}d=aB(a+314|0,e);b=w[c+8|0]|w[c+9|0]<<8|(w[c+10|0]<<16|w[c+11|0]<<24);t[d+8|0]=b;t[d+9|0]=b>>>8;t[d+10|0]=b>>>16;t[d+11|0]=b>>>24;b=w[c+4|0]|w[c+5|0]<<8|(w[c+6|0]<<16|w[c+7|0]<<24);f=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);t[d|0]=f;t[d+1|0]=f>>>8;t[d+2|0]=f>>>16;t[d+3|0]=f>>>24;t[d+4|0]=b;t[d+5|0]=b>>>8;t[d+6|0]=b>>>16;t[d+7|0]=b>>>24;g=SR(e);h=g+3|0;b=0;d=1;while(1){f=d;d=d?g:h;Yh(v[a>>2],(d|32)&65535,w[ic(c,b)|0]);Yh(v[a>>2],(d|64)&65535,w[ic(c,b|2)|0]);Yh(v[a>>2],(d|96)&65535,w[ic(c,b|4)|0]);Yh(v[a>>2],(d|128)&65535,w[ic(c,b|6)|0]);Yh(v[a>>2],(d|224)&65535,w[ic(c,b|8)|0]);d=0;b=1;if(f){continue}break}Yh(v[a>>2],Hu(e)|192,w[ic(c,10)|0])}}function wia(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,w=0,x=0,y=0,z=0,A=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0;i=gb-16|0;gb=i;f=v[a+48>>2];m=v[a+24>>2];n=v[a+20>>2];k=v[a+44>>2];o=v[a+16>>2];g=v[a+4>>2];h=v[a>>2];v[i+8>>2]=h;v[i+12>>2]=g;e=v[a+12>>2];v[i>>2]=v[a+8>>2];v[i+4>>2]=e;a:{if(!d){e=k;k=f;break a}while(1){e=g+o|0;p=t[e-3|0];g=(((h>>>16|0)+4&131064)<<1)+b|0;h=u[g+24>>1];q=t[e-2|0];r=u[g+26>>1];s=t[e-1|0];w=u[g+28>>1];x=t[e|0];y=u[g+30>>1];z=t[e+1|0];A=u[g+32>>1];C=t[e+2|0];D=u[g+34>>1];E=t[e+3|0];F=u[g+36>>1];G=t[e+4|0];g=u[g+38>>1];e=v[a+60>>2];H=e;I=e>>31;e=Lb(k,-16777216,16776704);j=v[a+64>>2];f=Lb(f,-16777216,16776704);e=kqa(j,j>>31,e,e>>31);j=jb;J=e;e=v[a+68>>2];l=kqa(e,e>>31,f,f>>31);e=J+l|0;f=jb+j|0;f=e>>>0<l>>>0?f+1|0:f;j=e;g=(((((B(C,D)+B(z,A)|0)+B(E,F)|0)+B(g,G)<<8)/2|0)+((((B(q,r)+B(h,p)|0)+B(s,w)|0)+B(x,y)<<8)/2|0)|0)/16384<<8;e=g;h=kqa(H,I,e,e>>31);e=j+h|0;f=jb+f|0;f=e>>>0<h>>>0?f+1|0:f;e=e+8388608|0;f=e>>>0<8388608?f+1|0:f;f=Jc(e,f,24);e=v[a+72>>2];h=(f|0)/256|0;v[c>>2]=v[c>>2]+B(h,n);v[c+4>>2]=v[c+4>>2]+B(h,m);e=f-(e&g)|0;Ub(i+8|0,i);d=d-1|0;if(d){c=c+8|0;h=v[i+8>>2];g=v[i+12>>2];f=k;k=e;continue}break}h=v[i+8>>2];g=v[i+12>>2]}v[a+48>>2]=k;v[a+44>>2]=e;v[a>>2]=h;v[a+4>>2]=g;gb=i+16|0}function yga(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;e=gb-32|0;gb=e;v[e+24>>2]=c>>>4;v[e+16>>2]=v[a>>2];j=v[Fb(e+24|0,e+16|0)>>2];b=zb(b);if(j){a=v[a+20>>2];c=j;while(1){d=b;f=w[d+4|0]|w[d+5|0]<<8|(w[d+6|0]<<16|w[d+7|0]<<24);g=w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24);d=f;i=g<<8&16711680|g<<24;k=d<<24|g>>>8;f=d<<8|g>>>24;i=k&65280|f&255|i;v[e+24>>2]=((d&255)<<24|g>>>8)&-16777216|((d&16777215)<<8|g>>>24)&16711680|(d>>>8&65280|d>>>24)|l;v[e+28>>2]=i;v[e+16>>2]=0;v[e+20>>2]=-1074790400;v[e+8>>2]=0;v[e+12>>2]=1072693248;h=A[bh(e+24|0,e+16|0,e+8|0)>>3]*32768;A[e+24>>3]=h;d=a;h=ee(h);a:{if(D(h)<2147483648){f=~~h;break a}f=-2147483648}m=d,n=Uc(f),u[m>>1]=n;d=b;f=w[d+12|0]|w[d+13|0]<<8|(w[d+14|0]<<16|w[d+15|0]<<24);g=w[d+8|0]|w[d+9|0]<<8|(w[d+10|0]<<16|w[d+11|0]<<24);d=f;i=g<<8&16711680|g<<24;k=d<<24|g>>>8;f=d<<8|g>>>24;i=k&65280|f&255|i;v[e+24>>2]=((d&255)<<24|g>>>8)&-16777216|((d&16777215)<<8|g>>>24)&16711680|(d>>>8&65280|d>>>24)|l;v[e+28>>2]=i;v[e+16>>2]=0;v[e+20>>2]=-1074790400;v[e+8>>2]=0;v[e+12>>2]=1072693248;h=A[bh(e+24|0,e+16|0,e+8|0)>>3]*32768;A[e+24>>3]=h;d=a;h=ee(h);b:{if(D(h)<2147483648){f=~~h;break b}f=-2147483648}m=d,n=Uc(f),u[m+2>>1]=n;a=a+4|0;b=b+16|0;c=c-1|0;if(c){continue}break}}gb=e+32|0;return j<<4}function Eja(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;b=gb-48|0;gb=b;o=v[a+16>>2];h=v[a+44>>2];v[b+32>>2]=h;i=v[a+48>>2];v[b+36>>2]=i;f=v[a+52>>2];v[b+40>>2]=f;k=v[a+56>>2];v[b+44>>2]=k;p=v[a+24>>2];q=v[a+20>>2];e=v[a+4>>2];g=v[a>>2];v[b+24>>2]=g;v[b+28>>2]=e;j=v[a+12>>2];v[b+16>>2]=v[a+8>>2];v[b+20>>2]=j;if(d){while(1){e=((((e&2147483647)<<1|g>>>31)&2147483646)<<1)+o|0;f=u[e>>1];v[b+8>>2]=f;v[b+12>>2]=u[e+2>>1];i=0;k=1;while(1){j=v[a+60>>2];l=j;g=(b+32|0)+(i<<3)|0;n=v[g>>2];e=Lb(n,-16777216,16776704);m=v[a+64>>2];h=Lb(v[g+4>>2],-16777216,16776704);r=j>>31;j=f<<8;f=j;f=kqa(l,r,f,f>>31);l=jb;m=kqa(m,m>>31,e,e>>31);f=m+f|0;e=jb+l|0;e=f>>>0<m>>>0?e+1|0:e;l=f;f=v[a+68>>2];h=kqa(f,f>>31,h,h>>31);f=l+h|0;e=jb+e|0;e=f>>>0<h>>>0?e+1|0:e;f=f+8388608|0;e=f>>>0<8388608?e+1|0:e;e=Jc(f,e,24);v[g+4>>2]=n;f=v[a+72>>2];v[(b+8|0)+(i<<2)>>2]=(e|0)/256;v[g>>2]=e-(f&j);if(k){i=1;k=0;f=v[b+12>>2];continue}break}v[c>>2]=v[c>>2]+B(v[b+8>>2],q);v[c+4>>2]=v[c+4>>2]+B(v[b+12>>2],p);Ub(b+24|0,b+16|0);d=d-1|0;if(d){c=c+8|0;g=v[b+24>>2];e=v[b+28>>2];continue}break}g=v[b+24>>2];k=v[b+44>>2];f=v[b+40>>2];h=v[b+32>>2];i=v[b+36>>2];e=v[b+28>>2]}v[a+56>>2]=k;v[a+52>>2]=f;v[a+48>>2]=i;v[a+44>>2]=h;v[a>>2]=g;v[a+4>>2]=e;gb=b+48|0}function L2(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;a=gb-496|0;gb=a;g=a+488|0;Fc(g,d);v[22656]=0;m=T(2452,g|0)|0;g=v[22656];v[22656]=0;a:{b:{c:{d:{e:{f:{g:{if((g|0)!=1){if(Ab(f)){g=v[yk(f,0)>>2];v[22656]=0;h=Q(2474,m|0,45)|0;k=v[22656];v[22656]=0;if((k|0)==1){break g}n=(g|0)==(h|0)}k=Kb(a+456|0);g=Kb(a+440|0);h=Kb(a+424|0);v[22656]=0;na(2497,c|0,n|0,a+488|0,a+480|0,a+476|0,a+472|0,k|0,g|0,h|0,a+420|0);c=v[22656];v[22656]=0;if((c|0)==1){break f}v[a+4>>2]=2428;c=ge(a+8|0,0,a+4|0);i=Ab(f);l=v[a+420>>2];h:{if((i|0)>(l|0)){i=Ab(f);j=((Ab(h)+(i-l<<1)|0)+Ab(g)|0)+1|0;break h}j=(Ab(h)+Ab(g)|0)+2|0}i=a+16|0;j=j+l|0;if(j>>>0<101){break e}Ee(c,Cd(j<<2));i=v[c>>2];if(i){break e}v[22656]=0;X(2429);b=v[22656];v[22656]=0;if((b|0)==1){break d}L()}f=P()|0;O()|0;break b}f=P()|0;O()|0;break b}f=P()|0;O()|0;break c}j=v[d+4>>2];o=Jb(f);p=Jb(f);f=Ab(f);v[22656]=0;qa(2498,i|0,a+4|0,a|0,j|0,o|0,(f<<2)+p|0,m|0,n|0,a+480|0,v[a+476>>2],v[a+472>>2],k|0,g|0,h|0,l|0);f=v[22656];v[22656]=0;if((f|0)!=1){v[22656]=0;b=la(2477,b|0,i|0,v[a+4>>2],v[a>>2],d|0,e|0)|0;d=v[22656];v[22656]=0;if((d|0)!=1){break a}}}f=P()|0;O()|0;Ic(c)}Hc(h);Hc(g);vb(k)}Wb(a+488|0);S(f|0);L()}Ic(c);Hc(h);Hc(g);vb(k);Wb(a+488|0);gb=a+496|0;return b|0}function x1(a,b,c,d,e,f,g,h){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0;k=gb-16|0;gb=k;i=d;j=(c|0)==(d|0);a:{if(j){break a}i=c;while(1){if(!w[i|0]){break a}i=i+1|0;if((i|0)!=(d|0)){continue}break}i=d}v[h>>2]=f;v[e>>2]=c;b:{c:{if(j|(f|0)==(g|0)){break c}while(1){j=v[b+4>>2];v[k+8>>2]=v[b>>2];v[k+12>>2]=j;l=gb-16|0;gb=l;v[l+12>>2]=v[a+8>>2];m=vi(l+8|0,l+12|0);v[22656]=0;j=HH(f,e,i-c|0,g-f>>2,b);n=v[22656];v[22656]=0;d:{if((n|0)!=1){hf(m);gb=l+16|0;break d}a=P()|0;O()|0;hf(m);S(a|0);L()}e:{f:{g:{h:{i:{j:{k:{if((j|0)==-1){v[h>>2]=f;if(v[e>>2]!=(c|0)){while(1){g=1;l:{m:{n:{b=TG(f,c,i-c|0,k+8|0,v[a+8>>2]);switch(b+2|0){case 0:break i;case 2:break l;case 1:break n;default:break m}}v[e>>2]=c;break k}g=b}f=v[h>>2]+4|0;v[h>>2]=f;c=c+g|0;if((c|0)!=v[e>>2]){continue}break}}v[e>>2]=c;break c}f=v[h>>2]+(j<<2)|0;v[h>>2]=f;if((f|0)==(g|0)){break h}c=v[e>>2];if((d|0)==(i|0)){i=d;break e}if(!TG(f,c,1,b,v[a+8>>2])){break j}}a=2;break b}v[h>>2]=v[h>>2]+4;c=v[e>>2]+1|0;v[e>>2]=c;i=c;if((c|0)==(d|0)){break g}while(1){if(!w[i|0]){break f}i=i+1|0;if((i|0)!=(d|0)){continue}break}break g}v[e>>2]=c;a=1;break b}c=v[e>>2];break c}i=d}f=v[h>>2]}if((c|0)==(d|0)){break c}if((f|0)!=(g|0)){continue}break}}a=(c|0)!=(d|0)}gb=k+16|0;return a|0}function xna(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;b=tv(a);if(b>>>0<=63){k=gb-32|0;gb=k;a:{b:{j=64-b|0;c:{if(j>>>0<=(v[wb(a)>>2]-v[a+4>>2]|0)/33>>>0){b=gb-16|0;gb=b;c=b;v[b>>2]=a;a=v[a+4>>2];v[b+4>>2]=a;v[b+8>>2]=a+B(j,33);a=v[b+4>>2];d=v[b+8>>2];if((a|0)!=(d|0)){while(1){HC(a);a=a+33|0;v[c+4>>2]=a;if((a|0)!=(d|0)){continue}break}}$b(c);gb=b+16|0;break c}i=wb(a);f=k+8|0;d=a;c=tv(a)+j|0;h=gb-16|0;gb=h;v[h+12>>2]=c;e=gb-16|0;gb=e;v[e+12>>2]=130150524;v[22656]=0;v[e+8>>2]=2147483647;g=Fb(e+12|0,e+8|0);b=v[22656];v[22656]=0;d:{if((b|0)!=1){gb=e+16|0;b=v[g>>2];break d}V(0)|0;O()|0;Bb();L()}e:{if(b>>>0>=c>>>0){c=sW(d);if(c>>>0<b>>>1>>>0){v[h+8>>2]=c<<1;b=v[Lc(h+8|0,h+12|0)>>2]}gb=h+16|0;break e}Sc();L()}d=tv(a);e=0;g=gb-16|0;gb=g;v[g+12>>2]=0;kf(f+12|0,i);if(b){c=b;if(b>>>0>=130150525){rd(8445);L()}e=Mc(B(c,33),1)}v[f>>2]=e;c=B(d,33)+e|0;v[f+8>>2]=c;v[f+4>>2]=c;l=dc(f),m=B(b,33)+e|0,v[l>>2]=m;gb=g+16|0;v[22656]=0;vW(f,j);b=v[22656];v[22656]=0;if((b|0)==1){break b}b=a;c=f;i=c+4|0;d=v[a+4>>2];a=v[a>>2];g=d-a|0;d=v[i>>2]+B((g|0)/-33|0,33)|0;v[i>>2]=d;if((g|0)>0){hc(d,a,g)}wc(b,i);wc(b+4|0,c+8|0);wc(wb(b),dc(c));v[c>>2]=v[c+4>>2];uW(f)}gb=k+32|0;break a}a=P()|0;O()|0;uW(f);S(a|0);L()}return}if((b|0)!=64){_k(a,v[a>>2]+2112|0)}}function Fja(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;b=gb-48|0;gb=b;o=v[a+16>>2];h=v[a+44>>2];v[b+32>>2]=h;i=v[a+48>>2];v[b+36>>2]=i;f=v[a+52>>2];v[b+40>>2]=f;k=v[a+56>>2];v[b+44>>2]=k;p=v[a+24>>2];q=v[a+20>>2];e=v[a+4>>2];g=v[a>>2];v[b+24>>2]=g;v[b+28>>2]=e;j=v[a+12>>2];v[b+16>>2]=v[a+8>>2];v[b+20>>2]=j;if(d){while(1){e=(((e&2147483647)<<1|g>>>31)&-2)+o|0;f=t[e|0]<<8;v[b+8>>2]=f;v[b+12>>2]=t[e+1|0]<<8;i=0;k=1;while(1){j=v[a+60>>2];l=j;g=(b+32|0)+(i<<3)|0;n=v[g>>2];e=Lb(n,-16777216,16776704);m=v[a+64>>2];h=Lb(v[g+4>>2],-16777216,16776704);r=j>>31;j=f<<8;f=j;f=kqa(l,r,f,f>>31);l=jb;m=kqa(m,m>>31,e,e>>31);f=m+f|0;e=jb+l|0;e=f>>>0<m>>>0?e+1|0:e;l=f;f=v[a+68>>2];h=kqa(f,f>>31,h,h>>31);f=l+h|0;e=jb+e|0;e=f>>>0<h>>>0?e+1|0:e;f=f+8388608|0;e=f>>>0<8388608?e+1|0:e;e=Jc(f,e,24);v[g+4>>2]=n;f=v[a+72>>2];v[(b+8|0)+(i<<2)>>2]=(e|0)/256;v[g>>2]=e-(f&j);if(k){i=1;k=0;f=v[b+12>>2];continue}break}v[c>>2]=v[c>>2]+B(v[b+8>>2],q);v[c+4>>2]=v[c+4>>2]+B(v[b+12>>2],p);Ub(b+24|0,b+16|0);d=d-1|0;if(d){c=c+8|0;g=v[b+24>>2];e=v[b+28>>2];continue}break}g=v[b+24>>2];k=v[b+44>>2];f=v[b+40>>2];h=v[b+32>>2];i=v[b+36>>2];e=v[b+28>>2]}v[a+56>>2]=k;v[a+52>>2]=f;v[a+48>>2]=i;v[a+44>>2]=h;v[a>>2]=g;v[a+4>>2]=e;gb=b+48|0}function rea(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=C(0),k=C(0),l=0,m=0,n=C(0);i=gb-16|0;gb=i;a:{if(u[d>>1]>u[d+2>>1]){break a}if(!Nb(b)){break a}g=u[e>>1];if((g|0)<u[d>>1]){break a}h=u[d+2>>1];if((h|0)<(g|0)){break a}if((Nb(b)-1&65535)>>>0>(h-g&65535)>>>0|y[a+36>>2]>65535){break a}b:{if(!Nb(b)){break b}while(1){if(!(z[Mb(b,f)>>2]<C(0))){f=f+1|0;if(Nb(b)>>>0>f>>>0){continue}break b}break}f=0;break a}f=0;if(z[c>>2]<=C(0)){break a}u[a>>1]=1;u[a+28>>1]=x[d>>1];l=a,m=pN(Nb(b)),u[l+30>>1]=m;z[a+32>>2]=D(z[c>>2]);g=a+4|0;El(g,(u[d+2>>1]-u[d>>1]|0)+1|0);c=Vb(b);f=Zb(b);l=i,m=Vb(g),v[l+8>>2]=m;h=$o(i+8|0,u[e>>1]-u[d>>1]|0);b=gb-16|0;gb=b;yc(b+8|0,Mn($l(c),$l(f),$l(h)));gb=b+16|0;c=u[a+28>>1];f=u[e>>1];c:{if((c|0)>=(f|0)){break c}b=f;while(1){b=b-1|0;j=z[Mb(g,u[a+30>>1]+(b-c|0)|0)>>2];k=z[a+32>>2];l=Mb(g,b-u[a+28>>1]|0),n=C(j/k),z[l>>2]=n;f=u[e>>1];c=u[a+28>>1];if((c|0)>=(b|0)){break c}if((f|0)!=-32768){continue}break}}d:{h=u[a+30>>1];b=h+f|0;if((b|0)>u[d+2>>1]|(32767-h|0)<(f|0)){break d}while(1){j=z[a+32>>2];k=z[Mb(g,b-((c<<16>>16)+h|0)|0)>>2];l=Mb(g,b-u[a+28>>1]|0),n=C(j*k),z[l>>2]=n;if(u[d+2>>1]<=(b|0)){break d}h=u[a+30>>1];if(u[e>>1]>(32767-h|0)){break d}b=b+1|0;c=x[a+28>>1];continue}}nq(a);f=1}gb=i+16|0;return f|0}function iia(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;e=gb-48|0;gb=e;m=v[a+16>>2];f=Ud(e+16|0);v[f+8>>2]=a+112;v[f+16>>2]=v[a+128>>2];o=f,p=jg(b+327720|0,v[b+20>>2],(v[a+88>>2]&16384)>>>14|0),v[o+12>>2]=p;b=v[f+16>>2];if(b){o=f,p=lg(a+8|0,b),v[o>>2]=p;v[f+4>>2]=jb}k=v[a+40>>2];l=v[a+36>>2];h=v[a+4>>2];g=v[a>>2];v[e+8>>2]=g;v[e+12>>2]=h;i=v[a+12>>2];v[e>>2]=v[a+8>>2];v[e+4>>2]=i;a:{if(d){while(1){i=0;j=g;v[e+40>>2]=g;v[e+44>>2]=n;h=(((h&2147483647)<<1|g>>>31)&-2)+m|0;b:{if((b|0)<=0){break b}while(1){g=(i&2147483647)<<1|j>>>31;Id(v[f+8>>2],t[(g|1)+h|0]+t[h+(g&-2)|0]<<5);Hd(v[f+8>>2],4);Ub(e+40|0,f);if((b|0)<2){break b}b=b-1|0;j=v[e+40>>2];i=v[e+44>>2];continue}}d=d-1|0;b=v[f+8>>2];Ub(b,b+8|0);b=v[f+8>>2];g=v[b+4>>2];if(g){j=b;b=(v[e+44>>2]&2147483647)<<1|v[e+40>>2]>>>31;Id(j,t[(b|1)+h|0]+t[h+(b&-2)|0]<<5);Hd(v[f+8>>2],g);b=v[f+8>>2];g=v[b>>2];v[b>>2]=g;v[b+4>>2]=0}b=ig(b,v[f+12>>2]);h=v[a+32>>2];l=v[a+28>>2]+l|0;i=l>>12;v[c>>2]=v[c>>2]+B(b,i);k=h+k|0;j=k>>12;v[c+4>>2]=v[c+4>>2]+B(b,j);Ub(e+8|0,e);if(d){c=c+8|0;b=v[f+16>>2];g=v[e+8>>2];h=v[e+12>>2];continue}break}g=v[e+8>>2];h=v[e+12>>2];break a}j=k>>12;i=l>>12}v[a+40>>2]=k;v[a+20>>2]=i;v[a+36>>2]=l;v[a+24>>2]=j;v[a>>2]=g;v[a+4>>2]=h;gb=e+48|0}function nga(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;h=gb-16|0;gb=h;b=a+8|0;nu(b,Yd(b));l=wb(b),m=0,v[l>>2]=m;l=b,m=fc(b),v[l>>2]=m;l=fc(b),m=0,v[l>>2]=m;v[a+32>>2]=0;v[a+36>>2]=0;d=a+4|0;v[v[d>>2]>>2]=0;b=v[a>>2];v[v[d>>2]+40>>2]=v[b+480196>>2];v[v[d>>2]+44>>2]=v[b+480204>>2];v[v[d>>2]+80>>2]=v[b+480200>>2];j=x[b+480188>>1];v[h+8>>2]=0;v[h+12>>2]=0;i=h+8|0;u[i+4>>1]=65280;v[i>>2]=0;g=gb-16|0;gb=g;v[g+12>>2]=j;f=a+20|0;a:{if(tg(f)>>>0>=j>>>0){l=g,m=rf(f),v[l+8>>2]=m;c=v[f>>2];b=i;e=v[Fb(g+12|0,g+8|0)>>2];if(e){while(1){v[c>>2]=v[b>>2];u[c+4>>1]=x[b+4>>1];c=c+8|0;e=e-1|0;if(e){continue}break}}b=v[g+12>>2];c=v[g+8>>2];if(b>>>0>c>>>0){fP(f,b-c|0,i);break a}_k(f,v[f>>2]+(b<<3)|0);break a}b=f;if(v[b>>2]){Od(b);gP(v[b>>2],tg(b));l=wb(b),m=0,v[l>>2]=m;v[b>>2]=0;v[b+4>>2]=0}c=hs(f,j);if(Lw()>>>0<c>>>0){Sc();L()}e=c;if(c>>>0>=536870912){rd(8445);L()}e=Mc(e<<3,4);v[b>>2]=e;v[b+4>>2]=e;l=wb(b),m=e+(c<<3)|0,v[l>>2]=m;fP(f,j,i)}gb=g+16|0;if(x[v[a>>2]+480188>>1]){while(1){b=B(k,872);$m((b+v[d>>2]|0)+616|0,7,v[a>>2],k&65535,134217728);t[(b+v[d>>2]|0)+1433|0]=0;t[(b+v[d>>2]|0)+1432|0]=0;t[(b+v[d>>2]|0)+1415|0]=0;t[(b+v[d>>2]|0)+1418|0]=0;t[(b+v[d>>2]|0)+1413|0]=0;k=k+1|0;if(k>>>0<x[v[a>>2]+480188>>1]){continue}break}}gb=h+16|0}function iqa(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{g=b;if(g){e=c;if(!e){break j}f=d;if(!f){break i}f=E(f)-E(g)|0;if(f>>>0<=31){break h}break b}if((d|0)==1|d>>>0>1){break b}b=(a>>>0)/(c>>>0)|0;hb=a-B(b,c)|0;ib=0;jb=0;return b}e=d;if(!a){break g}if(!e){break f}f=e-1|0;if(f&e){break f}hb=a;ib=f&g;a=g>>>jqa(e)|0;jb=0;return a}f=e-1|0;if(!(f&e)){break e}j=(E(e)+33|0)-E(g)|0;h=0-j|0;break c}j=f+1|0;h=63-f|0;break c}hb=0;a=(g>>>0)/(e>>>0)|0;ib=g-B(a,e)|0;jb=0;return a}f=E(e)-E(g)|0;if(f>>>0<31){break d}break b}hb=a&f;ib=0;if((e|0)==1){break a}c=a;a=jqa(e);d=a&31;if((a&63)>>>0>=32){f=0;a=b>>>d|0}else{f=b>>>d|0;a=((1<<d)-1&b)<<32-d|c>>>d}jb=f;return a}j=f+1|0;h=63-f|0}e=b;g=a;f=j&63;i=f&31;if((f&63)>>>0>=32){f=0;l=e>>>i|0}else{f=e>>>i|0;l=((1<<i)-1&e)<<32-i|g>>>i}a=h&63;h=a&31;if((a&63)>>>0>=32){e=g<<h;a=0}else{e=(1<<h)-1&g>>>32-h|b<<h;a=g<<h}b=e;if(j){g=d-1|0;e=c-1|0;g=(e|0)!=-1?g+1|0:g;h=e;while(1){e=l;f=f<<1|e>>>31;e=e<<1;k=f;f=b>>>31|e;m=k;e=k;k=f;i=g-((f>>>0>h>>>0)+e|0)|0;f=i>>31;e=f;i=e;f=c&e;l=k-f|0;f=m-((d&e)+(f>>>0>k>>>0)|0)|0;e=b<<1|a>>>31;a=n|a<<1;b=e|o;e=0;m=e;k=i&1;n=k;j=j-1|0;if(j){continue}break}}hb=l;ib=f;e=b<<1|a>>>31;a=k|a<<1;jb=e|m;return a}hb=a;ib=b;a=0;b=0}jb=b;return a}function uga(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,m=0,o=0,p=0,q=0,r=0,s=0,t=0,x=0;g=gb-32|0;gb=g;s=g,t=B(v[a>>2],fd(a)),v[s+4>>2]=t;qc(g+4|0,c>>>3|0);c=zb(b);j=A[e+8>>3];k=v[g+4>>2];a:{if(!k){break a}e=k;while(1){m=0;f=c;o=w[f+4|0]|w[f+5|0]<<8|(w[f+6|0]<<16|w[f+7|0]<<24);h=w[f|0]|w[f+1|0]<<8|(w[f+2|0]<<16|w[f+3|0]<<24);q=h<<24|h<<8&16711680;p=m;m=o<<24|h>>>8;f=o<<8|h>>>24;p=p|0;m=m&65280|f&255|q;f=o;l(0,((f&255)<<24|h>>>8)&-16777216|((f&16777215)<<8|h>>>24)&16711680|(f>>>8&65280|f>>>24)|p);l(1,m&2147483647);i=+n();j=j<i?i:j;c=c+8|0;e=e-1|0;if(e){continue}break}if(j==0){break a}r=1/j;c=v[a+20>>2];while(1){e=b;a=w[e+4|0]|w[e+5|0]<<8|(w[e+6|0]<<16|w[e+7|0]<<24);h=w[e|0]|w[e+1|0]<<8|(w[e+2|0]<<16|w[e+3|0]<<24);f=h<<24;q=0;o=h<<8&16711680|f;p=a<<24|h>>>8;f=a<<8|h>>>24;e=a;l(0,((e&255)<<24|h>>>8)&-16777216|((e&16777215)<<8|h>>>24)&16711680|(e>>>8&65280|e>>>24)|q);l(1,o|(p&65280|f&255));s=g,x=r*+n(),A[s+24>>3]=x;v[g+16>>2]=0;v[g+20>>2]=-1074790400;v[g+8>>2]=0;v[g+12>>2]=1072693248;i=A[bh(g+24|0,g+16|0,g+8|0)>>3]*32768;A[g+24>>3]=i;a=c;i=ee(i);b:{if(D(i)<2147483648){e=~~i;break b}e=-2147483648}s=a,t=Uc(e),u[s>>1]=t;b=b+8|0;c=c+2|0;k=k-1|0;if(k){continue}break}}if(d){A[d>>3]=j}gb=g+32|0;return v[g+4>>2]<<3}function P2(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;a=gb-192|0;gb=a;g=a+184|0;Fc(g,d);v[22656]=0;m=T(21,g|0)|0;g=v[22656];v[22656]=0;a:{b:{c:{d:{e:{f:{g:{if((g|0)!=1){if(Ab(f)){g=w[pc(f,0)|0];v[22656]=0;h=Q(22,m|0,45)|0;k=v[22656];v[22656]=0;if((k|0)==1){break g}n=(g|0)==(h&255)}k=Kb(a+160|0);g=Kb(a+144|0);h=Kb(a+128|0);v[22656]=0;na(2495,c|0,n|0,a+184|0,a+176|0,a+175|0,a+174|0,k|0,g|0,h|0,a+124|0);c=v[22656];v[22656]=0;if((c|0)==1){break f}v[a+4>>2]=2428;c=ge(a+8|0,0,a+4|0);i=Ab(f);l=v[a+124>>2];h:{if((i|0)>(l|0)){i=Ab(f);j=((Ab(h)+(i-l<<1)|0)+Ab(g)|0)+1|0;break h}j=(Ab(h)+Ab(g)|0)+2|0}i=a+16|0;j=j+l|0;if(j>>>0<101){break e}Ee(c,Cd(j));i=v[c>>2];if(i){break e}v[22656]=0;X(2429);b=v[22656];v[22656]=0;if((b|0)==1){break d}L()}f=P()|0;O()|0;break b}f=P()|0;O()|0;break b}f=P()|0;O()|0;break c}j=v[d+4>>2];o=Jb(f);p=Jb(f);f=Ab(f);v[22656]=0;qa(2496,i|0,a+4|0,a|0,j|0,o|0,f+p|0,m|0,n|0,a+176|0,t[a+175|0],t[a+174|0],k|0,g|0,h|0,l|0);f=v[22656];v[22656]=0;if((f|0)!=1){v[22656]=0;b=la(17,b|0,i|0,v[a+4>>2],v[a>>2],d|0,e|0)|0;d=v[22656];v[22656]=0;if((d|0)!=1){break a}}}f=P()|0;O()|0;Ic(c)}vb(h);vb(g);vb(k)}Wb(a+184|0);S(f|0);L()}Ic(c);vb(h);vb(g);vb(k);Wb(a+184|0);gb=a+192|0;return b|0}function Boa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;c=gb-48|0;gb=c;a:{if(!Pb(b,9)){break a}i=a+484344|0;j=a+480280|0;while(1){ip(b,c+44|0);d=sg(b);b:{e=w[c+44|0]|w[c+45|0]<<8|(w[c+46|0]<<16|w[c+47|0]<<24);c:{if((e|0)==1229999433|(e|0)==1397771593){break c}e=w[c+44|0]|w[c+45|0]<<8|(w[c+46|0]<<16|w[c+47|0]<<24);if((e|0)==1297110104|(e|0)==1297110099){break c}if(Pb(b,d)){break b}}pg(b,8);break a}Td(c,b,d);g=kc(c+24|0,c);xb(c);d=j;d:{e:{f:{if((w[c+44|0]|w[c+45|0]<<8|(w[c+46|0]<<16|w[c+47|0]<<24))==1481001027){while(1){v[22656]=0;e=T(192,g|0)|0;f=v[22656];v[22656]=0;if((f|0)==1){break f}t[d+8|0]=e;d=d+32|0;if((i|0)!=(d|0)){continue}break d}}if(w[c+44|0]!=70){break e}e=w[c+45|0];h=(e|0)==88;g:{if(!h){if((e-48&255)>>>0>9){break e}d=t[c+46|0];if((d|0)>47){break g}break e}d=t[c+46|0];if((d|0)<48){break e}}if((d&255)>>>0>57){break e}f=t[c+47|0];if((f|0)<48|(f|0)>57){break e}d=(f+(h?-16:B(e,100)+48|0)|0)+B(d,10)&255;if(d>>>0>249){break d}v[22656]=0;R(605,g|0,(B(d,160)+a|0)+906300|0);d=v[22656];v[22656]=0;if((d|0)!=1){break d}}a=P()|0;O()|0;xb(c+24|0);S(a|0);L()}if((w[c+44|0]|w[c+45|0]<<8|(w[c+46|0]<<16|w[c+47|0]<<24))!=1430540109){break d}v[a+1074308>>2]=0;k=1}xb(c+24|0);if(Pb(b,9)){continue}break}}gb=c+48|0;return k|0}function ox(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,u=0,x=0;r=a;j=gb-1040|0;gb=j;s=v[115137];a:{b:{c:{a=j+16|0;m=a;e=b;g=v[115196];d:{e:{while(1){if((e|0)!=w[d+86784|0]){c=87;d=d+1|0;if((d|0)!=87){continue}break e}break}c=d;if(c){break e}e=86880;break d}d=86880;while(1){h=w[d|0];e=d+1|0;d=e;if(h){continue}d=e;c=c-1|0;if(c){continue}break}}c=v[g+20>>2];if(c){k=v[c+4>>2];d=e;f=v[c>>2];i=v[f>>2]+1794895138|0;l=um(v[f+8>>2],i);g=um(v[f+12>>2],i);h=um(v[f+16>>2],i);f:{if(k>>>2>>>0<=l>>>0){break f}c=k-(l<<2)|0;if((g|h)&3|(c>>>0<=g>>>0|c>>>0<=h>>>0)){break f}u=h>>>2|0;x=g>>>2|0;while(1){n=l>>>1|0;g=n+o|0;h=g<<1;c=(h+x<<2)+f|0;p=um(v[c>>2],i);c=um(v[c+4>>2],i);if(c>>>0>=k>>>0|k-c>>>0<=p>>>0|w[(c+p|0)+f|0]){break f}c=wj(d,c+f|0);if(!c){d=(h+u<<2)+f|0;c=um(v[d>>2],i);d=um(v[d+4>>2],i);if(d>>>0>=k>>>0|c>>>0>=k-d>>>0){break f}q=w[(c+d|0)+f|0]?0:d+f|0;break f}if((l|0)==1){break f}c=(c|0)<0;l=c?n:l-n|0;o=c?o:g;continue}}}d=q?q:e;e=Nf(d);g:{if(e>>>0>=1024){hc(m,d,1023);t[m+1023|0]=0;e=68;break g}hc(m,d,e+1|0);e=0}switch(e+1|0){case 1:break a;case 0:break c;default:break b}}e=v[115137]}a=18726;if((e|0)==28){break a}Da();L()}if(!w[a|0]){v[j>>2]=b;a=j+16|0;Mx(a,1024,10351,j)}v[115137]=s;Tb(r,a);gb=j+1040|0}function wW(a,b){var c=0,d=0,e=0,f=0;c=gb-16|0;gb=c;d=w[a|0];a:{if(d>>>0>21){break a}t[a|0]=w[d+28896|0];b:{switch(d-8|0){case 0:t[b|0]=w[b|0]<<1;break a;case 4:t[b|0]=w[b|0]+1>>>1;break a;case 5:a=w[b|0];t[b|0]=B(a>>>4|0,10)+(a&15);break a;case 6:c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{d=w[b|0];switch((d>>>4|0)-1|0){case 11:case 12:case 13:break a;case 9:break e;case 8:break f;case 6:break g;case 5:break h;case 4:break i;case 3:break j;case 1:break k;case 0:break l;case 14:break c;case 10:break d;default:break m}}t[a|0]=0;break a}t[a|0]=29;t[c+15|0]=w[b|0]&15;t[c+14|0]=14;e=b,f=w[ac(c+15|0,c+14|0)|0]<<4|15,t[e|0]=f;break a}t[a|0]=29;t[c+13|0]=w[b|0]&15;t[c+12|0]=14;e=b,f=w[ac(c+13|0,c+12|0)|0]|240,t[e|0]=f;break a}t[b|0]=d&15|48;break a}t[a|0]=35;t[b|0]=w[b|0]<<4^128;break a}t[b|0]=d&15|176;break a}t[b|0]=d&15|64;break a}t[a|0]=15;t[b|0]=w[b|0]&15;break a}t[a|0]=24;t[b|0]=(w[b|0]<<3&120)+8&240;break a}t[a|0]=24;t[b|0]=(w[b|0]&15)+1>>>1;break a}t[a|0]=10;break a;case 8:a=w[b|0];if(a>>>0<=223){t[b|0]=a>>>0>63?-16:a<<2&240;break a}if(a>>>0<=239){t[b|0]=a<<2&48|15;break a}t[b|0]=a<<4|15;break a;case 9:break b;default:break a}}a=w[b|0];if(a>>>0<=223){t[b|0]=a>>>0>63?15:a>>>2|0;break a}if(a>>>0>239){break a}t[b|0]=a>>>2&3|240}gb=c+16|0}function UY(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;g=gb-144|0;gb=g;v[22656]=0;l=T(416,a|0)|0;e=v[22656];v[22656]=0;if((e|0)!=1){a:{if(l){e=g+8|0;o=e|4;p=e|6;q=e|5;k=e|2;m=e|3;while(1){v[22656]=0;R(445,a|0,g+8|0);e=v[22656];v[22656]=0;if((e|0)==1){break a}e=g+8|0;e=Ib(w[e|0]|w[e+1|0]<<8);b:{if(!e|e>>>0>x[c+480192>>1]){break b}e=v[((e<<2)+c|0)+900380>>2];if(!e){break b}v[22656]=0;e=ji(e,b);f=v[22656];v[22656]=0;if((f|0)==1){break a}c:{if(!w[m|0]){break c}if(t[k|0]&1){t[e+12|0]=w[e+12|0]|1}if(w[k|0]&2){t[e+12|0]=w[e+12|0]|4}if(!(w[k|0]&4)){break c}t[e+12|0]=w[e+12|0]|2}t[g+4|0]=w[m|0];v[22656]=0;t[g+7|0]=31;f=ac(g+4|0,g+7|0);i=v[22656];v[22656]=0;if((i|0)==1){break a}f=w[f|0];v[22656]=0;i=f+1&255;R(446,e|0,i|0);f=v[22656];v[22656]=0;if((f|0)==1){break a}t[e+13|0]=w[q|0];t[e+14|0]=w[p|0];f=w[o|0];t[e+15|0]=f;t[e+16|0]=f;f=0;if(!i){break b}while(1){h=(g+8|0)+(f<<2)|0;j=h+8|0;j=Ib(w[j|0]|w[j+1|0]<<8);r=Mb(e,f),s=j,u[r>>1]=s;h=h+10|0;h=Ib(w[h|0]|w[h+1|0]<<8);u[g+4>>1]=d?h+128>>>2|0:h;zg(g+4|0,64);h=w[g+4|0];r=Mb(e,f),s=h,t[r+2|0]=s;f=f+1|0;if((i|0)!=(f|0)){continue}break}}n=n+1|0;if((n&65535)>>>0<l>>>0){continue}break}}xb(a);gb=g+144|0;return}}b=P()|0;O()|0;xb(a);S(b|0);L()}function BV(a,b){var c=0,d=0;a:{b:{c:{d:{if(je(a,13819)){break d}if(je(a,14601)){break d}if(je(a,10889)){break d}if(je(a,11026)){break d}if(!je(a,11476)){break c}}u[b+10>>1]=4;v[b>>2]=9290;break b}e:{f:{if(je(a,14596)){break f}if(je(a,10894)){break f}if(!je(a,13809)){break e}}t[b+12|0]=1;v[b>>2]=5538;u[b+10>>1]=4;return 1}g:{if(!je(a,11511)){if(!je(a,11516)){break g}}u[b+10>>1]=8;v[b>>2]=5302;break b}h:{if(!je(a,12495)){if(!je(a,12500)){break h}}v[b>>2]=14173;u[b+10>>1]=t[a+2|0]-48;break b}i:{if(!je(a,33192)){if(!je(a,33197)){break i}}v[b+4>>2]=1;v[b>>2]=13979;u[b+10>>1]=w[a|0]==56?8:4;return 1}if(!(sd(a,12596,3)|(w[a+3|0]-52&255)>>>0>4)){v[b>>2]=5656;a=t[a+3|0];u[b+8>>1]=1088;u[b+10>>1]=a-48;break b}j:{if(sd(a,10959,3)){if(sd(a,11083,3)){break j}}if((w[a+3|0]-52&255)>>>0>5){break j}t[b+15|0]=1;t[b+13|0]=1;v[b>>2]=5401;u[b+10>>1]=t[a+3|0]-48;return 1}k:{if((w[a|0]-49&255)>>>0>8){break k}if(!sd(a+1|0,11104,3)){t[b+14|0]=1;v[b>>2]=5704;u[b+10>>1]=t[a|0]-48;return 1}c=w[a+2|0]|w[a+3|0]<<8;if((c|0)!=18499&(c|0)!=20035|(w[a+1|0]-48&255)>>>0>9){break k}t[b+14|0]=1;v[b>>2]=5704;u[b+10>>1]=(t[a+1|0]+B(t[a|0],10)|0)-528;return 1}if(sd(a,10780,3)|(w[a+3|0]-49&255)>>>0>8){break a}v[b>>2]=5565;u[b+10>>1]=t[a+3|0]-48}d=1}return d}function Om(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;e=gb-16|0;gb=e;d=e+8|0;f=a+1074312|0;Db(d,f,96);d=Cb(d);v[b+660>>2]=(d?0:v[b+660>>2])+c;a:{if(!(w[b+88|0]&2)|(!(v[a+480180>>2]&18)|y[b+84>>2]>c>>>0)){break a}d=v[b+84>>2];if(!d){break a}g=c;c=v[b+80>>2];c=((g-c>>>0)%(d-c>>>0)|0)+c|0}c=c>>>(v[b+88>>2]&1&v[a+480180>>2]==16384)|0;b:{c:{d=b+788|0;if(!Rd(d)){g=e+8|0;Db(g,f,114);if(!Cb(g)){break c}}d:{if(!v[b+656>>2]){break d}if(!Rd(d)){break d}d=x[vd(v[b+656>>2]+236|0,w[b+788|0]-1|0)>>1];if(!d|d>>>0>x[a+480190>>1]){break b}}if(w[a+480210|0]&32){d=c;c=v[b+660>>2];v[b+660>>2]=d+c}v[b>>2]=0;v[b+4>>2]=c;if((!(w[b+88|0]&2)|y[b+84>>2]>c>>>0)&y[b+76>>2]>c>>>0){break b}c=e+8|0;Db(c,f,57);if(!(!Cb(c)&v[a+480180>>2]!=16)){v[b+700>>2]=0;v[b+88>>2]=v[b+88>>2]|2097152;break b}if(!(v[a+480180>>2]&1048581)){c=e+8|0;Db(c,f,27);if(Cb(c)){if(w[a+480208|0]&4){d=v[b+76>>2];v[b>>2]=0;v[b+4>>2]=d;break b}v[b>>2]=0;v[b+4>>2]=0;break b}d=v[b+80>>2];v[b>>2]=0;v[b+4>>2]=d;if(!(w[a+480208|0]&4)){break b}a=v[b+76>>2];if(a>>>0<5){break b}v[b>>2]=0;v[b+4>>2]=a-2;break b}if(!(w[b+88|0]&2)|v[a+480180>>2]!=1){break b}a=v[b+80>>2];v[b>>2]=0;v[b+4>>2]=a;break b}if(!(v[a+480180>>2]&268582928)|y[b+76>>2]<=c>>>0){break b}v[b>>2]=0;v[b+4>>2]=c}gb=e+16|0}function IP(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;f=gb-32|0;gb=f;d=v[b+64>>2];a:{b:{h=v[b+60>>2];e=x[b+68>>1];if(!((h|0)==-1&(e|0)==65535)){c:{if((d|0)==-1){break c}g=f+24|0;d=a+1074312|0;Db(g,d,68);if(Cb(g)){break c}g=f+16|0;Db(g,d,103);if(i=Cb(g),j=0,k=(e|0)!=65535,k?i:j){break c}g=f+8|0;Db(g,d,49);if(i=Cb(g),j=0,k=(e|0)!=65535,k?i:j){break c}d=v[b+64>>2];break b}if((e|0)==65535){u[b+68>>1]=x[b+72>>1]+1}if((h|0)==-1){v[b+60>>2]=0}d=x[b+68>>1];e=a+484360|0;d:{if(tc(Sb(e))>>>0>d>>>0){d=x[b+68>>1];break d}d=x[Sb(e)+28>>1];u[b+68>>1]=d}e:{if(x[b+72>>1]==(d&65535)){break e}d=f+24|0;e=a+1074312|0;Db(d,e,26);if(Cb(d)){break e}d=f+16|0;Db(d,e,68);if(Cb(d)|v[a+480180>>2]==1|!x[a+480188>>1]){break e}d=0;while(1){t[(B(d,872)+b|0)+1457|0]=0;d=d+1|0;if(d>>>0<x[a+480188>>1]){continue}break}}v[b+52>>2]=v[b+60>>2];if(c){c=1;if(w[a+480208|0]&32){break a}}u[b+74>>1]=x[b+68>>1];c=1;break a}if((d|0)!=-1){break b}c=0;break a}v[b+52>>2]=d;u[b+74>>1]=x[b+72>>1];f:{if(!v[b+20>>2]){break f}if(v[a+480180>>2]==32){c=f+24|0;Db(c,a+1074312|0,103);if(Cb(c)){break f}}if(v[a+480180>>2]==2){break f}v[b+52>>2]=v[b+52>>2]+1}c=0;if(y[b+64>>2]<y[_b(a+484344|0,x[b+70>>1])+12>>2]){break a}v[b+52>>2]=0;u[b+74>>1]=x[b+74>>1]+1;c=0}gb=f+32|0;return c}function H8(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0;b=gb-2160|0;gb=b;Qb(b+112|0,0,2048);a:{b:{c:{f=v[c+4>>2];if(!f){a=ba(8)|0;v[22656]=0;b=Q(70,b+96|0,7723)|0;c=v[22656];v[22656]=0;if((c|0)==1){break c}rc(a,b);v[22656]=0;U(186,a|0,54952,1936);a=v[22656];v[22656]=0;if((a|0)!=1){break a}c=P()|0;O()|0;vb(b);break b}g=v[c>>2];d=v[c+12>>2];h=v[c+8>>2];v[b+88>>2]=h;v[b+92>>2]=d;c=v[b+92>>2];v[b+40>>2]=v[b+88>>2];v[b+44>>2]=c;v[b+84>>2]=f;v[b+80>>2]=g;c=v[b+84>>2];v[b+32>>2]=v[b+80>>2];v[b+36>>2]=c;c=b;j=b;i=gL(b+32|0);if(i){e=b- -64|0;v[e>>2]=h;v[b+68>>2]=d;d=v[e+4>>2];v[b+24>>2]=v[e>>2];v[b+28>>2]=d;v[b+60>>2]=f;v[b+56>>2]=g;d=v[b+60>>2];v[b+16>>2]=v[b+56>>2];v[b+20>>2]=d;d=fL(b+16|0)}else{d=0}v[j+72>>2]=d;v[c+76>>2]=0;c=0;d=2048;while(1){d:{e=kb[f|0](g,(b+112|0)+c|0,d)|0;c=e+c|0;if(!e){break d}d=d-e|0;if(d){continue}}break}c=wd(b+48|0,zb(b+112|0),c);f=v[c+4>>2];v[b+8>>2]=v[c>>2];v[b+12>>2]=f;a=lA(a,b+8|0,i?b+72|0:0);if(a+1>>>0>=3){a=ba(8)|0;v[22656]=0;b=Q(70,b+96|0,5190)|0;c=v[22656];v[22656]=0;if((c|0)!=1){rc(a,b);v[22656]=0;U(186,a|0,54952,1936);a=v[22656];v[22656]=0;if((a|0)!=1){break a}c=P()|0;O()|0;vb(b);break b}c=P()|0;O()|0;ca(a|0);break b}gb=b+2160|0;return a|0}c=P()|0;O()|0;ca(a|0)}S(c|0)}L()}function BH(a,b,c,d,e){var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,u=0;k=gb-16|0;gb=k;a:{b:{c:{if((c|0)<=36){g=w[a|0];if(g){break c}f=a;break b}v[115137]=28;d=0;e=0;break a}f=a;d:{while(1){if(!vm(g<<24>>24)){break d}g=w[f+1|0];h=f+1|0;f=h;if(g){continue}break}f=h;break b}e:{g=w[f|0];switch(g-43|0){case 0:case 2:break e;default:break b}}m=(g|0)==45?-1:0;f=f+1|0}f:{if(!(c&-17|w[f|0]!=48)){o=1;if((w[f+1|0]&223)==88){f=f+2|0;l=16;break f}f=f+1|0;l=c?c:8;break f}l=c?c:10}p=l;q=l>>31;c=0;while(1){g:{g=-48;h=t[f|0];h:{if((h-48&255)>>>0<10){break h}g=-87;if((h-97&255)>>>0<26){break h}g=-55;if((h-65&255)>>>0>25){break g}}h=g+h|0;if((h|0)>=(l|0)){break g}qf(k,p,q,0,0,j,i,0,0);g=1;i:{if(v[k+8>>2]|v[k+12>>2]){break i}r=kqa(j,i,p,q);n=jb;s=h>>31;u=s^-1;if((n|0)==(u|0)&(h^-1)>>>0<r>>>0|n>>>0>u>>>0){break i}i=n+s|0;g=h+r|0;i=g>>>0<h>>>0?i+1|0:i;j=g;o=1;g=c}f=f+1|0;c=g;continue}break}if(b){v[b>>2]=o?f:a}j:{k:{if(c){v[115137]=68;a=d&1;m=a?0:m;j=d;i=e;break k}if((e|0)==(i|0)&d>>>0>j>>>0|e>>>0>i>>>0){break j}a=d&1}if(!(a|m)){v[115137]=68;a=d;d=a-1|0;e=e-!a|0;break a}if((e|0)==(i|0)&d>>>0>=j>>>0|e>>>0>i>>>0){break j}v[115137]=68;break a}a=m;b=a^j;d=b-a|0;c=a>>31;e=(c^i)-((a>>>0>b>>>0)+c|0)|0}gb=k+16|0;jb=e;return d}function rpa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;h=gb-32|0;gb=h;v[h+24>>2]=b;b=v[a>>2];m=h,n=Vb(a),v[m>>2]=n;b=ck(h+24|0,h)+b|0;a:{g=TX(c,d);b:{if((g|0)<=0){break b}i=v[wb(a)>>2];e=v[a+4>>2];if((g|0)<=(i-e|0)){v[h>>2]=d;i=e-b|0;if((i|0)<(g|0)){v[h>>2]=c;ow(h,i);l=v[h>>2];k=gb-16|0;gb=k;j=Ai(k,a,g-i|0);wb(a);f=gb-16|0;gb=f;v[f>>2]=d;v[f+8>>2]=l;if(Gb(f+8|0,f)){while(1){d=f+8|0;mp(v[j+4>>2],v[d>>2]);Pe(d);v[j+4>>2]=v[j+4>>2]+1;if(Gb(d,f)){continue}break}}gb=f+16|0;$b(j);gb=k+16|0;if((i|0)<=0){break b}}k=gb-16|0;gb=k;f=e;j=b;i=a;l=v[a+4>>2];a=(l-(b+g|0)|0)+b|0;g=Ai(k,i,e-a|0);if(a>>>0<e>>>0){e=v[g+4>>2];d=a;while(1){wb(i);mp(e,d);e=e+1|0;v[g+4>>2]=e;d=d+1|0;if(f>>>0>d>>>0){continue}break}}$b(g);zr(j,a,l);gb=k+16|0;Vi(c,v[h>>2],b);break b}e=wb(a);e=Zg(h,qh(a,oc(a)+g|0),b-v[a>>2]|0,e);v[22656]=0;SX(e,c,d);c=v[22656];v[22656]=0;if((c|0)==1){break a}vt(a);c=v[e+4>>2];j=e+4|0;Dk(wb(a),v[a>>2],b,j);wb(a);i=e+8|0;d=i;g=v[a+4>>2];if((g|0)!=(b|0)){f=v[d>>2];while(1){mp(f,b);f=v[d>>2]+1|0;v[d>>2]=f;b=b+1|0;if((g|0)!=(b|0)){continue}break}}xc(a,j);xc(a+4|0,i);xc(wb(a),dc(e));v[e>>2]=v[e+4>>2];ut(a,oc(a));b=c;be(e)}Hg(b);gb=h+32|0;return}a=P()|0;O()|0;be(e);S(a|0);L()}function NO(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;e=gb-16|0;gb=e;a:{b:{d=a+484360|0;if(tc(Sb(d))>>>0<=b>>>0){break b}if(Po(Sb(d),b)){break b}while(1){b=b+1|0;c=b&65535;if(tc(Sb(d))>>>0<=c>>>0){break a}if(!Po(Sb(d),b&65535)){continue}break}break a}c=b}if(tc(Sb(d))>>>0>c>>>0){d=a+1074312|0;g=a+1298224|0;c=a+1074992|0;while(1){t[c+797|0]=0;v[c+700>>2]=0;t[c+841|0]=0;t[c+805|0]=0;v[c+708>>2]=0;t[c+821|0]=0;v[c+764>>2]=0;t[c+819|0]=0;t[c+820|0]=0;f=e+8|0;Db(f,d,23);if(Cb(f)){t[c+807|0]=1;t[c+808|0]=0}t[c+839|0]=0;c=c+872|0;if((g|0)!=(c|0)){continue}break}MO(a);c:{if(!(b&65535)){b=a;c=0;while(1){$m((b+B(c,872)|0)+1074992|0,7,b,c&65535,134217728);c=c+1|0;if((c|0)!=256){continue}break}Ko(b+1298224|0,1);v[b+1074456>>2]=v[b+480200>>2];v[b+1074416>>2]=v[b+480196>>2];v[b+1074420>>2]=v[b+480204>>2];v[b+480208>>2]=v[b+480208>>2]&-769;yA(b+1074376|0);u[b+1074450>>1]=0;v[b+1074392>>2]=-2;c=b+1074428|0;v[c>>2]=0;v[c+4>>2]=0;c=b+1074396|0;v[c>>2]=0;v[c+4>>2]=0;v[b+1074376>>2]=0;v[b+1074380>>2]=0;break c}u[a+1074450>>1]=b;u[a+1074446>>1]=0;b=a+1074424|0;v[b>>2]=0;v[b+4>>2]=0;v[a+1074392>>2]=-2;v[a+1074432>>2]=0;b=a+1074396|0;v[b>>2]=0;v[b+4>>2]=0;v[a+1074380>>2]=0}v[a+480208>>2]=v[a+480208>>2]&-769}gb=e+16|0}function zq(a){var b=0,c=0,d=0,e=0,f=0,g=0;c=gb-16|0;gb=c;a:{b:{c:{d:{e:{f:{g:{h:{b=v[a+480180>>2];i:{if((b|0)<=2047){if((b|0)<=31){switch(b-1|0){case 2:case 4:case 5:case 6:break d;case 7:break g;case 0:case 1:case 3:break i;default:break e}}if((b|0)<=255){if((b|0)==32){break i}if((b|0)==64){break b}break d}if((b|0)==256|(b|0)==512){break b}break d}d=1;if((b|0)<=4194303){if((b|0)<=65535){if((b|0)==2048){break b}if((b|0)!=8192){break d}break b}if((b|0)==65536){break c}if((b|0)!=2097152){break d}break a}if((b|0)>67108863){break h}if((b|0)==4194304){break f}if((b|0)!=16777216){break d}}d=v[a+480180>>2];break a}if((b|0)==67108864|(b|0)==134217728){break a}if((b|0)!=536870912){break d}break a}d=4;if(x[a+480192>>1]){break a}a=a+484344|0;f=c,g=Vb(a),v[f+8>>2]=g;f=c,g=Zb(a),v[f>>2]=g;d=1;if(!Gb(c+8|0,c)){break a}while(1){a=v[c+8>>2];if(!(!hi(a)|v[a+12>>2]==64)){d=4;break a}a=c+8|0;VO(a);if(Gb(a,c)){continue}break}break a}d=32;if(x[a+480188>>1]>16){break a}if(!x[a+480188>>1]){break b}b=0;while(1){e=(b<<5)+a|0;if(t[e+480281|0]&1|x[e+480286>>1]!=64){break a}b=b+1|0;if(b>>>0<x[a+480188>>1]){continue}break}break b}if((b|0)==16){break b}}d=32;break a}d=16777216;break a}d=2}gb=c+16|0;return d}function o8(a,b){a=a|0;b=+b;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;d=gb-80|0;gb=d;a:{b:{c:{d:{e:{f:{g:{if(Bj(a)){zh(d+72|0);break g}c=d+32|0;po(c,a);v[22656]=0;c=T(2084,c|0)|0;e=v[22656];v[22656]=0;if((e|0)==1){break f}v[d+72>>2]=c;Yf(d+32|0)}if(Bj(a)){e=a+36|0}else{e=v[d+72>>2]}c=v[a+8>>2];if((c|0)!=-1){break c}c=v[e+4>>2]-24|0;h=ko(e);if(h){break e}break d}g=P()|0;O()|0;Yf(d+32|0);break a}j=A[c>>3];while(1){f=Xl(e,g);if(i+A[f>>3]>b){c=f;break d}i=i+j;g=g+1|0;if((h|0)!=(g|0)){continue}break}}b=b-i;break b}c=Xl(e,c)}e=a+24|0;f=v[e>>2];g=x[c+12>>1];v[22656]=0;R(2085,f|0,g|0);f=v[22656];v[22656]=0;if((f|0)!=1){h:{f=v[e>>2];g=w[a+64|0];c=AL(vV(d+32|0,b),w[c+16|0],x[c+12>>1],v[c+8>>2]);v[22656]=0;h=v[c+12>>2];v[d+16>>2]=v[c+8>>2];v[d+20>>2]=h;h=v[c+20>>2];v[d+24>>2]=v[c+16>>2];v[d+28>>2]=h;h=v[c+4>>2];v[d+8>>2]=v[c>>2];v[d+12>>2]=h;Y(2049,d+56|0,f|0,(g?7:1)|0,d+8|0);c=v[22656];v[22656]=0;if((c|0)==1){break h}g=d+56|0;c=IO(g);f=t[c+26|0]&1;h=v[(f?c+8|0:c+12|0)>>2];f=x[(f?c+20|0:c+22|0)>>1];b=A[c>>3];en(g);u[v[e>>2]+1074448>>1]=f;u[v[e>>2]+1074450>>1]=f;v[v[e>>2]+1074428>>2]=h;v[v[e>>2]+1074392>>2]=-2;b=i+b;A[a+16>>3]=b;xl(d+72|0);gb=d+80|0;return+b}}g=P()|0;O()|0;xl(d+72|0)}S(g|0);L()}function zfa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;j=gb-48|0;gb=j;l=-1;e=gb-32|0;gb=e;f=e+24|0;i=j+8|0;uF(f,i);g=yb(f);f=v[e+28>>2];d=v[e+24>>2];v[e+8>>2]=d;v[e+12>>2]=f;v[e>>2]=d;v[e+4>>2]=f;d=e+16|0;f=a;hd(d,f,e);d=yb(d);if((d|0)==(g|0)){bd(f,yb(e+24|0))}gb=e+32|0;f=(d|0)==(g|0);if(!f){vF(i)}a:{if(!f){break a}l=0;if(!XN(j+8|0)){break a}if(c){e=a;d=j+8|0;b:{if(!c){break b}m=Nf(c);if(!m){break b}q=v[e+12>>2];if(Wl(e,w[d+16|0]|w[d+17|0]<<8|(w[d+18|0]<<16|w[d+19|0]<<24))){c:{if(!(w[d+12|0]|w[d+13|0]<<8|(w[d+14|0]<<16|w[d+15|0]<<24))){break c}while(1){if(!Wf(e,5)){break c}d:{if((w[d+4|0]|w[d+5|0]<<8)>>>0>=64){f=e;i=ew(e);h=i&63;e:{if(!(i&64)){break e}g=6;while(1){k=ew(f);h=(k&127)<<g|h;if(!(k&128)){break e}k=g>>>0<25;g=g+7|0;if(k){continue}break}}if(((i&128?0-h|0:h)|0)<=0){break d}}h=0;g=1;while(1){f=ew(e);if(f){k=Zq(f<<24>>24);o=h>>>0>=m>>>0;i=o&g;f=i;f:{if(o){break f}f=i;if(!(g&1)){break f}f=w[c+h|0]==(k&255)}g=f;h=h+1|0;continue}break}bd(e,4);n=(h|0)==(m|0)?g?1:n:n}p=p+1|0;if(p>>>0<(w[d+12|0]|w[d+13|0]<<8|(w[d+14|0]<<16|w[d+15|0]<<24))>>>0){continue}break}}h=n&1}Wl(e,q)}if(!h){break a}}l=Oe(a,b,WN(j+8|0),0)}gb=j+48|0;return l|0}function gqa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;f=gb-32|0;gb=f;t[f+16|0]=44;v[f+8>>2]=-1;v[f+12>>2]=0;v[f>>2]=1058;v[f+4>>2]=2;j=a;c=gb+-64|0;gb=c;k=c;a=f;h=v[a>>2]&2?16:10;g=gb-32|0;gb=g;d=He(g+16|0,1,0);a:{b:{c:{while(1){e=Jb(d);i=Jb(d);l=Ab(d);m=v[b>>2];v[22656]=0;ha(92,g+8|0,e|0,i+l|0,m|0,h|0);e=v[22656];v[22656]=0;if((e|0)==1){break b}if(!v[g+12>>2]){break c}e=Ab(d);v[22656]=0;v[g+4>>2]=e;e=xf(g+4|0);i=v[22656];v[22656]=0;if((i|0)!=1){v[22656]=0;U(75,d|0,e|0,0);e=v[22656];v[22656]=0;if((e|0)!=1){continue}}break}break b}b=v[g+8>>2];h=Jb(d);v[22656]=0;R(76,d|0,b-h|0);b=v[22656];v[22656]=0;if((b|0)!=1){v[22656]=0;R(77,k|0,d|0);b=v[22656];v[22656]=0;if((b|0)==1){break b}vb(d);gb=g+32|0;break a}}a=P()|0;O()|0;vb(d);S(a|0);L()}b=c+16|0;Ml(b,c,a);v[22656]=0;U(89,c+32|0,b|0,a|0);b=v[22656];v[22656]=0;d:{e:{f:{g:{h:{if((b|0)!=1){v[22656]=0;U(90,c+48|0,c+32|0,a|0);a=v[22656];v[22656]=0;if((a|0)==1){break h}v[22656]=0;R(72,j|0,c+48|0);a=v[22656];v[22656]=0;if((a|0)==1){break g}vb(c+48|0);vb(c+32|0);vb(c+16|0);vb(c);gb=c- -64|0;break d}a=P()|0;O()|0;break e}a=P()|0;O()|0;break f}a=P()|0;O()|0;vb(c+48|0)}vb(c+32|0)}vb(c+16|0);vb(c);S(a|0);L()}gb=f+32|0}function _g(a,b,c,d){var e=0,f=0,g=0,h=0;g=gb-16|0;gb=g;v[g+12>>2]=d;e=b-1|0;f=0;a:{if(e>>>0>249){break a}h=_l(a);f=v[a+480180>>2];if(!h){if(f&17408){a=((e&255)>>>0)/12|0;f=x[((e-B(a,12)&255)<<1)+39696>>1]<<4>>>a|0;break a}if(!d){v[g+12>>2]=8363;d=8363}if(Hj(a)){a=((e&255)>>>0)/12|0;b=kqa(v[(e-B(a,12)<<6&960)+43584>>2]<<a,0,d,0);a=jb;c=a>>>21|0;f=Qc((a&2097151)<<11|b>>>21,c);break a}if(w[a+480208|0]&16){a=e&255;f=x[((a>>>0)%12<<1)+39696>>1]<<5>>>(a>>>0)/12|0;break a}a=((e&255)>>>0)/12|0;qc(g+12|0,-1>>>a|0);f=Qc(nqa(kqa(x[((e-B(a,12)&255)<<1)+39696>>1],0,267616,0),jb,v[g+12>>2]<<a,0),jb);break a}if(f&20){d=e>>>0>12;if(v[a+480180>>2]==16){b=c<<4}else{Db(g,a+1074312|0,76);b=Cb(g)?c&-8:c}c=d?e:12;if(w[a+480208|0]&16){a=(((b|0)/-2|0)-(c<<6)|0)+8448|0;f=(a|0)>1?a:1;break a}c=c-12|0;a=((c&255)>>>0)/12|0;d=((b|0)/16|0)+(c-B(a,12)<<3&248)|0;v[g>>2]=d+8;Zd(g,0,103);c=b;b=b>>31;c=(c+b^b)&15;b=d+(b|1)|0;b=(b|0)>-8?b:-8;f=B(c,x[(((b|0)<95?b:95)<<1)+40192>>1])+B(x[(v[g>>2]<<1)+40176>>1],16-c|0)<<1>>>a|0;break a}a=c&255;if(!(!(e>>>0<24|a>>>0>15)&e>>>0<108)){b=B(a>>>4|0,12);a=((e&255)>>>0)/12|0;f=x[(b+(e-B(a,12)&255)<<1)+39296>>1]<<5>>>a|0;break a}f=x[(b<<1)+39070>>1]<<2}gb=g+16|0;return f}function Nea(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;k=gb-16|0;gb=k;a:{b:{if(!Jd(a)){break b}if((b|0)==(c|0)|(fd(a)|0)!=2){break b}if(l=Jd(b),m=0,n=(a|0)!=(b|0),n?l:m){break b}if(l=Jd(c),m=0,n=(a|0)!=(c|0),n?l:m){break b}if((a|0)==(b|0)){j=v[b+20>>2]}else{j=Sq(v[a>>2],ij(a))}e=j;if((a|0)==(c|0)){f=v[c+20>>2]}else{f=Sq(v[a>>2],ij(a))}if(!(f?e:0)){if((a|0)!=(b|0)){Tq(j)}if((a|0)==(c|0)){break b}Tq(f);break b}c:{if((ij(a)|0)==2){g=j;e=f;h=v[a+20>>2];i=v[a>>2];if(i){while(1){u[g>>1]=x[h>>1];u[e>>1]=x[h+2>>1];h=h+4|0;e=e+2|0;g=g+2|0;i=i-1|0;if(i){continue}break}}break c}if((ij(a)|0)!=1){break c}g=j;e=f;h=v[a+20>>2];i=v[a>>2];if(i){while(1){t[g|0]=w[h|0];t[e|0]=w[h+1|0];h=h+2|0;e=e+1|0;g=g+1|0;i=i-1|0;if(i){continue}break}}}bp(b,a);v[b+20>>2]=j;u[b+34>>1]=x[b+34>>1]&65471;bp(c,a);v[c+20>>2]=f;u[c+34>>1]=x[c+34>>1]&65471;j=d+1298224|0;a=d+1074992|0;while(1){f=v[a+104>>2];if(!((f|0)!=(b|0)&(c|0)!=(f|0))){v[a+88>>2]=v[a+88>>2]&-65}a=a+872|0;if((j|0)!=(a|0)){continue}break}v[22656]=0;_h(b,d,0);a=v[22656];v[22656]=0;if((a|0)==1){break a}v[22656]=0;_h(c,d,0);a=v[22656];v[22656]=0;if((a|0)==1){break a}g=1}gb=k+16|0;return g|0}a=P()|0;O()|0;S(a|0);L()}function lia(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;e=gb-48|0;gb=e;k=v[a+16>>2];f=Ud(e+16|0);v[f+8>>2]=a+112;v[f+16>>2]=v[a+128>>2];o=f,p=jg(b+327720|0,v[b+20>>2],(v[a+88>>2]&16384)>>>14|0),v[o+12>>2]=p;b=v[f+16>>2];if(b){o=f,p=lg(a+8|0,b),v[o>>2]=p;v[f+4>>2]=jb}l=v[a+24>>2];m=v[a+20>>2];h=v[a+4>>2];g=v[a>>2];v[e+8>>2]=g;v[e+12>>2]=h;i=v[a+12>>2];v[e>>2]=v[a+8>>2];v[e+4>>2]=i;if(d){while(1){i=0;j=g;v[e+40>>2]=g;v[e+44>>2]=n;h=((((h&2147483647)<<1|g>>>31)&2147483646)<<1)+k|0;a:{if((b|0)<=0){break a}while(1){g=(i&2147483647)<<1|j>>>31;Id(v[f+8>>2],(u[(g<<1|2)+h>>1]+u[h+((g&2147483646)<<1)>>1]|0)/8<<16>>16);Hd(v[f+8>>2],4);Ub(e+40|0,f);if((b|0)<2){break a}b=b-1|0;j=v[e+40>>2];i=v[e+44>>2];continue}}d=d-1|0;b=v[f+8>>2];Ub(b,b+8|0);b=v[f+8>>2];g=v[b+4>>2];if(g){j=b;b=(v[e+44>>2]&2147483647)<<1|v[e+40>>2]>>>31;Id(j,(u[(b<<1|2)+h>>1]+u[h+((b&2147483646)<<1)>>1]|0)/8<<16>>16);Hd(v[f+8>>2],g);b=v[f+8>>2];g=v[b>>2];v[b>>2]=g;v[b+4>>2]=0}b=ig(b,v[f+12>>2]);v[c>>2]=v[c>>2]+B(b,m);v[c+4>>2]=v[c+4>>2]+B(b,l);Ub(e+8|0,e);if(d){c=c+8|0;b=v[f+16>>2];g=v[e+8>>2];h=v[e+12>>2];continue}break}g=v[e+8>>2];h=v[e+12>>2]}v[a>>2]=g;v[a+4>>2]=h;gb=e+48|0}function jZ(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;g=gb-32|0;gb=g;t[g+12|0]=0;l=YD(g+16|0,d,g+12|0);h=v[l>>2];v[g+12>>2]=d;f=d;a:{if(!b|!f){break a}while(1){m=g;i=b-1|0;f=w[a|0];b:{c:{if(!(!i|(f|0)!=(e&255))){f=w[a+1|0];v[22656]=0;v[g+8>>2]=f;f=Fb(g+8|0,g+12|0);i=v[22656];v[22656]=0;d:{if((i|0)!=1){k=a+2|0;i=b-2|0;if(!i){break d}j=v[f>>2];if(!(j&255)){break d}i=w[k|0];while(1){t[h|0]=i;f=v[g+12>>2]-1|0;v[g+12>>2]=f;h=h+1|0;j=j-1|0;if(j&255){continue}break}i=b-3|0;k=a+3|0;break b}a=P()|0;O()|0;gc(l);S(a|0);L()}t[h|0]=e;f=v[g+12>>2]-1|0;break c}k=a+1|0;t[h|0]=f;f=v[g+12>>2]-1|0}v[m+12>>2]=f;h=h+1|0}if(!i){break a}a=k;b=i;if(f){continue}break}}k=v[l>>2];e=d-f|0;if(e){h=128;i=0;while(1){b=w[k|0];j=0;f=0;while(1){a=c+i|0;t[a|0]=w[a|0]|(B(b&h,257)&65535)>>>(f-j&7);a=i+1|0;i=a>>>0<d>>>0?a:0;f=(a>>>0>=d>>>0)+f|0;h=(h<<8|h)>>>1&255;a=j&65535;j=j+1|0;if(a>>>0<7){continue}break}h=(B(h,257)&65535)>>>f&255;k=k+1|0;n=n+1|0;if((n|0)!=(e|0)){continue}break}j=0;while(1){d=c;f=d;m=j<<24>>24;b=t[d|0];d=128;e:{if((b|0)==-128){break e}a=b;d=a;if((a|0)>=0){break e}d=0-(b&127)|0}j=m-(d&255)|0;t[f|0]=j;c=c+1|0;e=e-1|0;if(e){continue}break}}gc(l);gb=g+32|0}function KM(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=C(0);c=gb-96|0;gb=c;d=v[b+4>>2];v[c+64>>2]=v[b>>2];v[c+68>>2]=d;b=Ud(c+56|0);d=v[c+68>>2];v[c+8>>2]=v[c+64>>2];v[c+12>>2]=d;d=v[b+4>>2];v[c>>2]=v[b>>2];v[c+4>>2]=d;d=ps(c+72|0,c+8|0,c);v[22656]=0;b=T(467,d|0)|0;e=v[22656];v[22656]=0;a:{if((e|0)==1){break a}v[22656]=0;b=W(1595,d|0,c+16|0,b|0)|0;e=v[22656];v[22656]=0;if((e|0)==1){break a}b:{if(!b|v[c+16>>2]!=542066252){break b}b=c+16|4;if(w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24)){break b}b=c+24|0;f=a,g=Ho((l(2,w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24)),q()),C(0),C(1)),z[f+4220>>2]=g;b=c+28|0;f=a,g=Ho((l(2,w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24)),q()),C(0),C(1)),z[f+4224>>2]=g;b=c+32|0;f=a,g=Ho((l(2,w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24)),q()),C(0),C(1)),z[f+4228>>2]=g;b=c+36|0;if((w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24))>>>0<=5){v[a+4232>>2]=w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24)}b=c+40|0;v[a+4236>>2]=w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24);t[a+4240|0]=w[c+44|0]!=0;t[a+4241|0]=w[c+45|0]!=0;t[a+4242|0]=w[c+46|0]!=0;t[a+4243|0]=w[c+47|0]!=0;t[a+4244|0]=w[c+48|0]!=0;Rt(a)}xb(d);gb=c+96|0;return}a=P()|0;O()|0;xb(d);S(a|0);L()}function Ria(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;g=gb-32|0;gb=g;a:{b:{c:{e=v[a+12>>2];h=v[a+8>>2];d:{if((e|0)<=1&h>>>0<=805306368|(e|0)<=0){if((e|0)>=-2&h>>>0>=3489660928|(e|0)>-2){break c}if((e|0)==-2&h>>>0>2147483647|e>>>0>4294967294){break d}break b}if((e|0)==1&h>>>0>2147483648|e>>>0>1){break b}}i=b+196648|0;break a}i=b+131112|0;break a}i=b+262184|0}j=v[a+16>>2];k=v[a+24>>2];l=v[a+20>>2];b=v[a+4>>2];f=v[a>>2];v[g+24>>2]=f;v[g+28>>2]=b;v[g+16>>2]=h;v[g+20>>2]=e;if(d){while(1){e=((((b&2147483647)<<1|f>>>31)&2147483646)<<1)+j|0;b=(f>>>16&65520)+i|0;m=u[b+14>>1];n=u[b+12>>1];o=u[b+10>>1];p=u[b+8>>1];q=u[b+6>>1];r=u[b+4>>1];s=u[b+2>>1];t=u[b>>1];h=0;b=1;while(1){f=h<<1;v[(g+8|0)+(h<<2)>>2]=(((((((B(u[(f|-8)+e>>1],s)+B(u[(f|-12)+e>>1],t)|0)+B(u[(f|-4)+e>>1],r)|0)+B(u[e+f>>1],q)|0)+B(u[(f|4)+e>>1],p)|0)+B(u[(f|8)+e>>1],o)|0)+B(u[(f|12)+e>>1],n)|0)+B(u[(f|16)+e>>1],m)|0)/32768;f=b;b=0;h=1;if(f){continue}break}v[c>>2]=v[c>>2]+B(v[g+8>>2],l);v[c+4>>2]=v[c+4>>2]+B(v[g+12>>2],k);Ub(g+24|0,g+16|0);d=d-1|0;if(d){c=c+8|0;f=v[g+24>>2];b=v[g+28>>2];continue}break}f=v[g+24>>2];b=v[g+28>>2]}v[a>>2]=f;v[a+4>>2]=b;gb=g+32|0}function b3(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0;h=gb-160|0;gb=h;v[h+144>>2]=c;v[h+152>>2]=b;v[h+20>>2]=2479;b=ge(h+24|0,h+32|0,h+20|0);v[22656]=0;Fc(h+16|0,e);a=v[22656];v[22656]=0;a:{b:{c:{d:{if((a|0)!=1){v[22656]=0;a=T(21,h+16|0)|0;i=v[22656];v[22656]=0;if((i|0)==1){break b}t[h+15|0]=0;e=v[e+4>>2];v[22656]=0;c=ra(2480,h+152|0,c|0,d|0,h+16|0,e|0,f|0,h+15|0,a|0,b|0,h+20|0,h+132|0)|0;d=v[22656];v[22656]=0;if((d|0)==1){break b}if(!c){break c}Se(g);if(!w[h+15|0]){break d}v[22656]=0;c=Q(22,a|0,45)|0;d=v[22656];v[22656]=0;if((d|0)==1){break b}v[22656]=0;R(61,g|0,c|0);c=v[22656];v[22656]=0;if((c|0)!=1){break d}break b}e=P()|0;O()|0;break a}v[22656]=0;d=Q(22,a|0,48)|0;a=v[22656];v[22656]=0;if((a|0)==1){break b}e=v[b>>2];c=v[h+20>>2];e:{if(e>>>0>=c-1>>>0){break e}a=(c+(e^-1)|0)+e|0;d=d&255;while(1){if((d|0)!=w[e|0]){break e}e=e+1|0;if((a|0)!=(e|0)){continue}break}e=a}v[22656]=0;U(2486,g|0,e|0,c|0);a=v[22656];v[22656]=0;if((a|0)!=1){break c}break b}v[22656]=0;a=Q(2431,h+152|0,h+144|0)|0;c=v[22656];v[22656]=0;if((c|0)==1){break b}if(a){v[f>>2]=v[f>>2]|2}a=v[h+152>>2];Wb(h+16|0);Ic(b);gb=h+160|0;return a|0}e=P()|0;O()|0;Wb(h+16|0)}Ic(b);S(e|0);L()}function M$(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0;if(Sg(a,v[b+8>>2],e)){fx(b,c,d);return}a:{if(Sg(a,v[b>>2],e)){if(!(v[b+16>>2]!=(c|0)&v[b+20>>2]!=(c|0))){if((d|0)!=1){break a}v[b+32>>2]=1;return}v[b+32>>2]=d;b:{if(v[b+44>>2]==4){break b}d=v[a+12>>2];if((d|0)<=0){v[b+44>>2]=4;break b}i=((d<<3)+a|0)+16|0;f=a+16|0;j=b;c:{d:{while(1){e:{u[b+52>>1]=0;ex(f,b,c,c,1,e);if(w[b+54|0]){break e}f:{if(!w[b+53|0]){break f}if(w[b+52|0]){d=1;if(v[b+24>>2]==1){break d}h=1;g=1;if(w[a+8|0]&2){break f}break d}h=1;d=g;if(!(t[a+8|0]&1)){break d}}f=f+8|0;if(i>>>0>f>>>0){continue}}break}d=g;a=4;if(!h){break c}}a=3}v[j+44>>2]=a;if(d&1){break a}}v[b+20>>2]=c;v[b+40>>2]=v[b+40>>2]+1;if(v[b+36>>2]!=1|v[b+24>>2]!=2){break a}t[b+54|0]=1;return}g=v[a+12>>2];f=a+16|0;Cs(f,b,c,d,e);if((g|0)<2){break a}g=f+(g<<3)|0;f=a+24|0;a=v[a+8>>2];if(!(!(a&2)&v[b+36>>2]!=1)){while(1){if(w[b+54|0]){break a}Cs(f,b,c,d,e);f=f+8|0;if(g>>>0>f>>>0){continue}break}break a}if(!(a&1)){while(1){if(w[b+54|0]|v[b+36>>2]==1){break a}Cs(f,b,c,d,e);f=f+8|0;if(g>>>0>f>>>0){continue}break a}}while(1){if(w[b+54|0]|v[b+36>>2]==1&v[b+24>>2]==1){break a}Cs(f,b,c,d,e);f=f+8|0;if(g>>>0>f>>>0){continue}break}}}function m1(a,b,c,d,e,f,g,h){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0;a=gb-16|0;gb=a;v[a+12>>2]=c;v[a+8>>2]=f;v[a+12>>2]=c;v[a+8>>2]=f;a:{b:{c=v[a+12>>2];if(d>>>0>c>>>0){while(1){if(f>>>0>=g>>>0){break b}k=t[c|0];b=k&255;c:{if((k|0)>=0){i=1;break c}k=2;if(b>>>0<194){break a}if(b>>>0<=223){if((d-c|0)<2){break b}i=w[c+1|0];if((i&192)!=128){break a}b=i&63|b<<6&1984;i=2;break c}if(b>>>0<=239){if((d-c|0)<3){break b}j=w[c+2|0];i=w[c+1|0];d:{e:{if((b|0)!=237){if((b|0)!=224){break e}if((i&224)==160){break d}break a}if((i&224)==128){break d}break a}if((i&192)!=128){break a}}if((j&192)!=128){break a}b=j&63|(b<<12&61440|(i&63)<<6);i=3;break c}if(b>>>0>244){break a}if((d-c|0)<4){break b}l=w[c+3|0];m=w[c+2|0];j=w[c+1|0];f:{g:{switch(b-240|0){case 0:if((j+112&255)>>>0<48){break f}break a;case 4:if((j&240)==128){break f}break a;default:break g}}if((j&192)!=128){break a}}if((m&192)!=128|(l&192)!=128){break a}i=4;b=l&63|(m<<6&4032|(b<<18&1835008|(j&63)<<12));if(b>>>0>1114111){break a}}v[f>>2]=b;v[a+12>>2]=c+i;f=v[a+8>>2]+4|0;v[a+8>>2]=f;c=v[a+12>>2];if(d>>>0>c>>>0){continue}break}}k=0;break a}k=1}v[e>>2]=v[a+12>>2];v[h>>2]=v[a+8>>2];gb=a+16|0;return k|0}function aT(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;g=gb-16|0;gb=g;a:{if(w[d|0]){e=ne(g+8|0,b);b=Rj(c,b);d=gb-16|0;gb=d;v[d+12>>2]=b;c=v[e+4>>2];b:{if(c){v[d+8>>2]=32-c;b=Fb(d+8|0,d+12|0);c=v[e>>2];b=v[b>>2];f=v[c>>2]&(-1<<v[e+4>>2]&-1>>>v[d+8>>2]-b);if(f){td(a,c,jqa(f));break b}f=v[d+12>>2];if((f|0)==(b|0)){xB(a,e,b);break b}b=f-b|0;v[d+12>>2]=b;v[e>>2]=c+4}if(b>>>0>=32){c=v[e>>2];while(1){f=v[c>>2];if(f){td(a,c,jqa(f));break b}c=c+4|0;v[e>>2]=c;b=b-32|0;v[d+12>>2]=b;if(b>>>0>31){continue}break}}c:{if(!b){c=v[e>>2];break c}c=v[e>>2];e=v[c>>2]&-1>>>32-b;if(!e){break c}td(a,c,jqa(e));break b}td(a,c,b)}break a}e=ne(g,b);b=Rj(c,b);d=gb-16|0;gb=d;v[d+12>>2]=b;c=v[e+4>>2];d:{if(c){v[d+8>>2]=32-c;b=v[Fb(d+8|0,d+12|0)>>2];c=v[e>>2];f=-1<<v[e+4>>2]&-1>>>v[d+8>>2]-b&(v[c>>2]^-1);if(f){td(a,c,jqa(f));break d}f=v[d+12>>2];if((f|0)==(b|0)){xB(a,e,b);break d}b=f-b|0;v[d+12>>2]=b;v[e>>2]=c+4}if(b>>>0>=32){c=v[e>>2];while(1){f=v[c>>2];if((f|0)!=-1){td(a,c,jqa(f^-1));break d}c=c+4|0;v[e>>2]=c;b=b-32|0;v[d+12>>2]=b;if(b>>>0>31){continue}break}}e:{if(!b){c=v[e>>2];break e}c=v[e>>2];e=(v[c>>2]^-1)&-1>>>32-b;if(!e){break e}td(a,c,jqa(e));break d}td(a,c,b)}}gb=d+16|0;gb=g+16|0}function Yia(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,w=0;g=gb-16|0;gb=g;f=v[a+48>>2];k=v[a+40>>2];l=v[a+36>>2];b=v[a+44>>2];q=v[a+16>>2];e=v[a+4>>2];i=e;h=v[a>>2];v[g+8>>2]=h;v[g+12>>2]=e;e=v[a+12>>2];v[g>>2]=v[a+8>>2];v[g+4>>2]=e;a:{if(d){while(1){e=i+q|0;i=t[e+2|0];m=t[e+1|0];n=t[e|0];o=t[e-1|0];e=v[a+60>>2];r=e;s=e>>31;e=Lb(b,-16777216,16776704);j=v[a+64>>2];f=Lb(f,-16777216,16776704);e=kqa(j,j>>31,e,e>>31);j=jb;w=e;e=v[a+68>>2];p=kqa(e,e>>31,f,f>>31);e=w+p|0;f=jb+j|0;f=e>>>0<p>>>0?f+1|0:f;j=e;e=h>>>21&2040;i=(((B(n,u[e+46162>>1])+B(o,u[e+46160>>1])|0)+B(m,u[e+46164>>1])|0)+B(i,u[e+46166>>1])<<8)/16384<<8;e=i;h=kqa(r,s,e,e>>31);e=j+h|0;f=jb+f|0;f=e>>>0<h>>>0?f+1|0:f;e=e+8388608|0;f=e>>>0<8388608?f+1|0:f;f=Jc(e,f,24);e=v[a+72>>2];h=v[a+32>>2];l=v[a+28>>2]+l|0;m=l>>12;o=(f|0)/256|0;v[c>>2]=v[c>>2]+B(m,o);k=h+k|0;n=k>>12;v[c+4>>2]=v[c+4>>2]+B(o,n);e=f-(e&i)|0;Ub(g+8|0,g);d=d-1|0;if(d){c=c+8|0;h=v[g+8>>2];i=v[g+12>>2];f=b;b=e;continue}break}h=v[g+8>>2];i=v[g+12>>2];f=b;break a}n=k>>12;m=l>>12;e=b}v[a+40>>2]=k;v[a+20>>2]=m;v[a+36>>2]=l;v[a+48>>2]=f;v[a+44>>2]=e;v[a+24>>2]=n;v[a>>2]=h;v[a+4>>2]=i;gb=g+16|0}function eda(a){a=a|0;var b=0,c=0,d=0,e=0,f=C(0),g=0,h=0;c=gb-32|0;gb=c;a:{b=v[a+20>>2];b:{if(!b){break b}v[b+148>>2]=-1;g=c,h=kb[v[v[a>>2]+40>>2]](a)|0,v[g+16>>2]=h;v[c+8>>2]=1073741822;e=v[pd(c+16|0,c+8|0)>>2];b=e<<2;if(!b){break b}d=v[a+20>>2];v[22656]=0;R(440,d+4|0,b+4|0);b=v[22656];v[22656]=0;c:{if((b|0)!=1){b=v[a+20>>2];v[22656]=0;Vd(c+8|0,b+4|0);b=v[22656];v[22656]=0;if((b|0)!=1){v[c>>2]=0;v[c+4>>2]=0;d=v[c+12>>2];b=c+16|0;v[b>>2]=v[c+8>>2];v[b+4>>2]=d;d=v[c+4>>2];v[b+8>>2]=v[c>>2];v[b+12>>2]=d;v[22656]=0;_(1633,b|0);b=v[22656];v[22656]=0;d:{e:{if((b|0)==1){break e}b=v[v[a>>2]+180>>2];v[22656]=0;R(b|0,a|0,-1);b=v[22656];v[22656]=0;if((b|0)==1){break e}b=0;if((e|0)>0){while(1){d=v[v[a>>2]+48>>2];v[22656]=0;f=C(Za(d|0,a|0,b|0));d=v[22656];v[22656]=0;if((d|0)==1){break d}v[22656]=0;z[c+8>>2]=f;R(1634,c+16|0,c+8|0);d=v[22656];v[22656]=0;if((d|0)==1){break d}b=b+1|0;if((e|0)!=(b|0)){continue}break}}b=v[v[a>>2]+184>>2];v[22656]=0;_(b|0,a|0);b=v[22656];v[22656]=0;if((b|0)!=1){break b}}b=V(89116)|0;break c}b=V(89116)|0;break c}b=V(89116)|0;break c}b=V(89116)|0}if((O()|0)!=(ea(89116)|0)){break a}Z(b|0)|0;yr(v[a+20>>2]+4|0);$()}gb=c+32|0;return}S(b|0);L()}function Gd(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=gb+-64|0;gb=d;v[a+480180>>2]=b;b=zq(a);oA(d,b);e=v[d+12>>2];c=a+1074320|0;v[c>>2]=v[d+8>>2];v[c+4>>2]=e;c=v[d+4>>2];v[a+1074312>>2]=v[d>>2];v[a+1074316>>2]=c;hu(a+8|0,b);c=x[a+480192>>1];if(c){b=1;while(1){e=(((b&65535)<<2)+a|0)+900380|0;f=v[e>>2];if(f){Yb(sv(f));c=x[a+480192>>1]}v[e>>2]=0;b=b+1|0;if((b&65535)>>>0<=c>>>0){continue}break}}v[a+480184>>2]=0;v[a+480188>>2]=0;v[a+480236>>2]=65536;v[a+480228>>2]=48;v[a+480232>>2]=48;t[a+480268|0]=5;v[a+480260>>2]=16;v[a+480264>>2]=32767;v[a+480204>>2]=125e4;v[a+480208>>2]=0;v[a+480196>>2]=6;v[a+480200>>2]=256;v[a+1074304>>2]=0;v[a+1074308>>2]=0;u[a+480192>>1]=0;nA(a,4);e=gb+-64|0;gb=e;b=a+484344|0;BN(b);f=Sf(b);c=pz(e+8|0,b);v[22656]=0;U(1487,b|0,f|0,c|0);b=v[22656];v[22656]=0;a:{if((b|0)!=1){Km(c);gb=e- -64|0;break a}a=P()|0;O()|0;Km(c);S(a|0);L()}mS(a+484360|0);Se(a+1298268|0);Se(a+1298280|0);Se(a+1298292|0);c=a+1298304|0;d=Qb(d,0,64);b=$O(d);Eb(c,b);Eb(c+12|0,b+12|0);Eb(c+24|0,b+24|0);Eb(c+36|0,b+36|0);Eb(c+48|0,b+48|0);v[c+60>>2]=v[b+60>>2];mu(b);xD(a+1298368|0);Gg(a+480248|0);if(v[a+480180>>2]&738230281){v[a+480208>>2]=v[a+480208>>2]|8388608}gb=d- -64|0}function oha(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;g=gb-16|0;gb=g;i=g;c=gb-160|0;gb=c;e=c+24|0;h=ju(e+56|0);v[e>>2]=75508;v[h>>2]=75528;v[22656]=0;f=e+4|0;W(95,e|0,75540,f|0)|0;d=v[22656];v[22656]=0;a:{if((d|0)!=1){b:{v[e>>2]=75508;v[h>>2]=75528;v[22656]=0;Q(96,f|0,16)|0;d=v[22656];v[22656]=0;if((d|0)==1){break b}break a}}a=P()|0;O()|0;oh(h);S(a|0);L()}h=v[v[e>>2]-12>>2];v[22656]=0;f=ga(79)|0;d=v[22656];v[22656]=0;c:{d:{e:{f:{g:{h:{if((d|0)==1){break h}v[22656]=0;U(80,c+16|0,h+(c+24|0)|0,f|0);d=v[22656];v[22656]=0;if((d|0)==1){break h}Wb(c+16|0);v[22656]=0;f=Hg(17);d=v[22656];v[22656]=0;if((d|0)==1){break g}v[22656]=0;v[c>>2]=f;f=mP(e,c);d=v[22656];v[22656]=0;if((d|0)==1){break g}j=A[b>>3];v[22656]=0;_a(83,f|0,+j)|0;b=v[22656];v[22656]=0;if((b|0)==1){break g}v[22656]=0;R(84,c|0,e|0);b=v[22656];v[22656]=0;if((b|0)==1){break f}v[22656]=0;R(77,i|0,c|0);b=v[22656];v[22656]=0;if((b|0)==1){break e}vb(c);Cq(e);gb=c+160|0;break c}a=P()|0;O()|0;break d}a=P()|0;O()|0;break d}a=P()|0;O()|0;break d}a=P()|0;O()|0;vb(c)}Cq(e);S(a|0);L()}v[22656]=0;R(72,a|0,g|0);a=v[22656];v[22656]=0;if((a|0)!=1){vb(g);gb=g+16|0;return}a=P()|0;O()|0;vb(g);S(a|0);L()}function Xia(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;h=gb-16|0;gb=h;e=v[a+48>>2];k=v[a+40>>2];l=v[a+36>>2];b=v[a+44>>2];q=v[a+16>>2];g=v[a+4>>2];j=v[a>>2];v[h+8>>2]=j;v[h+12>>2]=g;f=v[a+12>>2];v[h>>2]=v[a+8>>2];v[h+4>>2]=f;a:{if(d){while(1){f=(g<<1)+q|0;i=u[f>>1];m=u[f-2>>1];n=u[f+2>>1];r=u[f+4>>1];p=v[a+60>>2];f=Lb(b,-16777216,16776704);o=v[a+64>>2];g=Lb(e,-16777216,16776704);e=kqa(o,o>>31,f,f>>31);o=jb;f=e;e=j>>>21&2040;j=(((B(i,u[e+46162>>1])+B(m,u[e+46160>>1])|0)+B(n,u[e+46164>>1])|0)+B(r,u[e+46166>>1])|0)/16384<<8;e=j;i=kqa(p,p>>31,e,e>>31);f=f+i|0;e=jb+o|0;e=f>>>0<i>>>0?e+1|0:e;i=f;f=v[a+68>>2];g=kqa(f,f>>31,g,g>>31);f=i+g|0;e=jb+e|0;e=f>>>0<g>>>0?e+1|0:e;f=f+8388608|0;e=f>>>0<8388608?e+1|0:e;e=Jc(f,e,24);f=v[a+72>>2];g=v[a+32>>2];l=v[a+28>>2]+l|0;i=l>>12;n=(e|0)/256|0;v[c>>2]=v[c>>2]+B(i,n);k=g+k|0;m=k>>12;v[c+4>>2]=v[c+4>>2]+B(n,m);f=e-(f&j)|0;Ub(h+8|0,h);d=d-1|0;if(d){c=c+8|0;j=v[h+8>>2];g=v[h+12>>2];e=b;b=f;continue}break}j=v[h+8>>2];g=v[h+12>>2];e=b;break a}m=k>>12;i=l>>12;f=b}v[a+40>>2]=k;v[a+20>>2]=i;v[a+36>>2]=l;v[a+48>>2]=e;v[a+44>>2]=f;v[a+24>>2]=m;v[a>>2]=j;v[a+4>>2]=g;gb=h+16|0}function Sia(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,w=0;e=gb-32|0;gb=e;a:{b:{c:{g=v[a+12>>2];f=v[a+8>>2];d:{if((g|0)<=1&f>>>0<=805306368|(g|0)<=0){if((g|0)>=-2&f>>>0>=3489660928|(g|0)>-2){break c}if((g|0)==-2&f>>>0>2147483647|g>>>0>4294967294){break d}break b}if((g|0)==1&f>>>0>2147483648|g>>>0>1){break b}}i=b+196648|0;break a}i=b+131112|0;break a}i=b+262184|0}j=v[a+16>>2];k=v[a+24>>2];l=v[a+20>>2];b=v[a+4>>2];h=v[a>>2];v[e+24>>2]=h;v[e+28>>2]=b;v[e+16>>2]=f;v[e+20>>2]=g;g=a;if(d){while(1){f=(((b&2147483647)<<1|h>>>31)&-2)+j|0;a=(h>>>16&65520)+i|0;m=u[a+14>>1];n=u[a+12>>1];o=u[a+10>>1];p=u[a+8>>1];q=u[a+6>>1];r=u[a+4>>1];s=u[a+2>>1];w=u[a>>1];b=0;a=1;while(1){v[(e+8|0)+(b<<2)>>2]=(((((((B(t[(b|-4)+f|0],s)+B(t[(b|-6)+f|0],w)|0)+B(t[(b|-2)+f|0],r)|0)+B(t[b+f|0],q)|0)+B(t[(b|2)+f|0],p)|0)+B(t[(b|4)+f|0],o)|0)+B(t[(b|6)+f|0],n)|0)+B(t[(b|8)+f|0],m)<<8)/32768;h=a;a=0;b=1;if(h){continue}break}v[c>>2]=v[c>>2]+B(v[e+8>>2],l);v[c+4>>2]=v[c+4>>2]+B(v[e+12>>2],k);Ub(e+24|0,e+16|0);d=d-1|0;if(d){c=c+8|0;h=v[e+24>>2];b=v[e+28>>2];continue}break}h=v[e+24>>2];b=v[e+28>>2]}v[g>>2]=h;v[g+4>>2]=b;gb=e+32|0}function Cna(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;d=b&63;if(tv(c)>>>0>d>>>0){g=xW(c,d);h=gb-16|0;gb=h;c=a;t[c+12|0]=0;Gg(c);f=gb-32|0;gb=f;a:{b:{d=c;if(pe(d)>>>0<=14){e=wb(d);e=Ap(f+8|0,15,Nb(d),e);v[22656]=0;R(300,d|0,e|0);d=v[22656];v[22656]=0;if((d|0)==1){break b}gj(e)}gb=f+32|0;break a}a=P()|0;O()|0;gj(e);S(a|0);L()}d=w[g+1|0];c:{if(!d){break c}f=0-d|0;while(1){t[h+7|0]=64;f=(f<<16>>16)+d|0;j=qr(h+8|0,f&65535,w[ac(((i<<1)+g|0)+2|0,h+7|0)|0]);d=c;d:{if(y[d+4>>2]<y[wb(d)>>2]){qW(d,j);break d}k=gb-32|0;gb=k;e=d;l=wb(d);d=Ap(k+8|0,fh(d,Nb(d)+1|0),Nb(d),l);m=v[d+8>>2];v[22656]=0;hn(l,m,j);j=v[22656];v[22656]=0;e:{f:{if((j|0)==1){break f}v[d+8>>2]=v[d+8>>2]+4;v[22656]=0;R(300,e|0,d|0);e=v[22656];v[22656]=0;if((e|0)==1){break f}gj(d);gb=k+32|0;break e}a=P()|0;O()|0;gj(d);S(a|0);L()}}i=i+1|0;if((i|0)==15){break c}d=w[((i<<1)+g|0)+1|0];if(d){continue}break}}d=w[g+32|0];t[c+14|0]=d>>>4;t[c+13|0]=d&15;d=w[g+31|0];e=d&15;t[c+15|0]=e;t[c+16|0]=e;if(d&16){t[c+12|0]=w[c+12|0]|4}if(d&32){t[c+12|0]=w[c+12|0]|2}gb=h+16|0}g:{if(b<<24>>24>=0){c=w[a+12|0]&-2;a=a+12|0;break g}b=cd(a);c=w[a+12|0]&-2|b^1;a=a+12|0}t[a|0]=c}function jK(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;d=gb+-64|0;gb=d;c=v[a>>2];g=v[c>>2];e=v[g+4>>2];v[d+40>>2]=v[g+20>>2];a=v[g+16>>2];v[d+32>>2]=v[g+12>>2];v[d+36>>2]=a;Jf(d+48|0,d+32|0,e);e=v[c+4>>2];i=v[e+4>>2];j=v[e+8>>2];a=v[d+60>>2];v[d+24>>2]=v[d+56>>2];v[d+28>>2]=a;a=v[d+52>>2];v[d+16>>2]=v[d+48>>2];v[d+20>>2]=a;v[d+8>>2]=v[e+8>>2];a=v[e+4>>2];v[d>>2]=v[e>>2];v[d+4>>2]=a;l=d+16|0;e=gb-32|0;gb=e;a=d;a:{if(i>>>0<=y[d+4>>2]){if(i>>>0<=y[l+4>>2]){if(j>>>0<=y[a+8>>2]){if(If(l)>>>0>=j>>>0){if(j){g=b+12|0;while(1){h=0;if(i){while(1){f=ee(A[Wg(a,h,k)>>3]*134217728);c=Mb(b,h);m=c;c=_m(f)+(v[c>>2]>>1)|0;n=c;c=zt(g)+c&-4096;v[m>>2]=n-c;A[e+24>>3]=+(c|0)*7.450580596923828e-9;c=e;v[c+16>>2]=0;v[c+20>>2]=-1074790400;v[c+8>>2]=0;v[c+12>>2]=1072693248;f=A[bh(c+24|0,c+16|0,c+8|0)>>3]*32768;A[c+24>>3]=f;f=ee(f);b:{if(D(f)<2147483648){c=~~f;break b}c=-2147483648}c=Uc(c);o=go(l,h,k),p=c,u[o>>1]=p;h=h+1|0;if((i|0)!=(h|0)){continue}break}}k=k+1|0;if((j|0)!=(k|0)){continue}break}}gb=e+32|0;break a}aa(2959,6176,80,5856);L()}aa(2989,6176,79,5856);L()}aa(4211,6176,78,5856);L()}aa(4246,6176,77,5856);L()}gb=d- -64|0}function cK(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;d=gb+-64|0;gb=d;c=v[a>>2];g=v[c>>2];e=v[g+4>>2];v[d+40>>2]=v[g+20>>2];a=v[g+16>>2];v[d+32>>2]=v[g+12>>2];v[d+36>>2]=a;Jf(d+48|0,d+32|0,e);e=v[c+4>>2];i=v[e+4>>2];j=v[e+8>>2];a=v[d+60>>2];v[d+24>>2]=v[d+56>>2];v[d+28>>2]=a;a=v[d+52>>2];v[d+16>>2]=v[d+48>>2];v[d+20>>2]=a;v[d+8>>2]=v[e+8>>2];a=v[e+4>>2];v[d>>2]=v[e>>2];v[d+4>>2]=a;l=d+16|0;e=gb-32|0;gb=e;a=d;a:{if(i>>>0<=y[d+4>>2]){if(i>>>0<=y[l+4>>2]){if(j>>>0<=y[a+8>>2]){if(If(l)>>>0>=j>>>0){if(j){g=b+12|0;while(1){h=0;if(i){while(1){f=ee(A[Wg(a,h,k)>>3]*134217728);c=Mb(b,h);m=c;c=_m(f)+(v[c>>2]>>1)|0;n=c;c=zt(g)+c&-4096;v[m>>2]=n-c;A[e+24>>3]=+(c|0)*7.450580596923828e-9;c=e;v[c+16>>2]=0;v[c+20>>2]=-1074790400;v[c+8>>2]=0;v[c+12>>2]=1072693248;f=A[bh(c+24|0,c+16|0,c+8|0)>>3]*32768;A[c+24>>3]=f;f=ee(f);b:{if(D(f)<2147483648){c=~~f;break b}c=-2147483648}c=Uc(c);o=fo(l,h,k),p=c,u[o>>1]=p;h=h+1|0;if((i|0)!=(h|0)){continue}break}}k=k+1|0;if((j|0)!=(k|0)){continue}break}}gb=e+32|0;break a}aa(2959,6176,80,5856);L()}aa(2989,6176,79,5856);L()}aa(4211,6176,78,5856);L()}aa(4246,6176,77,5856);L()}gb=d- -64|0}function Ru(a,b){var c=0,d=0,e=0,f=0;f=gb-48|0;gb=f;e=f+24|0;rT(e,a+8|0,a+10|0,a+12|0,a+16|0,a+14|0);rT(f,b+8|0,b+10|0,b+12|0,b+16|0,b+14|0);b=1;a=v[e>>2];d=Ib(w[a|0]|w[a+1|0]<<8);a=f;c=v[a>>2];a:{if(d>>>0<Ib(w[c|0]|w[c+1|0]<<8)>>>0){break a}b=0;c=v[a>>2];d=Ib(w[c|0]|w[c+1|0]<<8);c=v[e>>2];if(d>>>0<Ib(w[c|0]|w[c+1|0]<<8)>>>0){break a}b=1;c=v[e+4>>2];d=Ib(w[c|0]|w[c+1|0]<<8);c=v[a+4>>2];b:{if(d>>>0<Ib(w[c|0]|w[c+1|0]<<8)>>>0){break b}b=0;c=v[a+4>>2];d=Ib(w[c|0]|w[c+1|0]<<8);c=v[e+4>>2];if(d>>>0<Ib(w[c|0]|w[c+1|0]<<8)>>>0){break b}b=1;c=v[e+8>>2];d=Ib(w[c|0]|w[c+1|0]<<8);c=v[a+8>>2];c:{if(d>>>0<Ib(w[c|0]|w[c+1|0]<<8)>>>0){break c}b=0;c=v[a+8>>2];d=Ib(w[c|0]|w[c+1|0]<<8);c=v[e+8>>2];if(d>>>0<Ib(w[c|0]|w[c+1|0]<<8)>>>0){break c}b=1;c=v[e+12>>2];d=Ib(w[c|0]|w[c+1|0]<<8)<<16>>16;c=v[a+12>>2];d:{if((d|0)<Ib(w[c|0]|w[c+1|0]<<8)<<16>>16){break d}b=0;c=v[a+12>>2];d=Ib(w[c|0]|w[c+1|0]<<8)<<16>>16;c=v[e+12>>2];if((d|0)<Ib(w[c|0]|w[c+1|0]<<8)<<16>>16){break d}b=v[e+16>>2];c=Ib(w[b|0]|w[b+1|0]<<8);b=v[a+16>>2];b=c>>>0<Ib(w[b|0]|w[b+1|0]<<8)>>>0;if(!b){a=v[a+16>>2];Ib(w[a|0]|w[a+1|0]<<8);a=v[e+16>>2];Ib(w[a|0]|w[a+1|0]<<8)}}}}}gb=f+48|0;return b}function po(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;c=gb-80|0;gb=c;g=dd(a);e=b+24|0;a:{b:{if(Pi(v[e>>2]+484360|0)){if(Pi(v[e>>2]+484360|0)){b=0;while(1){f=v[e>>2];a=AL(wV(c+40|0,1),b&255,0,0);v[22656]=0;d=v[a+12>>2];v[c+8>>2]=v[a+8>>2];v[c+12>>2]=d;d=v[a+20>>2];v[c+16>>2]=v[a+16>>2];v[c+20>>2]=d;d=v[a+4>>2];v[c>>2]=v[a>>2];v[c+4>>2]=d;Y(2049,c- -64|0,f|0,0,c|0);a=v[22656];v[22656]=0;c:{d:{if((a|0)!=1){a=c- -64|0;i=c,j=Vb(a),v[i+32>>2]=j;i=c,j=Zb(a),v[i+24>>2]=j;if(Gb(c+32|0,c+24|0)){break d}break c}a=P()|0;O()|0;break b}while(1){e:{a=v[c+32>>2];h=A[a>>3];f=v[a+16>>2];d=x[a+24>>1];a=c+40|0;v[a+16>>2]=b;v[a+12>>2]=d;v[a+8>>2]=f;A[a>>3]=h;v[22656]=0;R(2050,g|0,a|0);a=v[22656];v[22656]=0;if((a|0)==1){break e}a=c+32|0;v[a>>2]=v[a>>2]+32;if(Gb(a,c+24|0)){continue}break c}break}a=P()|0;O()|0;en(c- -64|0);break b}en(c- -64|0);b=b+1|0;if(Pi(v[e>>2]+484360|0)>>>0>b>>>0){continue}break}}gb=c+80|0;return}b=ba(8)|0;v[22656]=0;c=Q(70,c+40|0,4354)|0;a=v[22656];v[22656]=0;if((a|0)!=1){rc(b,c);v[22656]=0;U(186,b|0,54952,1936);a=v[22656];v[22656]=0;if((a|0)!=1){break a}a=P()|0;O()|0;vb(c);break b}a=P()|0;O()|0;ca(b|0)}Yf(g);S(a|0)}L()}function QH(a,b){var c=0,d=0,e=0,f=0,g=0;a:{b:{c:{c=v[a+4>>2];d:{if(c>>>0<y[a+104>>2]){v[a+4>>2]=c+1;c=w[c|0];break d}c=md(a)}switch(c-43|0){case 0:case 2:break b;default:break c}}b=c-48|0;break a}f=(c|0)==45;g=!b;b=v[a+4>>2];e:{if(b>>>0<y[a+104>>2]){v[a+4>>2]=b+1;c=w[b|0];break e}c=md(a)}b=c-48|0;if(!(g|b>>>0<10|!v[a+104>>2])){v[a+4>>2]=v[a+4>>2]-1}}f:{if(b>>>0<10){while(1){d=(B(d,10)+c|0)-48|0;e=(d|0)<214748364;b=v[a+4>>2];g:{if(b>>>0<y[a+104>>2]){v[a+4>>2]=b+1;c=w[b|0];break g}c=md(a)}b=c-48|0;if(e&b>>>0<=9){continue}break}e=d;d=d>>31;h:{if(b>>>0>=10){break h}while(1){e=kqa(e,d,10,0);c=e+c|0;b=jb;b=c>>>0<e>>>0?b+1|0:b;e=c-48|0;d=b-(c>>>0<48)|0;b=v[a+4>>2];i:{if(b>>>0<y[a+104>>2]){v[a+4>>2]=b+1;c=w[b|0];break i}c=md(a)}b=c-48|0;if(b>>>0>9){break h}if(e>>>0<2061584302&(d|0)<=21474836|(d|0)<21474836){continue}break}}if(b>>>0<10){while(1){b=v[a+4>>2];j:{if(b>>>0<y[a+104>>2]){v[a+4>>2]=b+1;b=w[b|0];break j}b=md(a)}if(b-48>>>0<10){continue}break}}if(v[a+104>>2]){v[a+4>>2]=v[a+4>>2]-1}a=e;e=f?0-a|0:a;d=f?0-(((a|0)!=0)+d|0)|0:d;break f}d=-2147483648;if(!v[a+104>>2]){break f}v[a+4>>2]=v[a+4>>2]-1;jb=-2147483648;return 0}jb=d;return e}function Lga(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;if(y[a+4>>2]<y[wb(a)>>2]){h=gb-16|0;gb=h;c=h;v[c>>2]=a;d=v[a+4>>2];v[c+4>>2]=d;v[c+8>>2]=d+28;a=wb(a);d=v[c+4>>2];v[22656]=0;Au(a,d,b);a=v[22656];v[22656]=0;a:{if((a|0)!=1){v[c+4>>2]=v[c+4>>2]+28;$b(c);gb=h+16|0;break a}a=P()|0;O()|0;$b(c);S(a|0);L()}return}i=gb-32|0;gb=i;h=a;j=wb(a);e=i+8|0;c=_i(a)+1|0;f=gb-16|0;gb=f;v[f+12>>2]=c;d=c;c=gb-16|0;gb=c;g=a;wb(a);v[c+12>>2]=153391689;v[22656]=0;v[c+8>>2]=2147483647;k=Fb(c+12|0,c+8|0);l=v[22656];v[22656]=0;b:{if((l|0)!=1){gb=c+16|0;c=v[k>>2];break b}V(0)|0;O()|0;Bb();L()}c:{if(c>>>0>=d>>>0){d=$i(g);if(d>>>0<c>>>1>>>0){v[f+8>>2]=d<<1;c=v[Lc(f+8|0,f+12|0)>>2]}gb=f+16|0;break c}Sc();L()}g=_i(a);a=0;d=gb-16|0;gb=d;v[d+12>>2]=0;Bh(e+12|0,j);if(c){a=c;if(a>>>0>153391689){rd(8445);L()}a=Mc(B(a,28),4)}v[e>>2]=a;g=B(g,28)+a|0;v[e+8>>2]=g;v[e+4>>2]=g;m=dc(e),n=B(c,28)+a|0,v[m>>2]=n;gb=d+16|0;a=v[e+8>>2];v[22656]=0;Au(j,a,b);a=v[22656];v[22656]=0;d:{e:{if((a|0)==1){break e}v[e+8>>2]=v[e+8>>2]+28;v[22656]=0;RQ(h,e);a=v[22656];v[22656]=0;if((a|0)==1){break e}QQ(e);gb=i+32|0;break d}a=P()|0;O()|0;QQ(e);S(a|0);L()}}function Pma(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0;e=gb-16|0;gb=e;ud(b,0);f=w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24);a:{if(c&34){if(d){v[b+24>>2]=f;break a}g=b,h=Ah(Ek(+(f+1408|0)/1536)*8363),v[g+24>>2]=h;break a}t[b+37|0]=(c|0)==16?f:f^128;t[b+36|0]=w[a+4|0]}t[e+15|0]=w[a+5|0];t[e+14|0]=64;g=b,h=w[ac(e+15|0,e+14|0)|0]<<2,u[g+30>>1]=h;d=a+6|0;if((w[d|0]|w[d+1|0]<<8)>>>0<=256){u[b+28>>1]=w[d|0]|w[d+1|0]<<8;u[b+34>>1]=x[b+34>>1]|32}d=a+8|0;v[b>>2]=w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24);d=a+12|0;v[b+4>>2]=w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24);d=a+16|0;v[b+8>>2]=w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24);d=a+20|0;if(w[d|0]&16){u[b+34>>1]=x[b+34>>1]|2}if(w[d|0]&32){u[b+34>>1]=x[b+34>>1]|4}if(t[d+1|0]&1){u[b+34>>1]=x[b+34>>1]|8}if(w[d+1|0]&2){u[b+34>>1]=x[b+34>>1]|16}t[b+38|0]=w[(w[a+22|0]&7)+46144|0];t[b+39|0]=w[a+23|0];t[b+40|0]=w[a+24|0];t[b+41|0]=w[a+25|0];if((c|0)==32){t[e+13|0]=w[a+26|0];t[e+12|0]=64;g=b,h=w[ac(e+13|0,e+12|0)|0],u[g+32>>1]=h}c=a+27|0;v[b+12>>2]=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);a=a+31|0;v[b+16>>2]=w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24);gb=e+16|0}function Gpa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;f=gb-2608|0;gb=f;d=f;sD(d,a);v[d+1060>>2]=0;v[d+1064>>2]=0;e=d+2604|0;a=d+1068|0;while(1){t[a+4|0]=0;u[a>>1]=0;u[a+2>>1]=0;a=a+6|0;if((e|0)!=(a|0)){continue}break}v[22656]=0;_(490,d|0);a=v[22656];v[22656]=0;a:{b:{c:{d:{e:{f:{g:{if((a|0)!=1){if(!(u[d+1068>>1]<0|u[d+1070>>1]<0)){if(!c){break d}while(1){v[22656]=0;j=Q(200,d|0,1)|0;a=v[22656];v[22656]=0;if((a|0)==1){break f}a=0;while(1){v[22656]=0;k=Q(200,d|0,1)|0;e=v[22656];v[22656]=0;if((e|0)==1){break g}a=u[(B(a,6)+d|0)+(k?1070:1068)>>1];h:{if((a|0)>255){break h}e=B(a,6)+d|0;g=w[e+1072|0];if(u[e+1068>>1]<0){break h}if(u[e+1070>>1]>=0){continue}}break}g=(j?-1:0)^g;i=(i&255)+(g&255)|0;t[b+h|0]=i;h=h+1|0;if((h|0)!=(c|0)){continue}break}break d}v[22656]=0;a=nn(d);b=v[22656];v[22656]=0;if((b|0)!=1){break c}}a=V(27364)|0;break e}a=V(27364)|0;break e}a=V(27364)|0}if((O()|0)!=(ea(27364)|0)){break a}Z(a|0)|0;v[22656]=0;X(20);a=v[22656];v[22656]=0;if((a|0)==1){break b}}v[22656]=0;a=nn(d);b=v[22656];v[22656]=0;if((b|0)!=1){break c}a=P()|0;O()|0;break a}xb(d);gb=f+2608|0;return a|0}a=P()|0;O()|0}xb(d);S(a|0);L()}function jia(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;e=gb-48|0;gb=e;m=v[a+16>>2];f=Ud(e+16|0);v[f+8>>2]=a+112;v[f+16>>2]=v[a+128>>2];n=f,o=jg(b+327720|0,v[b+20>>2],(v[a+88>>2]&16384)>>>14|0),v[n+12>>2]=o;b=v[f+16>>2];if(b){n=f,o=lg(a+8|0,b),v[n>>2]=o;v[f+4>>2]=jb}j=v[a+40>>2];k=v[a+36>>2];g=v[a+4>>2];h=v[a>>2];v[e+8>>2]=h;v[e+12>>2]=g;i=v[a+12>>2];v[e>>2]=v[a+8>>2];v[e+4>>2]=i;a:{if(d){while(1){l=0;i=l;v[e+40>>2]=h;v[e+44>>2]=i;g=(g<<1)+m|0;b:{if((b|0)<=0){break b}while(1){Id(v[f+8>>2],u[(i<<1)+g>>1]/4<<16>>16);Hd(v[f+8>>2],4);Ub(e+40|0,f);if((b|0)<2){break b}b=b-1|0;i=v[e+44>>2];continue}}d=d-1|0;b=v[f+8>>2];Ub(b,b+8|0);b=v[f+8>>2];h=v[b+4>>2];if(h){Id(b,u[g+(v[e+44>>2]<<1)>>1]/4<<16>>16);Hd(v[f+8>>2],h);b=v[f+8>>2];h=v[b>>2];v[b>>2]=h;v[b+4>>2]=0}b=ig(b,v[f+12>>2]);g=v[a+32>>2];k=v[a+28>>2]+k|0;i=k>>12;v[c>>2]=v[c>>2]+B(b,i);j=g+j|0;l=j>>12;v[c+4>>2]=v[c+4>>2]+B(b,l);Ub(e+8|0,e);if(d){c=c+8|0;b=v[f+16>>2];h=v[e+8>>2];g=v[e+12>>2];continue}break}h=v[e+8>>2];g=v[e+12>>2];break a}l=j>>12;i=k>>12}v[a+40>>2]=j;v[a+20>>2]=i;v[a+36>>2]=k;v[a+24>>2]=l;v[a>>2]=h;v[a+4>>2]=g;gb=e+48|0}function lka(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;k=gb-48|0;gb=k;if(Te(b)>>>0>c>>>0){while(1){f=l&65535;if(hi(bf(b,f))){n=k+24|0;r=n;e=Vb(bf(b,f));f=Zb(bf(b,f));o=kT(k,d);p=o;h=gb-16|0;gb=h;v[h>>2]=f;v[h+8>>2]=e;if(Gb(h+8|0,h)){while(1){f=p;j=gb-16|0;gb=j;m=h+8|0;e=v[m>>2];if(!(w[e+3|0]!=4|w[e+5|0])){g=j+8|0;Ce(g,f,x[f+14>>1]);Uf(g,0);t[e+3|0]=0}g=w[e+2|0];if(!(w[e+4|0]|(g|0)!=11)){i=j+8|0;Ce(i,f,x[f+14>>1]);Uf(i,0);t[e+2|0]=0;g=0}a:{b:{c:{if(!w[e|0]){g=j+8|0;Ce(g,f,x[f+14>>1]);if(Cb(g)){break c}g=w[e+2|0]}i=w[e+3|0];q=j+8|0;Ce(q,f,x[f+14>>1]);Uf(q,(i|0)==4|(g|0)==11);g=w[e+3|0];break b}g=w[e+3|0];i=w[e+2|0];if(!(g|(i|0)==11)){t[e+5|0]=0;t[e+3|0]=4;break a}if(i|(g|0)==4){break b}t[e+4|0]=0;t[e+2|0]=11}d:{if(!(!w[f+16|0]|g)){t[e+5|0]=125;t[e+3|0]=17;break d}e:{switch(g-16|0){case 1:break d;case 0:break e;default:break a}}if(w[e+5|0]){break a}t[e+5|0]=6;t[f+16|0]=1;break a}t[f+16|0]=0}u[f+14>>1]=(x[f+14>>1]+1>>>0)%x[f+12>>1];gb=j+16|0;bk(m);if(Gb(m,h)){continue}break}}iT(r,p);gb=h+16|0;Ye(n);Ye(o)}l=l+1|0;if((l&65535)>>>0<=c>>>0){continue}break}}iT(a,d);gb=k+48|0}function XN(a){var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0;a:{if((w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24))!=-1641380927){break a}d=a+16|0;b=d;if((w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24))>>>0<36){break a}e=a+24|0;b=e;if((w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24))>>>0<36){break a}f=a+32|0;b=f;if((w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24))>>>0<36){break a}c=a+12|0;b=c;if(!(w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24))){break a}b=c;if((w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24))>>>0>858993459){break a}b=a+20|0;if(!(w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24))|(w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24))>>>0>536870911){break a}a=a+28|0;g=w[a+1|0]<<8;h=w[a+2|0]<<16|w[a+3|0]<<24;if(!(w[a|0]|g|h)|(h|(g|w[a|0]))>>>0>1073741823|B(w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24),-5)-1>>>0<(w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24))>>>0){break a}if((w[e|0]|w[e+1|0]<<8|(w[e+2|0]<<16|w[e+3|0]<<24))>>>0>((w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24))<<3^-1)>>>0){break a}i=(w[f|0]|w[f+1|0]<<8|(w[f+2|0]<<16|w[f+3|0]<<24))>>>0<=((w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24))<<2^-1)>>>0}return i}function wda(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;h=gb-16|0;gb=h;if(!w[a+4242|0]){gz(a);a:{if(!w[a+4240|0]){break a}e=OO(v[a+16>>2]);if(e==A[a+4288>>3]){break a}A[a+4288>>3]=e;Qt(a)}f=a+4256|0;b:{if(w[a+4244|0]){g=f;if(A[f>>3]>1){v[g>>2]=0;v[g+4>>2]=1072693248}break b}i=(v[a+4232>>2]&-2)!=4;e=A[f>>3];c:{if(D(e)<2147483648){g=~~e;break c}g=-2147483648}if(!(i|(g|0)<=0)){ez(a);e=A[a+4256>>3]}A[f>>3]=e-+(g|0)}e=0;d:{e:{switch(v[a+4232>>2]){case 0:e=ri(A[f>>3]*6.283185307179586);break d;case 1:e=D(A[f>>3]+-.5)*-4+1;break d;case 2:e=A[f>>3];e=e+e+-1;break d;case 3:e=A[f>>3]<.5?-1:1;break d;case 4:e=A[a+4272>>3];break d;case 5:break e;default:break d}}e=A[a+4256>>3];e=e*(e*e)*(e*(e*6+-15)+10);e=A[a+4280>>3]*e+A[a+4272>>3]*(1-e)}A[h+8>>3]=(w[a+4241|0]?-e:e)*+z[a+4220>>2]+ +z[a+4224>>2];WP(h+8|0,1);f=pk(a);f:{if(!f){break f}g=v[a+4236>>2];if(w[a+4243|0]){k=f,l=g>>>8&15|176|(g&127)<<8|gn(A[h+8>>3]*127)<<16,j=v[v[f>>2]+68>>2],kb[j](k|0,l|0)|0;break f}kb[v[v[f>>2]+44>>2]](f,g,C(A[h+8>>3]))}A[a+4256>>3]=A[a+4256>>3]+A[a+4264>>3]*+(d>>>0)}g=a;a=a+44|0;Ei(g,b,c,Nd(a,0),Nd(a,1),d);gb=h+16|0}function fha(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;k=gb-16|0;gb=k;o=k,p=Zb(a),v[o>>2]=p;d=v[Fd(k+8|0,k)>>2];h=gb-32|0;gb=h;v[h+24>>2]=d;d=v[a>>2];o=h,p=Vb(a),v[o>>2]=p;d=d+(sp(h+24|0,h)<<1)|0;a:{b:{f=$q(b,c);c:{if((f|0)<=0){break c}i=v[wb(a)>>2];e=v[a+4>>2];if((f|0)<=i-e>>1){j=e-d|0;i=j>>1;d:{if((i|0)>=(f|0)){g=c;break d}v[h>>2]=b;jS(h,i);g=v[h>>2];cS(a,g,c,f-i|0);if((j|0)<=0){break c}}m=gb-16|0;gb=m;i=e;j=d;l=a;n=v[a+4>>2];a=(n-((f<<1)+d|0)|0)+d|0;f=li(m,l,e-a>>1);if(a>>>0<e>>>0){e=v[f+4>>2];c=a;while(1){wb(l);To(e,c);e=e+2|0;v[f+4>>2]=e;c=c+2|0;if(i>>>0>c>>>0){continue}break}}$b(f);zr(j,a,n);gb=m+16|0;Mn(b,g,d);break c}g=wb(a);e=Gn(h,Vk(a,tc(a)+f|0),d-v[a>>2]>>1,g);v[22656]=0;YQ(e,b,c);b=v[22656];v[22656]=0;if((b|0)==1){break b}b=a;Fp(a);c=e;i=v[c+4>>2];g=d;l=c+4|0;Dk(wb(a),v[a>>2],d,l);wb(a);f=c+8|0;j=f;d=v[a+4>>2];if((g|0)!=(d|0)){a=v[j>>2];while(1){To(a,g);a=v[j>>2]+2|0;v[j>>2]=a;g=g+2|0;if((d|0)!=(g|0)){continue}break}}xc(b,l);xc(b+4|0,f);xc(wb(b),dc(c));v[c>>2]=v[c+4>>2];$r(b,tc(b));d=i;Hh(e)}Hg(d);gb=h+32|0;break a}a=P()|0;O()|0;Hh(e);S(a|0);L()}gb=k+16|0}function lv(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;e=gb-32|0;gb=e;t[e+16|0]=44;v[e+8>>2]=-1;v[e+12>>2]=0;v[e>>2]=1058;v[e+4>>2]=2;i=a;c=gb+-64|0;gb=c;j=c;a=e;h=v[a>>2]&2?16:10;f=gb-32|0;gb=f;d=He(f+16|0,1,0);a:{b:{c:{while(1){eO(f+8|0,Jb(d),Jb(d)+Ab(d)|0,w[b|0],h);if(!v[f+12>>2]){break c}g=Ab(d);v[22656]=0;v[f+4>>2]=g;g=xf(f+4|0);k=v[22656];v[22656]=0;if((k|0)!=1){v[22656]=0;U(75,d|0,g|0,0);g=v[22656];v[22656]=0;if((g|0)!=1){continue}}break}break b}b=v[f+8>>2];h=Jb(d);v[22656]=0;R(76,d|0,b-h|0);b=v[22656];v[22656]=0;d:{if((b|0)!=1){v[22656]=0;R(77,j|0,d|0);b=v[22656];v[22656]=0;if((b|0)!=1){break d}break b}break b}vb(d);gb=f+32|0;break a}a=P()|0;O()|0;vb(d);S(a|0);L()}b=c+16|0;Ml(b,c,a);v[22656]=0;U(89,c+32|0,b|0,a|0);b=v[22656];v[22656]=0;e:{f:{g:{h:{i:{if((b|0)!=1){v[22656]=0;U(90,c+48|0,c+32|0,a|0);a=v[22656];v[22656]=0;if((a|0)==1){break i}v[22656]=0;R(72,i|0,c+48|0);a=v[22656];v[22656]=0;if((a|0)==1){break h}vb(c+48|0);vb(c+32|0);vb(c+16|0);vb(c);gb=c- -64|0;break e}a=P()|0;O()|0;break f}a=P()|0;O()|0;break g}a=P()|0;O()|0;vb(c+48|0)}vb(c+32|0)}vb(c+16|0);vb(c);S(a|0);L()}gb=e+32|0}function mia(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;e=gb-48|0;gb=e;k=v[a+16>>2];f=Ud(e+16|0);v[f+8>>2]=a+112;v[f+16>>2]=v[a+128>>2];o=f,p=jg(b+327720|0,v[b+20>>2],(v[a+88>>2]&16384)>>>14|0),v[o+12>>2]=p;b=v[f+16>>2];if(b){o=f,p=lg(a+8|0,b),v[o>>2]=p;v[f+4>>2]=jb}l=v[a+24>>2];m=v[a+20>>2];h=v[a+4>>2];g=v[a>>2];v[e+8>>2]=g;v[e+12>>2]=h;i=v[a+12>>2];v[e>>2]=v[a+8>>2];v[e+4>>2]=i;if(d){while(1){i=0;j=g;v[e+40>>2]=g;v[e+44>>2]=n;h=(((h&2147483647)<<1|g>>>31)&-2)+k|0;a:{if((b|0)<=0){break a}while(1){g=(i&2147483647)<<1|j>>>31;Id(v[f+8>>2],t[(g|1)+h|0]+t[h+(g&-2)|0]<<5);Hd(v[f+8>>2],4);Ub(e+40|0,f);if((b|0)<2){break a}b=b-1|0;j=v[e+40>>2];i=v[e+44>>2];continue}}d=d-1|0;b=v[f+8>>2];Ub(b,b+8|0);b=v[f+8>>2];g=v[b+4>>2];if(g){j=b;b=(v[e+44>>2]&2147483647)<<1|v[e+40>>2]>>>31;Id(j,t[(b|1)+h|0]+t[h+(b&-2)|0]<<5);Hd(v[f+8>>2],g);b=v[f+8>>2];g=v[b>>2];v[b>>2]=g;v[b+4>>2]=0}b=ig(b,v[f+12>>2]);v[c>>2]=v[c>>2]+B(b,m);v[c+4>>2]=v[c+4>>2]+B(b,l);Ub(e+8|0,e);if(d){c=c+8|0;b=v[f+16>>2];g=v[e+8>>2];h=v[e+12>>2];continue}break}g=v[e+8>>2];h=v[e+12>>2]}v[a>>2]=g;v[a+4>>2]=h;gb=e+48|0}function ada(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0;c=gb+-64|0;gb=c;g=dd(a);v[22656]=0;_(1647,g|0);b=v[22656];v[22656]=0;a:{if((b|0)!=1){b=50416;b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{while(1){d=wg(44);if(d){h=v[b>>2];f=v[b+4>>2];v[22656]=0;f=Q(70,c+32|0,f|0)|0;e=v[22656];v[22656]=0;if((e|0)==1){break k}v[22656]=0;R(1648,c+48|0,f|0);e=v[22656];v[22656]=0;if((e|0)==1){break j}e=v[b+8>>2];v[22656]=0;e=Q(70,c|0,e|0)|0;i=v[22656];v[22656]=0;if((i|0)==1){break i}v[22656]=0;R(1648,c+16|0,e|0);i=v[22656];v[22656]=0;if((i|0)==1){break h}v[22656]=0;da(1649,d|0,h|0,c+48|0,c+16|0)|0;h=v[22656];v[22656]=0;if((h|0)==1){break g}Hb(c+16|0);vb(e);Hb(c+48|0);vb(f);v[c+60>>2]=d;v[22656]=0;R(1650,g|0,c+60|0);d=v[22656];v[22656]=0;if((d|0)==1){break b}d=v[c+60>>2];v[d+32>>2]=v[b+12>>2];v[d+36>>2]=v[b+16>>2];t[d+40|0]=w[b+20|0];t[d+41|0]=w[d+41|0]&253|w[b+21|0]<<1}b=b+24|0;if((b|0)!=50728){continue}break}gb=c- -64|0;return a|0}b=P()|0;O()|0;break c}b=P()|0;O()|0;break d}b=P()|0;O()|0;break e}b=P()|0;O()|0;break f}b=P()|0;O()|0;Hb(c+16|0)}vb(e)}Hb(c+48|0)}vb(f)}Yb(d);break a}b=P()|0;O()|0;break a}b=P()|0;O()|0}Hl(g);S(b|0);L()}function Pda(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;c=Vf(a);if(c>>>0<b>>>0){f=gb-32|0;gb=f;a:{b:{e=b-c|0;c:{if(e>>>0<=v[wb(a)>>2]-v[a+4>>2]>>11>>>0){c=gb-16|0;gb=c;g=a;b=c;v[b>>2]=a;a=v[a+4>>2];v[b+4>>2]=a;v[b+8>>2]=a+(e<<11);d:{a=v[b+4>>2];d=v[b+8>>2];if((a|0)!=(d|0)){while(1){wb(g);v[22656]=0;fz(a);e=v[22656];v[22656]=0;if((e|0)==1){break d}a=a+2048|0;v[b+4>>2]=a;if((a|0)!=(d|0)){continue}break}}$b(b);gb=c+16|0;break c}a=P()|0;O()|0;$b(b);S(a|0);L()}h=wb(a);i=f+8|0;b=Vf(a)+e|0;d=gb-16|0;gb=d;v[d+12>>2]=b;c=b;b=gb-16|0;gb=b;g=a;wb(a);v[b+12>>2]=2097151;v[22656]=0;v[b+8>>2]=2147483647;j=Fb(b+12|0,b+8|0);k=v[22656];v[22656]=0;e:{if((k|0)!=1){gb=b+16|0;b=v[j>>2];break e}V(0)|0;O()|0;Bb();L()}f:{if(b>>>0>=c>>>0){c=Dl(g);if(c>>>0<b>>>1>>>0){v[d+8>>2]=c<<1;b=v[Lc(d+8|0,d+12|0)>>2]}gb=d+16|0;break f}Sc();L()}b=RM(i,b,Vf(a),h);v[22656]=0;R(1541,b|0,e|0);c=v[22656];v[22656]=0;if((c|0)==1){break b}v[22656]=0;R(1537,a|0,b|0);a=v[22656];v[22656]=0;if((a|0)==1){break b}St(b)}gb=f+32|0;break a}a=P()|0;O()|0;St(b);S(a|0);L()}return}if(b>>>0<c>>>0){b=v[a>>2]+(b<<11)|0;Vf(a);QM(a,b);SM(a)}}function Hka(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,z=0;i=gb-16|0;gb=i;ud(d,32);g=i+8|0;KT(g,a+20|0,b);p=g;g=fc(g);KT(i,a+36|0,c);q=i;a=0;g=v[g>>2];if(g-1>>>0<=838859){a=v[fc(i)>>2];v[d>>2]=B(g,320);u[d+34>>1]=1;l=Ql(d);if(l){k=g<<2;e=+(k>>>0);r=+(a>>>0)/e;s=+(g>>>0)/e;z=1/+y[d>>2];g=0;while(1){m=+(g>>>0);a=v[p>>2];n=0;o=0;if(Jd(b)){e=s*m+ +(a>>>0);a:{if(e<4294967296&e>=0){a=~~e>>>0;break a}a=0}f=fd(b);h=B(a,f);e=e-+(a>>>0);b:{if(t[b+34|0]&1){j=v[b+20>>2];a=x[j+(h<<1)>>1];f=u[j+(f+h<<1)>>1];break b}a=v[b+20>>2];f=w[a+(f+h|0)|0]<<8;a=w[a+h|0]<<8}o=(1-e)*+(a<<16>>16)+e*+(f<<16>>16)}a=v[q>>2];if(Jd(c)){e=r*m+ +(a>>>0);c:{if(e<4294967296&e>=0){a=~~e>>>0;break c}a=0}f=fd(c);h=B(a,f);e=e-+(a>>>0);d:{if(t[c+34|0]&1){j=v[c+20>>2];a=x[j+(h<<1)>>1];f=u[j+(f+h<<1)>>1];break d}a=v[c+20>>2];f=w[a+(f+h|0)|0]<<8;a=w[a+h|0]<<8}n=(1-e)*+(a<<16>>16)+e*+(f<<16>>16)}f=0;a=g;while(1){e=z*+(a>>>0);h=JT(n*e+o*(1-e));u[v[d+20>>2]+(a<<1)>>1]=h;a=a+k|0;f=f+1|0;if((f|0)!=80){continue}break}g=g+1|0;if((k|0)!=(g|0)){continue}break}}a=(l|0)!=0}gb=i+16|0;return a|0}function Aca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=C(0),g=C(0),h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=C(0),q=0,r=0,s=0,t=C(0);a:{if(!v[a+4272>>2]){break a}i=a+44|0;if(!mi(i)){break a}k=Nd(i,0);l=Nd(i,1);m=od(i,0);n=od(i,1);if(d){j=a+4256|0;e=v[a+4268>>2];o=d;while(1){f=z[l>>2];g=z[k>>2];s=Mb(j,e<<1),t=g,z[s>>2]=t;s=Mb(j,v[a+4268>>2]<<1|1),t=f,z[s>>2]=t;f=C(C(D(nM(C(C(C(D(g))+C(D(f)))*C(536870912)),31,5)))*C(4.656612873077393e-10));g=z[a+4276>>2];f=C(f+C(C(g-f)*z[(f>=g?4236:4240)+a>>2]));z[a+4276>>2]=f;p=z[a+4232>>2];g=z[a+4244>>2];f=C(C(C(z[a+4248>>2]*C(g-(f<g?g:f)))+C(.9999998807907104))*C(2147483648));b:{if(f<C(4294967296)&f>=C(0)){e=~~f>>>0;break b}e=0}h=e<<5;q=h;r=h|-2147483648;h=e>>>0<67108864;f=C(p*C(C((h?q:r)>>>(h?31:32-(e>>>26|0)|0)>>>0)*C(4.656612873077393e-10)));e=v[a+4272>>2];e=(((e+(v[a+4252>>2]+(v[a+4268>>2]<<12)|0)|0)-1|0)/4096|0)%(e|0)<<1;s=m,t=C(z[Mb(j,e)>>2]*f),z[s>>2]=t;s=n,t=C(z[Mb(j,e|1)>>2]*f),z[s>>2]=t;h=v[a+4268>>2];e=h-1|0;v[a+4268>>2]=e;if(!h){e=v[a+4272>>2]+e|0;v[a+4268>>2]=e}n=n+4|0;m=m+4|0;l=l+4|0;k=k+4|0;o=o-1|0;if(o){continue}break}}Ei(a,b,c,od(i,0),od(i,1),d)}}function hc(a,b,c){var d=0,e=0,f=0;if(c>>>0>=512){$a(a|0,b|0,c|0)|0;return a}e=a+c|0;a:{if(!((a^b)&3)){b:{if(!(a&3)){c=a;break b}if(!c){c=a;break b}c=a;while(1){t[c|0]=w[b|0];b=b+1|0;c=c+1|0;if(!(c&3)){break b}if(c>>>0<e>>>0){continue}break}}d=e&-4;c:{if(d>>>0<64){break c}f=d+-64|0;if(f>>>0<c>>>0){break c}while(1){v[c>>2]=v[b>>2];v[c+4>>2]=v[b+4>>2];v[c+8>>2]=v[b+8>>2];v[c+12>>2]=v[b+12>>2];v[c+16>>2]=v[b+16>>2];v[c+20>>2]=v[b+20>>2];v[c+24>>2]=v[b+24>>2];v[c+28>>2]=v[b+28>>2];v[c+32>>2]=v[b+32>>2];v[c+36>>2]=v[b+36>>2];v[c+40>>2]=v[b+40>>2];v[c+44>>2]=v[b+44>>2];v[c+48>>2]=v[b+48>>2];v[c+52>>2]=v[b+52>>2];v[c+56>>2]=v[b+56>>2];v[c+60>>2]=v[b+60>>2];b=b- -64|0;c=c- -64|0;if(f>>>0>=c>>>0){continue}break}}if(c>>>0>=d>>>0){break a}while(1){v[c>>2]=v[b>>2];b=b+4|0;c=c+4|0;if(d>>>0>c>>>0){continue}break}break a}if(e>>>0<4){c=a;break a}d=e-4|0;if(d>>>0<a>>>0){c=a;break a}c=a;while(1){t[c|0]=w[b|0];t[c+1|0]=w[b+1|0];t[c+2|0]=w[b+2|0];t[c+3|0]=w[b+3|0];b=b+4|0;c=c+4|0;if(d>>>0>=c>>>0){continue}break}}if(c>>>0<e>>>0){while(1){t[c|0]=w[b|0];b=b+1|0;c=c+1|0;if((e|0)!=(c|0)){continue}break}}return a}function kia(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;e=gb-48|0;gb=e;m=v[a+16>>2];f=Ud(e+16|0);v[f+8>>2]=a+112;v[f+16>>2]=v[a+128>>2];n=f,o=jg(b+327720|0,v[b+20>>2],(v[a+88>>2]&16384)>>>14|0),v[n+12>>2]=o;b=v[f+16>>2];if(b){n=f,o=lg(a+8|0,b),v[n>>2]=o;v[f+4>>2]=jb}j=v[a+40>>2];k=v[a+36>>2];g=v[a+4>>2];h=v[a>>2];v[e+8>>2]=h;v[e+12>>2]=g;i=v[a+12>>2];v[e>>2]=v[a+8>>2];v[e+4>>2]=i;a:{if(d){while(1){l=0;i=l;v[e+40>>2]=h;v[e+44>>2]=i;g=g+m|0;b:{if((b|0)<=0){break b}while(1){Id(v[f+8>>2],t[g+i|0]<<6);Hd(v[f+8>>2],4);Ub(e+40|0,f);if((b|0)<2){break b}b=b-1|0;i=v[e+44>>2];continue}}d=d-1|0;b=v[f+8>>2];Ub(b,b+8|0);b=v[f+8>>2];h=v[b+4>>2];if(h){Id(b,t[g+v[e+44>>2]|0]<<6);Hd(v[f+8>>2],h);b=v[f+8>>2];h=v[b>>2];v[b>>2]=h;v[b+4>>2]=0}b=ig(b,v[f+12>>2]);g=v[a+32>>2];k=v[a+28>>2]+k|0;i=k>>12;v[c>>2]=v[c>>2]+B(b,i);j=g+j|0;l=j>>12;v[c+4>>2]=v[c+4>>2]+B(b,l);Ub(e+8|0,e);if(d){c=c+8|0;b=v[f+16>>2];h=v[e+8>>2];g=v[e+12>>2];continue}break}h=v[e+8>>2];g=v[e+12>>2];break a}l=j>>12;i=k>>12}v[a+40>>2]=j;v[a+20>>2]=i;v[a+36>>2]=k;v[a+24>>2]=l;v[a>>2]=h;v[a+4>>2]=g;gb=e+48|0}function ST(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;c=dh(a);if(c>>>0<b>>>0){j=gb-32|0;gb=j;a:{b:{i=b-c|0;c:{if(i>>>0<=v[wb(a)>>2]-v[a+4>>2]>>8>>>0){b=gb-16|0;gb=b;c=b;v[b>>2]=a;a=v[a+4>>2];v[b+4>>2]=a;v[b+8>>2]=a+(i<<8);a=v[b+4>>2];d=v[b+8>>2];if((a|0)!=(d|0)){while(1){GB(a);a=a+256|0;v[c+4>>2]=a;if((a|0)!=(d|0)){continue}break}}$b(c);gb=b+16|0;break c}k=wb(a);e=j+8|0;d=a;b=dh(a)+i|0;f=gb-16|0;gb=f;v[f+12>>2]=b;g=gb-16|0;gb=g;v[g+12>>2]=16777215;v[22656]=0;v[g+8>>2]=2147483647;h=Fb(g+12|0,g+8|0);c=v[22656];v[22656]=0;d:{if((c|0)!=1){gb=g+16|0;c=v[h>>2];break d}V(0)|0;O()|0;Bb();L()}e:{if(b>>>0<=c>>>0){b=KB(d);if(b>>>0<c>>>1>>>0){v[f+8>>2]=b<<1;c=v[Lc(f+8|0,f+12|0)>>2]}gb=f+16|0;break e}Sc();L()}d=dh(a);b=0;h=gb-16|0;gb=h;v[h+12>>2]=0;kf(e+12|0,k);if(c){b=c;if(b>>>0>=16777216){rd(8445);L()}b=Mc(b<<8,1)}v[e>>2]=b;d=(d<<8)+b|0;v[e+8>>2]=d;v[e+4>>2]=d;l=dc(e),m=(c<<8)+b|0,v[l>>2]=m;gb=h+16|0;v[22656]=0;vT(e,i);b=v[22656];v[22656]=0;if((b|0)==1){break b}Zk(a,e);uT(e)}gb=j+32|0;break a}a=P()|0;O()|0;uT(e);S(a|0);L()}return}if(b>>>0<c>>>0){_k(a,v[a>>2]+(b<<8)|0)}}function z7(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;c=gb+-64|0;gb=c;d=v[a>>2];a=v[d>>2];g=v[a+4>>2];v[c+40>>2]=v[a+20>>2];e=v[a+16>>2];v[c+32>>2]=v[a+12>>2];v[c+36>>2]=e;Jf(c+48|0,c+32|0,g);a=v[d+4>>2];e=v[a+4>>2];h=v[a+8>>2];d=v[c+60>>2];v[c+24>>2]=v[c+56>>2];v[c+28>>2]=d;d=v[c+52>>2];v[c+16>>2]=v[c+48>>2];v[c+20>>2]=d;v[c+8>>2]=v[a+8>>2];d=v[a+4>>2];v[c>>2]=v[a>>2];v[c+4>>2]=d;j=c+16|0;d=gb-32|0;gb=d;g=c;a:{if(y[c+4>>2]>=e>>>0){if(y[j+4>>2]>=e>>>0){if(y[g+8>>2]>=h>>>0){if(If(j)>>>0>=h>>>0){if(h){k=b+12|0;while(1){b=0;if(e){while(1){l=d,m=+(_m(ee(A[Wg(g,b,i)>>3]*134217728))+id(yt(k),21)|0)*7.450580596923828e-9,A[l+24>>3]=m;a=d;v[a+16>>2]=0;v[a+20>>2]=-1074790400;v[a+8>>2]=0;v[a+12>>2]=1072693248;f=A[bh(a+24|0,a+16|0,a+8|0)>>3]*32768;A[a+24>>3]=f;f=ee(f);b:{if(D(f)<2147483648){a=~~f;break b}a=-2147483648}a=Uc(a);l=go(j,b,i),n=a,u[l>>1]=n;b=b+1|0;if((b|0)!=(e|0)){continue}break}}i=i+1|0;if((i|0)!=(h|0)){continue}break}}gb=d+32|0;break a}aa(2959,6176,80,5856);L()}aa(2989,6176,79,5856);L()}aa(4211,6176,78,5856);L()}aa(4246,6176,77,5856);L()}gb=c- -64|0}function q7(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;c=gb+-64|0;gb=c;d=v[a>>2];a=v[d>>2];g=v[a+4>>2];v[c+40>>2]=v[a+20>>2];e=v[a+16>>2];v[c+32>>2]=v[a+12>>2];v[c+36>>2]=e;Jf(c+48|0,c+32|0,g);a=v[d+4>>2];e=v[a+4>>2];h=v[a+8>>2];d=v[c+60>>2];v[c+24>>2]=v[c+56>>2];v[c+28>>2]=d;d=v[c+52>>2];v[c+16>>2]=v[c+48>>2];v[c+20>>2]=d;v[c+8>>2]=v[a+8>>2];d=v[a+4>>2];v[c>>2]=v[a>>2];v[c+4>>2]=d;j=c+16|0;d=gb-32|0;gb=d;g=c;a:{if(y[c+4>>2]>=e>>>0){if(y[j+4>>2]>=e>>>0){if(y[g+8>>2]>=h>>>0){if(If(j)>>>0>=h>>>0){if(h){k=b+12|0;while(1){b=0;if(e){while(1){l=d,m=+(_m(ee(A[Wg(g,b,i)>>3]*134217728))+id(yt(k),21)|0)*7.450580596923828e-9,A[l+24>>3]=m;a=d;v[a+16>>2]=0;v[a+20>>2]=-1074790400;v[a+8>>2]=0;v[a+12>>2]=1072693248;f=A[bh(a+24|0,a+16|0,a+8|0)>>3]*32768;A[a+24>>3]=f;f=ee(f);b:{if(D(f)<2147483648){a=~~f;break b}a=-2147483648}a=Uc(a);l=fo(j,b,i),n=a,u[l>>1]=n;b=b+1|0;if((b|0)!=(e|0)){continue}break}}i=i+1|0;if((i|0)!=(h|0)){continue}break}}gb=d+32|0;break a}aa(2959,6176,80,5856);L()}aa(2989,6176,79,5856);L()}aa(4211,6176,78,5856);L()}aa(4246,6176,77,5856);L()}gb=c- -64|0}function OZ(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;h=gb-32|0;gb=h;d=b;e=tc(d);f=c;a:{if(e>>>0<f>>>0){l=gb-32|0;gb=l;b:{c:{i=f-e|0;d:{if(i>>>0<=v[wb(d)>>2]-v[d+4>>2]>>1>>>0){e=gb-16|0;gb=e;e:{f=li(e,d,i);g=v[f+4>>2];i=v[f+8>>2];if((g|0)!=(i|0)){while(1){wb(d);v[22656]=0;Pk(g);j=v[22656];v[22656]=0;if((j|0)==1){break e}g=g+2|0;v[f+4>>2]=g;if((g|0)!=(i|0)){continue}break}}$b(f);gb=e+16|0;break d}a=P()|0;O()|0;$b(f);S(a|0);L()}k=wb(d);f=Vk(d,tc(d)+i|0);m=tc(d);j=gb-16|0;gb=j;v[j+12>>2]=0;e=l+8|0;Bh(e+12|0,k);if(f){g=f;if(f>>>0>2147483647){rd(8445);L()}g=Mc(g<<1,1)}v[e>>2]=g;k=(m<<1)+g|0;v[e+8>>2]=k;v[e+4>>2]=k;n=dc(e),o=(f<<1)+g|0,v[n>>2]=o;gb=j+16|0;v[22656]=0;R(345,e|0,i|0);f=v[22656];v[22656]=0;if((f|0)==1){break c}v[22656]=0;R(346,d|0,e|0);d=v[22656];v[22656]=0;if((d|0)==1){break c}mE(e)}gb=l+32|0;break b}a=P()|0;O()|0;mE(e);S(a|0);L()}break a}if(f>>>0<e>>>0){yn(d,v[d>>2]+(f<<1)|0)}}c=Pb(a,c<<1);if(c){d=gb-16|0;gb=d;bc(h+24|0,v[b>>2],tc(b)<<1);gb=d+16|0;b=v[h+28>>2];v[h+8>>2]=v[h+24>>2];v[h+12>>2]=b;kd(h+16|0,a,h+8|0)}gb=h+32|0;return c|0}function $m(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0;f=gb-16|0;gb=f;if(b&2){t[a+841|0]=0;v[a+708>>2]=0;v[a+656>>2]=0;v[a+104>>2]=0;t[a+797|0]=0;v[a+764>>2]=0;u[a+802>>1]=0;u[a+804>>1]=0;v[a+696>>2]=0;v[a+668>>2]=0;v[a+88>>2]=v[a+88>>2]|6144;g=f+8|0;Db(g,c+1074312|0,23);if(Cb(g)){t[a+807|0]=1;t[a+808|0]=0}t[a+846|0]=0;t[a+839|0]=0;u[a+774>>1]=0;t[a+850|0]=255;v[a+660>>2]=0;t[a+851|0]=w[a+851|0]&240;ap(a+788|0)}if(b&4){v[a+84>>2]=0;v[a+76>>2]=0;v[a+80>>2]=0;v[a+700>>2]=0;v[a+656>>2]=0;v[a+104>>2]=0;v[a+92>>2]=0;v[a+96>>2]=0;v[a>>2]=0;v[a+4>>2]=0;t[a+845|0]=0;t[a+838|0]=0;v[a+688>>2]=0;v[a+672>>2]=0;v[a+676>>2]=0;u[a+820>>1]=0;t[a+819|0]=0;u[a+836>>1]=32512;u[a+842>>1]=0;v[a+20>>2]=0;v[a+24>>2]=0;v[a+8>>2]=0;v[a+12>>2]=0;v[a+28>>2]=0;v[a+32>>2]=0;v[a+852>>2]=0;v[a+856>>2]=0;t[a+851|0]=w[a+851|0]&207}if(b&1){a:{if(d>>>0<=126){b=(d<<5)+c|0;c=v[b+480280>>2];v[a+88>>2]=c;v[a+692>>2]=x[b+480284>>1];v[a+748>>2]=x[b+480286>>1];if(!(c&1024)){break a}v[a+88>>2]=c&-1025|e;break a}v[a+748>>2]=64;v[a+692>>2]=128;v[a+88>>2]=0}u[a+784>>1]=0;t[a+795|0]=0;t[a+796|0]=0}gb=f+16|0}function xia(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;f=gb-32|0;gb=f;k=v[a+40>>2];l=v[a+36>>2];m=v[a+16>>2];e=v[a+4>>2];g=e;h=v[a>>2];v[f+24>>2]=h;v[f+28>>2]=e;e=v[a+12>>2];v[f+16>>2]=v[a+8>>2];v[f+20>>2]=e;a:{if(d){while(1){i=((((g&2147483647)<<1|h>>>31)&2147483646)<<1)+m|0;e=(((h>>>16|0)+4&131064)<<1)+b|0;h=u[e+38>>1];n=u[e+36>>1];o=u[e+34>>1];p=u[e+32>>1];q=u[e+30>>1];r=u[e+28>>1];s=u[e+26>>1];t=u[e+24>>1];j=0;e=1;while(1){g=j<<1;v[(f+8|0)+(j<<2)>>2]=(((((B(u[(g|8)+i>>1],o)+B(u[(g|4)+i>>1],p)|0)+B(u[(g|12)+i>>1],n)|0)+B(u[(g|16)+i>>1],h)|0)/2|0)+((((B(u[(g|-8)+i>>1],s)+B(u[(g|-12)+i>>1],t)|0)+B(u[(g|-4)+i>>1],r)|0)+B(u[g+i>>1],q)|0)/2|0)|0)/16384;g=e;e=0;j=1;if(g){continue}break}e=v[a+32>>2];l=v[a+28>>2]+l|0;j=l>>12;v[c>>2]=v[c>>2]+B(j,v[f+8>>2]);k=e+k|0;e=k>>12;v[c+4>>2]=v[c+4>>2]+B(e,v[f+12>>2]);Ub(f+24|0,f+16|0);d=d-1|0;if(d){c=c+8|0;h=v[f+24>>2];g=v[f+28>>2];continue}break}h=v[f+24>>2];g=v[f+28>>2];break a}e=k>>12;j=l>>12}v[a+40>>2]=k;v[a+20>>2]=j;v[a+36>>2]=l;v[a+24>>2]=e;v[a>>2]=h;v[a+4>>2]=g;gb=f+32|0}function nja(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;h=gb-16|0;gb=h;f=v[a+48>>2];k=v[a+40>>2];l=v[a+36>>2];b=v[a+44>>2];q=v[a+16>>2];e=v[a+4>>2];g=e;i=v[a>>2];v[h+8>>2]=i;v[h+12>>2]=e;e=v[a+12>>2];v[h>>2]=v[a+8>>2];v[h+4>>2]=e;a:{if(d){while(1){e=g+q|0;m=t[e+1|0];e=t[e|0];g=v[a+60>>2];n=g;o=g>>31;g=Lb(b,-16777216,16776704);j=v[a+64>>2];f=Lb(f,-16777216,16776704);g=kqa(j,j>>31,g,g>>31);j=jb;r=g;g=v[a+68>>2];p=kqa(g,g>>31,f,f>>31);g=r+p|0;f=jb+j|0;f=g>>>0<p>>>0?f+1|0:f;j=g;g=((B(m-e|0,i>>>10&4194048)|0)/16384|0)+(e<<8)<<8;e=g;i=kqa(n,o,e,e>>31);e=j+i|0;f=jb+f|0;f=e>>>0<i>>>0?f+1|0:f;e=e+8388608|0;f=e>>>0<8388608?f+1|0:f;f=Jc(e,f,24);e=v[a+72>>2];i=v[a+32>>2];l=v[a+28>>2]+l|0;m=l>>12;o=(f|0)/256|0;v[c>>2]=v[c>>2]+B(m,o);k=i+k|0;n=k>>12;v[c+4>>2]=v[c+4>>2]+B(o,n);e=f-(e&g)|0;Ub(h+8|0,h);d=d-1|0;if(d){c=c+8|0;i=v[h+8>>2];g=v[h+12>>2];f=b;b=e;continue}break}i=v[h+8>>2];g=v[h+12>>2];f=b;break a}n=k>>12;m=l>>12;e=b}v[a+40>>2]=k;v[a+20>>2]=m;v[a+36>>2]=l;v[a+48>>2]=f;v[a+44>>2]=e;v[a+24>>2]=n;v[a>>2]=i;v[a+4>>2]=g;gb=h+16|0}function Pia(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;g=gb-16|0;gb=g;a:{b:{c:{e=v[a+12>>2];h=v[a+8>>2];d:{if((e|0)<=1&h>>>0<=805306368|(e|0)<=0){if((e|0)>=-2&h>>>0>=3489660928|(e|0)>-2){break c}if((e|0)==-2&h>>>0>2147483647|e>>>0>4294967294){break d}break b}if((e|0)==1&h>>>0>2147483648|e>>>0>1){break b}}l=b+196648|0;break a}l=b+131112|0;break a}l=b+262184|0}m=v[a+16>>2];i=v[a+40>>2];j=v[a+36>>2];f=v[a+4>>2];k=v[a>>2];v[g+8>>2]=k;v[g+12>>2]=f;v[g>>2]=h;v[g+4>>2]=e;e:{if(d){while(1){h=v[a+32>>2];j=v[a+28>>2]+j|0;b=j>>12;e=(f<<1)+m|0;f=(k>>>16&65520)+l|0;f=(((((((B(u[e-4>>1],u[f+2>>1])+B(u[e-6>>1],u[f>>1])|0)+B(u[e-2>>1],u[f+4>>1])|0)+B(u[e>>1],u[f+6>>1])|0)+B(u[e+2>>1],u[f+8>>1])|0)+B(u[e+4>>1],u[f+10>>1])|0)+B(u[e+6>>1],u[f+12>>1])|0)+B(u[e+8>>1],u[f+14>>1])|0)/32768|0;v[c>>2]=v[c>>2]+B(b,f);i=h+i|0;h=i>>12;v[c+4>>2]=v[c+4>>2]+B(f,h);Ub(g+8|0,g);d=d-1|0;if(d){c=c+8|0;k=v[g+8>>2];f=v[g+12>>2];continue}break}k=v[g+8>>2];f=v[g+12>>2];break e}h=i>>12;b=j>>12}v[a+40>>2]=i;v[a+20>>2]=b;v[a+36>>2]=j;v[a+24>>2]=h;v[a>>2]=k;v[a+4>>2]=f;gb=g+16|0}function gJ(a,b,c,d,e,f,g,h){var i=0,j=0,k=0,l=0,m=0,n=C(0),o=0,p=0;a:{if(w[b+21|0]){l=v[f>>2];j=v[e>>2];o=1;b:{if((h|0)>0){p=B(d,g);m=v[b>>2];while(1){if(v[a+1396>>2]<=9){sl(a)}k=v[a+1392>>2];g=u[(((k&1023)<<1)+b|0)+36>>1];c:{if((g|0)>=0){i=k;k=w[g+v[b+8>>2]|0];v[a+1392>>2]=i>>>k;i=v[a+1396>>2]-k|0;k=(i|0)<0;v[a+1396>>2]=k?0:i;g=k?-1:g;break c}g=Cm(a,b)}if((g|0)>=v[b+2092>>2]?w[b+23|0]:0){break a}if((g|0)<0){if(!w[a+1376|0]){o=0;if(v[a+1384>>2]){break b}}ec(a,21);return 0}k=B(d,l);m=(k+(j+m|0)|0)>(p|0)?(j+p|0)-k|0:m;k=B(g,v[b>>2]);d:{if(w[b+22|0]){g=0;n=C(0);if((m|0)<=0){break d}while(1){n=C(n+z[v[b+28>>2]+(g+k<<2)>>2]);i=v[(j<<2)+c>>2];if(i){i=i+(l<<2)|0;z[i>>2]=n+z[i>>2]}j=j+1|0;i=(j|0)==(d|0);j=i?0:j;l=i+l|0;g=g+1|0;if((m|0)!=(g|0)){continue}break}break d}g=0;if((m|0)<=0){break d}while(1){i=v[(j<<2)+c>>2];if(i){i=i+(l<<2)|0;z[i>>2]=z[i>>2]+C(z[v[b+28>>2]+(g+k<<2)>>2]+C(0))}j=j+1|0;i=(j|0)==(d|0);j=i?0:j;l=i+l|0;g=g+1|0;if((m|0)!=(g|0)){continue}break}}h=h-m|0;if((h|0)>0){continue}break}}v[e>>2]=j;v[f>>2]=l}return o}ec(a,21);return 0}aa(4596,10534,1887,3608);L()}function Vt(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;i=a;a=gb+-64|0;gb=a;j=a;g=v[c>>2]&2?16:10;f=gb-32|0;gb=f;d=He(f+16|0,1,0);a:{b:{c:{while(1){e=Jb(d);h=Jb(d);k=Ab(d);l=v[b>>2];v[22656]=0;ha(91,f+8|0,e|0,h+k|0,l|0,g|0);e=v[22656];v[22656]=0;if((e|0)==1){break b}if(!v[f+12>>2]){break c}e=Ab(d);v[22656]=0;v[f+4>>2]=e;e=xf(f+4|0);h=v[22656];v[22656]=0;if((h|0)!=1){v[22656]=0;U(75,d|0,e|0,0);e=v[22656];v[22656]=0;if((e|0)!=1){continue}}break}break b}b=v[f+8>>2];g=Jb(d);v[22656]=0;R(76,d|0,b-g|0);b=v[22656];v[22656]=0;if((b|0)!=1){v[22656]=0;R(86,j|0,d|0);b=v[22656];v[22656]=0;if((b|0)==1){break b}vb(d);gb=f+32|0;break a}}a=P()|0;O()|0;vb(d);S(a|0);L()}b=a+16|0;Ml(b,a,c);v[22656]=0;U(93,a+32|0,b|0,c|0);b=v[22656];v[22656]=0;d:{e:{f:{g:{h:{if((b|0)!=1){v[22656]=0;U(94,a+48|0,a+32|0,c|0);b=v[22656];v[22656]=0;if((b|0)==1){break h}v[22656]=0;R(85,i|0,a+48|0);b=v[22656];v[22656]=0;if((b|0)==1){break g}vb(a+48|0);vb(a+32|0);vb(a+16|0);vb(a);gb=a- -64|0;break d}b=P()|0;O()|0;break e}b=P()|0;O()|0;break f}b=P()|0;O()|0;vb(a+48|0)}vb(a+32|0)}vb(a+16|0);vb(a);S(b|0);L()}}function Qw(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;a:{i=a;a=gb+-64|0;gb=a;j=a;g=v[c>>2]&2?16:10;f=gb-32|0;gb=f;d=He(f+16|0,1,0);b:{c:{d:{while(1){e=Jb(d);h=Jb(d);k=Ab(d);l=v[b>>2];v[22656]=0;ha(92,f+8|0,e|0,h+k|0,l|0,g|0);e=v[22656];v[22656]=0;if((e|0)==1){break c}if(!v[f+12>>2]){break d}e=Ab(d);v[22656]=0;v[f+4>>2]=e;e=xf(f+4|0);h=v[22656];v[22656]=0;if((h|0)!=1){v[22656]=0;U(75,d|0,e|0,0);e=v[22656];v[22656]=0;if((e|0)!=1){continue}}break}break c}b=v[f+8>>2];g=Jb(d);v[22656]=0;R(76,d|0,b-g|0);b=v[22656];v[22656]=0;if((b|0)!=1){v[22656]=0;R(86,j|0,d|0);b=v[22656];v[22656]=0;if((b|0)==1){break c}vb(d);gb=f+32|0;break b}}a=P()|0;O()|0;vb(d);S(a|0);L()}b=a+16|0;Ml(b,a,c);v[22656]=0;U(93,a+32|0,b|0,c|0);b=v[22656];v[22656]=0;e:{f:{g:{h:{if((b|0)!=1){v[22656]=0;U(94,a+48|0,a+32|0,c|0);b=v[22656];v[22656]=0;if((b|0)==1){break h}v[22656]=0;R(85,i|0,a+48|0);b=v[22656];v[22656]=0;if((b|0)==1){break g}vb(a+48|0);vb(a+32|0);vb(a+16|0);vb(a);gb=a- -64|0;break a}b=P()|0;O()|0;break e}b=P()|0;O()|0;break f}b=P()|0;O()|0;vb(a+48|0)}vb(a+32|0)}vb(a+16|0);vb(a);S(b|0);L()}}function KV(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;i=a;a=gb+-64|0;gb=a;j=a;g=v[c>>2]&2?16:10;f=gb-32|0;gb=f;d=He(f+16|0,1,0);a:{b:{c:{while(1){e=Jb(d);h=Jb(d);k=Ab(d);l=v[b>>2];v[22656]=0;ha(91,f+8|0,e|0,h+k|0,l|0,g|0);e=v[22656];v[22656]=0;if((e|0)==1){break b}if(!v[f+12>>2]){break c}e=Ab(d);v[22656]=0;v[f+4>>2]=e;e=xf(f+4|0);h=v[22656];v[22656]=0;if((h|0)!=1){v[22656]=0;U(75,d|0,e|0,0);e=v[22656];v[22656]=0;if((e|0)!=1){continue}}break}break b}b=v[f+8>>2];g=Jb(d);v[22656]=0;R(76,d|0,b-g|0);b=v[22656];v[22656]=0;if((b|0)!=1){v[22656]=0;R(77,j|0,d|0);b=v[22656];v[22656]=0;if((b|0)==1){break b}vb(d);gb=f+32|0;break a}}a=P()|0;O()|0;vb(d);S(a|0);L()}b=a+16|0;Ml(b,a,c);v[22656]=0;U(89,a+32|0,b|0,c|0);b=v[22656];v[22656]=0;d:{e:{f:{g:{h:{if((b|0)!=1){v[22656]=0;U(90,a+48|0,a+32|0,c|0);b=v[22656];v[22656]=0;if((b|0)==1){break h}v[22656]=0;R(72,i|0,a+48|0);b=v[22656];v[22656]=0;if((b|0)==1){break g}vb(a+48|0);vb(a+32|0);vb(a+16|0);vb(a);gb=a- -64|0;break d}b=P()|0;O()|0;break e}b=P()|0;O()|0;break f}b=P()|0;O()|0;vb(a+48|0)}vb(a+32|0)}vb(a+16|0);vb(a);S(b|0);L()}}function mja(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;h=gb-16|0;gb=h;f=v[a+48>>2];k=v[a+40>>2];l=v[a+36>>2];b=v[a+44>>2];q=v[a+16>>2];e=v[a+4>>2];g=e;i=v[a>>2];v[h+8>>2]=i;v[h+12>>2]=e;e=v[a+12>>2];v[h>>2]=v[a+8>>2];v[h+4>>2]=e;a:{if(d){while(1){e=(g<<1)+q|0;m=u[e+2>>1];e=u[e>>1];g=v[a+60>>2];n=g;o=g>>31;g=Lb(b,-16777216,16776704);j=v[a+64>>2];f=Lb(f,-16777216,16776704);g=kqa(j,j>>31,g,g>>31);j=jb;r=g;g=v[a+68>>2];p=kqa(g,g>>31,f,f>>31);g=r+p|0;f=jb+j|0;f=g>>>0<p>>>0?f+1|0:f;j=g;g=e+((B(m-e|0,i>>>18|0)|0)/16384|0)<<8;e=g;i=kqa(n,o,e,e>>31);e=j+i|0;f=jb+f|0;f=e>>>0<i>>>0?f+1|0:f;e=e+8388608|0;f=e>>>0<8388608?f+1|0:f;f=Jc(e,f,24);e=v[a+72>>2];i=v[a+32>>2];l=v[a+28>>2]+l|0;m=l>>12;o=(f|0)/256|0;v[c>>2]=v[c>>2]+B(m,o);k=i+k|0;n=k>>12;v[c+4>>2]=v[c+4>>2]+B(o,n);e=f-(e&g)|0;Ub(h+8|0,h);d=d-1|0;if(d){c=c+8|0;i=v[h+8>>2];g=v[h+12>>2];f=b;b=e;continue}break}i=v[h+8>>2];g=v[h+12>>2];f=b;break a}n=k>>12;m=l>>12;e=b}v[a+40>>2]=k;v[a+20>>2]=m;v[a+36>>2]=l;v[a+48>>2]=f;v[a+44>>2]=e;v[a+24>>2]=n;v[a>>2]=i;v[a+4>>2]=g;gb=h+16|0}function Mc(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;if(fF(b)){j=b>>>0>4?b:4;b=a?a:1;a:{b:{while(1){h=gb-16|0;gb=h;v[h+12>>2]=0;e=b;c:{d:{a=j;if((a|0)!=8){if(a&3|a>>>0<4){break c}c=a>>>2|0;if(c-1&c|e>>>0>-64-a>>>0){break c}c=16;d=a>>>0>16?a:16;e:{if(!(d-1&d)){a=d;break e}while(1){a=c;c=a<<1;if(a>>>0<d>>>0){continue}break}}if(e>>>0>=-64-a>>>0){v[115137]=48;break c}i=e>>>0<11?16:e+11&-8;f=Cd((i+a|0)+12|0);if(!f){break c}c=f-8|0;f:{if(!(f&a-1)){a=c;break f}e=f-4|0;d=v[e>>2];g=a;a=((a+f|0)-1&0-a)-8|0;a=(a-c>>>0>15?0:g)+a|0;g=a-c|0;f=(d&-8)-g|0;if(!(d&3)){c=v[c>>2];v[a+4>>2]=f;v[a>>2]=c+g;break f}v[a+4>>2]=f|v[a+4>>2]&1|2;d=a+f|0;v[d+4>>2]=v[d+4>>2]|1;v[e>>2]=g|v[e>>2]&1|2;d=c+g|0;v[d+4>>2]=v[d+4>>2]|1;Bs(c,g)}d=v[a+4>>2];g:{if(!(d&3)){break g}c=d&-8;if(c>>>0<=i+16>>>0){break g}v[a+4>>2]=i|d&1|2;e=a+i|0;d=c-i|0;v[e+4>>2]=d|3;c=a+c|0;v[c+4>>2]=v[c+4>>2]|1;Bs(e,d)}a=a+8|0;break d}a=Cd(e);if(a){break d}break c}v[h+12>>2]=a}gb=h+16|0;a=v[h+12>>2];if(!a){a=v[116505];if(!a){break b}kb[a|0]();continue}break}break a}a=ba(4)|0;nm(a);ia(a|0,89116,1928);L()}return a}return sf(a)}function hqa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;f=gb-32|0;gb=f;v[f+24>>2]=b;b=v[a>>2];m=f,n=Vb(a),v[m>>2]=n;b=b+(sp(f+24|0,f)<<1)|0;d=v[a+4>>2];a:{b:{if(d>>>0<y[wb(a)>>2]){if((b|0)!=(d|0)){break b}d=gb-16|0;gb=d;a=li(d,a,1);Fr(v[a+4>>2],c);v[a+4>>2]=v[a+4>>2]+2;$b(a);gb=d+16|0;break a}d=wb(a);e=FD(f,MY(a,tc(a)+1|0),b-v[a>>2]>>1,d);v[22656]=0;R(447,e|0,c|0);c=v[22656];v[22656]=0;if((c|0)!=1){c=v[e+4>>2];j=e+4|0;ml(v[a>>2],b,j);h=e+8|0;i=h;g=v[a+4>>2];if((g|0)!=(b|0)){d=v[i>>2];while(1){Fr(d,b);d=v[i>>2]+2|0;v[i>>2]=d;b=b+2|0;if((g|0)!=(b|0)){continue}break}}wc(a,j);wc(a+4|0,h);wc(wb(a),dc(e));v[e>>2]=v[e+4>>2];b=c;rp(e);break a}a=P()|0;O()|0;rp(e);S(a|0);L()}l=gb-16|0;gb=l;j=d;k=v[a+4>>2];i=b;e=b+(k-(b+2|0)|0)|0;h=li(l,a,d-e>>1);if(d>>>0>e>>>0){g=v[h+4>>2];d=e;while(1){Fr(g,d);g=g+2|0;v[h+4>>2]=g;d=d+2|0;if(j>>>0>d>>>0){continue}break}}$b(h);if((e|0)!=(i|0)){while(1){k=k-2|0;e=e-2|0;CY(k,e);if((e|0)!=(i|0)){continue}break}}gb=l+16|0;a=((b>>>0<=c>>>0&y[a+4>>2]>c>>>0)<<1)+c|0;t[b|0]=w[a|0];t[b+1|0]=w[a+1|0]}Hg(b);gb=f+32|0}function Qia(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;f=gb-16|0;gb=f;a:{b:{c:{e=v[a+12>>2];g=v[a+8>>2];d:{if((e|0)<=1&g>>>0<=805306368|(e|0)<=0){if((e|0)>=-2&g>>>0>=3489660928|(e|0)>-2){break c}if((e|0)==-2&g>>>0>2147483647|e>>>0>4294967294){break d}break b}if((e|0)==1&g>>>0>2147483648|e>>>0>1){break b}}l=b+196648|0;break a}l=b+131112|0;break a}l=b+262184|0}m=v[a+16>>2];i=v[a+40>>2];j=v[a+36>>2];b=v[a+4>>2];k=v[a>>2];v[f+8>>2]=k;v[f+12>>2]=b;v[f>>2]=g;v[f+4>>2]=e;e:{if(d){while(1){g=v[a+32>>2];j=v[a+28>>2]+j|0;e=j>>12;h=b+m|0;b=(k>>>16&65520)+l|0;b=(((((((B(t[h-2|0],u[b+2>>1])+B(t[h-3|0],u[b>>1])|0)+B(t[h-1|0],u[b+4>>1])|0)+B(t[h|0],u[b+6>>1])|0)+B(t[h+1|0],u[b+8>>1])|0)+B(t[h+2|0],u[b+10>>1])|0)+B(t[h+3|0],u[b+12>>1])|0)+B(t[h+4|0],u[b+14>>1])<<8)/32768|0;v[c>>2]=v[c>>2]+B(e,b);i=g+i|0;g=i>>12;v[c+4>>2]=v[c+4>>2]+B(b,g);Ub(f+8|0,f);d=d-1|0;if(d){c=c+8|0;k=v[f+8>>2];b=v[f+12>>2];continue}break}k=v[f+8>>2];b=v[f+12>>2];break e}g=i>>12;e=j>>12}v[a+40>>2]=i;v[a+20>>2]=e;v[a+36>>2]=j;v[a+24>>2]=g;v[a>>2]=k;v[a+4>>2]=b;gb=f+16|0}function IV(a,b,c,d,e){var f=0,g=0;f=gb-16|0;gb=f;g=x[c>>1];a:{if(w[d|0]<=4){while(1){d=g<<1;u[c>>1]=d;t[b|0]=(d&65534)>>>0>255;d=w[c|0];u[c>>1]=d;if(!d){if(!lf(a,f+15|0)){break a}d=w[f+15|0];u[c>>1]=d<<1|1;t[b|0]=d>>>7;u[c>>1]=w[c|0]}u[e>>1]=t[b|0]+(x[e>>1]<<1);d=x[c>>1]<<1;u[c>>1]=d;t[b|0]=(d&65534)>>>0>255;d=w[c|0];u[c>>1]=d;if(!d){if(!lf(a,f+14|0)){break a}d=w[f+14|0];u[c>>1]=d<<1|1;t[b|0]=d>>>7;u[c>>1]=w[c|0]}u[e>>1]=t[b|0]+(x[e>>1]<<1);d=x[c>>1]<<1;u[c>>1]=d;t[b|0]=(d&65534)>>>0>255;g=w[c|0];u[c>>1]=g;if(!g){if(!lf(a,f+13|0)){break a}d=w[f+13|0];u[c>>1]=d<<1|1;t[b|0]=d>>>7;g=w[c|0];u[c>>1]=g;if(w[b|0]){continue}break a}if(w[b|0]){continue}break a}}while(1){d=g<<1;u[c>>1]=d;t[b|0]=(d&65534)>>>0>255;d=w[c|0];u[c>>1]=d;if(!d){if(!lf(a,f+12|0)){break a}d=w[f+12|0];u[c>>1]=d<<1|1;t[b|0]=d>>>7;u[c>>1]=w[c|0]}u[e>>1]=t[b|0]+(x[e>>1]<<1);d=x[c>>1]<<1;u[c>>1]=d;t[b|0]=(d&65534)>>>0>255;g=w[c|0];u[c>>1]=g;if(!g){if(!lf(a,f+11|0)){break a}d=w[f+11|0];u[c>>1]=d<<1|1;t[b|0]=d>>>7;g=w[c|0];u[c>>1]=g;if(w[b|0]){continue}break a}if(w[b|0]){continue}break}}gb=f+16|0}function AK(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;v[a+4>>2]=c;v[a>>2]=b;b=(c>>>0)/48|0;g=((B(b,48)|0)!=(c|0))+b|0;v[a+12>>2]=g;b=(c>>>0)/(g>>>0)|0;v[a+8>>2]=b;i=b>>>0<64;d=b;e=d&31;if((d&63)>>>0>=32){d=-1<<e}else{d=(1<<e)-1&-1>>>32-e|-1<<e}e=0;v[a+24>>2]=e;f=i?d&65536:0;v[a+28>>2]=f;d=e;i=0-d|0;e=nqa(d,f,g,0);a:{b:{f=65536-(f+((d|0)!=0)|0)|0;d=jb;if((f|0)==(d|0)&e>>>0<i>>>0|d>>>0<f>>>0){g=g+1|0;v[a+12>>2]=g;b=(c>>>0)/(g>>>0)|0;v[a+8>>2]=b;if(b>>>0>63){break b}d=b;e=d&31;if((d&63)>>>0>=32){d=-1<<e}else{d=(1<<e)-1&-1>>>32-e|-1<<e}v[a+24>>2]=0;v[a+28>>2]=d&65536}v[a+16>>2]=g-((c>>>0)%(g>>>0)|0);if(b>>>0>62){break a}h=1;c=b+1|0;d=c&31;if((c&63)>>>0>=32){d=-1<<d}else{d=(1<<d)-1&-1>>>32-d|-1<<d}j=d&65536;break a}v[a+24>>2]=0;v[a+28>>2]=0;v[a+16>>2]=(B(b,g)-c|0)+g}v[a+32>>2]=k;v[a+36>>2]=j;d=63-b|0;f=d&31;c=a;g=a;if((d&63)>>>0>=32){d=0;f=-1>>>f|0}else{e=-1>>>f|0;d=e;f=d|(1<<f)-1<<32-f}v[g+48>>2]=h?f:-1;v[c+52>>2]=h?d:-1;h=b;b=64-b|0;d=b&31;e=a;if((b&63)>>>0>=32){b=0;d=-1>>>d|0}else{f=-1>>>d|0;b=f;d=b|(1<<d)-1<<32-d}v[e+40>>2]=h?d:0;v[c+44>>2]=h?b:0;return a}function pna(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;e=gb-432|0;gb=e;vc(b);CC(b,e+376|0,e+296|0,e+8|0);d=e;f=e+408|0;if(Xb(w[f|0]|w[f+1|0]<<8|(w[f+2|0]<<16|w[f+3|0]<<24))){f=w[e+427|0]+1|0}else{f=1}n=d,o=Xi(f),t[n+4|0]=o;h=w[ac(29024,e+4|0)|0];t[e+7|0]=h;u[e+4>>1]=4;a:{b:{if(!h){break b}f=e+392|0;k=e+291|0;while(1){d=e+8|0;d=Ib(w[d|0]|w[d+1|0]<<8);c:{d:{if(w[k|0]>63){break d}d=d<<16>>16;if((d|0)<0){break d}if(d){l=d&65535;g=0;while(1){d=f;e:{if(!Wc(b,Xb(w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24))+(g<<2)|0)){break e}if(!Wc(b,Kr(b))){break e}d=e;f:{if(!c){j=Ae(b);break f}j=Mr(b)}u[d+2>>1]=j;n=e,o=x[Le(e+4|0,e+2|0)>>1],u[n+4>>1]=o}g=g+1|0;if((l|0)!=(g|0)){continue}break}}d=e+296|0;if(Xb(w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24))>>>0>m>>>0){d=e+296|0;if(Wc(b,Xb(w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24)))){break c}}t[e+7|0]=i+1;break b}Xr(a);break a}d=e+296|0;m=Xb(w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24));CC(b,e+376|0,d,e+8|0);i=i+1|0;if((i&255)>>>0<h>>>0){continue}break}}AC(a,e+4|0,e+7|0)}gb=e+432|0}function ND(a){var b=0,c=0,d=0,e=0,f=0,g=0,h=0;a:{if((w[a|0]-1&255)>>>0>14){break a}b=a+1954|0;d=a+1698|0;while(1){if(t[d|0]<-1){break a}d=d+1|0;if((b|0)!=(d|0)){continue}break}d=0;while(1){b:{h=0;f=B(d,13)+a|0;if(w[f+14|0]){break b}e=(d<<4)+a|0;b=e+418|0;if(w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24)){break b}c=e+422|0;if(w[f+942|0]|(w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24))>>>0>1048575){break b}b=B(d,11)+a|0;f=b+1346|0;if(w[f|0]>15|w[b+1351|0]>3|w[b+1356|0]>3){break b}c:{if(!(w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24))){break c}b=e+430|0;if((w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24))>>>0>1048574){break c}if((w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24))>>>0>(w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24))>>>0){break b}e=e+426|0;if((w[e|0]|w[e+1|0]<<8|(w[e+2|0]<<16|w[e+3|0]<<24))>>>0>(w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24))>>>0){break b}}h=1;b=1;d:{if(g){break d}e:{if(w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24)){break e}if(sd(f,28493,11)){break e}b=0;break d}b=1}g=b;d=d+1|0;if((d|0)!=32){continue}}break}g=g&h}return g}function Vca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=C(0),g=0,h=0,i=0,j=0,k=0,l=C(0),m=0,n=0,o=0,p=0,q=C(0),r=C(0),s=C(0),t=C(0),u=C(0),x=0,y=0,A=C(0);h=a+44|0;g=Nd(h,0);k=Nd(h,1);m=od(h,0);n=od(h,1);p=B(w[a+4233|0],v[v[a+16>>2]+1074404>>2]);e=p<<1;i=a+4208|0;if(Nb(i)>>>0<e>>>0){El(i,e)}j=CM(a);a:{if(j){if(!d){break a}e=v[a+4220>>2];x=j-1|0;j=0;while(1){if(e>>>0>=p>>>0){v[a+4220>>2]=0;e=0}s=z[k>>2];t=z[g>>2];o=e;e=e-p|0;e=((e|0)<0?o:e)<<1;u=z[Mb(i,e)>>2];f=z[Mb(i,e|1)>>2];q=C(t+u);z[m>>2]=q;r=C(s+f);z[n>>2]=r;f=C(0);l=C(0);b:{c:{switch(x|0){case 0:f=z[a+4224>>2];l=C(r*f);f=C(q*f);break b;case 1:case 2:f=z[a+4224>>2];l=C(q*f);f=C(r*f);break b;case 3:break c;default:break b}}f=C(C(u+C(C(t+s)*C(.5)))*z[a+4224>>2]);l=f}n=n+4|0;m=m+4|0;k=k+4|0;g=g+4|0;y=Mb(i,v[a+4220>>2]<<1),A=C(D(f))<C(1.0000000195414814e-24)?C(0):f,z[y>>2]=A;y=Mb(i,v[a+4220>>2]<<1|1),A=C(D(l))<C(1.0000000195414814e-24)?C(0):l,z[y>>2]=A;e=v[a+4220>>2]+1|0;v[a+4220>>2]=e;j=j+1|0;if((j|0)!=(d|0)){continue}break}break a}o=g;g=d<<2;BM(o,o+g|0,m);BM(k,g+k|0,n)}Ei(a,b,c,od(h,0),od(h,1),d)}function epa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0;f=gb-16|0;gb=f;ud(b,32);e=a+4|0;h=b,i=Xb(w[e|0]|w[e+1|0]<<8|(w[e+2|0]<<16|w[e+3|0]<<24)),v[h>>2]=i;e=a+10|0;e=Xb(w[e|0]|w[e+1|0]<<8|(w[e+2|0]<<16|w[e+3|0]<<24));v[b+4>>2]=e;g=e;e=a+14|0;h=b,i=g+Xb(w[e|0]|w[e+1|0]<<8|(w[e+2|0]<<16|w[e+3|0]<<24))|0,v[h+8>>2]=i;e=b;if(c?d:1){c=a+46|0;c=Xb(w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24))}v[e+24>>2]=c;c=w[a+8|0]<<28>>24;a:{if((d|0)!=841887798){break a}d=a+42|0;if(!Ib(w[d|0]|w[d+1|0]<<8)){break a}if((Ib(w[d|0]|w[d+1|0]<<8)|0)==48){break a}c=(c-(Ib(w[d|0]|w[d+1|0]<<8)<<7)|0)+6144|0}Qo(b,+(c|0)*.0006510416666666666);t[f+15|0]=w[a+9|0];t[f+14|0]=64;h=b,i=w[ac(f+15|0,f+14|0)|0]<<2,u[h+30>>1]=i;if(t[a+40|0]&1){u[b+34>>1]=x[b+34>>1]|64;v[b>>2]=v[b>>2]>>>1;v[b+4>>2]=v[b+4>>2]>>>1;v[b+8>>2]=v[b+8>>2]>>>1}b:{if(w[a+41|0]<=8){a=v[b+4>>2];c=v[b+8>>2];break b}u[b+34>>1]=x[b+34>>1]|1;v[b>>2]=v[b>>2]>>>1;a=v[b+4>>2]>>>1|0;v[b+4>>2]=a;c=v[b+8>>2]>>>1|0;v[b+8>>2]=c}c:{if(a+1>>>0<c>>>0){u[b+34>>1]=x[b+34>>1]|2;break c}v[b+4>>2]=0;v[b+8>>2]=0}gb=f+16|0}function Aea(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;e=Sf(a);if(e>>>0<b>>>0){j=gb-32|0;gb=j;a:{b:{d=b-e|0;c:{if(d>>>0<=(v[wb(a)>>2]-v[a+4>>2]|0)/52>>>0){oz(a,d,c);break c}f=wb(a);g=yN(a,Sf(a)+d|0);i=Sf(a);e=0;h=gb-16|0;gb=h;v[h+12>>2]=0;b=j+8|0;kf(b+12|0,f);if(g){e=uN(g)}v[b>>2]=e;f=B(i,52)+e|0;v[b+8>>2]=f;v[b+4>>2]=f;l=dc(b),m=B(g,52)+e|0,v[l>>2]=m;gb=h+16|0;v[22656]=0;U(1492,b|0,d|0,c|0);c=v[22656];v[22656]=0;if((c|0)==1){break b}c=a;DO(a);wb(a);e=b;f=b+4|0;g=f;h=v[a>>2];a=v[a+4>>2];if((h|0)!=(a|0)){d=v[g>>2];while(1){d=d-52|0;a=a-52|0;i=sN(d,wb(a));v[d>>2]=v[a>>2];v[d+4>>2]=v[a+4>>2];k=v[wb(a)>>2];l=wb(i),m=k,v[l>>2]=m;l=wb(a),m=0,v[l>>2]=m;v[a>>2]=0;v[a+4>>2]=0;v[d+20>>2]=v[a+20>>2];i=v[a+16>>2];v[d+12>>2]=v[a+12>>2];v[d+16>>2]=i;$u(d+24|0,a+24|0);Dc(d+36|0,a+36|0);v[d+48>>2]=v[a+48>>2];d=v[g>>2]-52|0;v[g>>2]=d;if((a|0)!=(h|0)){continue}break}}wc(c,f);wc(c+4|0,e+8|0);wc(wb(c),dc(e));v[e>>2]=v[e+4>>2];tN(c,Sf(c));rN(b)}gb=j+32|0;break a}a=P()|0;O()|0;rN(b);S(a|0);L()}return}if(b>>>0<e>>>0){zN(a,v[a>>2]+B(b,52)|0)}}function yia(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,w=0;f=gb-32|0;gb=f;k=v[a+40>>2];l=v[a+36>>2];m=v[a+16>>2];e=v[a+4>>2];h=e;i=v[a>>2];v[f+24>>2]=i;v[f+28>>2]=e;e=v[a+12>>2];v[f+16>>2]=v[a+8>>2];v[f+20>>2]=e;a:{if(d){while(1){j=(((h&2147483647)<<1|i>>>31)&-2)+m|0;e=(((i>>>16|0)+4&131064)<<1)+b|0;i=u[e+38>>1];n=u[e+36>>1];o=u[e+34>>1];p=u[e+32>>1];q=u[e+30>>1];r=u[e+28>>1];s=u[e+26>>1];w=u[e+24>>1];g=0;e=1;while(1){v[(f+8|0)+(g<<2)>>2]=(((((B(t[(g|4)+j|0],o)+B(t[(g|2)+j|0],p)|0)+B(t[(g|6)+j|0],n)|0)+B(t[(g|8)+j|0],i)<<8)/2|0)+((((B(t[(g|-4)+j|0],s)+B(t[(g|-6)+j|0],w)|0)+B(t[(g|-2)+j|0],r)|0)+B(t[g+j|0],q)<<8)/2|0)|0)/16384;h=e;e=0;g=1;if(h){continue}break}h=v[a+32>>2];l=v[a+28>>2]+l|0;e=l>>12;v[c>>2]=v[c>>2]+B(e,v[f+8>>2]);k=h+k|0;g=k>>12;v[c+4>>2]=v[c+4>>2]+B(g,v[f+12>>2]);Ub(f+24|0,f+16|0);d=d-1|0;if(d){c=c+8|0;i=v[f+24>>2];h=v[f+28>>2];continue}break}i=v[f+24>>2];h=v[f+28>>2];break a}g=k>>12;e=l>>12}v[a+40>>2]=k;v[a+20>>2]=e;v[a+36>>2]=l;v[a+24>>2]=g;v[a>>2]=i;v[a+4>>2]=h;gb=f+32|0}function fba(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;i=gb-32|0;gb=i;d=gb-16|0;gb=d;YW(d+8|0,b);gb=d+16|0;v[i+16>>2]=v[d+8>>2];j=i+24|0;k=j;f=gb-32|0;gb=f;c=b;e=a;b=Yd(e);d=fc(e);a:{b:{if(b){c:{while(1){d:{h=b+16|0;e:{if(Bu(wb(e),c,h)){if(!v[b>>2]){break b}d=b;break e}if(!Bu(wb(e),h,c)){break c}d=b+4|0;if(!v[b+4>>2]){break d}b=d;d=b}b=v[b>>2];continue}break}v[f+28>>2]=b;b=d;break a}v[f+28>>2]=b;b=d;break a}b=fc(e)}v[f+28>>2]=b}d=b;b=v[b>>2];t[f+27|0]=0;if(!b){h=gb-16|0;gb=h;b=fc(a);e=Mc(40,4);g=h+8|0;t[g+4|0]=0;v[g>>2]=b;c=gb-16|0;gb=c;v[c+12>>2]=e;v[22656]=0;e=f+8|0;b=e;NQ(b,c+12|0,g);g=v[22656];v[22656]=0;f:{if((g|0)!=1){gb=c+16|0;break f}V(0)|0;O()|0;Bb();L()}c=v[b>>2];v[22656]=0;g=c+16|0;c=v[22656];v[22656]=0;g:{if((c|0)!=1){c=gb-16|0;gb=c;v[c+8>>2]=v[i+16>>2];Dc(g,v[c+8>>2]);Kb(g+12|0);gb=c+16|0;l=fc(b),m=1,t[l+4|0]=m;gb=h+16|0;break g}a=P()|0;O()|0;OQ(b);S(a|0);L()}AS(a,v[f+28>>2],d,v[e>>2]);b=ce(e);t[f+27|0]=1;OQ(e)}l=k,m=v[yc(f+8|0,b)>>2],v[l>>2]=m;t[k+4|0]=w[f+27|0];gb=f+32|0;a=ue(j);gb=i+32|0;return a+12|0}function Foa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;g=gb-32|0;gb=g;f=b;d=Nb(f);e=c;a:{if(d>>>0<e>>>0){l=gb-32|0;gb=l;b:{c:{h=e-d|0;d:{if(h>>>0<=v[wb(f)>>2]-v[f+4>>2]>>2>>>0){i=gb-16|0;gb=i;e:{d=Fg(i,f,h);e=v[d+4>>2];h=v[d+8>>2];if((e|0)!=(h|0)){while(1){wb(f);v[22656]=0;ak(e);j=v[22656];v[22656]=0;if((j|0)==1){break e}e=e+4|0;v[d+4>>2]=e;if((e|0)!=(h|0)){continue}break}}$b(d);gb=i+16|0;break d}a=P()|0;O()|0;$b(d);S(a|0);L()}k=wb(f);i=fh(f,Nb(f)+h|0);m=Nb(f);e=0;j=gb-16|0;gb=j;v[j+12>>2]=0;d=l+8|0;Bh(d+12|0,k);if(i){e=RW(i)}v[d>>2]=e;k=(m<<2)+e|0;v[d+8>>2]=k;v[d+4>>2]=k;n=dc(d),o=(i<<2)+e|0,v[n>>2]=o;gb=j+16|0;v[22656]=0;R(662,d|0,h|0);e=v[22656];v[22656]=0;if((e|0)==1){break c}v[22656]=0;R(663,f|0,d|0);f=v[22656];v[22656]=0;if((f|0)==1){break c}SW(d)}gb=l+32|0;break b}a=P()|0;O()|0;SW(d);S(a|0);L()}break a}if(d>>>0>e>>>0){hj(f,v[f>>2]+(e<<2)|0)}}c=Pb(a,c<<2);if(c){f=gb-16|0;gb=f;bc(g+24|0,v[b>>2],Nb(b)<<2);gb=f+16|0;b=v[g+28>>2];v[g+8>>2]=v[g+24>>2];v[g+12>>2]=b;kd(g+16|0,a,g+8|0)}gb=g+32|0;return c|0}function aja(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,w=0;g=gb-16|0;gb=g;f=v[a+48>>2];l=v[a+24>>2];m=v[a+20>>2];b=v[a+44>>2];n=v[a+16>>2];i=v[a+4>>2];h=v[a>>2];v[g+8>>2]=h;v[g+12>>2]=i;e=v[a+12>>2];v[g>>2]=v[a+8>>2];v[g+4>>2]=e;a:{if(!d){e=b;b=f;break a}while(1){e=i+n|0;i=t[e+2|0];o=t[e+1|0];p=t[e|0];q=t[e-1|0];e=v[a+60>>2];r=e;s=e>>31;e=Lb(b,-16777216,16776704);j=v[a+64>>2];f=Lb(f,-16777216,16776704);e=kqa(j,j>>31,e,e>>31);j=jb;w=e;e=v[a+68>>2];k=kqa(e,e>>31,f,f>>31);e=w+k|0;f=jb+j|0;f=e>>>0<k>>>0?f+1|0:f;j=e;e=h>>>21&2040;i=(((B(u[e+46162>>1],p)+B(q,u[e+46160>>1])|0)+B(o,u[e+46164>>1])|0)+B(i,u[e+46166>>1])<<8)/16384<<8;e=i;h=kqa(r,s,e,e>>31);e=j+h|0;f=jb+f|0;f=e>>>0<h>>>0?f+1|0:f;e=e+8388608|0;f=e>>>0<8388608?f+1|0:f;f=Jc(e,f,24);e=v[a+72>>2];h=(f|0)/256|0;v[c>>2]=v[c>>2]+B(h,m);v[c+4>>2]=v[c+4>>2]+B(h,l);e=f-(e&i)|0;Ub(g+8|0,g);d=d-1|0;if(d){c=c+8|0;h=v[g+8>>2];i=v[g+12>>2];f=b;b=e;continue}break}h=v[g+8>>2];i=v[g+12>>2]}v[a+48>>2]=b;v[a+44>>2]=e;v[a>>2]=h;v[a+4>>2]=i;gb=g+16|0}function Rja(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;g=gb-48|0;gb=g;u[a>>1]=0;u[a+2>>1]=0;u[a+4>>1]=0;d=g+44|0;ip(b,d);a:{if(!RS(d)){break a}c=w[g+46|0];f=w[g+47|0];e=w[g+45|0];t[a+4|0]=1;h=e>>>3&3;d=(h|0)!=3;i=e>>>1&3;e=i^3;f=f>>>0<192;u[a+2>>1]=x[(B(d,6)+(e<<1)|0)+33672>>1]<<f;e=B(B(w[(e+B(d,3)|0)+33449|0],x[((B(d,90)+B(e,30)|0)+(c>>>3&30)|0)+33456>>1]),1e3);c=c>>>1|0;c=B(((e>>>0)/x[(B(h,6)+(c&6)|0)+33648>>1]|0)+(c&1)|0,(i|0)==3?4:1);u[a>>1]=c;e=w[(f|d<<1)+33684|0];if(e+8>>>0>(c&65535)>>>0){break a}d=g;c=gb-48|0;gb=c;v[c+44>>2]=e+4;v[c+24>>2]=36;f=v[Fb(c+44|0,c+24|0)>>2];if(!Pb(b,f)){f=nf(b)}h=c+24|0;ds(h,d);i=wd(c+32|0,v[h>>2],f);j=v[i+4>>2];v[c+8>>2]=v[i>>2];v[c+12>>2]=j;cc(c+16|0,b,c+8|0);ds(h,d);Qb(v[c+24>>2]+f|0,0,36-f|0);Rb(b,v[c+44>>2]);gb=c+48|0;b=2;if(e>>>0>2){while(1){if(w[b+g|0]){break a}b=b+1|0;if((e|0)!=(b|0)){continue}break}}b=a;d=e+g|0;if((w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24))==1868983881){d=1}else{d=(w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24))==1735289176}t[b+5|0]=d}gb=g+48|0;return a|0}function jk(a,b,c,d,e,f,g,h){var i=0,j=0,k=0,l=0,m=0;i=gb-32|0;gb=i;v[i+16>>2]=c;v[i+24>>2]=b;b=i+8|0;Fc(b,d);v[22656]=0;j=T(2452,b|0)|0;b=v[22656];v[22656]=0;if((b|0)!=1){Wb(i+8|0);v[e>>2]=0;a:{if((g|0)==(h|0)){break a}while(1){b:{if(jl(i+24|0,i+16|0)){break b}c:{if((Sn(j,v[g>>2])|0)==37){c=g+4|0;if((h|0)==(c|0)){break b}d:{e:{b=Sn(j,v[c>>2]);if((b|0)==69){break e}k=0;if((b&255)==48){break e}c=g;break d}if((g+8|0)==(h|0)){break b}k=b;b=Sn(j,v[g+8>>2])}l=i,m=kb[v[v[a>>2]+36>>2]](a,v[i+24>>2],v[i+16>>2],d,e,f,b,k)|0,v[l+24>>2]=m;g=c+8|0;break c}if(kl(j,8192,v[g>>2])){while(1){f:{g=g+4|0;if((h|0)==(g|0)){g=h;break f}if(kl(j,8192,v[g>>2])){continue}}break}if(!ym(i+24|0,i+16|0)){break c}while(1){if(!kl(j,8192,xm(i+24|0))){break c}b=i+24|0;wm(b);if(ym(b,i+16|0)){continue}break}break c}if((qn(j,xm(i+24|0))|0)==(qn(j,v[g>>2])|0)){g=g+4|0;wm(i+24|0);break c}v[e>>2]=4}if((g|0)==(h|0)){break a}if(!v[e>>2]){continue}break a}break}v[e>>2]=4}if(jl(i+24|0,i+16|0)){v[e>>2]=v[e>>2]|2}gb=i+32|0;return v[i+24>>2]}a=P()|0;O()|0;Wb(i+8|0);S(a|0);L()}function $ia(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;h=gb-16|0;gb=h;e=v[a+48>>2];m=v[a+24>>2];n=v[a+20>>2];b=v[a+44>>2];o=v[a+16>>2];g=v[a+4>>2];i=v[a>>2];v[h+8>>2]=i;v[h+12>>2]=g;f=v[a+12>>2];v[h>>2]=v[a+8>>2];v[h+4>>2]=f;a:{if(!d){f=b;b=e;break a}while(1){f=(g<<1)+o|0;j=u[f>>1];p=u[f-2>>1];q=u[f+2>>1];r=u[f+4>>1];l=v[a+60>>2];f=Lb(b,-16777216,16776704);k=v[a+64>>2];g=Lb(e,-16777216,16776704);e=kqa(k,k>>31,f,f>>31);k=jb;f=e;e=i>>>21&2040;i=(((B(j,u[e+46162>>1])+B(p,u[e+46160>>1])|0)+B(u[e+46164>>1],q)|0)+B(r,u[e+46166>>1])|0)/16384<<8;e=i;j=kqa(l,l>>31,e,e>>31);f=f+j|0;e=jb+k|0;e=f>>>0<j>>>0?e+1|0:e;j=f;f=v[a+68>>2];g=kqa(f,f>>31,g,g>>31);f=j+g|0;e=jb+e|0;e=f>>>0<g>>>0?e+1|0:e;f=f+8388608|0;e=f>>>0<8388608?e+1|0:e;e=Jc(f,e,24);f=v[a+72>>2];g=(e|0)/256|0;v[c>>2]=v[c>>2]+B(g,n);v[c+4>>2]=v[c+4>>2]+B(g,m);f=e-(f&i)|0;Ub(h+8|0,h);d=d-1|0;if(d){c=c+8|0;i=v[h+8>>2];g=v[h+12>>2];e=b;b=f;continue}break}i=v[h+8>>2];g=v[h+12>>2]}v[a+48>>2]=b;v[a+44>>2]=f;v[a>>2]=i;v[a+4>>2]=g;gb=h+16|0}function kk(a,b,c,d,e,f,g,h){var i=0,j=0,k=0,l=0,m=0;i=gb-32|0;gb=i;v[i+16>>2]=c;v[i+24>>2]=b;b=i+8|0;Fc(b,d);v[22656]=0;j=T(21,b|0)|0;b=v[22656];v[22656]=0;if((b|0)!=1){Wb(i+8|0);v[e>>2]=0;a:{if((g|0)==(h|0)){break a}while(1){b:{if(mk(i+24|0,i+16|0)){break b}c:{if((Tn(j,t[g|0])|0)==37){c=g+1|0;if((h|0)==(c|0)){break b}d:{e:{b=Tn(j,t[c|0]);if((b|0)==69){break e}k=0;if((b&255)==48){break e}c=g;break d}if((g+2|0)==(h|0)){break b}k=b;b=Tn(j,t[g+2|0])}l=i,m=kb[v[v[a>>2]+36>>2]](a,v[i+24>>2],v[i+16>>2],d,e,f,b,k)|0,v[l+24>>2]=m;g=c+2|0;break c}if(nh(j,8192,t[g|0])){while(1){f:{g=g+1|0;if((h|0)==(g|0)){g=h;break f}if(nh(j,8192,t[g|0])){continue}}break}if(!nk(i+24|0,i+16|0)){break c}while(1){if(!nh(j,8192,pl(i+24|0))){break c}b=i+24|0;ol(b);if(nk(b,i+16|0)){continue}break}break c}if((Ex(j,pl(i+24|0))|0)==(Ex(j,t[g|0])|0)){g=g+1|0;ol(i+24|0);break c}v[e>>2]=4}if((g|0)==(h|0)){break a}if(!v[e>>2]){continue}break a}break}v[e>>2]=4}if(mk(i+24|0,i+16|0)){v[e>>2]=v[e>>2]|2}gb=i+32|0;return v[i+24>>2]}a=P()|0;O()|0;Wb(i+8|0);S(a|0);L()}function fJ(a,b,c,d,e){var f=C(0),g=C(0),h=0,i=C(0),j=C(0),k=0;if(!(a&3)){if((a|0)>=4){k=a>>>2|0;a=(c<<2)+b|0;d=a+(d<<2)|0;while(1){b=d-4|0;g=z[b>>2];i=z[a>>2];j=z[d>>2];z[a>>2]=i+j;c=a-4|0;f=z[c>>2];z[c>>2]=f+z[b>>2];i=C(i-j);f=C(f-g);z[d>>2]=C(i*z[e>>2])-C(f*z[e+4>>2]);z[b>>2]=C(f*z[e>>2])+C(i*z[e+4>>2]);b=d-12|0;i=z[b>>2];c=a-8|0;f=z[c>>2];h=c;c=d-8|0;j=z[c>>2];z[h>>2]=f+j;h=a-12|0;g=z[h>>2];z[h>>2]=g+z[b>>2];f=C(f-j);g=C(g-i);z[c>>2]=C(f*z[e+32>>2])-C(g*z[e+36>>2]);z[b>>2]=C(g*z[e+32>>2])+C(f*z[e+36>>2]);b=d-20|0;i=z[b>>2];c=a-16|0;f=z[c>>2];h=c;c=d-16|0;j=z[c>>2];z[h>>2]=f+j;h=a-20|0;g=z[h>>2];z[h>>2]=g+z[b>>2];f=C(f-j);g=C(g-i);z[c>>2]=C(f*z[e+64>>2])-C(g*z[e+68>>2]);z[b>>2]=C(g*z[e+64>>2])+C(f*z[e+68>>2]);b=d-28|0;i=z[b>>2];c=a-24|0;f=z[c>>2];h=c;c=d-24|0;j=z[c>>2];z[h>>2]=f+j;h=a-28|0;g=z[h>>2];z[h>>2]=g+z[b>>2];f=C(f-j);g=C(g-i);z[c>>2]=C(f*z[e+96>>2])-C(g*z[e+100>>2]);z[b>>2]=C(g*z[e+96>>2])+C(f*z[e+100>>2]);d=d-32|0;a=a-32|0;e=e+128|0;b=k>>>0>1;k=k-1|0;if(b){continue}break}}return}aa(12897,10534,2423,6368);L()}function zm(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;f=gb-16|0;gb=f;v[a+4>>2]=0;if(w[uj(f+8|0,a,1)|0]){a:{b:{c:{if((b|0)==2147483647){while(1){b=v[v[a>>2]-12>>2];v[22656]=0;b=v[(a+b|0)+24>>2];d=v[22656];v[22656]=0;if((d|0)==1){break c}v[22656]=0;b=T(2316,b|0)|0;d=v[22656];v[22656]=0;if((d|0)==1){break c}if(Ie(b,-1)){break b}v[a+4>>2]=v[a+4>>2]+1;if(!Ie(b,c)){continue}break}d=0;break a}if(v[a+4>>2]>=(b|0)){break a}while(1){d:{d=v[v[a>>2]-12>>2];v[22656]=0;d=v[(a+d|0)+24>>2];e=v[22656];v[22656]=0;if((e|0)==1){break d}v[22656]=0;e=T(2316,d|0)|0;d=v[22656];v[22656]=0;if((d|0)==1){break d}if(Ie(e,-1)){break b}v[a+4>>2]=v[a+4>>2]+1;d=0;if(Ie(e,c)){break a}if(v[a+4>>2]<(b|0)){continue}break a}break}}b=V(0)|0;O()|0;Z(b|0)|0;d=1;tj(v[v[a>>2]-12>>2]+a|0,1);e:{f:{if(v[(v[v[a>>2]-12>>2]+a|0)+20>>2]&1){v[22656]=0;X(2027);a=v[22656];v[22656]=0;if((a|0)!=1){break e}a=P()|0;O()|0;v[22656]=0;X(20);b=v[22656];v[22656]=0;if((b|0)==1){break f}S(a|0);L()}$();break a}V(0)|0;O()|0;Bb()}L()}d=2}ih(v[v[a>>2]-12>>2]+a|0,d)}gb=f+16|0;return a|0}function s5(a,b){a=a|0;b=+b;var c=0,d=0,e=0,f=0,g=0,h=0,i=0;d=gb-32|0;gb=d;v[22656]=0;g=Q(15,d+24|0,a|0)|0;c=v[22656];v[22656]=0;a:{b:{c:{if((c|0)!=1){d:{if(!w[g|0]){break d}c=v[v[a>>2]-12>>2];v[22656]=0;Fc(d+16|0,a+c|0);c=v[22656];v[22656]=0;e:{f:{g:{if((c|0)!=1){v[22656]=0;c=T(2324,d+16|0)|0;e=v[22656];v[22656]=0;if((e|0)==1){break g}Wb(d+16|0);e=cj(d+8|0,a);f=v[v[a>>2]-12>>2];v[22656]=0;f=a+f|0;h=T(16,f|0)|0;i=v[22656];v[22656]=0;if((i|0)==1){break f}e=v[e>>2];v[22656]=0;c=Ra(2325,c|0,e|0,f|0,h|0,+b)|0;e=v[22656];v[22656]=0;if((e|0)==1){break f}v[d+16>>2]=c;if(!bw(d+16|0)){break d}c=v[v[a>>2]-12>>2];v[22656]=0;R(18,a+c|0,5);c=v[22656];v[22656]=0;if((c|0)!=1){break d}c=V(0)|0;O()|0;break e}c=V(0)|0;O()|0;break e}c=V(0)|0;O()|0;Wb(d+16|0);break e}c=V(0)|0;O()|0}nl(g);break c}nl(g);break b}c=V(0)|0;O()|0}Z(c|0)|0;c=v[v[a>>2]-12>>2];v[22656]=0;_(19,a+c|0);c=v[22656];v[22656]=0;if((c|0)==1){break a}$()}gb=d+32|0;return a|0}a=P()|0;O()|0;v[22656]=0;X(20);d=v[22656];v[22656]=0;if((d|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}function E4(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=gb-32|0;gb=d;a=mc(a);a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{if((Ss(b,c,0)|0)!=-1){while(1){f=Ss(b,c,e);v[22656]=0;Y(140,d|0,b|0,e|0,f-e|0);f=v[22656];v[22656]=0;if((f|0)==1){break j}v[22656]=0;R(141,d+16|0,d|0);f=v[22656];v[22656]=0;if((f|0)==1){break i}v[22656]=0;R(142,a|0,d+16|0);f=v[22656];v[22656]=0;if((f|0)==1){break h}vb(d+16|0);vb(d);e=Ss(b,c,e)+Ab(c)|0;if((Ss(b,c,e)|0)!=-1){continue}break}}k:{if(cd(a)){v[22656]=0;Y(140,d+16|0,b|0,e|0,-1);c=v[22656];v[22656]=0;if((c|0)==1){break f}c=d+16|0;f=Ab(c);vb(c);if(!f){break k}}v[22656]=0;Y(140,d|0,b|0,e|0,-1);b=v[22656];v[22656]=0;if((b|0)==1){break e}v[22656]=0;R(141,d+16|0,d|0);b=v[22656];v[22656]=0;if((b|0)==1){break d}v[22656]=0;R(142,a|0,d+16|0);b=v[22656];v[22656]=0;if((b|0)==1){break c}vb(d+16|0);vb(d)}gb=d+32|0;return}e=P()|0;O()|0;break a}e=P()|0;O()|0;break g}e=P()|0;O()|0;vb(d+16|0)}vb(d);break a}e=P()|0;O()|0;break a}e=P()|0;O()|0;break a}e=P()|0;O()|0;break b}e=P()|0;O()|0;vb(d+16|0)}vb(d)}sm(a);S(e|0);L()}function _u(a,b){a=a|0;b=b|0;a:{b:{switch((w[a+3|0]|64)+-64|0){case 0:t[a+3|0]=w[a+5|0]?37:0;return;case 1:t[a+3|0]=16;return;case 2:t[a+3|0]=12;return;case 3:t[a+3|0]=14;if(b){break a}b=a;a=w[a+5|0];t[b+5|0]=B(a>>>4|0,10)+(a&15);return;case 4:t[a+3|0]=11;return;case 5:t[a+3|0]=3;return;case 6:t[a+3|0]=2;return;case 7:t[a+3|0]=4;return;case 8:t[a+3|0]=5;return;case 9:t[a+3|0]=18;return;case 10:t[a+3|0]=1;return;case 11:t[a+3|0]=7;return;case 12:t[a+3|0]=6;return;case 13:t[a+3|0]=21;return;case 14:t[a+3|0]=22;return;case 15:t[a+3|0]=10;return;case 16:t[a+3|0]=29;return;case 17:t[a+3|0]=15;return;case 18:t[a+3|0]=8;return;case 19:t[a+3|0]=20;return;case 20:t[a+3|0]=17;return;case 21:t[a+3|0]=26;return;case 22:t[a+3|0]=23;return;case 23:t[a+3|0]=24;return;case 24:t[a+3|0]=9;return;case 25:t[a+3|0]=27;return;case 26:t[a+3|0]=31;return;case 28:t[a+3|0]=b?32:31;return;case 29:t[a+3|0]=b?33:0;return;case 27:t[a+3|0]=b?34:0;return;case 30:t[a+3|0]=b?35:0;return;case 31:t[a+3|0]=b?36:0;return;default:break b}}t[a+3|0]=0}}function zz(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0,j=0;f=gb-16|0;gb=f;d=a+2|0;if(!(w[d|0]==255|!w[d|0])){v[f+12>>2]=w[d|0]+1;v[f+8>>2]=10;kh(b,v[pd(f+12|0,f+8|0)>>2]);d=w[a+3|0];t[b+15|0]=d;t[b+16|0]=d;t[b+13|0]=w[a+4|0];t[b+14|0]=w[a+5|0];d=0;g=511;a:{b:{switch(c-1|0){case 1:e=4096;g=128;break a;case 0:break b;default:break a}}e=32768;g=1024}if(Nb(b)){c=g>>>1|e;while(1){h=(d<<2)+a|0;e=h+6|0;e=w[e|0]|w[e+1|0]<<8;i=Mb(b,d),j=e>>>4|0,u[i>>1]=j;e=0;c:{if(d){e=d-1|0;if(x[Mb(b,d)>>1]>=x[Mb(b,e)>>1]){break c}e=x[Mb(b,e)>>1]+1|0}i=Mb(b,d),j=e,u[i>>1]=j}e=h+8|0;v[f+12>>2]=(c+((w[e|0]|w[e+1|0]<<8)<<16>>16)|0)/(g|0);v[f+8>>2]=0;v[f+4>>2]=64;e=v[dj(f+12|0,f+8|0,f+4|0)>>2];i=Mb(b,d),j=e,t[i+2|0]=j;d=d+1|0;if(Nb(b)>>>0>d>>>0){continue}break}}t[b+12|0]=w[b+12|0]&254|t[a|0]&1;c=b;if(w[a|0]&2){d=w[b+15|0];e=Nb(b);d=w[b+12|0]&-5|(d>>>0<=e>>>0)<<2}else{d=w[b+12|0]&-5}t[c+12|0]=d;c=b;d:{e:{if(w[a|0]&4){a=w[b+13|0];if(a>>>0<=w[b+14|0]){break e}}a=w[b+12|0]&-3;break d}d=Nb(b);a=w[b+12|0]&-3|(a>>>0<=d>>>0)<<1}t[c+12|0]=a}gb=f+16|0}function xP(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0;h=gb-16|0;gb=h;f=B(b,872)+a|0;a:{if(c){e=h+8|0;Db(e,a+1074312|0,90);if(!Cb(e)){t[(B(b,872)+a|0)+1075803|0]=c}t[(B(b,872)+a|0)+1075804|0]=c;break a}c=w[f+1075804|0]}e=f+1074992|0;g=c&255;j=0-g|0;i=d?i:!(v[a+480180>>2]&204473357);sP(a,b,j,i);b:{c:{if(v[a+480180>>2]!=16777216){break c}f=v[(B(b,872)+a|0)+1075648>>2];if(!f|!v[f+44>>2]){break c}b=c&255;if(!(b>>>0<240|d)){rP(a,e,240-g|0);break b}if(!(b>>>0<224|d)){qP(e,224-g|0);break b}pP(e,j);break b}if(v[a+480180>>2]==268435456){v[(B(b,872)+a|0)+1075700>>2]=65535}if((c&255)>>>0>223&i){d:{d=g&15;if(!d){break d}c=c&240;if((c|0)!=224){if((c|0)!=240){break d}nP(a,e,d);break b}if(v[a+480180>>2]==524288){break d}uP(a,e,d);break b}if(v[a+480180>>2]!=524288){break b}}e:{if(!(t[(B(b,872)+a|0)+1075843|0]&1)){break e}if(v[a+1074416>>2]==1){c=h+8|0;Db(c,a+1074312|0,6);if(Cb(c)){break e}}if(v[a+480180>>2]&32832){break e}if(!(v[a+480208>>2]&2)|v[a+480180>>2]!=8){break b}}sk(a,e,(B(b,872)+a|0)+1075692|0,0-(g<<2)|0,0)}gb=h+16|0}function r7(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;b=gb+-64|0;gb=b;c=v[a>>2];a=v[c>>2];d=v[a+4>>2];v[b+40>>2]=v[a+20>>2];e=v[a+16>>2];v[b+32>>2]=v[a+12>>2];v[b+36>>2]=e;Jf(b+48|0,b+32|0,d);a=v[c+4>>2];d=v[a+4>>2];e=v[a+8>>2];c=v[b+60>>2];v[b+24>>2]=v[b+56>>2];v[b+28>>2]=c;c=v[b+52>>2];v[b+16>>2]=v[b+48>>2];v[b+20>>2]=c;v[b+8>>2]=v[a+8>>2];c=v[a+4>>2];v[b>>2]=v[a>>2];v[b+4>>2]=c;j=b+16|0;c=gb-32|0;gb=c;a=b;a:{if(d>>>0<=y[b+4>>2]){if(d>>>0<=y[j+4>>2]){if(y[a+8>>2]>=e>>>0){if(If(j)>>>0>=e>>>0){if(e){while(1){f=0;if(d){while(1){k=c,l=A[Wg(a,f,h)>>3],A[k+24>>3]=l;v[c+16>>2]=0;v[c+20>>2]=-1074790400;v[c+8>>2]=0;v[c+12>>2]=1072693248;g=A[bh(c+24|0,c+16|0,c+8|0)>>3]*32768;A[c+24>>3]=g;g=ee(g);b:{if(D(g)<2147483648){i=~~g;break b}i=-2147483648}i=Uc(i);k=fo(j,f,h),m=i,u[k>>1]=m;f=f+1|0;if((d|0)!=(f|0)){continue}break}}h=h+1|0;if((e|0)!=(h|0)){continue}break}}gb=c+32|0;break a}aa(2959,6176,80,5856);L()}aa(2989,6176,79,5856);L()}aa(4211,6176,78,5856);L()}aa(4246,6176,77,5856);L()}gb=b- -64|0}function HO(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=gb-16|0;gb=d;a:{b:{switch(w[a+480224|0]-1|0){default:c=v[a+24620>>2];v[d+12>>2]=1;v[d+8>>2]=v[b+44>>2]<<1;c=kqa(c,c>>31,5e4,0);f=jb;b=v[Lc(d+12|0,d+8|0)>>2];c=Ac(lqa(c,f,b,b>>31),jb);break a;case 0:c=v[a+24620>>2];v[d+12>>2]=1;v[d+8>>2]=v[b+44>>2];c=kqa(c,c>>31,1e4,0);f=jb;b=v[Lc(d+12|0,d+8|0)>>2];c=Ac(lqa(c,f,b,b>>31),jb);break a;case 1:break b}}e=60/(+y[b+44>>2]/1e4*(+(kqa(v[b+32>>2],0,v[b+40>>2],0)>>>0)+ +(jb>>>0)*4294967296))*+y[a+24620>>2];c:{d:{c=a+484344|0;if(!me(c,x[b+70>>1])){break d}if(!(cd(_b(c,x[b+70>>1])+24|0)^1)){break d}c=_b(c,x[b+70>>1])+24|0;break c}c=a+480248|0}if(!cd(c)){e=e*+y[Mb(c,y[b+48>>2]%(Nb(c)>>>0)|0)>>2]*5.960464477539063e-8}e:{if(D(e)<2147483648){c=~~e;break e}c=-2147483648}e=A[b+8>>3]+(e-+(c>>>0));A[b+8>>3]=e;if(e>=1){A[b+8>>3]=e+-1;c=c+1|0;break a}if(!(A[a+1074384>>3]<=-1)){break a}A[b+8>>3]=e+1;c=c-1|0}b=kqa(v[a+480244>>2],0,c,0)+32768|0;a=jb;a=b>>>0<32768?a+1|0:a;a=Qc((a&65535)<<16|b>>>16,a>>>16|0);gb=d+16|0;return(a?a:1)|0}function A7(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;b=gb+-64|0;gb=b;c=v[a>>2];a=v[c>>2];d=v[a+4>>2];v[b+40>>2]=v[a+20>>2];e=v[a+16>>2];v[b+32>>2]=v[a+12>>2];v[b+36>>2]=e;Jf(b+48|0,b+32|0,d);a=v[c+4>>2];d=v[a+4>>2];e=v[a+8>>2];c=v[b+60>>2];v[b+24>>2]=v[b+56>>2];v[b+28>>2]=c;c=v[b+52>>2];v[b+16>>2]=v[b+48>>2];v[b+20>>2]=c;v[b+8>>2]=v[a+8>>2];c=v[a+4>>2];v[b>>2]=v[a>>2];v[b+4>>2]=c;j=b+16|0;c=gb-32|0;gb=c;a=b;a:{if(d>>>0<=y[b+4>>2]){if(d>>>0<=y[j+4>>2]){if(y[a+8>>2]>=e>>>0){if(If(j)>>>0>=e>>>0){if(e){while(1){f=0;if(d){while(1){k=c,l=A[Wg(a,f,h)>>3],A[k+24>>3]=l;v[c+16>>2]=0;v[c+20>>2]=-1074790400;v[c+8>>2]=0;v[c+12>>2]=1072693248;g=A[bh(c+24|0,c+16|0,c+8|0)>>3]*32768;A[c+24>>3]=g;g=ee(g);b:{if(D(g)<2147483648){i=~~g;break b}i=-2147483648}i=Uc(i);k=go(j,f,h),m=i,u[k>>1]=m;f=f+1|0;if((d|0)!=(f|0)){continue}break}}h=h+1|0;if((e|0)!=(h|0)){continue}break}}gb=c+32|0;break a}aa(2959,6176,80,5856);L()}aa(2989,6176,79,5856);L()}aa(4211,6176,78,5856);L()}aa(4246,6176,77,5856);L()}gb=b- -64|0}function Bc(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;a:{c=v[b>>2];f=gb-48|0;gb=f;e=v[b+4>>2];d=w[b+8|0];e=e-(((d|0)==1|(d|0)==4)&(e|0)!=0)|0;b=Kb(a);b:{c:{d:{e:{f:{g:{h:{if((d-1&255)>>>0<=1){t[f+32|0]=0;a=Xm(c,c+e|0,f+32|0);v[22656]=0;U(68,b|0,c|0,a|0);a=v[22656];v[22656]=0;if((a|0)!=1){break h}a=P()|0;O()|0;break b}if((d-3&255)>>>0>1){break h}v[22656]=0;U(68,b|0,c|0,c+e|0);a=v[22656];v[22656]=0;if((a|0)==1){break g}c=zd(b);d=gf(b);e=zd(b);a=gb-32|0;gb=a;v[a+16>>2]=d;v[a+24>>2]=c;v[a+8>>2]=e;if(Gb(a+24|0,a+16|0)){while(1){d=a+8|0;c=a+24|0;e=t[v[c>>2]];t[v[d>>2]]=e?e:32;Pe(c);Pe(d);if(Gb(c,a+16|0)){continue}break}}gb=a+32|0;v[22656]=0;c=Q(69,f+16|0,b|0)|0;a=v[22656];v[22656]=0;if((a|0)==1){break f}v[22656]=0;d=Q(70,f|0,14911)|0;a=v[22656];v[22656]=0;if((a|0)==1){break e}v[22656]=0;U(71,f+32|0,c|0,d|0);a=v[22656];v[22656]=0;if((a|0)==1){break d}a=f+32|0;Eb(b,a);vb(a);vb(d);vb(c)}gb=f+48|0;break a}a=P()|0;O()|0;break b}a=P()|0;O()|0;break b}a=P()|0;O()|0;break c}a=P()|0;O()|0;vb(d)}vb(c)}vb(b);S(a|0);L()}}function aw(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0,j=0;h=a;a=gb+-64|0;gb=a;i=a;g=v[c>>2]&2?16:10;e=gb-32|0;gb=e;d=He(e+16|0,1,0);a:{b:{c:{while(1){eO(e+8|0,Jb(d),Jb(d)+Ab(d)|0,w[b|0],g);if(!v[e+12>>2]){break c}f=Ab(d);v[22656]=0;v[e+4>>2]=f;f=xf(e+4|0);j=v[22656];v[22656]=0;if((j|0)!=1){v[22656]=0;U(75,d|0,f|0,0);f=v[22656];v[22656]=0;if((f|0)!=1){continue}}break}break b}b=v[e+8>>2];g=Jb(d);v[22656]=0;R(76,d|0,b-g|0);b=v[22656];v[22656]=0;d:{if((b|0)!=1){v[22656]=0;R(86,i|0,d|0);b=v[22656];v[22656]=0;if((b|0)!=1){break d}break b}break b}vb(d);gb=e+32|0;break a}a=P()|0;O()|0;vb(d);S(a|0);L()}b=a+16|0;Ml(b,a,c);v[22656]=0;U(93,a+32|0,b|0,c|0);b=v[22656];v[22656]=0;e:{f:{g:{h:{i:{if((b|0)!=1){v[22656]=0;U(94,a+48|0,a+32|0,c|0);b=v[22656];v[22656]=0;if((b|0)==1){break i}v[22656]=0;R(85,h|0,a+48|0);b=v[22656];v[22656]=0;if((b|0)==1){break h}vb(a+48|0);vb(a+32|0);vb(a+16|0);vb(a);gb=a- -64|0;break e}b=P()|0;O()|0;break f}b=P()|0;O()|0;break g}b=P()|0;O()|0;vb(a+48|0)}vb(a+32|0)}vb(a+16|0);vb(a);S(b|0);L()}}function ey(a,b,c,d){var e=0,f=0,g=0,h=0,i=0;g=gb-32|0;gb=g;e=d&2147483647;h=e;f=e-1006698496|0;e=e-1140785152|0;i=c;a:{if((f|0)==(e|0)&c>>>0>c>>>0|e>>>0>f>>>0){e=d<<4|c>>>28;c=c<<4|b>>>28;b=b&268435455;h=b;if((b|0)==134217728&(a|0)!=0|b>>>0>134217728){e=e+1073741824|0;a=c+1|0;e=a?e:e+1|0;f=a;break a}f=c;e=e+1073741824|0;if(a|h^134217728){break a}b=c&1;a=b+f|0;e=a>>>0<b>>>0?e+1|0:e;f=a;break a}if(!(!i&(h|0)==2147418112?!(a|b):h>>>0<2147418112)){f=c;c=d<<4|c>>>28;f=f<<4|b>>>28;e=c&524287|2146959360;break a}f=0;e=2146435072;if(h>>>0>1140785151){break a}e=0;h=h>>>16|0;if(h>>>0<15249){break a}e=d&65535|65536;Kf(g+16|0,a,b,c,e,h-15233|0);pm(g,a,b,c,e,15361-h|0);e=v[g+4>>2];h=e;a=v[g+8>>2];c=v[g+12>>2]<<4|a>>>28;f=a<<4|e>>>28;e=c;a=h&268435455;c=a;b=v[g>>2]|((v[g+16>>2]|v[g+24>>2])!=0|(v[g+20>>2]|v[g+28>>2])!=0);if((a|0)==134217728&(b|0)!=0|a>>>0>134217728){a=f+1|0;e=a?e:e+1|0;f=a;break a}if(b|c^134217728){break a}a=f+(f&1)|0;e=a>>>0<f>>>0?e+1|0:e;f=a}gb=g+32|0;l(0,f|0);l(1,d&-2147483648|e);return+n()}function u_(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;d=gb-112|0;gb=d;vc(b);ss(a);a:{if(!sF(b,d+72|0)){break a}if(!tF(d+72|0)){break a}b:{if(!c){break b}c=d+72|4;if(!Pb(b,Xb(w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24))-28|0)){break a}_w(a);g=d,h=Zw(),v[g+48>>2]=h;e=d+48|0;Yw(lj(a)+32|0,e);qs(e);f=v[lj(a)+32>>2];v[22656]=0;R(281,e|0,b|0);b=v[22656];v[22656]=0;c:{if((b|0)==1){break c}b=v[d+48>>2];c=Xb(w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24));e=Xb(w[d+84|0]|w[d+85|0]<<8|(w[d+86|0]<<16|w[d+87|0]<<24));v[22656]=0;b=da(282,b|0,c-28|0,f|0,e|0)|0;c=v[22656];v[22656]=0;if((c|0)==1){break c}e=0;if(!b){break a}Vd(d+32|0,f);b=v[d+36>>2];v[d+16>>2]=v[d+32>>2];v[d+20>>2]=b;rh(d+40|0,d+16|0);b=Ud(d+24|0);c=v[d+44>>2];v[d+8>>2]=v[d+40>>2];v[d+12>>2]=c;c=v[b+4>>2];v[d>>2]=v[b>>2];v[d+4>>2]=c;b=ps(d+48|0,d+8|0,d);Vc(lj(a)+12|0,b);xb(b);break b}a=Ca(89116,28304)|0;b=O()|0;d:{if((ea(89116)|0)!=(b|0)){if((ea(28304)|0)!=(b|0)){break d}}Z(a|0)|0;$();e=0;break a}S(a|0);L()}e=1}gb=d+112|0;return e|0}function kC(a,b,c,d,e){var f=0,g=0,h=0,i=0,j=0,k=0,l=0;h=gb-32|0;gb=h;uV(a,b);i=gb-16|0;gb=i;ud(c,1);a=b+22|0;k=c,l=Ib(w[a|0]|w[a+1|0]<<8)<<1,v[k>>2]=l;t[c+37|0]=w[b+24|0]<<4;t[i+15|0]=w[b+25|0];t[i+14|0]=64;k=c,l=w[ac(i+15|0,i+14|0)|0]<<2,u[k+30>>1]=l;a=b+26|0;j=Ib(w[a|0]|w[a+1|0]<<8);a=j<<1;f=b+28|0;g=Ib(w[f|0]|w[f+1|0]<<8);f=g<<1;a:{if(g>>>0<=1){g=v[c>>2];break a}g=v[c>>2];a=a+f>>>0<=g>>>0?a:g>>>0<f+j>>>0?a:j}b:{c:{switch(g|0){case 2:v[c>>2]=0;break b;case 0:break b;default:break c}}v[c+4>>2]=a;f=a+f|0;v[c+8>>2]=f;if(a>>>0>=g>>>0){a=g-1|0;v[c+4>>2]=a}if(!(!(f>>>0<4|a>>>0>f>>>0)&f-a>>>0>3)){v[c+4>>2]=0;v[c+8>>2]=0;f=0;a=0}if(!(f>>>0>8|a|(!e|f>>>0>=g>>>0))){v[c+8>>2]=0;break b}if(a>>>0>=f>>>0){break b}u[c+34>>1]=x[c+34>>1]|2}gb=i+16|0;Rk(h,3,b);a=h+16|0;Bc(a,h);v[22656]=0;Q(301,d|0,a|0)|0;a=v[22656];v[22656]=0;if((a|0)!=1){a=d+32|0;vb(h+16|0);while(1){if((w[d|0]-1&255)>>>0<=30){t[d|0]=32}d=d+1|0;if((a|0)!=(d|0)){continue}break}a=lC(b);gb=h+32|0;return a}a=P()|0;O()|0;vb(h+16|0);S(a|0);L()}function nq(a){a=a|0;var b=0,c=0,d=0,e=C(0),f=0,g=C(0),h=0,i=0,j=0,k=0,l=C(0);b=v[a+36>>2];if(!b){Gg(a+16|0);return}a:{b:{c:{switch(x[a>>1]){case 3:c=a+16|0;if(b>>>0>=1001){Gg(c);return}El(c,b);b=x[a+28>>1];d=a+4|0;Nb(d);e=Im(a,(b<<16)+65536>>16);f=u[a+28>>1];Nb(d);b=1;e=oe(C(e/Im(a,f)),C(C(1)/C(v[a+36>>2]+1>>>0)));if(!v[a+36>>2]){break b}while(1){g=oe(e,C(b>>>0));k=Mb(c,b-1|0),l=g,z[k>>2]=l;b=b+1|0;if(b>>>0<=y[a+36>>2]){continue}break};break b;case 1:c=a+16|0;d=x[a+30>>1];if(d>>>0>1e3/(b>>>0)>>>0){Gg(c);return}El(c,B(b,d));b=u[a+28>>1];Nb(a+4|0);h=b;b=x[a+30>>1];h=to(h,b);if(!d){break b}while(1){b=to(f+h<<16>>16,b&65535)<<16;j=b>>16;e=oe(C(Im(a,b+65536>>16)/Im(a,j)),C(C(1)/C(v[a+36>>2]+1>>>0)));i=1;b=1;if(v[a+36>>2]){while(1){g=oe(e,C((b&65535)>>>0));k=Mb(c,(B(v[a+36>>2],j)+i|0)-1|0),l=g,z[k>>2]=l;b=b+1|0;i=b&65535;if(i>>>0<=y[a+36>>2]){continue}break}}f=f+1|0;if(d>>>0<=(f&65535)>>>0){break b}b=x[a+30>>1];continue};case 0:break a;default:break c}}Gg(a+16|0);v[a+36>>2]=0}return}Gg(a+16|0)}function d4(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0;g=gb-32|0;gb=g;v[g+24>>2]=b;a:{b:{if(!(v[d+4>>2]&1)){v[g>>2]=-1;b=kb[v[v[a>>2]+16>>2]](a,b,c,d,e,g)|0;v[g+24>>2]=b;c:{switch(v[g>>2]){case 1:t[f|0]=1;break a;case 0:break b;default:break c}}t[f|0]=1;v[e>>2]=4;break a}Fc(g,d);v[22656]=0;b=T(2452,g|0)|0;a=v[22656];v[22656]=0;d:{e:{f:{g:{if((a|0)!=1){Wb(g);Fc(g,d);v[22656]=0;a=T(2453,g|0)|0;d=v[22656];v[22656]=0;if((d|0)==1){break g}Wb(g);v[22656]=0;R(2454,g|0,a|0);d=v[22656];v[22656]=0;if((d|0)==1){b=P()|0;O()|0;break d}v[22656]=0;R(2455,g|12,a|0);a=v[22656];v[22656]=0;if((a|0)==1){break f}v[22656]=0;d=g+24|0;a=sa(2456,d|0,c|0,g|0,d|0,b|0,e|0,1)|0;b=v[22656];v[22656]=0;if((b|0)==1){break e}t[f|0]=(a|0)==(g|0);b=v[g+24>>2];while(1){d=Hc(d-12|0);if((g|0)!=(d|0)){continue}break}break a}b=P()|0;O()|0;Wb(g);break d}b=P()|0;O()|0;Wb(g);break d}b=P()|0;O()|0;Hc(g);break d}b=P()|0;O()|0;while(1){d=Hc(d-12|0);if((g|0)!=(d|0)){continue}break}}S(b|0);L()}t[f|0]=0}gb=g+32|0;return b|0}function x4(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0;g=gb-32|0;gb=g;v[g+24>>2]=b;a:{b:{if(!(v[d+4>>2]&1)){v[g>>2]=-1;b=kb[v[v[a>>2]+16>>2]](a,b,c,d,e,g)|0;v[g+24>>2]=b;c:{switch(v[g>>2]){case 1:t[f|0]=1;break a;case 0:break b;default:break c}}t[f|0]=1;v[e>>2]=4;break a}Fc(g,d);v[22656]=0;b=T(21,g|0)|0;a=v[22656];v[22656]=0;d:{e:{f:{g:{if((a|0)!=1){Wb(g);Fc(g,d);v[22656]=0;a=T(2424,g|0)|0;d=v[22656];v[22656]=0;if((d|0)==1){break g}Wb(g);v[22656]=0;R(2425,g|0,a|0);d=v[22656];v[22656]=0;if((d|0)==1){b=P()|0;O()|0;break d}v[22656]=0;R(2426,g|12,a|0);a=v[22656];v[22656]=0;if((a|0)==1){break f}v[22656]=0;d=g+24|0;a=sa(2427,d|0,c|0,g|0,d|0,b|0,e|0,1)|0;b=v[22656];v[22656]=0;if((b|0)==1){break e}t[f|0]=(a|0)==(g|0);b=v[g+24>>2];while(1){d=vb(d-12|0);if((g|0)!=(d|0)){continue}break}break a}b=P()|0;O()|0;Wb(g);break d}b=P()|0;O()|0;Wb(g);break d}b=P()|0;O()|0;vb(g);break d}b=P()|0;O()|0;while(1){d=vb(d-12|0);if((g|0)!=(d|0)){continue}break}}S(b|0);L()}t[f|0]=0}gb=g+32|0;return b|0}function yP(a,b,c,d){var e=0,f=0,g=0,h=0,i=0;h=gb-16|0;gb=h;g=B(b,872)+a|0;a:{if(c){e=h+8|0;Db(e,a+1074312|0,90);if(!Cb(e)){t[(B(b,872)+a|0)+1075804|0]=c}t[(B(b,872)+a|0)+1075803|0]=c;break a}c=w[g+1075803|0]}e=g+1074992|0;f=c&255;i=d?i:!(v[a+480180>>2]&204473357);sP(a,b,f,i);b:{c:{if(v[a+480180>>2]!=16777216){break c}g=v[(B(b,872)+a|0)+1075648>>2];if(!g|!v[g+44>>2]){break c}b=c&255;if(!(b>>>0<240|d)){rP(a,e,f-240|0);break b}if(!(b>>>0<224|d)){qP(e,f-224|0);break b}pP(e,f);break b}if(v[a+480180>>2]==268435456){v[(B(b,872)+a|0)+1075700>>2]=1}if((c&255)>>>0>223&i){d:{d=f&15;if(!d){break d}c=c&240;if((c|0)!=224){if((c|0)!=240){break d}oP(a,e,d);break b}if(v[a+480180>>2]==524288){break d}tP(a,e,d);break b}if(v[a+480180>>2]!=524288){break b}}e:{if(!(t[(B(b,872)+a|0)+1075843|0]&1)){break e}if(v[a+1074416>>2]==1){c=h+8|0;Db(c,a+1074312|0,6);if(Cb(c)){break e}}if(v[a+480180>>2]&32832){break e}if(!(v[a+480208>>2]&2)|v[a+480180>>2]!=8){break b}}sk(a,e,(B(b,872)+a|0)+1075692|0,f<<2,0)}gb=h+16|0}function dq(a,b,c,d,e,f){var g=C(0),h=C(0),i=0,j=C(0),k=C(0),l=0;if((a|0)>=4){l=a>>>2|0;a=(c<<2)+b|0;d=a+(d<<2)|0;b=f<<2;while(1){c=d-4|0;h=z[c>>2];j=z[a>>2];k=z[d>>2];z[a>>2]=j+k;f=a-4|0;g=z[f>>2];z[f>>2]=g+z[c>>2];j=C(j-k);g=C(g-h);z[d>>2]=C(j*z[e>>2])-C(g*z[e+4>>2]);z[c>>2]=C(g*z[e>>2])+C(j*z[e+4>>2]);f=d-12|0;j=z[f>>2];c=a-8|0;g=z[c>>2];i=c;c=d-8|0;k=z[c>>2];z[i>>2]=g+k;i=a-12|0;h=z[i>>2];z[i>>2]=h+z[f>>2];i=c;g=C(g-k);c=b+e|0;h=C(h-j);z[i>>2]=C(g*z[c>>2])-C(h*z[c+4>>2]);z[f>>2]=C(h*z[c>>2])+C(g*z[c+4>>2]);e=d-20|0;j=z[e>>2];f=a-16|0;g=z[f>>2];i=f;f=d-16|0;k=z[f>>2];z[i>>2]=g+k;i=a-20|0;h=z[i>>2];z[i>>2]=h+z[e>>2];g=C(g-k);c=b+c|0;h=C(h-j);z[f>>2]=C(g*z[c>>2])-C(h*z[c+4>>2]);z[e>>2]=C(h*z[c>>2])+C(g*z[c+4>>2]);e=d-28|0;j=z[e>>2];f=a-24|0;g=z[f>>2];i=f;f=d-24|0;k=z[f>>2];z[i>>2]=g+k;i=a-28|0;h=z[i>>2];z[i>>2]=h+z[e>>2];g=C(g-k);c=b+c|0;h=C(h-j);z[f>>2]=C(g*z[c>>2])-C(h*z[c+4>>2]);z[e>>2]=C(h*z[c>>2])+C(g*z[c+4>>2]);e=b+c|0;d=d-32|0;a=a-32|0;c=l>>>0>1;l=l-1|0;if(c){continue}break}}}function nia(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;e=gb-48|0;gb=e;j=v[a+16>>2];f=Ud(e+16|0);v[f+8>>2]=a+112;v[f+16>>2]=v[a+128>>2];n=f,o=jg(b+327720|0,v[b+20>>2],(v[a+88>>2]&16384)>>>14|0),v[n+12>>2]=o;b=v[f+16>>2];if(b){n=f,o=lg(a+8|0,b),v[n>>2]=o;v[f+4>>2]=jb}k=v[a+24>>2];l=v[a+20>>2];h=v[a+4>>2];g=v[a>>2];v[e+8>>2]=g;v[e+12>>2]=h;i=v[a+12>>2];v[e>>2]=v[a+8>>2];v[e+4>>2]=i;if(d){while(1){i=0;v[e+40>>2]=g;v[e+44>>2]=m;h=(h<<1)+j|0;a:{if((b|0)<=0){break a}while(1){Id(v[f+8>>2],u[(i<<1)+h>>1]/4<<16>>16);Hd(v[f+8>>2],4);Ub(e+40|0,f);if((b|0)<2){break a}b=b-1|0;i=v[e+44>>2];continue}}d=d-1|0;b=v[f+8>>2];Ub(b,b+8|0);b=v[f+8>>2];g=v[b+4>>2];if(g){Id(b,u[h+(v[e+44>>2]<<1)>>1]/4<<16>>16);Hd(v[f+8>>2],g);b=v[f+8>>2];g=v[b>>2];v[b>>2]=g;v[b+4>>2]=0}b=ig(b,v[f+12>>2]);v[c>>2]=v[c>>2]+B(b,l);v[c+4>>2]=v[c+4>>2]+B(b,k);Ub(e+8|0,e);if(d){c=c+8|0;b=v[f+16>>2];g=v[e+8>>2];h=v[e+12>>2];continue}break}g=v[e+8>>2];h=v[e+12>>2]}v[a>>2]=g;v[a+4>>2]=h;gb=e+48|0}function FO(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0;e=gb-560|0;gb=e;u[e+558>>1]=b;a:{b:{if((b-1&65535)>>>0>254){break b}d=((b<<2)+a|0)+900380|0;f=v[d>>2];c:{if(f){c=GS(e,c);d=v[c+4>>2];b=f;v[b>>2]=v[c>>2];v[b+4>>2]=d;d=w[c+11|0]|w[c+12|0]<<8|(w[c+13|0]<<16|w[c+14|0]<<24);g=w[c+7|0]|w[c+8|0]<<8|(w[c+9|0]<<16|w[c+10|0]<<24);t[b+7|0]=g;t[b+8|0]=g>>>8;t[b+9|0]=g>>>16;t[b+10|0]=g>>>24;t[b+11|0]=d;t[b+12|0]=d>>>8;t[b+13|0]=d>>>16;t[b+14|0]=d>>>24;t[b+15|0]=w[c+15|0];d=v[c+44>>2];v[b+40>>2]=v[c+40>>2];v[b+44>>2]=d;d=v[c+36>>2];v[b+32>>2]=v[c+32>>2];v[b+36>>2]=d;d=v[c+28>>2];v[b+24>>2]=v[c+24>>2];v[b+28>>2]=d;d=v[c+20>>2];v[b+16>>2]=v[c+16>>2];v[b+20>>2]=d;eA(b+48|0,c+48|0);eA(b+68|0,c+68|0);eA(b+88|0,c+88|0);hc(b+108|0,c+108|0,448);sv(c);break c}b=wg(556);if(!b){f=0;v[d>>2]=0;break b}v[22656]=0;f=Q(1324,b|0,c|0)|0;c=v[22656];v[22656]=0;if((c|0)==1){break a}v[d>>2]=b}h=a,i=x[Le(a+480192|0,e+558|0)>>1],u[h+480192>>1]=i}gb=e+560|0;return f|0}a=P()|0;O()|0;Yb(b);S(a|0);L()}function Cja(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;h=gb-16|0;gb=h;e=v[a+48>>2];l=v[a+40>>2];m=v[a+36>>2];b=v[a+44>>2];o=v[a+16>>2];g=v[a+4>>2];j=v[a>>2];v[h+8>>2]=j;v[h+12>>2]=g;f=v[a+12>>2];v[h>>2]=v[a+8>>2];v[h+4>>2]=f;a:{if(d){while(1){j=u[(g<<1)+o>>1];i=v[a+60>>2];f=Lb(b,-16777216,16776704);n=v[a+64>>2];g=Lb(e,-16777216,16776704);j=j<<8;e=j;e=kqa(i,i>>31,e,e>>31);i=jb;k=kqa(n,n>>31,f,f>>31);f=k+e|0;e=jb+i|0;e=f>>>0<k>>>0?e+1|0:e;i=f;f=v[a+68>>2];g=kqa(f,f>>31,g,g>>31);f=i+g|0;e=jb+e|0;e=f>>>0<g>>>0?e+1|0:e;f=f+8388608|0;e=f>>>0<8388608?e+1|0:e;e=Jc(f,e,24);f=v[a+72>>2];g=v[a+32>>2];m=v[a+28>>2]+m|0;i=m>>12;n=(e|0)/256|0;v[c>>2]=v[c>>2]+B(i,n);l=g+l|0;k=l>>12;v[c+4>>2]=v[c+4>>2]+B(n,k);f=e-(f&j)|0;Ub(h+8|0,h);d=d-1|0;if(d){c=c+8|0;g=v[h+12>>2];e=b;b=f;continue}break}j=v[h+8>>2];g=v[h+12>>2];e=b;break a}k=l>>12;i=m>>12;f=b}v[a+40>>2]=l;v[a+20>>2]=i;v[a+36>>2]=m;v[a+48>>2]=e;v[a+44>>2]=f;v[a+24>>2]=k;v[a>>2]=j;v[a+4>>2]=g;gb=h+16|0}function Wd(a){var b=0,c=0,d=0,e=0,f=0;c=gb-32|0;gb=c;v[c+12>>2]=0;v[c+8>>2]=2532;d=v[c+12>>2];v[c>>2]=v[c+8>>2];v[c+4>>2]=d;d=v[c+4>>2];b=c+16|0;v[b+4>>2]=v[c>>2];v[b+8>>2]=d;v[b>>2]=a;d=gb-16|0;gb=d;e=a;if(v[a>>2]!=-1){yc(d,qT(d+8|0,b));b=d;a:{b:{c:{if(!v[e>>2]){ef(e,1);v[22656]=0;f=v[22656];v[22656]=0;d:{if((f|0)==1){break d}v[22656]=0;_(2538,b|0);b=v[22656];v[22656]=0;if((b|0)==1){break d}v[22656]=0;b=v[22656];v[22656]=0;if((b|0)==1){break d}v[e>>2]=-1;v[22656]=0;b=v[22656];v[22656]=0;if((b|0)==1){break d}v[22656]=0;b=v[22656];v[22656]=0;if((b|0)!=1){break a}}a=V(0)|0;O()|0;Z(a|0)|0;v[22656]=0;a=v[22656];v[22656]=0;e:{if((a|0)==1){break e}ef(e,0);v[22656]=0;a=v[22656];v[22656]=0;if((a|0)==1){break e}v[22656]=0;a=v[22656];v[22656]=0;if((a|0)==1){break e}v[22656]=0;X(2027);a=v[22656];v[22656]=0;if((a|0)!=1){break b}}a=P()|0;O()|0;v[22656]=0;X(20);d=v[22656];v[22656]=0;if((d|0)==1){break c}S(a|0);L()}break a}V(0)|0;O()|0;Bb()}L()}}gb=d+16|0;gb=c+32|0;return v[a+4>>2]-1|0}function Dja(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;h=gb-16|0;gb=h;e=v[a+48>>2];l=v[a+40>>2];m=v[a+36>>2];b=v[a+44>>2];o=v[a+16>>2];g=v[a+4>>2];j=v[a>>2];v[h+8>>2]=j;v[h+12>>2]=g;f=v[a+12>>2];v[h>>2]=v[a+8>>2];v[h+4>>2]=f;a:{if(d){while(1){j=t[g+o|0];i=v[a+60>>2];f=Lb(b,-16777216,16776704);n=v[a+64>>2];g=Lb(e,-16777216,16776704);j=j<<16;e=j;e=kqa(i,i>>31,e,e>>31);i=jb;k=kqa(n,n>>31,f,f>>31);f=k+e|0;e=jb+i|0;e=f>>>0<k>>>0?e+1|0:e;i=f;f=v[a+68>>2];g=kqa(f,f>>31,g,g>>31);f=i+g|0;e=jb+e|0;e=f>>>0<g>>>0?e+1|0:e;f=f+8388608|0;e=f>>>0<8388608?e+1|0:e;e=Jc(f,e,24);f=v[a+72>>2];g=v[a+32>>2];m=v[a+28>>2]+m|0;i=m>>12;n=(e|0)/256|0;v[c>>2]=v[c>>2]+B(i,n);l=g+l|0;k=l>>12;v[c+4>>2]=v[c+4>>2]+B(n,k);f=e-(f&j)|0;Ub(h+8|0,h);d=d-1|0;if(d){c=c+8|0;g=v[h+12>>2];e=b;b=f;continue}break}j=v[h+8>>2];g=v[h+12>>2];e=b;break a}k=l>>12;i=m>>12;f=b}v[a+40>>2]=l;v[a+20>>2]=i;v[a+36>>2]=m;v[a+48>>2]=e;v[a+44>>2]=f;v[a+24>>2]=k;v[a>>2]=j;v[a+4>>2]=g;gb=h+16|0}function n1(a,b,c,d,e,f,g,h){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;a=gb-16|0;gb=a;v[a+12>>2]=c;v[a+8>>2]=f;v[a+12>>2]=c;v[a+8>>2]=f;a:{b:{c:{b=v[a+12>>2];d:{if(d>>>0>b>>>0){while(1){c=v[b>>2];if(c>>>0>1114111|(c&-2048)==55296){break b}e:{if(c>>>0<=127){f=v[a+8>>2];b=1;if((g-f|0)<=0){break d}v[a+8>>2]=f+1;t[f|0]=c;break e}if(c>>>0<=2047){b=v[a+8>>2];if((g-b|0)<2){break c}v[a+8>>2]=b+1;t[b|0]=c>>>6|192;b=v[a+8>>2];v[a+8>>2]=b+1;t[b|0]=c&63|128;break e}b=v[a+8>>2];f=g-b|0;if(c>>>0<=65535){if((f|0)<3){break c}v[a+8>>2]=b+1;t[b|0]=c>>>12|224;b=v[a+8>>2];v[a+8>>2]=b+1;t[b|0]=c>>>6&63|128;b=v[a+8>>2];v[a+8>>2]=b+1;t[b|0]=c&63|128;break e}if((f|0)<4){break c}v[a+8>>2]=b+1;t[b|0]=c>>>18|240;b=v[a+8>>2];v[a+8>>2]=b+1;t[b|0]=c>>>12&63|128;b=v[a+8>>2];v[a+8>>2]=b+1;t[b|0]=c>>>6&63|128;b=v[a+8>>2];v[a+8>>2]=b+1;t[b|0]=c&63|128}b=v[a+12>>2]+4|0;v[a+12>>2]=b;if(b>>>0<d>>>0){continue}break}}b=0}break a}b=1;break a}b=2}v[e>>2]=v[a+12>>2];v[h>>2]=v[a+8>>2];gb=a+16|0;return b|0}function RI(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0;d=gb-208|0;gb=d;v[d+8>>2]=1;v[d+12>>2]=0;h=b<<2;a:{if(!h){break a}v[d+16>>2]=4;v[d+20>>2]=4;b=4;e=4;g=2;while(1){f=e;e=b;b=(b+4|0)+f|0;v[(d+16|0)+(g<<2)>>2]=b;g=g+1|0;if(b>>>0<h>>>0){continue}break}e=(a+h|0)-4|0;b:{if(e>>>0<=a>>>0){g=0;b=1;e=0;break b}g=1;b=1;while(1){c:{if((g&3)==3){cy(a,c,b,d+16|0);lt(d+8|0,2);b=b+2|0;break c}f=b-1|0;d:{if(y[(d+16|0)+(f<<2)>>2]>=e-a>>>0){kt(a,c,d+8|0,b,0,d+16|0);break d}cy(a,c,b,d+16|0)}if((b|0)==1){jt(d+8|0,1);b=0;break c}jt(d+8|0,f);b=1}f=v[d+8>>2];g=f|1;v[d+8>>2]=g;a=a+4|0;if(e>>>0>a>>>0){continue}break}g=f>>>0>1;e=v[d+12>>2]!=0}kt(a,c,d+8|0,b,0,d+16|0);if(!(e?1:(b|0)!=1|g)){break a}while(1){e:{if((b|0)<=1){f=d+8|0;e=QI(f);lt(f,e);g=v[d+8>>2];b=b+e|0;break e}f=d+8|0;jt(f,2);v[d+8>>2]=v[d+8>>2]^7;lt(f,1);i=a-4|0;h=d+16|0;e=b-2|0;kt(i-v[h+(e<<2)>>2]|0,c,f,b-1|0,1,h);jt(f,1);g=v[d+8>>2]|1;v[d+8>>2]=g;kt(i,c,f,e,1,h);b=e}a=a-4|0;if(v[d+12>>2]|(g|0)!=1|(b|0)!=1){continue}break}}gb=d+208|0}function lT(a,b,c){var d=0,e=0;d=w[a|0]&15;t[a|0]=w[d+33392|0];a:{b:{c:{switch(d|0){case 0:if(c>>>0>50?w[b|0]:0){break b}t[a|0]=0;return;case 5:d:{d=w[b|0];e=d&15;if((e|0)!=2){d=d&240;if((d|0)!=32){break d}}t[a|0]=20;t[b|0]=159;return}e:{if((e|0)!=12){if((d|0)!=192){break b}if(c>>>0>50){break e}break b}if(c>>>0<51){break b}}t[a|0]=25;t[b|0]=0;return;case 7:if(c>>>0>51){break b}t[a|0]=0;return;case 10:a=w[b|0]&240;if(!a){break b}t[b|0]=a;return;case 11:t[b|0]=B(w[b|0]&15,17);return;case 12:t[b|0]=w[b|0]>>>2;return;case 13:a=w[b|0];t[b|0]=B(a>>>4|0,10)+(a&15);return;case 14:f:{switch((w[b|0]>>>4|0)-1|0){case 0:t[a|0]=2;break a;case 1:t[a|0]=3;break a;case 7:if(c>>>0<52){break b}t[a|0]=20;t[b|0]=w[b|0]&15|96;return;case 8:t[a|0]=15;t[b|0]=w[b|0]&15;return;case 9:t[a|0]=11;t[b|0]=w[b|0]<<4|15;return;case 10:t[a|0]=11;break a;case 11:case 12:break f;default:break b}}t[a|0]=20;return;case 15:break c;default:break b}}if(w[b|0]<48){break b}t[a|0]=17}return}t[b|0]=w[b|0]|240}function dL(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;d=gb-32|0;gb=d;a:{b:{c:{d:{e:{f:{g:{if(Bj(a)){zh(d+24|0);break g}c=d+8|0;po(c,a);v[22656]=0;c=T(2084,c|0)|0;e=v[22656];v[22656]=0;if((e|0)==1){break f}v[d+24>>2]=c;Yf(d+8|0)}if(Bj(a)){c=a+36|0}else{c=v[d+24>>2]}if((b|0)==-1){f=4194304;e=0;break d}if((b|0)>=0){e=b;if((ko(c)|0)>(b|0)){break d}}b=ba(8)|0;v[22656]=0;c=Q(70,d+8|0,8199)|0;a=v[22656];v[22656]=0;if((a|0)==1){break e}rc(b,c);v[22656]=0;U(186,b|0,54952,1936);a=v[22656];v[22656]=0;if((a|0)!=1){break a}a=P()|0;O()|0;vb(c);break c}a=P()|0;O()|0;Yf(d+8|0);break b}a=P()|0;O()|0;ca(b|0);break c}v[a+8>>2]=b;b=a+24|0;g=v[b>>2];v[g+480208>>2]=v[g+480208>>2]&-4194305|f;b=v[b>>2];f=w[Xl(c,e)+16|0];v[22656]=0;Qi(b+484360|0,f);b=v[22656];v[22656]=0;h:{if((b|0)==1){break h}b=Xl(c,e);c=v[b+8>>2];b=v[b+12>>2];v[22656]=0;+oa(1944,a|0,b|0,c|0);b=v[22656];v[22656]=0;if((b|0)==1){break h}v[a+16>>2]=0;v[a+20>>2]=0;xl(d+24|0);gb=d+32|0;return}a=P()|0;O()|0}xl(d+24|0)}S(a|0)}L()}function Pfa(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0;d=gb-32|0;gb=d;e=d;b=gb-32|0;gb=b;v[b+16>>2]=1073741824;u[b+22>>1]=12;v[b+12>>2]=15;c=sf(64);v[22656]=0;f=T(1316,c|0)|0;g=v[22656];v[22656]=0;a:{b:{c:{if((g|0)!=1){c=os(b+8|0,f);f=v[c>>2];v[22656]=0;R(1317,f|0,a|0);a=v[22656];v[22656]=0;if((a|0)==1){break c}a=v[c>>2];v[22656]=0;a=W(1318,a|0,b+22|0,b+16|0)|0;f=v[22656];v[22656]=0;if((f|0)==1){break c}d:{if(!a){gA(b+24|0);break d}a=v[c>>2];v[22656]=0;R(1319,a|0,b+12|0);a=v[22656];v[22656]=0;if((a|0)==1){break c}pi(b+24|0,c)}Jg(c);gb=b+32|0;a=v[b+24>>2];break a}a=P()|0;O()|0;Yb(c);break b}a=P()|0;O()|0;Jg(c)}S(a|0);L()}v[e+24>>2]=a;a=0;e:{f:{g:{while(1){b=v[d+24>>2];v[22656]=0;u[d+22>>1]=a;e=Q(2,d+8|0,(a<<2)+38432|0)|0;c=v[22656];v[22656]=0;if((c|0)==1){break g}v[22656]=0;U(1315,b|0,d+22|0,e|0);b=v[22656];v[22656]=0;if((b|0)==1){break f}vb(e);a=a+1|0;if((a|0)!=12){continue}break}gb=d+32|0;return v[d+24>>2]}a=P()|0;O()|0;break e}a=P()|0;O()|0;vb(e)}Jg(d+24|0);S(a|0);L()}function ffa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;f=gb-32|0;gb=f;g=gb-16|0;gb=g;d=b;c=a+33|0;v[d>>2]=w[c+206|0]|w[c+207|0]<<8;SN(c,d+48|0,w[c+192|0],w[c+200|0],w[c+194|0],w[c+195|0],w[c+196|0],0);SN(c,d+68|0,w[c+193|0],w[c+201|0],w[c+197|0],w[c+198|0],w[c+199|0],1);h=d+236|0;while(1){j=w[c+e|0];k=vd(h,e+12|0),l=j,u[k>>1]=l;e=e+1|0;if((e|0)!=96){continue}break}if(w[c+208|0]){t[d+31|0]=w[c+209|0]+1;h=w[d+31|0];a:{b:{if(!h){e=1;break b}e=16;if(h>>>0<17){break a}}t[d+31|0]=e}u[g+14>>1]=w[c+210|0]|w[c+211|0]<<8;u[g+12>>1]=127;k=d,l=w[Pc(g+14|0,g+12|0)|0]+1|0,t[k+30|0]=l}t[d+33|0]=w[c+212|0];gb=g+16|0;c=b+236|0;while(1){d=0;e=a+i|0;if(w[e+33|0]<(w[a+27|0]|w[a+28|0]<<8)>>>0){d=w[e+33|0]}k=vd(c,i+12|0),l=d,u[k>>1]=l;i=i+1|0;if((i|0)!=96){continue}break}Rk(f,3,a+4|0);d=f+16|0;Bc(d,f);v[22656]=0;Q(301,b+492|0,d|0)|0;d=v[22656];v[22656]=0;if((d|0)!=1){vb(f+16|0);if(!w[a+241|0]){t[b+30|0]=w[a+26|0]}gb=f+32|0;return}a=P()|0;O()|0;vb(f+16|0);S(a|0);L()}function yW(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0;g=gb-16|0;gb=g;t[g+14|0]=d;t[g+15|0]=c;t[g+13|0]=e;t[g+12|0]=f;if((d-1&255)>>>0<=5){t[g+14|0]=d+15}wW(g+15|0,g+13|0);wW(g+14|0,g+12|0);a:{b:{d=w[g+15|0];c:{if((d|0)==10){c=w[g+12|0];d=w[g+13|0]&15;t[g+13|0]=d?-1:c;f=c|d<<8;d=w[g+14|0];if((d|0)!=10){break c}d=0;t[g+14|0]=0;break c}if(w[g+14|0]!=10){break b}c=w[g+12|0]&15;t[g+12|0]=c?-1:0;f=c<<8}if(f-256>>>0>4294967038){break b}if(Fj(d)>>>0>=Fj(10)>>>0){break b}t[a+5|0]=f;t[a+2|0]=15;t[a+3|0]=10;t[a+4|0]=f>>>8;break a}if(b){t[a+2|0]=1;t[a+4|0]=b+2>>>2}tz(g+15|0,g+13|0,g+14|0,g+12|0);c=w[g+15|0];d:{if(!c){break d}d=w[g+14|0];if(!d){t[g+14|0]=c;t[g+12|0]=w[g+13|0];t[g+15|0]=0;break d}if(!((c|0)==20|(c|0)!=(d|0))){t[g+15|0]=0;break d}if(!b){vo(g+8|0,g+15|0,g+13|0,g+14|0,g+12|0);t[a+2|0]=w[g+15|0];t[a+4|0]=w[g+13|0];break d}if(Fj(c)>>>0<=Fj(w[g+14|0])>>>0){break d}fi(g+15|0,g+14|0);fi(g+13|0,g+12|0)}t[a+3|0]=w[g+14|0];t[a+5|0]=w[g+12|0]}gb=g+16|0}function Sea(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;e=gb-16|0;gb=e;ud(c,0);d=a+36|0;u[e+14>>1]=w[d|0]|w[d+1|0]<<8;u[e+12>>1]=32767;f=c,g=(x[Pc(e+14|0,e+12|0)>>1]<<8>>>0)/32767|0,u[f+28>>1]=g;d=a+38|0;u[e+10>>1]=w[d|0]|w[d+1|0]<<8;u[e+8>>1]=32767;f=c,g=(x[Pc(e+10|0,e+8|0)>>1]<<8>>>0)/32767|0,u[f+30>>1]=g;u[c+32>>1]=64;d=a+44|0;v[c>>2]=w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24);d=a+48|0;v[c+4>>2]=w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24);d=a+52|0;v[c+8>>2]=w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24);d=a+56|0;v[c+24>>2]=w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24);d=b+166|0;if(w[d|0]<=4){t[c+38|0]=w[w[d|0]+49066|0]}t[c+39|0]=w[b+167|0];d=b+171|0;t[c+41|0]=(w[d|0]|w[d+1|0]<<8)>>>4;b=b+169|0;b=(w[b|0]|w[b+1|0]<<8)>>>2|0;t[c+40|0]=b;if(w[c+41|0]|b&255){t[c+39|0]=w[c+39|0]^-1}a=a+40|0;if(w[a|0]&4){u[c+34>>1]=x[c+34>>1]|1}if(w[a|0]&8){u[c+34>>1]=x[c+34>>1]|2}if(w[a|0]&16){u[c+34>>1]=x[c+34>>1]|4}if(w[a|0]&32){u[c+34>>1]=x[c+34>>1]|32}gb=e+16|0}function Y8(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;if(y[a+4>>2]<y[wb(a)>>2]){c=gb-16|0;gb=c;v[c>>2]=a;a=v[a+4>>2];v[c+4>>2]=a;v[c+8>>2]=a+24;BK(v[c+4>>2],b);v[c+4>>2]=v[c+4>>2]+24;$b(c);gb=c+16|0;return}i=gb-32|0;gb=i;j=wb(a);d=i+8|0;e=a;h=ko(a)+1|0;f=gb-16|0;gb=f;v[f+12>>2]=h;a:{c=EV();if(h>>>0<=c>>>0){e=kv(e);if(e>>>0<c>>>1>>>0){v[f+8>>2]=e<<1;c=v[Lc(f+8|0,f+12|0)>>2]}gb=f+16|0;break a}Sc();L()}h=ko(a);f=gb-16|0;gb=f;v[f+12>>2]=0;kf(d+12|0,j);if(c){e=c;if(c>>>0>=178956971){rd(8445);L()}g=Mc(B(e,24),8)}v[d>>2]=g;e=B(h,24)+g|0;v[d+8>>2]=e;v[d+4>>2]=e;k=dc(d),l=B(c,24)+g|0,v[k>>2]=l;gb=f+16|0;c=d;BK(v[c+8>>2],b);v[c+8>>2]=v[c+8>>2]+24;b=a;e=c+4|0;g=v[a>>2];a=v[a+4>>2]-g|0;f=v[e>>2]+B((a|0)/-24|0,24)|0;v[e>>2]=f;if((a|0)>0){hc(f,g,a)}wc(b,e);wc(b+4|0,d+8|0);wc(wb(b),dc(d));v[d>>2]=v[d+4>>2];a=c;b=v[c+8>>2];d=v[c+4>>2];if((b|0)!=(d|0)){v[a+8>>2]=b+B(((b-d|0)-24>>>0)/24^-1,24)}a=v[c>>2];if(a){Iy(a,(v[dc(c)>>2]-v[c>>2]|0)/24|0)}gb=i+32|0}function oia(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;e=gb-48|0;gb=e;j=v[a+16>>2];f=Ud(e+16|0);v[f+8>>2]=a+112;v[f+16>>2]=v[a+128>>2];n=f,o=jg(b+327720|0,v[b+20>>2],(v[a+88>>2]&16384)>>>14|0),v[n+12>>2]=o;b=v[f+16>>2];if(b){n=f,o=lg(a+8|0,b),v[n>>2]=o;v[f+4>>2]=jb}k=v[a+24>>2];l=v[a+20>>2];h=v[a+4>>2];g=v[a>>2];v[e+8>>2]=g;v[e+12>>2]=h;i=v[a+12>>2];v[e>>2]=v[a+8>>2];v[e+4>>2]=i;if(d){while(1){i=0;v[e+40>>2]=g;v[e+44>>2]=m;h=h+j|0;a:{if((b|0)<=0){break a}while(1){Id(v[f+8>>2],t[h+i|0]<<6);Hd(v[f+8>>2],4);Ub(e+40|0,f);if((b|0)<2){break a}b=b-1|0;i=v[e+44>>2];continue}}d=d-1|0;b=v[f+8>>2];Ub(b,b+8|0);b=v[f+8>>2];g=v[b+4>>2];if(g){Id(b,t[h+v[e+44>>2]|0]<<6);Hd(v[f+8>>2],g);b=v[f+8>>2];g=v[b>>2];v[b>>2]=g;v[b+4>>2]=0}b=ig(b,v[f+12>>2]);v[c>>2]=v[c>>2]+B(b,l);v[c+4>>2]=v[c+4>>2]+B(b,k);Ub(e+8|0,e);if(d){c=c+8|0;b=v[f+16>>2];g=v[e+8>>2];h=v[e+12>>2];continue}break}g=v[e+8>>2];h=v[e+12>>2]}v[a>>2]=g;v[a+4>>2]=h;gb=e+48|0}function e0(a){a=a|0;var b=0,c=0,d=0,e=0;c=gb+-64|0;gb=c;a=Kb(a);v[22656]=0;b=ga(147)|0;d=v[22656];v[22656]=0;a:{b:{if((d|0)==1){break b}c:{d:{if(!b){break d}v[22656]=0;d=Q(2,c+32|0,6094)|0;b=v[22656];v[22656]=0;if((b|0)==1){break c}v[22656]=0;b=ga(147)|0;e=v[22656];v[22656]=0;e:{f:{g:{h:{if((e|0)==1){break h}v[22656]=0;v[c+12>>2]=b;R(153,c+16|0,c+12|0);b=v[22656];v[22656]=0;if((b|0)==1){break h}v[22656]=0;U(3,c+48|0,d|0,c+16|0);b=v[22656];v[22656]=0;if((b|0)==1){break g}b=c+48|0;Eb(a,b);vb(b);vb(c+16|0);vb(d);v[22656]=0;b=ga(149)|0;d=v[22656];v[22656]=0;if((d|0)==1){break b}if(!b){break e}v[22656]=0;Q(154,a|0,14604)|0;b=v[22656];v[22656]=0;if((b|0)!=1){break e}break b}b=P()|0;O()|0;break f}b=P()|0;O()|0;vb(c+16|0)}vb(d);break a}v[22656]=0;b=ga(148)|0;d=v[22656];v[22656]=0;if((d|0)==1){break b}if(!b){break d}v[22656]=0;Q(154,a|0,13875)|0;b=v[22656];v[22656]=0;if((b|0)==1){break b}}gb=c- -64|0;return}b=P()|0;O()|0;break a}b=P()|0;O()|0}vb(a);S(b|0);L()}function Qja(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0;h=zb(b);a:{b:{c:{d:{e:{f:{g:{while(1){b=c;if(!c){break g}c=b-1|0;if(!w[h+c|0]){continue}break}if((d|0)!=4){break e}c=0;break f}if((d|0)==4){break d}f=(d|0)==2;break c}while(1){h:{i:{j:{d=c+h|0;i=w[d|0];switch(i-10|0){case 0:break i;case 3:break j;default:break h}}e=e+1|0;break h}f=f+1|0}g=c?(w[d-1|0]==13&(i|0)==10)+g|0:g;c=c+1|0;if((c|0)!=(b|0)){continue}break}break d}f=(d|0)==2;break b}k:{if((e|0)==(f|0)){d=2;if((e|0)==(g|0)){break k}}if(e){d=0;if(!f){break k}}d=e?3:f?1:3}f=(d|0)==2;if(b){break b}}b=0;g=1;e=0;break a}g=0;c=0;e=0;while(1){e=e+1|0;c=((w[c+h|0]==13&f)+c|0)+1|0;if(c>>>0<b>>>0){continue}break}}Se(a);Rq(a,e);if(!g){g=(d|0)==1?32:13;d=d&-3?13:32;c=0;while(1){l:{m:{n:{o:{e=t[c+h|0];switch(e-10|0){case 1:case 2:break l;case 0:break m;case 3:break n;default:break o}}if(e){break l}e=32;break l}c=c+f|0;e=g;break l}e=d}Oo(a,e);c=c+1|0;if(c>>>0<b>>>0){continue}break}}return 1}function Bia(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;f=gb-32|0;gb=f;j=v[a+24>>2];k=v[a+20>>2];l=v[a+16>>2];i=v[a+4>>2];e=i;g=v[a>>2];v[f+24>>2]=g;v[f+28>>2]=e;i=v[a+12>>2];v[f+16>>2]=v[a+8>>2];v[f+20>>2]=i;i=a;if(d){while(1){h=((((e&2147483647)<<1|g>>>31)&2147483646)<<1)+l|0;a=(((g>>>16|0)+4&131064)<<1)+b|0;m=u[a+38>>1];n=u[a+36>>1];o=u[a+34>>1];p=u[a+32>>1];q=u[a+30>>1];r=u[a+28>>1];s=u[a+26>>1];t=u[a+24>>1];g=0;a=1;while(1){e=g<<1;v[(f+8|0)+(g<<2)>>2]=(((((B(u[(e|8)+h>>1],o)+B(u[(e|4)+h>>1],p)|0)+B(u[(e|12)+h>>1],n)|0)+B(u[(e|16)+h>>1],m)|0)/2|0)+((((B(u[(e|-8)+h>>1],s)+B(u[(e|-12)+h>>1],t)|0)+B(u[(e|-4)+h>>1],r)|0)+B(u[e+h>>1],q)|0)/2|0)|0)/16384;e=a;a=0;g=1;if(e){continue}break}v[c>>2]=v[c>>2]+B(v[f+8>>2],k);v[c+4>>2]=v[c+4>>2]+B(v[f+12>>2],j);Ub(f+24|0,f+16|0);d=d-1|0;if(d){c=c+8|0;g=v[f+24>>2];e=v[f+28>>2];continue}break}g=v[f+24>>2];e=v[f+28>>2]}v[i>>2]=g;v[i+4>>2]=e;gb=f+32|0}function rja(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;h=gb-16|0;gb=h;f=v[a+48>>2];m=v[a+24>>2];n=v[a+20>>2];b=v[a+44>>2];o=v[a+16>>2];e=v[a+4>>2];i=v[a>>2];v[h+8>>2]=i;v[h+12>>2]=e;g=v[a+12>>2];v[h>>2]=v[a+8>>2];v[h+4>>2]=g;a:{if(!d){g=b;b=f;break a}while(1){g=e+o|0;p=t[g+1|0];g=t[g|0];e=v[a+60>>2];q=e;r=e>>31;e=Lb(b,-16777216,16776704);j=v[a+64>>2];f=Lb(f,-16777216,16776704);e=kqa(j,j>>31,e,e>>31);j=jb;k=e;e=v[a+68>>2];l=kqa(e,e>>31,f,f>>31);e=k+l|0;f=jb+j|0;f=e>>>0<l>>>0?f+1|0:f;k=e;e=((B(p-g|0,i>>>10&4194048)|0)/16384|0)+(g<<8)<<8;i=kqa(q,r,e,e>>31);g=k+i|0;f=jb+f|0;f=g>>>0<i>>>0?f+1|0:f;g=g+8388608|0;f=g>>>0<8388608?f+1|0:f;f=Jc(g,f,24);g=v[a+72>>2];i=(f|0)/256|0;v[c>>2]=v[c>>2]+B(i,n);v[c+4>>2]=v[c+4>>2]+B(i,m);g=f-(e&g)|0;Ub(h+8|0,h);d=d-1|0;if(d){c=c+8|0;i=v[h+8>>2];e=v[h+12>>2];f=b;b=g;continue}break}i=v[h+8>>2];e=v[h+12>>2]}v[a+48>>2]=b;v[a+44>>2]=g;v[a>>2]=i;v[a+4>>2]=e;gb=h+16|0}function Pla(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;c=gb+-64|0;gb=c;m=c,n=nf(a)>>>5|0,u[m+32>>1]=n;u[c+16>>1]=3999;m=b,n=x[Pc(c+32|0,c+16|0)>>1],u[m+480190>>1]=n;a:{if(x[b+480190>>1]){h=c+58|0;i=c+56|0;j=c+62|0;l=c+52|0;k=c+60|0;g=1;while(1){d=g&65535;f=Bk(b,d);e=c+32|0;gv(a,e);ud(f,0);_j(c,2,e);e=c+16|0;Bc(e,c);v[22656]=0;Q(301,((d<<5)+b|0)+946304|0,e|0)|0;d=v[22656];v[22656]=0;if((d|0)==1){break a}d=c+16|0;vb(d);v[f+24>>2]=8287;m=c,n=Ib(w[k|0]|w[k+1|0]<<8),u[m+16>>1]=n;u[c>>1]=64;m=f,n=x[Pc(d,c)>>1]<<2,u[m+30>>1]=n;d=l;m=f,n=Xb(w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24))&-2,v[m>>2]=n;d=Ib(w[j|0]|w[j+1|0]<<8);m=Fe(f+68|0,0),n=d,v[m>>2]=n;d=Ib(w[i|0]|w[i+1|0]<<8);e=Ib(w[h|0]|w[h+1|0]<<8);b:{if(e>>>0<2){break b}e=d+e<<1;if(e>>>0>y[f>>2]){break b}v[f+16>>2]=e;v[f+12>>2]=d<<1;u[f+34>>1]=x[f+34>>1]|8}g=g+1|0;if(x[b+480190>>1]>=(g&65535)>>>0){continue}break}}gb=c- -64|0;return}a=P()|0;O()|0;vb(c+16|0);S(a|0);L()}function xL(a,b){var c=0,d=0,e=0,f=0,g=0;c=v[a>>2];v[a>>2]=b;if(c){v[22656]=0;b=c;T(1291,b|0)|0;a=v[22656];v[22656]=0;a:{if((a|0)!=1){c=v[b+4>>2];if(c){a=c;Fk(a);if(v[a>>2]){f=a;g=v[a>>2];d=v[a+4>>2];b:{while(1){if((d|0)==(g|0)){break b}e=wb(f);v[22656]=0;d=d-4|0;R(1326,e|0,d|0);e=v[22656];v[22656]=0;if((e|0)!=1){continue}break}V(0)|0;O()|0;Bb();L()}v[f+4>>2]=g;ai(wb(a),v[a>>2],pe(a))}Yb(c)}v[b+4>>2]=0;rA(b+1298368|0);mu(b+1298304|0);vb(b+1298292|0);vb(b+1298280|0);vb(b+1298268|0);lu(b+1298264|0);ku(b+1298260|0);Eq(b+1298224|0);a=b+946300|0;c=b+906300|0;while(1){a=Bq(a-160|0);if((c|0)!=(a|0)){continue}break}Ju(b+484360|0);pA(b+484344|0);Nc(b+480248|0);break a}V(0)|0;O()|0;rA(b+1298368|0);mu(b+1298304|0);vb(b+1298292|0);vb(b+1298280|0);vb(b+1298268|0);lu(b+1298264|0);ku(b+1298260|0);Eq(b+1298224|0);a=b+946300|0;c=b+906300|0;while(1){a=Bq(a-160|0);if((c|0)!=(a|0)){continue}break}Ju(b+484360|0);pA(b+484344|0);Nc(b+480248|0);Bb();L()}Yb(b)}}function qja(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;h=gb-16|0;gb=h;f=v[a+48>>2];m=v[a+24>>2];n=v[a+20>>2];b=v[a+44>>2];o=v[a+16>>2];e=v[a+4>>2];i=v[a>>2];v[h+8>>2]=i;v[h+12>>2]=e;g=v[a+12>>2];v[h>>2]=v[a+8>>2];v[h+4>>2]=g;a:{if(!d){g=b;b=f;break a}while(1){g=(e<<1)+o|0;p=u[g+2>>1];g=u[g>>1];e=v[a+60>>2];q=e;r=e>>31;e=Lb(b,-16777216,16776704);j=v[a+64>>2];f=Lb(f,-16777216,16776704);e=kqa(j,j>>31,e,e>>31);j=jb;k=e;e=v[a+68>>2];l=kqa(e,e>>31,f,f>>31);e=k+l|0;f=jb+j|0;f=e>>>0<l>>>0?f+1|0:f;k=e;e=g+((B(p-g|0,i>>>18|0)|0)/16384|0)<<8;i=kqa(q,r,e,e>>31);g=k+i|0;f=jb+f|0;f=g>>>0<i>>>0?f+1|0:f;g=g+8388608|0;f=g>>>0<8388608?f+1|0:f;f=Jc(g,f,24);g=v[a+72>>2];i=(f|0)/256|0;v[c>>2]=v[c>>2]+B(i,n);v[c+4>>2]=v[c+4>>2]+B(i,m);g=f-(e&g)|0;Ub(h+8|0,h);d=d-1|0;if(d){c=c+8|0;i=v[h+8>>2];e=v[h+12>>2];f=b;b=g;continue}break}i=v[h+8>>2];e=v[h+12>>2]}v[a+48>>2]=b;v[a+44>>2]=g;v[a>>2]=i;v[a+4>>2]=e;gb=h+16|0}function cz(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=C(0);b=gb+-64|0;gb=b;d=v[a+20>>2];a:{if(!d){break a}if(oc(d+4|0)>>>0<4){break a}Vd(b+32|0,v[a+20>>2]+4|0);d=Ud(b+24|0);c=v[b+36>>2];v[b+16>>2]=v[b+32>>2];v[b+20>>2]=c;c=v[d+4>>2];v[b+8>>2]=v[d>>2];v[b+12>>2]=c;d=VX(b+40|0,b+16|0,b+8|0);v[22656]=0;c=T(192,d|0)|0;f=v[22656];v[22656]=0;b:{if((f|0)!=1){if(c){break b}c=v[v[a>>2]+40>>2];v[22656]=0;c=T(c|0,a|0)|0;f=v[22656];v[22656]=0;c:{if((f|0)==1){break c}if(oc(v[a+20>>2]+4|0)-4>>>0<c<<2>>>0){break b}e=v[v[a>>2]+172>>2];f=0;v[22656]=0;R(e|0,a|0,-1);e=v[22656];v[22656]=0;if((e|0)==1){break c}if(c){while(1){v[22656]=0;g=C(Ba(635,d|0));e=v[22656];v[22656]=0;if((e|0)==1){break c}e=v[v[a>>2]+44>>2];v[22656]=0;Aa(e|0,a|0,f|0,C(g));e=v[22656];v[22656]=0;if((e|0)==1){break c}f=f+1|0;if((c|0)!=(f|0)){continue}break}}c=v[v[a>>2]+176>>2];v[22656]=0;_(c|0,a|0);a=v[22656];v[22656]=0;if((a|0)!=1){break b}}}a=P()|0;O()|0;xb(d);S(a|0);L()}xb(d)}gb=b- -64|0}function Of(a){a=a|0;var b=0;a:{b:{switch(w[a+3|0]){case 0:if(!w[a+5|0]){break a}t[a+3|0]=1;return;case 1:t[a+3|0]=2;return;case 2:t[a+3|0]=3;return;case 3:t[a+3|0]=4;return;case 4:t[a+3|0]=5;return;case 5:t[a+3|0]=6;return;case 6:t[a+3|0]=7;return;case 7:t[a+3|0]=8;return;case 8:t[a+3|0]=9;return;case 9:t[a+3|0]=10;return;case 10:t[a+3|0]=11;return;case 11:t[a+3|0]=12;return;case 12:t[a+3|0]=13;return;case 13:t[a+3|0]=14;b=a;a=w[a+5|0];t[b+5|0]=B(a>>>4|0,10)+(a&15);return;case 14:t[a+3|0]=19;return;case 15:if(w[a+5|0]<=31){t[a+3|0]=16;return}t[a+3|0]=17;return;case 16:t[a+3|0]=23;return;case 17:t[a+3|0]=24;return;case 20:t[a+3|0]=25;return;case 21:t[a+3|0]=30;return;case 25:t[a+3|0]=29;return;case 27:t[a+3|0]=15;return;case 29:t[a+3|0]=18;return;case 32:t[a+3|0]=37;return;case 33:t[a+3|0]=28;return;case 34:t[a+3|0]=27;return;case 35:t[a+3|0]=31;return;case 36:t[a+3|0]=32;return;case 38:t[a+3|0]=34;return;default:break b}}t[a+3|0]=0}}function Tia(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;f=gb-16|0;gb=f;a:{b:{c:{g=v[a+12>>2];h=v[a+8>>2];d:{if((g|0)<=1&h>>>0<=805306368|(g|0)<=0){if((g|0)>=-2&h>>>0>=3489660928|(g|0)>-2){break c}if((g|0)==-2&h>>>0>2147483647|g>>>0>4294967294){break d}break b}if((g|0)==1&h>>>0>2147483648|g>>>0>1){break b}}i=b+196648|0;break a}i=b+131112|0;break a}i=b+262184|0}j=v[a+16>>2];k=v[a+24>>2];l=v[a+20>>2];b=v[a+4>>2];e=v[a>>2];v[f+8>>2]=e;v[f+12>>2]=b;v[f>>2]=h;v[f+4>>2]=g;if(d){while(1){b=(b<<1)+j|0;e=(e>>>16&65520)+i|0;b=(((((((B(u[b-4>>1],u[e+2>>1])+B(u[b-6>>1],u[e>>1])|0)+B(u[b-2>>1],u[e+4>>1])|0)+B(u[b>>1],u[e+6>>1])|0)+B(u[b+2>>1],u[e+8>>1])|0)+B(u[b+4>>1],u[e+10>>1])|0)+B(u[b+6>>1],u[e+12>>1])|0)+B(u[b+8>>1],u[e+14>>1])|0)/32768|0;v[c>>2]=v[c>>2]+B(b,l);v[c+4>>2]=v[c+4>>2]+B(b,k);Ub(f+8|0,f);d=d-1|0;if(d){c=c+8|0;e=v[f+8>>2];b=v[f+12>>2];continue}break}e=v[f+8>>2];b=v[f+12>>2]}v[a>>2]=e;v[a+4>>2]=b;gb=f+16|0}function fg(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;c=gb-80|0;gb=c;d=v[a+28>>2];oo(v[v[d>>2]-12>>2]+d|0,0);if(!nd(a,4)){Uy(a)}a:{if(!v[a+4>>2]){break a}if(nd(a,6)){break a}if(nd(a,7)){break a}g=v[a+28>>2];e=v[a+84>>2];h=B(v[a+20>>2],v[a+4>>2]);f=h+v[a+80>>2]|0;e=sh(c- -64|0,f,f>>>0<h>>>0?e+1|0:e);f=v[e+12>>2];v[c+24>>2]=v[e+8>>2];v[c+28>>2]=f;d=v[e+4>>2];v[c+16>>2]=v[e>>2];v[c+20>>2]=d;lk(g,c+16|0)}d=0;b:{if(!nd(a,5)){break b}g=0;e=a+44|0;h=uf(e);d=0;if(!h){break b}d=a+32|0;while(1){c:{f=(v[a+96>>2]+g>>>0)%(h>>>0)|0;if(y[Tc(e,f)>>2]>=oc(d)>>>0){break c}i=qo(c+48|0,lc(d,v[Tc(e,f)>>2]),x[Tc(e,f)+12>>1]);j=Xy(b,i);Hb(i);if(!j){break c}v[a+96>>2]=(f+1>>>0)%(h>>>0);b=v[Tc(e,f)+4>>2];if(b){h=v[a+28>>2];g=b+v[a+8>>2]|0;a=v[a+12>>2];a=sh(c+32|0,g,b>>>0>g>>>0?a+1|0:a);b=v[a+12>>2];v[c+8>>2]=v[a+8>>2];v[c+12>>2]=b;b=v[a+4>>2];v[c>>2]=v[a>>2];v[c+4>>2]=b;lk(h,c)}d=Tc(e,f);break b}g=g+1|0;if((h|0)!=(g|0)){continue}break}d=0}gb=c+80|0;return d}function uu(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;f=gb-16|0;gb=f;e=f+8|0;g=a+1074312|0;Db(e,g,77);a:{if(j=Cb(e),k=0,l=v[c+88>>2]&134218752,l?j:k){break a}b:{c:{i=c;if(d){e=w[c+841|0];if(!e){break c}d=e-1|0;t[c+841|0]=d;if(d&255){break b}c=f+8|0;Db(c,g,16);if(!Cb(c)&v[a+480180>>2]!=2){break a}a=v[b+48>>2]+1|0}else{a=v[b+48>>2]}v[i+764>>2]=a;break a}e=f+8|0;Db(e,g,17);if(!(Cb(e)|v[a+480180>>2]&3|!x[a+480188>>1])){e=b+616|0;while(1){if(w[e+841|0]?(c|0)!=(e|0):0){break a}e=e+872|0;h=h+1|0;if(x[a+480188>>1]>(h&65535)>>>0){continue}break}}t[c+841|0]=d}d=v[c+764>>2];v[b+56>>2]=d;d:{if((d|0)==-1){break d}e:{if(v[b+60>>2]==-1){break e}e=f+8|0;Db(e,g,68);if(!Cb(e)){break e}v[b+60>>2]=d}v[b+64>>2]=d;d=f+8|0;Db(d,g,103);if(!Cb(d)){break d}u[b+68>>1]=65535}if(!x[a+480188>>1]|v[a+480180>>2]!=2){break a}d=0;while(1){e=B(d,872)+b|0;v[e+1380>>2]=v[c+764>>2];t[e+1457|0]=w[c+841|0];d=d+1|0;if(d>>>0<x[a+480188>>1]){continue}break}}gb=f+16|0}function G8(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;e=gb-80|0;gb=e;v[e+72>>2]=c;c=pi(a,e+72|0);g=zh(a+4|0);h=zh(a+24|0);i=zh(a+32|0);j=dd(a+36|0);v[a+56>>2]=3;k=mc(a+68|0);v[22656]=0;R(2079,a|0,d|0);f=v[22656];v[22656]=0;a:{b:{c:{d:{if((f|0)!=1){f=v[b>>2];l=v[b+4>>2];m=v[b+12>>2];v[e+40>>2]=v[b+8>>2];v[e+44>>2]=m;v[e+32>>2]=f;v[e+36>>2]=l;b=Ud(e+24|0);f=v[e+44>>2];v[e+16>>2]=v[e+40>>2];v[e+20>>2]=f;v[22656]=0;f=v[e+36>>2];v[e+8>>2]=v[e+32>>2];v[e+12>>2]=f;f=v[b+4>>2];v[e>>2]=v[b>>2];v[e+4>>2]=f;U(2073,e+48|0,e+8|0,e|0);b=v[22656];v[22656]=0;if((b|0)==1){break d}v[22656]=0;U(2080,a|0,e+48|0,d|0);b=v[22656];v[22656]=0;if((b|0)==1){break c}xb(e+48|0);v[22656]=0;_(2081,a|0);b=v[22656];v[22656]=0;if((b|0)==1){break b}eg(e+72|0);gb=e+80|0;return a|0}a=P()|0;O()|0;break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;xb(e+48|0);break a}a=P()|0;O()|0}yd(k);Yf(j);iq(i);Di(h);Ci(g);eg(c);eg(e+72|0);S(a|0);L()}function kK(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;d=gb+-64|0;gb=d;e=v[a>>2];f=v[e>>2];c=v[f+4>>2];v[d+40>>2]=v[f+20>>2];a=v[f+16>>2];v[d+32>>2]=v[f+12>>2];v[d+36>>2]=a;Jf(d+48|0,d+32|0,c);c=v[e+4>>2];h=v[c+4>>2];i=v[c+8>>2];a=v[d+60>>2];v[d+24>>2]=v[d+56>>2];v[d+28>>2]=a;a=v[d+52>>2];v[d+16>>2]=v[d+48>>2];v[d+20>>2]=a;v[d+8>>2]=v[c+8>>2];a=v[c+4>>2];v[d>>2]=v[c>>2];v[d+4>>2]=a;k=d+16|0;a=d;a:{if(h>>>0<=y[d+4>>2]){if(h>>>0<=y[k+4>>2]){if(i>>>0<=y[a+8>>2]){if(If(k)>>>0>=i>>>0){if(i){f=b+12|0;while(1){g=0;if(h){while(1){e=Xg(a,g,j);c=Mb(b,g);l=c;c=v[e>>2]+(v[c>>2]>>1)|0;e=c;c=zt(f)+c&-4096;v[l>>2]=e-c;c=id(c|2048,12);if((c|0)<-32768){c=-32768}if((c|0)>32767){c=32767}m=go(k,g,j),n=c,u[m>>1]=n;g=g+1|0;if((h|0)!=(g|0)){continue}break}}j=j+1|0;if((i|0)!=(j|0)){continue}break}}break a}aa(2959,6176,36,5889);L()}aa(2989,6176,35,5889);L()}aa(4211,6176,34,5889);L()}aa(4246,6176,33,5889);L()}gb=d- -64|0}function dK(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;d=gb+-64|0;gb=d;e=v[a>>2];f=v[e>>2];c=v[f+4>>2];v[d+40>>2]=v[f+20>>2];a=v[f+16>>2];v[d+32>>2]=v[f+12>>2];v[d+36>>2]=a;Jf(d+48|0,d+32|0,c);c=v[e+4>>2];h=v[c+4>>2];i=v[c+8>>2];a=v[d+60>>2];v[d+24>>2]=v[d+56>>2];v[d+28>>2]=a;a=v[d+52>>2];v[d+16>>2]=v[d+48>>2];v[d+20>>2]=a;v[d+8>>2]=v[c+8>>2];a=v[c+4>>2];v[d>>2]=v[c>>2];v[d+4>>2]=a;k=d+16|0;a=d;a:{if(h>>>0<=y[d+4>>2]){if(h>>>0<=y[k+4>>2]){if(i>>>0<=y[a+8>>2]){if(If(k)>>>0>=i>>>0){if(i){f=b+12|0;while(1){g=0;if(h){while(1){e=Xg(a,g,j);c=Mb(b,g);l=c;c=v[e>>2]+(v[c>>2]>>1)|0;e=c;c=zt(f)+c&-4096;v[l>>2]=e-c;c=id(c|2048,12);if((c|0)<-32768){c=-32768}if((c|0)>32767){c=32767}m=fo(k,g,j),n=c,u[m>>1]=n;g=g+1|0;if((h|0)!=(g|0)){continue}break}}j=j+1|0;if((i|0)!=(j|0)){continue}break}}break a}aa(2959,6176,36,5889);L()}aa(2989,6176,35,5889);L()}aa(4211,6176,34,5889);L()}aa(4246,6176,33,5889);L()}gb=d- -64|0}function Uia(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;f=gb-16|0;gb=f;a:{b:{c:{g=v[a+12>>2];h=v[a+8>>2];d:{if((g|0)<=1&h>>>0<=805306368|(g|0)<=0){if((g|0)>=-2&h>>>0>=3489660928|(g|0)>-2){break c}if((g|0)==-2&h>>>0>2147483647|g>>>0>4294967294){break d}break b}if((g|0)==1&h>>>0>2147483648|g>>>0>1){break b}}i=b+196648|0;break a}i=b+131112|0;break a}i=b+262184|0}j=v[a+16>>2];k=v[a+24>>2];l=v[a+20>>2];b=v[a+4>>2];e=v[a>>2];v[f+8>>2]=e;v[f+12>>2]=b;v[f>>2]=h;v[f+4>>2]=g;if(d){while(1){b=b+j|0;e=(e>>>16&65520)+i|0;b=(((((((B(t[b-2|0],u[e+2>>1])+B(t[b-3|0],u[e>>1])|0)+B(t[b-1|0],u[e+4>>1])|0)+B(t[b|0],u[e+6>>1])|0)+B(t[b+1|0],u[e+8>>1])|0)+B(t[b+2|0],u[e+10>>1])|0)+B(t[b+3|0],u[e+12>>1])|0)+B(t[b+4|0],u[e+14>>1])<<8)/32768|0;v[c>>2]=v[c>>2]+B(b,l);v[c+4>>2]=v[c+4>>2]+B(b,k);Ub(f+8|0,f);d=d-1|0;if(d){c=c+8|0;e=v[f+8>>2];b=v[f+12>>2];continue}break}e=v[f+8>>2];b=v[f+12>>2]}v[a>>2]=e;v[a+4>>2]=b;gb=f+16|0}function mT(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;a:{d=gb-16|0;gb=d;e=Kb(a);i=b;b:{if(Ab(b)){while(1){a=v[yk(i,g)>>2];c:{if(a>>>0>=2097152){v[22656]=0;R(66,e|0,63);a=v[22656];v[22656]=0;if((a|0)!=1){break c}break b}c=0;d:{e:{while(1){f=a&63;t[(d+10|0)+c|0]=f;if(a>>>0<64){break e}a=a>>>6|0;c=c+1|0;if((c|0)!=6){continue}break}b=7;c=6;break d}f:{if(!c){v[22656]=0;R(66,e|0,t[d+10|0]);break f}b=c+1|0;if((b|0)!=2){break d}c=1;b=2;if((f|0)!=1){break d}v[22656]=0;R(66,e|0,t[d+10|0]|64)}a=v[22656];v[22656]=0;if((a|0)!=1){break c}break b}f=(-1<<b^-1)<<7-c;c=b-1|0;j=c+(d+10|0)|0;a=b;while(1){g:{if((a|0)==(b|0)){a=w[j|0];v[22656]=0;R(66,e|0,(a|f)<<24>>24);h=v[22656];v[22656]=0;a=c;if((h|0)!=1){break g}break b}v[22656]=0;a=a-1|0;R(66,e|0,t[a+(d+10|0)|0]|-128);h=v[22656];v[22656]=0;if((h|0)==1){break b}}if(a){continue}break}}g=g+1|0;if(Ab(i)>>>0>g>>>0){continue}break}}gb=d+16|0;break a}a=P()|0;O()|0;vb(e);S(a|0);L()}}function mJ(a){var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0;c=v[a+32>>2];b=v[a+1380>>2];a:{b:{if((b|0)==-1){h=1;b=-1;break b}d=v[a+1116>>2];c:{if((d|0)<=(b|0)){break c}while(1){e=w[(a+b|0)+1120|0];c=e+c|0;if((e|0)!=255){break c}b=b+1|0;if((d|0)!=(b|0)){continue}break}b=d}if(y[a+40>>2]<c>>>0){ec(a,1);break a}b=(b|0)==(d|0)?-1:b}d:{while(1){if((b|0)!=-1){return 1}g=v[a+40>>2];if(g>>>0<=c+26>>>0){ec(a,1);break a}if((w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24))!=(w[90144]|w[90145]<<8|(w[90146]<<16|w[90147]<<24))){ec(a,21);break a}if(w[c+4|0]){ec(a,21);break a}e:{if(h){if(!v[a+992>>2]|!(t[c+5|0]&1)){break e}ec(a,21);break a}if(t[c+5|0]&1){break e}ec(a,21);break a}d=c+27|0;e=w[c+26|0];c=d+e|0;if(g>>>0<c>>>0){break d}h=0;b=0;f=0;f:{if(!e){break f}while(1){i=w[b+d|0];c=i+c|0;f=b;if((i|0)!=255){break f}b=b+1|0;if((e|0)!=(b|0)){continue}break}f=e}d=f;b=(d|0)==(e|0)?-1:d;if(c>>>0<=g>>>0){continue}break}ec(a,1);break a}ec(a,1)}return 0}function Cia(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,w=0;f=gb-32|0;gb=f;j=v[a+24>>2];k=v[a+20>>2];l=v[a+16>>2];h=v[a+4>>2];i=h;e=v[a>>2];v[f+24>>2]=e;v[f+28>>2]=h;h=v[a+12>>2];v[f+16>>2]=v[a+8>>2];v[f+20>>2]=h;h=a;if(d){while(1){g=(((i&2147483647)<<1|e>>>31)&-2)+l|0;a=(((e>>>16|0)+4&131064)<<1)+b|0;m=u[a+38>>1];n=u[a+36>>1];o=u[a+34>>1];p=u[a+32>>1];q=u[a+30>>1];r=u[a+28>>1];s=u[a+26>>1];w=u[a+24>>1];e=0;a=1;while(1){v[(f+8|0)+(e<<2)>>2]=(((((B(t[(e|4)+g|0],o)+B(t[(e|2)+g|0],p)|0)+B(t[(e|6)+g|0],n)|0)+B(t[(e|8)+g|0],m)<<8)/2|0)+((((B(t[(e|-4)+g|0],s)+B(t[(e|-6)+g|0],w)|0)+B(t[(e|-2)+g|0],r)|0)+B(t[e+g|0],q)<<8)/2|0)|0)/16384;i=a;a=0;e=1;if(i){continue}break}v[c>>2]=v[c>>2]+B(v[f+8>>2],k);v[c+4>>2]=v[c+4>>2]+B(v[f+12>>2],j);Ub(f+24|0,f+16|0);d=d-1|0;if(d){c=c+8|0;e=v[f+24>>2];i=v[f+28>>2];continue}break}e=v[f+24>>2];i=v[f+28>>2]}v[h>>2]=e;v[h+4>>2]=i;gb=f+32|0}function zx(a,b,c,d,e,f,g,h,i,j,k,l){var m=0;m=gb-16|0;gb=m;v[m+12>>2]=a;a:{b:{if((a|0)==(f|0)){if(!w[b|0]){break b}a=0;t[b|0]=0;b=v[e>>2];v[e>>2]=b+1;t[b|0]=46;if(!Ab(h)){break a}b=v[j>>2];if((b-i|0)>159){break a}c=v[k>>2];v[j>>2]=b+4;v[b>>2]=c;break a}c:{if((a|0)!=(g|0)){break c}if(!Ab(h)){break c}if(!w[b|0]){break b}a=0;b=v[j>>2];if((b-i|0)>159){break a}a=v[k>>2];v[j>>2]=b+4;v[b>>2]=a;a=0;v[k>>2]=0;break a}a=-1;f=yx(l,l+128|0,m+12|0)-l|0;if((f|0)>124){break a}g=w[(f>>2)+81024|0];d:{e:{a=f&-5;if((a|0)!=88){if((a|0)!=96){break e}b=v[e>>2];if((b|0)!=(d|0)){a=-1;if((w[b-1|0]&95)!=(w[c|0]&127)){break a}}v[e>>2]=b+1;t[b|0]=g;a=0;break a}t[c|0]=80;break d}a=t[c|0];if((a|0)!=(g&95)){break d}t[c|0]=a|128;if(!w[b|0]){break d}t[b|0]=0;if(!Ab(h)){break d}a=v[j>>2];if((a-i|0)>159){break d}b=v[k>>2];v[j>>2]=a+4;v[a>>2]=b}a=v[e>>2];v[e>>2]=a+1;t[a|0]=g;a=0;if((f|0)>84){break a}v[k>>2]=v[k>>2]+1;break a}a=-1}gb=m+16|0;return a}function lca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=C(0),m=0,n=0,o=0,p=0,q=C(0),r=C(0),s=C(0),t=C(0),u=0,x=0,y=0,A=0,B=0,E=C(0);f=gb-16|0;gb=f;a:{if(!v[a+4240>>2]){break a}g=a+44|0;if(!mi(g)){break a}l=z[a+4220>>2];A=f,B=Nd(g,0),v[A+8>>2]=B;A=f,B=Nd(g,1),v[A+12>>2]=B;A=f,B=od(g,0),v[A>>2]=B;A=f,B=od(g,1),v[A+4>>2]=B;if(d){m=a+4208|0;t=C(C(1)-l);j=d;while(1){h=0;i=1;k=0;while(1){n=(w[a+4264|0]?1-k|0:h)&255;u=v[((n<<2)+a|0)+4248>>2];x=v[a+4240>>2];y=v[a+4244>>2];o=h<<2;p=o+(f+8|0)|0;e=v[p>>2];v[p>>2]=e+4;q=z[e>>2];e=y-u|0;r=z[Mb(m,n+((e>>31&x)+e<<1)|0)>>2];s=C(C(q*z[a+4260>>2])+C(r*z[a+4224>>2]));A=Mb(m,v[a+4244>>2]<<1|h),E=C(D(s))<C(1.0000000195414814e-24)?C(0):s,z[A>>2]=E;h=f+o|0;e=v[h>>2];v[h>>2]=e+4;z[e>>2]=C(t*q)+C(l*r);k=k+1|0;e=i;i=0;h=1;if(e){continue}break}i=v[a+4244>>2]+1|0;v[a+4244>>2]=(i|0)==v[a+4240>>2]?0:i;j=j-1|0;if(j){continue}break}}Ei(a,b,c,od(g,0),od(g,1),d)}gb=f+16|0}function zga(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0;d=gb-32|0;gb=d;v[d+24>>2]=c>>>4;v[d+16>>2]=v[a>>2];h=v[Fb(d+24|0,d+16|0)>>2];b=zb(b);if(h){a=v[a+20>>2];c=h;while(1){f=w[b+4|0]|w[b+5|0]<<8|(w[b+6|0]<<16|w[b+7|0]<<24);v[d+24>>2]=w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24);v[d+28>>2]=f;v[d+16>>2]=0;v[d+20>>2]=-1074790400;v[d+8>>2]=0;v[d+12>>2]=1072693248;e=A[bh(d+24|0,d+16|0,d+8|0)>>3]*32768;A[d+24>>3]=e;f=a;e=ee(e);a:{if(D(e)<2147483648){g=~~e;break a}g=-2147483648}i=f,j=Uc(g),u[i>>1]=j;f=w[b+12|0]|w[b+13|0]<<8|(w[b+14|0]<<16|w[b+15|0]<<24);v[d+24>>2]=w[b+8|0]|w[b+9|0]<<8|(w[b+10|0]<<16|w[b+11|0]<<24);v[d+28>>2]=f;v[d+16>>2]=0;v[d+20>>2]=-1074790400;v[d+8>>2]=0;v[d+12>>2]=1072693248;e=A[bh(d+24|0,d+16|0,d+8|0)>>3]*32768;A[d+24>>3]=e;f=a;e=ee(e);b:{if(D(e)<2147483648){g=~~e;break b}g=-2147483648}i=f,j=Uc(g),u[i+2>>1]=j;a=a+4|0;b=b+16|0;c=c-1|0;if(c){continue}break}}gb=d+32|0;return h<<4}function EM(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;f=gb-16|0;gb=f;zi(f+8|0,b);b=v[f+12>>2];v[f>>2]=v[f+8>>2];v[f+4>>2]=b;h=gb-32|0;gb=h;c=v[f+4>>2];b=h;d=v[f>>2];v[b+8>>2]=d;v[b+12>>2]=c;v[b+16>>2]=d;v[b+20>>2]=c;rh(b+24|0,b+8|0);c=v[b+28>>2];v[b>>2]=v[b+24>>2];v[b+4>>2]=c;c=gb-32|0;gb=c;i=c,j=Hg(a),v[i+24>>2]=j;a=v[b+4>>2];b=v[b>>2];v[c+8>>2]=b;v[c+12>>2]=a;v[c+16>>2]=b;v[c+20>>2]=a;d=c+8|0;b=gb-16|0;gb=b;g=v[c+24>>2];e=g;a=v[e+12>>2];e=v[e+8>>2];a:{if((a|0)<0){break a}if(!a&yb(g)>>>0<e>>>0|a){break a}g=yb(v[c+24>>2]);e=v[c+24>>2];a=v[e+8>>2];e=0-((g>>>0<a>>>0)+v[e+12>>2]|0)|0;v[b+8>>2]=g-a;v[b+12>>2]=e;i=b,j=yb(d),v[i>>2]=j;v[b+4>>2]=0;a=Pr(b+8|0,b);a=OA(v[a>>2],v[a+4>>2]);if((yb(d)|0)!=(a|0)){break a}Rg(v[d>>2],a+v[d>>2]|0,zb(v[v[c+24>>2]>>2]+v[v[c+24>>2]+8>>2]|0));d=v[c+24>>2];e=d;g=a+v[d+8>>2]|0;d=v[d+12>>2];v[e+8>>2]=g;v[e+12>>2]=a>>>0>g>>>0?d+1|0:d}gb=b+16|0;gb=c+32|0;gb=h+32|0;gb=f+16|0}function HS(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0,k=C(0),l=0,m=0,n=0;h=gb-16|0;gb=h;if(Mj(a)){e=w[(ve(w[a+797|0])?a+797|0:a+799|0)|0];f=h+8|0;Db(f,d+1074312|0,34);if(!(!Cb(f)|!e|e>>>0>120)){e=w[ic(v[a+656>>2]+108|0,e-1|0)|0]}d=a;k=C(C(v[a+704>>2]<<4)*b);e=(c+e<<16)-3997696>>16;c=v[v[a+656>>2]+44>>2];i=v[c+36>>2];a=v[a+852>>2]+u[a+772>>1]|0;a:{if(!(a?i:0)){b=Im(c,a+e<<16>>16);break a}j=i+1|0;l=kz(a,j);f=to(a,j);a=u[c+28>>1];g=c+4|0;Nb(g);b=C(1);e=e+l<<16>>16;b:{if((e|0)<(a|0)){break b}if((e|0)>(x[c+28>>1]+Nb(g)<<16)-65536>>16){break b}if(!f){b=z[Mb(g,e-u[c+28>>1]|0)>>2];break a}a=x[c>>1];c:{if((a|0)==3){a=c+16|0;if(Nb(a)){b=z[Mb(a,f-1|0)>>2];break c}a=x[c>>1]}d:{if((a&65535)!=1){break d}a=c+16|0;if(!Nb(a)){break d}b=z[Mb(a,(B(i,to(e,x[c+30>>1])<<16>>16)+f|0)-1|0)>>2];break c}b=oe(C(Im(c,(e<<16)+65536>>16)/Im(c,e)),C(C(f|0)/C(j|0)))}b=C(b*z[Mb(g,e-u[c+28>>1]|0)>>2])}}m=d,n=Lj(C(k*b)),v[m+700>>2]=n}gb=h+16|0}function Cx(a,b,c,d,e,f,g,h,i,j,k,l){var m=0;m=gb-16|0;gb=m;t[m+15|0]=a;a:{b:{if((a|0)==(f|0)){if(!w[b|0]){break b}a=0;t[b|0]=0;b=v[e>>2];v[e>>2]=b+1;t[b|0]=46;if(!Ab(h)){break a}b=v[j>>2];if((b-i|0)>159){break a}c=v[k>>2];v[j>>2]=b+4;v[b>>2]=c;break a}c:{if((a|0)!=(g|0)){break c}if(!Ab(h)){break c}if(!w[b|0]){break b}a=0;b=v[j>>2];if((b-i|0)>159){break a}a=v[k>>2];v[j>>2]=b+4;v[b>>2]=a;a=0;v[k>>2]=0;break a}a=-1;f=Xm(l,l+32|0,m+15|0)-l|0;if((f|0)>31){break a}g=w[f+81024|0];d:{e:{switch((f&-2)-22|0){case 2:b=v[e>>2];if((b|0)!=(d|0)&(w[b-1|0]&95)!=(w[c|0]&127)){break a}v[e>>2]=b+1;t[b|0]=g;a=0;break a;case 0:t[c|0]=80;break d;default:break e}}a=t[c|0];if((a|0)!=(g&95)){break d}t[c|0]=a|128;if(!w[b|0]){break d}t[b|0]=0;if(!Ab(h)){break d}a=v[j>>2];if((a-i|0)>159){break d}b=v[k>>2];v[j>>2]=a+4;v[a>>2]=b}a=v[e>>2];v[e>>2]=a+1;t[a|0]=g;a=0;if((f|0)>21){break a}v[k>>2]=v[k>>2]+1;break a}a=-1}gb=m+16|0;return a}function PH(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0;h=gb-32|0;gb=h;f=d&2147483647;g=f;e=f-1065418752|0;i=f-1082064896|0;f=c;a:{if((e|0)==(i|0)&f>>>0<f>>>0|e>>>0<i>>>0){g=(d&33554431)<<7|c>>>25;f=0;j=f;i=c&33554431;if(!(!f&(i|0)==16777216?!(a|b):!f&i>>>0<16777216)){e=g+1073741825|0;break a}e=g+1073741824|0;if(i^16777216|a|(b|j)){break a}e=(g&1)+e|0;break a}if(!(!f&(g|0)==2147418112?!(a|b):g>>>0<2147418112)){e=((d&33554431)<<7|c>>>25)&4194303|2143289344;break a}e=2139095040;if(g>>>0>1082064895){break a}e=0;f=g>>>16|0;if(f>>>0<16145){break a}g=c;e=d&65535|65536;Kf(h+16|0,a,b,g,e,f-16129|0);pm(h,a,b,g,e,16257-f|0);b=v[h+8>>2];e=(v[h+12>>2]&33554431)<<7|b>>>25;g=v[h+4>>2];f=g;a=0;i=a;j=v[h>>2]|((v[h+16>>2]|v[h+24>>2])!=0|(v[h+20>>2]|v[h+28>>2])!=0);b=b&33554431;if(!(!a&(b|0)==16777216?!(f|j):!a&b>>>0<16777216)){e=e+1|0;break a}if(b^16777216|j|(f|i)){break a}e=(e&1)+e|0}gb=h+32|0;return l(2,d&-2147483648|e),q()}function YH(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;c=gb-32|0;gb=c;a:{if(w[a+52|0]){d=v[a+48>>2];if(!b){break a}t[a+52|0]=0;v[a+48>>2]=-1;break a}v[c+24>>2]=1;b:{e=v[Gf(c+24|0,a+44|0)>>2];if((e|0)>0){f=(e|0)>0?e:0;while(1){g=Ws(v[a+32>>2]);if((g|0)==-1){break b}t[(c+24|0)+d|0]=g;d=d+1|0;if((f|0)!=(d|0)){continue}break}}c:{if(w[a+53|0]){t[c+23|0]=w[c+24|0];break c}g=c+24|0;while(1){d:{d=v[a+40>>2];i=v[d>>2];j=v[d+4>>2];h=c+24|0;f=h+e|0;e:{switch(jI(v[a+36>>2],d,h,f,c+16|0,c+23|0,g,c+12|0)-1|0){case 0:break e;case 1:break b;case 2:break d;default:break c}}d=v[a+40>>2];v[d>>2]=i;v[d+4>>2]=j;if((e|0)==8){break b}d=Ws(v[a+32>>2]);if((d|0)==-1){break b}t[f|0]=d;e=e+1|0;continue}break}t[c+23|0]=w[c+24|0]}f:{if(!b){while(1){if((e|0)<=0){break f}e=e-1|0;if((Vs(Mg(t[e+(c+24|0)|0]),v[a+32>>2])|0)!=-1){continue}break b}}k=a,l=Mg(t[c+23|0]),v[k+48>>2]=l}d=Mg(t[c+23|0]);break a}d=-1}gb=c+32|0;return d}function PT(a){var b=0,c=0,d=0,e=0,f=0,g=0,h=0;g=gb-16|0;gb=g;b=v[a>>2];yc(g+8|0,b);a:{b:{c:{d:{e=b+16|0;e:{if(Dd(e)){while(1){f:{d=v[e>>2];v[22656]=0;d=T(56,d|0)|0;h=v[22656];v[22656]=0;if((h|0)==1){break f}f=d|f;c=c+32|0;if(c>>>0<32){continue}break e}break}c=V(89092)|0;if((O()|0)!=(ea(89092)|0)){break c}Z(c|0)|0;t[b+20|0]=0;v[22656]=0;_(38,b|0);c=v[22656];v[22656]=0;if((c|0)==1){break d}v[22656]=0;X(20);c=v[22656];v[22656]=0;if((c|0)!=1){break e}c=P()|0;O()|0;break c}t[b+20|0]=0}if(!w[b+20|0]){b=v[b+24>>2];c=v[b+2496>>2];e=(c<<2)+b|0;h=v[b+((c+397>>>0)%624<<2)>>2];d=(c+1>>>0)%624|0;c=v[b+(d<<2)>>2];c=h^(c&2147483647|v[e>>2]&-2147483648)>>>1^B(c&1,-1727483681);v[e>>2]=c;v[b+2496>>2]=d;b=c^c>>>11;b=b<<7&-1658038656^b;b=b<<15&-272236544^b;f=f^(b>>>18^b)}gb=g+16|0;break a}c=P()|0;O()|0;v[22656]=0;X(20);a=v[22656];v[22656]=0;if((a|0)==1){break b}}S(c|0);L()}V(0)|0;O()|0;Bb();L()}return v[a+28>>2]&f}function Lma(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;e=gb-16|0;gb=e;i=8;t[e+15|0]=8;u[e+12>>1]=0;v[e+8>>2]=0;if(d){l=B(c,d);c=0;while(1){if((l|0)>0){j=(k<<1)+b|0;n=j+(l<<1)|0;while(1){o=c;u[e+6>>1]=0;IV(a,e+14|0,e+12|0,e+15|0,e+6|0);a:{if(!i){h=x[e+6>>1];break a}h=x[e+6>>1];c=x[e+12>>1];g=i;while(1){f=c<<1;c=f&254;u[e+12>>1]=c;if(c){f=(f&65534)>>>0>255}else{if(!lf(a,e+5|0)){break a}f=w[e+5|0];c=f<<1&254|1;u[e+12>>1]=c;f=f>>>7|0}h=f|h<<1;g=g-1|0;if(g&255){continue}break}}c=1;m=h&65535;b:{if(m>>>0<4){break b}g=15;while(1){c=g;f=c&255;if(m>>>f&1){break b}g=c-1|0;if(f>>>0>1){continue}break}}i=(c+i&254)>>>1|0;t[e+15|0]=i;c=h&1;t[e+14|0]=c;g=c-1^(h&65534)>>>1;c=g+x[e+8>>1]|0;u[e+6>>1]=c;u[j>>1]=c;v[e+8>>2]=((g>>1)-(o<<16>>16)|0)+(c<<16>>16<<1);Zd(e+8|0,-32768,32767);j=(d<<1)+j|0;if(n>>>0>j>>>0){continue}break}}k=k+1|0;if((k|0)!=(d|0)){continue}break}}gb=e+16|0}function o1(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0;a=c;a:{if(!e|d>>>0<=a>>>0){break a}while(1){i=d;f=t[a|0];b=1;b:{if((f|0)>=0){break b}b=f&255;if(b>>>0<194){break a}if(b>>>0<=223){if((d-a|0)<2){break a}b=2;if((w[a+1|0]&192)==128){break b}break a}if(b>>>0<=239){if((d-a|0)<3){break a}h=w[a+2|0];f=w[a+1|0];c:{d:{if((b|0)!=237){if((b|0)!=224){break d}if((f&224)==160){break c}break a}if((f&224)==128){break c}break a}if((f&192)!=128){break a}}b=3;if((h&192)==128){break b}break a}if((d-a|0)<4|b>>>0>244|e-g>>>0<2){break a}h=w[a+3|0];j=w[a+2|0];f=w[a+1|0];e:{f:{switch(b-240|0){case 0:if((f+112&255)>>>0<48){break e}break a;case 4:if((f&240)==128){break e}break a;default:break f}}if((f&192)!=128){break a}}if((j&192)!=128|(h&192)!=128|(b<<18&1835008|(f&48)<<12)>>>0>1114111){break a}g=g+1|0;b=4}a=b+a|0;if(i>>>0<=a>>>0){break a}g=g+1|0;if(g>>>0<e>>>0){continue}break}}return a-c|0}function Nda(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=C(0),h=0,i=0,j=0,k=0,l=0,m=0,n=C(0),o=C(0),p=C(0),q=C(0),r=C(0),s=C(0),t=C(0),u=C(0),w=0,x=C(0);if(v[a+4220>>2]){f=a+44|0;i=Nd(f,0);j=Nd(f,1);k=od(f,0);l=od(f,1);if(d){h=a+4208|0;e=v[a+4224>>2];m=d;while(1){n=z[i>>2];o=z[j>>2];e=e-v[a+4228>>2]|0;e=(v[a+4220>>2]&e>>31)+e<<1;p=z[Mb(h,e)>>2];e=Mb(h,e|1);r=z[a+4256>>2];s=z[a+4248>>2];t=z[a+4252>>2];q=z[e>>2];u=z[a+4244>>2];g=C(C(C(C(n*r)+C(o*s))+C(p*t))+C(q*u));w=Mb(h,v[a+4224>>2]<<1),x=C(D(g))<C(1.0000000195414814e-24)?C(0):g,z[w>>2]=x;g=C(C(C(C(o*r)+C(n*s))+C(q*t))+C(p*u));w=Mb(h,v[a+4224>>2]<<1|1),x=C(D(g))<C(1.0000000195414814e-24)?C(0):g,z[w>>2]=x;e=v[a+4224>>2]+1|0;e=(e|0)==v[a+4220>>2]?0:e;v[a+4224>>2]=e;z[k>>2]=C(n*z[a+4240>>2])+C(p*z[a+4236>>2]);z[l>>2]=C(o*z[a+4240>>2])+C(q*z[a+4236>>2]);l=l+4|0;k=k+4|0;j=j+4|0;i=i+4|0;m=m-1|0;if(m){continue}break}}Ei(a,b,c,od(f,0),od(f,1),d)}}function LN(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,w=0,z=0,A=0;g=gb-32|0;gb=g;p=v[a+20>>2];h=x[a+34>>1]&65;v[g+16>>2]=h;v[g+8>>2]=h^65;q=b;h=c;k=a;j=a+24|0;r=d+1298224|0;e=d+1074992|0;l=Hj(d);s=a+4|0;t=a+12|0;u=a+8|0;w=a+16|0;while(1){if((k|0)==v[e+104>>2]){if(v[e+16>>2]){v[e+16>>2]=q}if(y[e+4>>2]>h>>>0){v[e>>2]=0;v[e+4>>2]=0}if(v[e+76>>2]){qc(e+76|0,h)}f=pF(e);i=v[(f?t:s)>>2];v[e+84>>2]=v[(f?w:u)>>2];v[e+80>>2]=i;f=v[e+88>>2]|v[g+16>>2];v[e+88>>2]=f;v[e+88>>2]=f&(v[g+8>>2]^-1);f=e+704|0;a:{if(!v[e+704>>2]|!v[k+24>>2]){break a}if(_l(d)){break a}m=v[(l?f:j)>>2];n=kqa(v[(l?j:f)>>2],0,v[e+700>>2],0);o=n+(m>>>1|0)|0;i=jb;z=e,A=Qc(nqa(o,o>>>0<n>>>0?i+1|0:i,m,0),jb),v[z+700>>2]=A}v[f>>2]=v[j>>2]}e=e+872|0;if((r|0)!=(e|0)){continue}break}v[a>>2]=c;v[a+20>>2]=b;v[22656]=0;Tq(p);a=v[22656];v[22656]=0;if((a|0)!=1){gb=g+32|0;return}a=P()|0;O()|0;S(a|0);L()}function bja(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;e=gb-32|0;gb=e;i=v[a+40>>2];j=v[a+36>>2];l=v[a+16>>2];b=v[a+4>>2];f=b;g=v[a>>2];v[e+24>>2]=g;v[e+28>>2]=b;b=v[a+12>>2];v[e+16>>2]=v[a+8>>2];v[e+20>>2]=b;a:{if(d){while(1){k=((((f&2147483647)<<1|g>>>31)&2147483646)<<1)+l|0;b=g>>>21&2040;g=u[b+46166>>1];m=u[b+46164>>1];n=u[b+46162>>1];o=u[b+46160>>1];h=0;b=1;while(1){f=h<<1;v[(e+8|0)+(h<<2)>>2]=(((B(u[f+k>>1],n)+B(u[(f|-4)+k>>1],o)|0)+B(u[(f|4)+k>>1],m)|0)+B(u[(f|8)+k>>1],g)|0)/16384;f=b;b=0;h=1;if(f){continue}break}b=v[a+32>>2];j=v[a+28>>2]+j|0;h=j>>12;v[c>>2]=v[c>>2]+B(h,v[e+8>>2]);i=b+i|0;b=i>>12;v[c+4>>2]=v[c+4>>2]+B(b,v[e+12>>2]);Ub(e+24|0,e+16|0);d=d-1|0;if(d){c=c+8|0;g=v[e+24>>2];f=v[e+28>>2];continue}break}g=v[e+24>>2];f=v[e+28>>2];break a}b=i>>12;h=j>>12}v[a+40>>2]=i;v[a+20>>2]=h;v[a+36>>2]=j;v[a+24>>2]=b;v[a>>2]=g;v[a+4>>2]=f;gb=e+32|0}function _1(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;b=Nb(465776);if(b>>>0<a>>>0){g=gb-32|0;gb=g;e=a-b|0;a:{if(e>>>0<=v[116446]-v[116445]>>2>>>0){aH(e);break a}f=px(465776);b=g+8|0;d=Nb(465776)+e|0;c=gb-16|0;gb=c;v[c+12>>2]=d;b:{a=np();if(d>>>0<=a>>>0){d=pe(465776);if(d>>>0<a>>>1>>>0){v[c+8>>2]=d<<1;a=v[Lc(c+8|0,c+12|0)>>2]}gb=c+16|0;break b}Sc();L()}h=Nb(465776);c=0;d=gb-16|0;gb=d;v[d+12>>2]=0;kf(b+12|0,f);if(a){c=OG(v[b+16>>2],a)}v[b>>2]=c;f=(h<<2)+c|0;v[b+8>>2]=f;v[b+4>>2]=f;i=dc(b),j=(a<<2)+c|0,v[i>>2]=j;gb=d+16|0;d=gb-16|0;gb=d;a=Tk(d,b+8|0,e);c=v[a>>2];if((c|0)!=v[a+4>>2]){while(1){Zo(c);c=v[a>>2]+4|0;v[a>>2]=c;if(v[a+4>>2]!=(c|0)){continue}break}}_c(a);gb=d+16|0;a=b+4|0;ml(v[116444],v[116445],a);wc(465776,a);wc(465780,b+8|0);wc(465784,dc(b));v[b>>2]=v[b+4>>2];a=b;wC(a);b=v[a>>2];if(b){NG(v[a+16>>2],b,Ck(a))}}gb=g+32|0;return}if(a>>>0<b>>>0){de(465776,v[116444]+(a<<2)|0)}}function SN(a,b,c,d,e,f,g,h){var i=0,j=0,k=0,l=0,m=0,n=0;k=gb-16|0;gb=k;t[k+15|0]=c;t[k+14|0]=12;kh(b,w[ac(k+15|0,k+14|0)|0]);if(Nb(b)){c=0;while(1){a:{b:{c:{switch(h|0){case 0:i=(c<<2)+a|0;j=i+96|0;j=w[j|0]|w[j+1|0]<<8;m=Mb(b,c),n=j,u[m>>1]=n;i=i+98|0;break b;case 1:break c;default:break a}}i=(c<<2)+a|0;j=i+144|0;j=w[j|0]|w[j+1|0]<<8;m=Mb(b,c),n=j,u[m>>1]=n;i=i+146|0}i=w[i|0];m=Mb(b,c),n=i,t[m+2|0]=n}d:{if(!c){break d}i=c-1|0;if(x[Mb(b,c)>>1]>=x[Mb(b,i)>>1]){break d}if(x[Mb(b,c)>>1]>255){break d}j=w[Mb(b,i)+1|0];l=Mb(b,c);u[l>>1]=x[l>>1]|j<<8;if(x[Mb(b,c)>>1]>=x[Mb(b,i)>>1]){break d}i=Mb(b,c);u[i>>1]=x[i>>1]+256}c=c+1|0;if(Nb(b)>>>0>c>>>0){continue}break}}t[b+12|0]=0;e:{if(!(d&1)){break e}if(cd(b)){break e}t[b+12|0]=w[b+12|0]|1}if(e>>>0<=11){if(d&2){t[b+12|0]=w[b+12|0]|4}t[b+15|0]=e;t[b+16|0]=e}if(!(g>>>0>11|f>>>0>g>>>0)){if(d&4){t[b+12|0]=w[b+12|0]|2}t[b+14|0]=g;t[b+13|0]=f}gb=k+16|0}function xfa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=gb-32|0;gb=d;f=Kb(d+16|0);a:{b:{c:{if(c>>>0<=63){break c}v[22656]=0;c=T(1419,b|0)|0;e=v[22656];v[22656]=0;d:{if((e|0)!=1){v[d+12>>2]=c;if((c|0)>0){break d}v[22656]=0;Q(70,a|0,18726)|0;a=v[22656];v[22656]=0;if((a|0)!=1){break b}}break a}v[22656]=0;c=T(467,b|0)|0;e=v[22656];v[22656]=0;e:{if((e|0)==1){break e}c=Ti(c);v[22656]=0;v[d+8>>2]=c;c=pd(d+12|0,d+8|0);e=v[22656];v[22656]=0;if((e|0)==1){break e}c=v[c>>2];v[22656]=0;R(60,f|0,c|0);c=v[22656];v[22656]=0;if((c|0)!=1){break c}}break a}f:{while(1){g:{v[22656]=0;c=T(374,b|0)|0;e=v[22656];v[22656]=0;if((e|0)==1){break g}if(!c){break f}v[22656]=0;W(1420,f|0,1,((c-65&255)>>>0<26?c+32|0:c)<<24>>24)|0;c=v[22656];v[22656]=0;if((c|0)!=1){continue}}break}break a}v[22656]=0;Q(318,b|0,4)|0;b=v[22656];v[22656]=0;if((b|0)==1){break a}Dc(a,f)}vb(f);gb=d+32|0;return}a=P()|0;O()|0;vb(f);S(a|0);L()}function GS(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;t[a+15|0]=0;t[a+16|0]=0;t[a+17|0]=0;t[a+18|0]=0;t[a+19|0]=0;t[a+20|0]=0;t[a+21|0]=0;t[a+22|0]=0;t[a+14|0]=5;u[a+12>>1]=0;v[a+8>>2]=128;v[a>>2]=256;v[a+4>>2]=64;v[a+28>>2]=0;t[a+27|0]=60;v[a+40>>2]=0;v[a+44>>2]=0;t[a+33|0]=2;t[a+34|0]=0;t[a+35|0]=0;t[a+36|0]=2;t[a+23|0]=0;t[a+24|0]=0;t[a+25|0]=255;t[a+26|0]=0;t[a+32|0]=0;d=mB(a+48|0);e=mB(a+68|0);f=mB(a+88|0);v[22656]=0;Uq(a+492|0);c=v[22656];v[22656]=0;a:{if((c|0)==1){break a}v[22656]=0;Uq(a+524|0);c=v[22656];v[22656]=0;if((c|0)==1){break a}v[22656]=0;hm(a,0,0);c=v[22656];v[22656]=0;if((c|0)==1){break a}v[22656]=0;gm(a,0,0);c=v[22656];v[22656]=0;if((c|0)==1){break a}v[a+40>>2]=0;v[a+44>>2]=0;v[22656]=0;pr(a,b);b=v[22656];v[22656]=0;if((b|0)==1){break a}d=a+108|0;b=0;while(1){c=ic(d,b);b=b+1|0;t[c|0]=b;if(b>>>0<128){continue}break}return a|0}a=P()|0;O()|0;dp(f);dp(e);dp(d);S(a|0);L()}function yka(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;g=gb-32|0;gb=g;e=b;f=uf(e);d=c;a:{if(f>>>0<d>>>0){k=gb-32|0;gb=k;b:{c:{i=d-f|0;d:{if(i>>>0<=v[wb(e)>>2]-v[e+4>>2]>>4>>>0){f=gb-16|0;gb=f;d=cq(f,e,i);e=v[d+4>>2];h=v[d+8>>2];if((e|0)!=(h|0)){while(1){Jv(e);e=e+16|0;v[d+4>>2]=e;if((e|0)!=(h|0)){continue}break}}$b(d);gb=f+16|0;break d}j=wb(e);f=fy(e,uf(e)+i|0);m=uf(e);l=gb-16|0;gb=l;v[l+12>>2]=0;d=k+8|0;kf(d+12|0,j);if(f){h=f;if(f>>>0>=268435456){rd(8445);L()}h=Mc(h<<4,1)}v[d>>2]=h;j=(m<<4)+h|0;v[d+8>>2]=j;v[d+4>>2]=j;n=dc(d),o=(f<<4)+h|0,v[n>>2]=o;gb=l+16|0;v[22656]=0;xT(d,i);f=v[22656];v[22656]=0;if((f|0)==1){break c}Zk(e,d);wT(d)}gb=k+32|0;break b}a=P()|0;O()|0;wT(d);S(a|0);L()}break a}if(d>>>0<f>>>0){_k(e,v[e>>2]+(d<<4)|0)}}if(Pb(a,c<<4)){bc(g+24|0,v[b>>2],uf(b)<<4);b=v[g+28>>2];v[g+8>>2]=v[g+24>>2];v[g+12>>2]=b;kd(g+16|0,a,g+8|0)}gb=g+32|0}function l1(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0;a=c;a:{if(!e|d>>>0<=a>>>0){break a}while(1){f=1;b=t[a|0];b:{if((b|0)>=0){break b}b=b&255;if(b>>>0<194){break a}if(b>>>0<=223){if((d-a|0)<2){break a}f=2;if((w[a+1|0]&192)==128){break b}break a}if(b>>>0<=239){if((d-a|0)<3){break a}g=w[a+2|0];f=w[a+1|0];c:{d:{if((b|0)!=237){if((b|0)!=224){break d}if((f&224)==160){break c}break a}if((f&224)==128){break c}break a}if((f&192)!=128){break a}}f=3;if((g&192)==128){break b}break a}if((d-a|0)<4|b>>>0>244){break a}f=w[a+3|0];i=w[a+2|0];g=w[a+1|0];e:{f:{switch(b-240|0){case 0:if((g+112&255)>>>0<48){break e}break a;case 4:if((g&240)==128){break e}break a;default:break f}}if((g&192)!=128){break a}}if((i&192)!=128|(f&192)!=128){break a}f=4;if((b<<18&1835008|(g&48)<<12)>>>0>1114111){break a}}a=a+f|0;if(d>>>0<=a>>>0){break a}h=h+1|0;if(h>>>0<e>>>0){continue}break}}return a-c|0}function Aka(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;g=gb-32|0;gb=g;e=b;f=ze(e);d=c;a:{if(f>>>0<d>>>0){k=gb-32|0;gb=k;b:{c:{i=d-f|0;d:{if(i>>>0<=v[wb(e)>>2]-v[e+4>>2]>>5>>>0){f=gb-16|0;gb=f;d=IB(f,e,i);e=v[d+4>>2];h=v[d+8>>2];if((e|0)!=(h|0)){while(1){$B(e);e=e+32|0;v[d+4>>2]=e;if((e|0)!=(h|0)){continue}break}}$b(d);gb=f+16|0;break d}j=wb(e);f=_q(e,ze(e)+i|0);m=ze(e);l=gb-16|0;gb=l;v[l+12>>2]=0;d=k+8|0;kf(d+12|0,j);if(f){h=f;if(f>>>0>=134217728){rd(8445);L()}h=Mc(h<<5,1)}v[d>>2]=h;j=(m<<5)+h|0;v[d+8>>2]=j;v[d+4>>2]=j;n=dc(d),o=(f<<5)+h|0,v[n>>2]=o;gb=l+16|0;v[22656]=0;BT(d,i);f=v[22656];v[22656]=0;if((f|0)==1){break c}Zk(e,d);AT(d)}gb=k+32|0;break b}a=P()|0;O()|0;AT(d);S(a|0);L()}break a}if(d>>>0<f>>>0){_k(e,v[e>>2]+(d<<5)|0)}}if(Pb(a,c<<5)){bc(g+24|0,v[b>>2],ze(b)<<5);b=v[g+28>>2];v[g+8>>2]=v[g+24>>2];v[g+12>>2]=b;kd(g+16|0,a,g+8|0)}gb=g+32|0}function Mea(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0;e=gb+-64|0;gb=e;g=uo(a);a:{b:{if(b-1>>>0>1023){break b}f=v[a+12>>2];if((f|0)==(b|0)){break b}if(c){c=v[g+8>>2];if(y[c+40>>2]<b>>>0|y[c+36>>2]>b>>>0){break b}f=v[a+12>>2]}f=B(Ji(a),b>>>0>f>>>0?b-f|0:f-b|0);c:{if(y[a+12>>2]<b>>>0){c=e;d:{if(d){d=Zb(a);break d}d=Vb(a)}v[c+48>>2]=d;c=Fd(e+56|0,e+48|0);d=e+40|0;gi(d);c=v[c>>2];v[22656]=0;Y(1475,a|0,c|0,f|0,d|0);c=v[22656];v[22656]=0;if((c|0)!=1){break c}a=V(89116)|0;if((O()|0)!=(ea(89116)|0)){break a}Z(a|0)|0;$();break b}if(d){i=e,j=Zb(a),v[i+48>>2]=j;i=e,j=bD(e+48|0,f),v[i+40>>2]=j;c=Fd(e+32|0,e+40|0);i=e,j=Zb(a),v[i+16>>2]=j;d=Fd(e+24|0,e+16|0);KN(a,v[c>>2],v[d>>2]);break c}i=e,j=Vb(a),v[i+40>>2]=j;c=Fd(e+8|0,e+40|0);i=e,j=Vb(a),v[i+16>>2]=j;i=e,j=CX(e+16|0,f),v[i+48>>2]=j;d=Fd(e,e+48|0);KN(a,v[c>>2],v[d>>2])}v[a+12>>2]=b;h=1}gb=e- -64|0;return h|0}S(a|0);L()}function F5(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;c=gb-32|0;gb=c;v[c+28>>2]=0;a:{b:{c:{if(w[uj(c+24|0,a,0)|0]){d=v[v[a>>2]-12>>2];v[22656]=0;Fc(c+16|0,a+d|0);d=v[22656];v[22656]=0;d:{e:{f:{g:{h:{if((d|0)!=1){v[22656]=0;d=T(2309,c+16|0)|0;e=v[22656];v[22656]=0;if((e|0)==1){break h}e=cj(c+8|0,a);f=Ui(c);g=v[v[a>>2]-12>>2];f=v[f>>2];e=v[e>>2];v[22656]=0;ka(2312,d|0,e|0,f|0,a+g|0,c+28|0,c+20|0);d=v[22656];v[22656]=0;if((d|0)==1){break h}Wb(c+16|0);break f}b=V(0)|0;O()|0;break g}b=V(0)|0;O()|0;Wb(c+16|0)}Z(b|0)|0;b=v[c+28>>2]|1;v[c+28>>2]=b;tj(v[v[a>>2]-12>>2]+a|0,b);if(!(v[(v[v[a>>2]-12>>2]+a|0)+20>>2]&1)){break e}v[22656]=0;X(2027);a=v[22656];v[22656]=0;if((a|0)!=1){break b}a=P()|0;O()|0;v[22656]=0;X(20);b=v[22656];v[22656]=0;if((b|0)==1){break c}S(a|0);L()}d=v[c+20>>2];v[b>>2]=d;break d}$()}ih(v[v[a>>2]-12>>2]+a|0,v[c+28>>2])}gb=c+32|0;break a}V(0)|0;O()|0;Bb()}L()}return a|0}function vga(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,m=0,o=0,p=0;f=gb-32|0;gb=f;m=f,o=B(v[a>>2],fd(a)),v[m+4>>2]=o;qc(f+4|0,c>>>3|0);c=zb(b);g=A[e+8>>3];h=v[f+4>>2];a:{if(!h){break a}e=h;while(1){k=(w[c+4|0]|w[c+5|0]<<8|(w[c+6|0]<<16|w[c+7|0]<<24))&2147483647;l(0,w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24));l(1,k|0);j=+n();g=g<j?j:g;c=c+8|0;e=e-1|0;if(e){continue}break}if(g==0){break a}j=1/g;c=v[a+20>>2];while(1){a=b;e=w[a+4|0]|w[a+5|0]<<8|(w[a+6|0]<<16|w[a+7|0]<<24);l(0,w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24));l(1,e|0);m=f,p=j*+n(),A[m+24>>3]=p;v[f+16>>2]=0;v[f+20>>2]=-1074790400;v[f+8>>2]=0;v[f+12>>2]=1072693248;i=A[bh(f+24|0,f+16|0,f+8|0)>>3]*32768;A[f+24>>3]=i;a=c;i=ee(i);b:{if(D(i)<2147483648){e=~~i;break b}e=-2147483648}m=a,o=Uc(e),u[m>>1]=o;b=b+8|0;c=c+2|0;h=h-1|0;if(h){continue}break}}if(d){A[d>>3]=g}gb=f+32|0;return v[f+4>>2]<<3}function qga(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=C(0),g=0,h=0,i=C(0),j=0,k=0;e=gb-16|0;gb=e;v[e+12>>2]=c>>>3;v[e+8>>2]=v[a>>2];h=v[Fb(e+12|0,e+8|0)>>2];i=z[d>>2];b=zb(b);if(h){a=v[a+20>>2];c=h;while(1){d=w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24);z[e+12>>2]=i*(l(2,d<<24|d<<8&16711680|(d>>>8&65280|d>>>24)),q());v[e+8>>2]=-1082130432;v[e+4>>2]=1065353216;f=C(z[zf(e+12|0,e+8|0,e+4|0)>>2]*C(32768));z[e+12>>2]=f;d=a;f=fe(f);a:{if(C(D(f))<C(2147483648)){g=~~f;break a}g=-2147483648}j=d,k=Uc(g),u[j>>1]=k;d=w[b+4|0]|w[b+5|0]<<8|(w[b+6|0]<<16|w[b+7|0]<<24);z[e+12>>2]=i*(l(2,d<<24|d<<8&16711680|(d>>>8&65280|d>>>24)),q());v[e+8>>2]=-1082130432;v[e+4>>2]=1065353216;f=C(z[zf(e+12|0,e+8|0,e+4|0)>>2]*C(32768));z[e+12>>2]=f;d=a;f=fe(f);b:{if(C(D(f))<C(2147483648)){g=~~f;break b}g=-2147483648}j=d,k=Uc(g),u[j+2>>1]=k;a=a+4|0;b=b+8|0;c=c-1|0;if(c){continue}break}}gb=e+16|0;return h<<3}function VH(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;c=gb-32|0;gb=c;a:{if(w[a+52|0]){d=v[a+48>>2];if(!b){break a}t[a+52|0]=0;v[a+48>>2]=-1;break a}v[c+24>>2]=1;b:{e=v[Gf(c+24|0,a+44|0)>>2];if((e|0)>0){f=(e|0)>0?e:0;while(1){g=Ws(v[a+32>>2]);if((g|0)==-1){break b}t[(c+24|0)+d|0]=g;d=d+1|0;if((f|0)!=(d|0)){continue}break}}c:{if(w[a+53|0]){v[c+20>>2]=t[c+24|0];break c}g=c+24|0;while(1){d:{d=v[a+40>>2];i=v[d>>2];j=v[d+4>>2];h=c+24|0;f=h+e|0;e:{switch(jI(v[a+36>>2],d,h,f,c+16|0,c+20|0,g,c+12|0)-1|0){case 0:break e;case 1:break b;case 2:break d;default:break c}}d=v[a+40>>2];v[d>>2]=i;v[d+4>>2]=j;if((e|0)==8){break b}d=Ws(v[a+32>>2]);if((d|0)==-1){break b}t[f|0]=d;e=e+1|0;continue}break}v[c+20>>2]=t[c+24|0]}f:{if(!b){while(1){if((e|0)<=0){break f}e=e-1|0;if((Vs(t[e+(c+24|0)|0],v[a+32>>2])|0)!=-1){continue}break b}}v[a+48>>2]=v[c+20>>2]}d=v[c+20>>2];break a}d=-1}gb=c+32|0;return d}function I9(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;v[22656]=0;_(2007,a|0);e=v[22656];v[22656]=0;a:{b:{c:{d:{e:{if((e|0)==1){break e}v[22656]=0;_(1960,b|0);e=v[22656];v[22656]=0;if((e|0)==1){break e}e=0;v[22656]=0;_(2008,c|0);f=v[22656];v[22656]=0;if((f|0)==1){break e}a=Qb(c,0,d);if(!w[b|0]){break b}if(wj(b,4310)|(d|0)!=8){break d}v[a+4>>2]=2009;v[a>>2]=2010;break c}b=V(0)|0;O()|0;Z(b|0)|0;v[22656]=0;Y(1911,9520,a|0,0,0);a=v[22656];v[22656]=0;if((a|0)==1){break a}$();return 0}if(wj(b,8531)|(d|0)!=64){break b}v[a+60>>2]=2011;v[a+56>>2]=2012;v[a+52>>2]=2013;v[a+48>>2]=2014;v[a+44>>2]=2015;v[a+40>>2]=2016;v[a+36>>2]=2017;v[a+32>>2]=2018;v[a+28>>2]=2019;v[a+24>>2]=2020;v[a+20>>2]=2021;v[a+16>>2]=2022;v[a+12>>2]=2023;v[a+8>>2]=2024;v[a+4>>2]=2025;v[a>>2]=2026}e=1}return e|0}a=P()|0;O()|0;v[22656]=0;X(20);b=v[22656];v[22656]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}function Pha(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;g=gb-16|0;gb=g;v[g+12>>2]=1;a:{if(bi(a)){n=g,o=ze(a),v[n+8>>2]=o;f=v[a>>2];c=b;k=v[Fb(g+12|0,g+8|0)>>2];if(k){while(1){d=c;if((c|0)!=(f|0)){h=Vb(d);l=Zb(d);i=gb-16|0;gb=i;j=AD(h,l);e=f;b:{if(j>>>0<=Pg(e)>>>0){if(tc(e)>>>0<j>>>0){v[i+8>>2]=h;jS(i+8|0,tc(e));m=h;h=v[i+8>>2];Vi(m,h,v[e>>2]);sS(e,h,l,j-tc(e)|0);break b}yn(e,Vi(h,l,v[e>>2]));break b}rS(e);aC(e,Vk(e,j));sS(e,h,l,j)}gb=i+16|0;ik(f+12|0,d+12|0);u[f+28>>1]=x[d+28>>1]}f=f+32|0;k=k-1|0;if(k){continue}break}}d=v[g+12>>2];c=v[g+8>>2];if(d>>>0>c>>>0){jB(a,d-c|0,b);break a}lS(a,v[a>>2]+(d<<5)|0);break a}c=a;if(v[c>>2]){ze(c);gS(c);eS(c);Yk(wb(c),v[c>>2],bi(c));n=wb(c),o=0,v[n>>2]=o;v[c>>2]=0;v[c+4>>2]=0}f=_q(a,1);if(zT()>>>0<f>>>0){Sc();L()}wb(c);d=dS(f);v[c>>2]=d;v[c+4>>2]=d;n=wb(c),o=d+(f<<5)|0,v[n>>2]=o;iB(c,0);jB(a,1,b)}gb=g+16|0}function cja(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;e=gb-32|0;gb=e;i=v[a+40>>2];j=v[a+36>>2];l=v[a+16>>2];b=v[a+4>>2];g=b;h=v[a>>2];v[e+24>>2]=h;v[e+28>>2]=b;b=v[a+12>>2];v[e+16>>2]=v[a+8>>2];v[e+20>>2]=b;a:{if(d){while(1){k=(((g&2147483647)<<1|h>>>31)&-2)+l|0;b=h>>>21&2040;h=u[b+46166>>1];m=u[b+46164>>1];n=u[b+46162>>1];o=u[b+46160>>1];f=0;b=1;while(1){v[(e+8|0)+(f<<2)>>2]=(((B(t[f+k|0],n)+B(t[(f|-2)+k|0],o)|0)+B(t[(f|2)+k|0],m)|0)+B(t[(f|4)+k|0],h)<<8)/16384;g=b;b=0;f=1;if(g){continue}break}g=v[a+32>>2];j=v[a+28>>2]+j|0;b=j>>12;v[c>>2]=v[c>>2]+B(b,v[e+8>>2]);i=g+i|0;f=i>>12;v[c+4>>2]=v[c+4>>2]+B(f,v[e+12>>2]);Ub(e+24|0,e+16|0);d=d-1|0;if(d){c=c+8|0;h=v[e+24>>2];g=v[e+28>>2];continue}break}h=v[e+24>>2];g=v[e+28>>2];break a}f=i>>12;b=j>>12}v[a+40>>2]=i;v[a+20>>2]=b;v[a+36>>2]=j;v[a+24>>2]=f;v[a>>2]=h;v[a+4>>2]=g;gb=e+32|0}function boa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;f=gb-32|0;gb=f;g=fg(a,c);se(f+8|0,v[a+28>>2]);d=v[f+20>>2];v[f+24>>2]=v[f+16>>2];v[f+28>>2]=d;a:{if(!g){if(nd(a,5)){break a}}d=gb-48|0;gb=d;h=v[a+28>>2];ag(h,d+46|0);b:{c:{d:{e:{f:{if(x[d+46>>1]>=4001){k=v[b+12>>2];e=gb-16|0;gb=e;i=d+16|0;j=Tb(e,13033);Dc(i,j);vb(j);gb=e+16|0;v[22656]=0;U(1092,d+32|0,i|0,d+46|0);e=v[22656];v[22656]=0;if((e|0)==1){break f}v[22656]=0;U(560,k|0,2,d+32|0);e=v[22656];v[22656]=0;if((e|0)==1){break e}vb(d+32|0);Hb(d+16|0);u[d+46>>1]=4e3}Af(Tj(b,0),x[d+46>>1]);b=Tj(b,0);l=d,m=Vb(b),v[l+32>>2]=m;l=d,m=Zb(b),v[l+16>>2]=m;if(Gb(d+32|0,d+16|0)){break c}break b}a=P()|0;O()|0;break d}a=P()|0;O()|0;vb(d+32|0)}Hb(d+16|0);S(a|0);L()}while(1){b=d+32|0;e=v[b>>2];ag(h,d+14|0);u[e>>1]=x[d+14>>1];of(b);if(Gb(b,d+16|0)){continue}break}}gb=d+48|0}Zf(a,g,c,f+24|0);gb=f+32|0}function s7(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;c=gb+-64|0;gb=c;e=v[a>>2];a=v[e>>2];f=v[a+4>>2];v[c+40>>2]=v[a+20>>2];d=v[a+16>>2];v[c+32>>2]=v[a+12>>2];v[c+36>>2]=d;Jf(c+48|0,c+32|0,f);a=v[e+4>>2];e=v[a+4>>2];f=v[a+8>>2];d=v[c+60>>2];v[c+24>>2]=v[c+56>>2];v[c+28>>2]=d;d=v[c+52>>2];v[c+16>>2]=v[c+48>>2];v[c+20>>2]=d;v[c+8>>2]=v[a+8>>2];d=v[a+4>>2];v[c>>2]=v[a>>2];v[c+4>>2]=d;h=c+16|0;a=c;a:{if(y[c+4>>2]>=e>>>0){if(y[h+4>>2]>=e>>>0){if(y[a+8>>2]>=f>>>0){if(If(h)>>>0>=f>>>0){if(f){i=b+12|0;while(1){b=0;if(e){while(1){d=id((v[Xg(a,b,g)>>2]+id(yt(i),21)|0)+2048|0,12);if((d|0)<-32768){d=-32768}if((d|0)>32767){d=32767}j=fo(h,b,g),k=d,u[j>>1]=k;b=b+1|0;if((b|0)!=(e|0)){continue}break}}g=g+1|0;if((g|0)!=(f|0)){continue}break}}break a}aa(2959,6176,36,5889);L()}aa(2989,6176,35,5889);L()}aa(4211,6176,34,5889);L()}aa(4246,6176,33,5889);L()}gb=c- -64|0}function Cm(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;sl(a);a:{b:{c:{g=v[b+32>>2];d:{if(!g){d=v[b+2084>>2];if(d){break d}break b}f=v[b+4>>2];if((f|0)<9){break c}d=v[b+2084>>2];if(!d){break c}}h=v[a+1392>>2];j=Bm(h);e=v[b+2092>>2];if((e|0)>=2){while(1){f=e>>>1|0;i=f+c|0;g=j>>>0<y[(i<<2)+d>>2];c=g?c:i;e=g?f:e-f|0;if((e|0)>1){continue}break}}e=a;d=v[a+1396>>2];c=w[b+23|0]?c:v[v[b+2088>>2]+(c<<2)>>2];b=w[c+v[b+8>>2]|0];e:{if((d|0)<(b|0)){c=-1;a=0;break e}v[a+1392>>2]=h>>>b;a=d-b|0}v[e+1396>>2]=a;return c}if(w[b+23|0]){break a}if((f|0)>0){d=v[b+8>>2];while(1){f:{e=w[c+d|0];if((e|0)==255){break f}h=v[a+1392>>2];if(v[g+(c<<2)>>2]!=(h&(-1<<e^-1))){break f}d=v[a+1396>>2];if((d|0)>=(e|0)){v[a+1392>>2]=h>>>e;v[a+1396>>2]=d-w[v[b+8>>2]+c|0];return c}v[a+1396>>2]=0;break b}c=c+1|0;if((f|0)!=(c|0)){continue}break}}ec(a,21);v[a+1396>>2]=0}return-1}aa(8668,10534,1705,2537);L()}function B7(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;c=gb+-64|0;gb=c;e=v[a>>2];a=v[e>>2];f=v[a+4>>2];v[c+40>>2]=v[a+20>>2];d=v[a+16>>2];v[c+32>>2]=v[a+12>>2];v[c+36>>2]=d;Jf(c+48|0,c+32|0,f);a=v[e+4>>2];e=v[a+4>>2];f=v[a+8>>2];d=v[c+60>>2];v[c+24>>2]=v[c+56>>2];v[c+28>>2]=d;d=v[c+52>>2];v[c+16>>2]=v[c+48>>2];v[c+20>>2]=d;v[c+8>>2]=v[a+8>>2];d=v[a+4>>2];v[c>>2]=v[a>>2];v[c+4>>2]=d;h=c+16|0;a=c;a:{if(y[c+4>>2]>=e>>>0){if(y[h+4>>2]>=e>>>0){if(y[a+8>>2]>=f>>>0){if(If(h)>>>0>=f>>>0){if(f){i=b+12|0;while(1){b=0;if(e){while(1){d=id((v[Xg(a,b,g)>>2]+id(yt(i),21)|0)+2048|0,12);if((d|0)<-32768){d=-32768}if((d|0)>32767){d=32767}j=go(h,b,g),k=d,u[j>>1]=k;b=b+1|0;if((b|0)!=(e|0)){continue}break}}g=g+1|0;if((g|0)!=(f|0)){continue}break}}break a}aa(2959,6176,36,5889);L()}aa(2989,6176,35,5889);L()}aa(4211,6176,34,5889);L()}aa(4246,6176,33,5889);L()}gb=c- -64|0}function Lx(a){var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;h=Nf(a);a:{if(!v[115994]|!w[a|0]){break a}c=a;b:{if(c&3){while(1){b=w[c|0];if(!b|(b|0)==61){break b}c=c+1|0;if(c&3){continue}break}}b=v[c>>2];c:{if((b^-1)&b-16843009&-2139062144){break c}while(1){b=b^1027423549;if((b^-1)&b-16843009&-2139062144){break c}b=v[c+4>>2];c=c+4|0;if(!(b-16843009&(b^-1)&-2139062144)){continue}break}}while(1){b=c;e=w[c|0];if(e){c=b+1|0;if((e|0)!=61){continue}}break}c=b}if(w[c|0]==61?c:0){break a}d=v[v[115994]>>2];if(!d){break a}d:{while(1){i=v[115994];c=a;e=0;g=h;b=0;e:{if(!g){break e}b=w[c|0];f:{if(!b){break f}while(1){g:{j=w[d|0];if(!j){break g}g=g-1|0;if(!g|(b|0)!=(j|0)){break g}d=d+1|0;b=w[c+1|0];c=c+1|0;if(b){continue}break f}break}e=b}b=(e&255)-w[d|0]|0}if(!b){c=v[(f<<2)+i>>2]+h|0;if(w[c|0]==61){break d}}f=f+1|0;d=v[(f<<2)+i>>2];if(d){continue}break}return 0}f=c+1|0}return f}function Kma(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;e=gb-16|0;gb=e;u[e+12>>1]=0;v[e+8>>2]=0;if(d){l=B(c,d);n=(l|0)<=0;j=4;while(1){if(!n){i=b+k|0;o=l+i|0;while(1){p=g;t[e+7|0]=0;HV(a,e+15|0,e+12|0,e+7|0);a:{if(!j){g=w[e+7|0];break a}g=w[e+7|0];c=x[e+12>>1];f=j;b:{while(1){h=c<<1;c=h&254;c:{if(c){h=(h&65534)>>>0>255;break c}if(!lf(a,e+6|0)){break b}c=w[e+6|0];h=c>>>7|0;c=c<<1&254|1}g=g<<1|h;f=f-1|0;if(f&255){continue}break}u[e+12>>1]=c;break a}u[e+12>>1]=0}c=1;m=g&255;d:{if(m>>>0<4){break d}f=7;while(1){c=f;h=c&255;if(m>>>h&1){break d}f=c-1|0;if(h>>>0>1){continue}break}}f=g&1;t[e+15|0]=f;f=f-1^(g&254)>>>1;g=f+w[e+8|0]|0;t[e+7|0]=g;t[i|0]=g;v[e+8>>2]=((f>>1)-(p<<24>>24)|0)+(g<<24>>24<<1);Zd(e+8|0,-128,127);j=(c+j&254)>>>1|0;i=d+i|0;if(o>>>0>i>>>0){continue}break}}k=k+1|0;if((k|0)!=(d|0)){continue}break}}gb=e+16|0}function Gja(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;h=gb-16|0;gb=h;e=v[a+48>>2];l=v[a+24>>2];m=v[a+20>>2];b=v[a+44>>2];n=v[a+16>>2];g=v[a+4>>2];i=v[a>>2];v[h+8>>2]=i;v[h+12>>2]=g;f=v[a+12>>2];v[h>>2]=v[a+8>>2];v[h+4>>2]=f;a:{if(!d){f=b;b=e;break a}while(1){i=u[(g<<1)+n>>1];j=v[a+60>>2];f=Lb(b,-16777216,16776704);k=v[a+64>>2];g=Lb(e,-16777216,16776704);i=i<<8;e=i;e=kqa(j,j>>31,e,e>>31);j=jb;k=kqa(k,k>>31,f,f>>31);f=k+e|0;e=jb+j|0;e=f>>>0<k>>>0?e+1|0:e;j=f;f=v[a+68>>2];g=kqa(f,f>>31,g,g>>31);f=j+g|0;e=jb+e|0;e=f>>>0<g>>>0?e+1|0:e;f=f+8388608|0;e=f>>>0<8388608?e+1|0:e;e=Jc(f,e,24);f=v[a+72>>2];g=(e|0)/256|0;v[c>>2]=v[c>>2]+B(g,m);v[c+4>>2]=v[c+4>>2]+B(g,l);f=e-(f&i)|0;Ub(h+8|0,h);d=d-1|0;if(d){c=c+8|0;g=v[h+12>>2];e=b;b=f;continue}break}i=v[h+8>>2];g=v[h+12>>2]}v[a+48>>2]=b;v[a+44>>2]=f;v[a>>2]=i;v[a+4>>2]=g;gb=h+16|0}function wA(a,b){var c=0,d=0,e=0,f=0,g=0;d=x[a+480188>>1];a:{if(d>>>0<=255){f=a+1298260|0;while(1){e=B(d,872)+a|0;c=e+1075068|0;b:{if(v[c>>2]){break b}if(!tk(e+1074992|0)){break a}if(v[c>>2]){break b}if(w[e+1075081|0]&24){break a}}if(w[e+1075081|0]&2){if(!Dd(f)){break a}if(!DP(v[f>>2],d&65535)){break a}}d=d+1|0;if((d&65535)!=256){continue}break}}g=8388608;if(b>>>0<=255){b=B(b,872)+a|0;if(!v[b+1075688>>2]){d=65535;if(v[b+1075068>>2]){break a}}g=v[b+1075680>>2]|v[b+1075672>>2]<<9}d=65535;b=x[a+480188>>1];if(b>>>0>255){break a}e=0;while(1){c=B(b,872)+a|0;if(!(v[c+1075688>>2]?0:v[c+1075068>>2])){f=(v[c+1075680>>2]|v[c+1075672>>2]<<9)>>>(v[c+1075080>>2]>>>1&1)|0;c:{d:{if(f>>>0<g>>>0){c=v[c+1075716>>2];break d}if((f|0)!=(g|0)){break c}c=v[c+1075716>>2];if(e>>>0>=c>>>0){break c}}g=f;d=b;e=c}b=b+1|0;if((b&65535)!=256){continue}break a}break}d=b}return d&65535}function jea(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;e=gb-32|0;gb=e;v[e+24>>2]=d;j=fg(a,c);se(e,v[a+28>>2]);d=v[e+12>>2];v[e+16>>2]=v[e+8>>2];v[e+20>>2]=d;a:{if(!j){if(nd(a,5)){break a}}l=v[e+24>>2];d=gb-48|0;gb=d;h=v[a+28>>2];zl(h,d+40|0);f=v[d+44>>2];if(!f&y[d+40>>2]>=257|f){v[d+40>>2]=256;v[d+44>>2]=0}b:{c:{d:{e:{f:{if(v[d+40>>2]|v[d+44>>2]){while(1){ag(h,d+38|0);f=Kb(d+24|0);v[22656]=0;W(655,h|0,f|0,255)|0;g=v[22656];v[22656]=0;if((g|0)==1){break f}v[22656]=0;U(13,d+8|0,l|0,f|0);g=v[22656];v[22656]=0;if((g|0)==1){break e}v[22656]=0;g=Q(1515,b|0,d+38|0)|0;i=v[22656];v[22656]=0;if((i|0)==1){break d}i=g;g=d+8|0;Eb(i,g);vb(g);vb(f);f=v[d+44>>2];k=k+1|0;if(!f&k>>>0<y[d+40>>2]|f){continue}break}}gb=d+48|0;break b}a=P()|0;O()|0;break c}a=P()|0;O()|0;break c}a=P()|0;O()|0;vb(d+8|0)}vb(f);S(a|0);L()}}Zf(a,j,c,e+16|0);gb=e+32|0}function i3(){var a=0,b=0,c=0,d=0;c=gb-32|0;gb=c;a:{a=Tb(c+16|0,12139);if(!Ab(a)){break a}b:{if((xg(a,11846)|0)!=-1){b=xg(a,11846);v[22656]=0;Y(151,c|0,a|0,b+1|0,-1);b=v[22656];v[22656]=0;if((b|0)==1){break b}Eb(a,c);vb(c)}if((xg(a,13873)|0)!=-1){b=xg(a,13873);v[22656]=0;Y(151,c|0,a|0,b+1|0,-1);b=v[22656];v[22656]=0;if((b|0)==1){break b}Eb(a,c);vb(c)}if((xg(a,11163)|0)!=-1){b=xg(a,11163);v[22656]=0;Y(151,c|0,a|0,0,b|0);b=v[22656];v[22656]=0;if((b|0)==1){break b}Eb(a,c);vb(c)}if((xg(a,11038)|0)!=-1){b=xg(a,11038);v[22656]=0;Y(151,c|0,a|0,0,b|0);b=v[22656];v[22656]=0;if((b|0)==1){break b}Eb(a,c);vb(c)}if((xg(a,11081)|0)!=-1){b=xg(a,11081);v[22656]=0;Y(151,c|0,a|0,0,b|0);b=v[22656];v[22656]=0;if((b|0)==1){break b}Eb(a,c);vb(c)}v[22656]=0;b=T(152,a|0)|0;d=v[22656];v[22656]=0;if((d|0)!=1){break a}}c=P()|0;O()|0;vb(a);S(c|0);L()}vb(a);gb=c+32|0;return b|0}function Aaa(a){a=a|0;var b=0,c=0,d=0,e=0,f=0;c=gb-48|0;gb=c;v[22656]=0;_(1934,a|0);b=v[22656];v[22656]=0;a:{b:{c:{if((b|0)!=1){d=Kb(c+32|0);b=v[a+24>>2];v[22656]=0;R(1959,c+16|0,b|0);b=v[22656];v[22656]=0;d:{if((b|0)!=1){b=c+16|0;e=c,f=Vb(b),v[e+8>>2]=f;e=c,f=Zb(b),v[e>>2]=f;if(!Gb(c+8|0,c)){break b}while(1){e:{b=v[c+8>>2];v[22656]=0;Q(1168,d|0,b|0)|0;b=v[22656];v[22656]=0;if((b|0)==1){break e}b=c+8|0;sr(b);e=c,f=Zb(c+16|0),v[e>>2]=f;if(!Gb(b,c)){break b}v[22656]=0;Q(1917,d|0,11821)|0;b=v[22656];v[22656]=0;if((b|0)!=1){continue}}break}b=V(0)|0;O()|0;yd(c+16|0);break d}b=V(0)|0;O()|0}vb(d);break c}b=V(0)|0;O()|0}Z(b|0)|0;b=0;v[22656]=0;Y(1911,3648,a|0,0,0);a=v[22656];v[22656]=0;if((a|0)!=1){$();break a}a=P()|0;O()|0;v[22656]=0;X(20);c=v[22656];v[22656]=0;if((c|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}b=ie(Jb(d));yd(c+16|0);vb(d)}gb=c+48|0;return b|0}function V9(a){a=a|0;var b=0,c=0,d=0,e=0,f=0;c=gb-48|0;gb=c;v[22656]=0;_(1934,a|0);b=v[22656];v[22656]=0;a:{b:{c:{if((b|0)!=1){d=Kb(c+32|0);b=v[a+24>>2];v[22656]=0;R(1994,c+16|0,b|0);b=v[22656];v[22656]=0;d:{if((b|0)!=1){b=c+16|0;e=c,f=Vb(b),v[e+8>>2]=f;e=c,f=Zb(b),v[e>>2]=f;if(!Gb(c+8|0,c)){break b}while(1){e:{b=v[c+8>>2];v[22656]=0;Q(1168,d|0,b|0)|0;b=v[22656];v[22656]=0;if((b|0)==1){break e}b=c+8|0;sr(b);e=c,f=Zb(c+16|0),v[e>>2]=f;if(!Gb(b,c)){break b}v[22656]=0;Q(1917,d|0,11821)|0;b=v[22656];v[22656]=0;if((b|0)!=1){continue}}break}b=V(0)|0;O()|0;yd(c+16|0);break d}b=V(0)|0;O()|0}vb(d);break c}b=V(0)|0;O()|0}Z(b|0)|0;b=0;v[22656]=0;Y(1911,4111,a|0,0,0);a=v[22656];v[22656]=0;if((a|0)!=1){$();break a}a=P()|0;O()|0;v[22656]=0;X(20);c=v[22656];v[22656]=0;if((c|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}b=ie(Jb(d));yd(c+16|0);vb(d)}gb=c+48|0;return b|0}function Hja(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;h=gb-16|0;gb=h;e=v[a+48>>2];l=v[a+24>>2];m=v[a+20>>2];b=v[a+44>>2];n=v[a+16>>2];g=v[a+4>>2];i=v[a>>2];v[h+8>>2]=i;v[h+12>>2]=g;f=v[a+12>>2];v[h>>2]=v[a+8>>2];v[h+4>>2]=f;a:{if(!d){f=b;b=e;break a}while(1){i=t[g+n|0];j=v[a+60>>2];f=Lb(b,-16777216,16776704);k=v[a+64>>2];g=Lb(e,-16777216,16776704);i=i<<16;e=i;e=kqa(j,j>>31,e,e>>31);j=jb;k=kqa(k,k>>31,f,f>>31);f=k+e|0;e=jb+j|0;e=f>>>0<k>>>0?e+1|0:e;j=f;f=v[a+68>>2];g=kqa(f,f>>31,g,g>>31);f=j+g|0;e=jb+e|0;e=f>>>0<g>>>0?e+1|0:e;f=f+8388608|0;e=f>>>0<8388608?e+1|0:e;e=Jc(f,e,24);f=v[a+72>>2];g=(e|0)/256|0;v[c>>2]=v[c>>2]+B(g,m);v[c+4>>2]=v[c+4>>2]+B(g,l);f=e-(f&i)|0;Ub(h+8|0,h);d=d-1|0;if(d){c=c+8|0;g=v[h+12>>2];e=b;b=f;continue}break}i=v[h+8>>2];g=v[h+12>>2]}v[a+48>>2]=b;v[a+44>>2]=f;v[a>>2]=i;v[a+4>>2]=g;gb=h+16|0}function DU(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;c=gb-48|0;gb=c;v[a>>2]=0;v[a+4>>2]=0;v[c+44>>2]=0;wb(b);ff(a+8|0,c+44|0,c+40|0);if(v[b+4>>2]){Yr(a,v[b+4>>2]);Ak(c+32|0,b);Vl(c+24|0,b);b=v[c+36>>2];v[c+16>>2]=v[c+32>>2];v[c+20>>2]=b;b=v[c+28>>2];v[c+8>>2]=v[c+24>>2];v[c+12>>2]=b;b=gb-80|0;gb=b;f=a;g=v[a+4>>2];d=v[c+20>>2];j=d;h=v[c+16>>2];v[b+72>>2]=h;v[b+76>>2]=d;e=v[c+12>>2];k=e;i=v[c+8>>2];v[b+64>>2]=i;v[b+68>>2]=e;v[b+24>>2]=h;v[b+28>>2]=d;v[b+16>>2]=i;v[b+20>>2]=e;d=CU(b+24|0,b+16|0)+v[a+4>>2]|0;v[a+4>>2]=d;a:{b:{if(!g){e=d-1|0;break b}e=d-1|0;if((e^g-1)>>>0<32){break a}}v[v[f>>2]+((d>>>0<33?0:e>>>5|0)<<2)>>2]=0}v[b+48>>2]=i;v[b+52>>2]=k;v[b+56>>2]=h;v[b+60>>2]=j;d=b+40|0;zp(d,f,g);f=v[b+60>>2];v[b+8>>2]=v[b+56>>2];v[b+12>>2]=f;f=v[b+52>>2];v[b>>2]=v[b+48>>2];v[b+4>>2]=f;BU(b+32|0,b+8|0,b,d);gb=b+80|0}gb=c+48|0;return a|0}function W8(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;c=gb-32|0;gb=c;k=c,l=zL(),v[k+24>>2]=l;d=c+24|0;xL(a+24|0,ce(d));Di(d);u[a+28>>1]=0;g=cY();v[c+16>>2]=4;e=c;h=gb-16|0;gb=h;f=sf(144);j=c+16|0;i=v[j>>2];v[22656]=0;g=W(2052,f|0,g|0,i|0)|0;i=v[22656];v[22656]=0;a:{if((i|0)!=1){f=v[Wi(h+8|0,g)>>2];gb=h+16|0;break a}a=P()|0;O()|0;Yb(f);S(a|0);L()}v[e+24>>2]=f;wL(a+32|0,ce(d));iq(d);k=c,l=yL(v[a>>2]),v[k+24>>2]=l;vL(a+4|0,ce(d));Ci(d);no(v[a+24>>2],v[a+4>>2]);v[a+60>>2]=0;v[a+48>>2]=1065353216;v[a+52>>2]=0;v[a+16>>2]=0;v[a+20>>2]=0;v[a+8>>2]=0;t[a- -64|0]=0;k=c,l=or(b),v[k+24>>2]=l;k=c,l=Dh(b),v[k+16>>2]=l;b:{if(og(d,j)){while(1){e=ue(c+24|0);b=gg(c,e);v[22656]=0;Y(2e3,a|0,b|0,e+12|0,0);e=v[22656];v[22656]=0;if((e|0)==1){break b}vb(b);b=c+24|0;Uj(b);if(og(b,c+16|0)){continue}break}}gb=c+32|0;return}a=P()|0;O()|0;vb(b);S(a|0);L()}function oA(a,b){var c=0;c=gb-16|0;gb=c;a=sA(a);a:{b:{c:{switch(b-1|0){default:if((b|0)!=16777216){break b}Ob(a,7,1);Ob(a,9,1);Ob(a,10,1);Ob(a,13,1);Ob(a,15,1);Ob(a,16,1);Ob(a,17,1);Ob(a,18,1);Ob(a,20,1);Ob(a,21,1);Ob(a,24,1);Ob(a,25,1);Ob(a,26,1);Ob(a,28,1);Ob(a,30,1);Ob(a,31,1);Ob(a,33,1);Ob(a,34,1);Ob(a,39,1);Ob(a,41,1);Ob(a,44,1);Ob(a,46,1);Ob(a,45,1);Ob(a,47,1);Ob(a,48,1);Ob(a,50,1);Ob(a,99,1);Ob(a,102,1);Ob(a,104,1);Ob(a,105,1);Ob(a,115,1);break a;case 1:mA(c,2);b=v[c+12>>2];v[a+8>>2]=v[c+8>>2];v[a+12>>2]=b;b=v[c+4>>2];v[a>>2]=v[c>>2];v[a+4>>2]=b;Rf(a,107);break a;case 3:mA(c,4);b=v[c+12>>2];v[a+8>>2]=v[c+8>>2];v[a+12>>2]=b;b=v[c+4>>2];v[a>>2]=v[c>>2];v[a+4>>2]=b;Rf(a,4);break a;case 2:break b;case 0:break c}}Ob(a,88,1);break a}mA(c,b);b=v[c+12>>2];v[a+8>>2]=v[c+8>>2];v[a+12>>2]=b;b=v[c+4>>2];v[a>>2]=v[c>>2];v[a+4>>2]=b}gb=c+16|0}function nN(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;h=gb-32|0;gb=h;l=h,m=ar(b),v[l+16>>2]=m;i=h+24|0;k=i;c=gb-32|0;gb=c;f=b;d=a;b=Yd(d);e=fc(d);a:{b:{if(b){d=wb(d);c:{while(1){d:{g=b+16|0;e:{if(eN(d,f,g)){if(!v[b>>2]){break b}e=b;break e}if(!dN(g,f)){break c}e=b+4|0;if(!v[b+4>>2]){break d}b=e;e=b}b=v[b>>2];continue}break}v[c+28>>2]=b;b=e;break a}v[c+28>>2]=b;b=e;break a}b=fc(d)}v[c+28>>2]=b}e=b;b=v[b>>2];t[c+27|0]=0;if(!b){d=gb-16|0;gb=d;b=fc(a);f=c+8|0;g=Vj(f,_W(),Wj(d+8|0,b));b=v[g>>2];v[22656]=0;j=b+16|0;b=v[22656];v[22656]=0;f:{if((b|0)!=1){b=gb-16|0;gb=b;v[b+8>>2]=v[h+16>>2];u[j>>1]=x[v[b+8>>2]>>1];Kb(j+4|0);gb=b+16|0;l=fc(g),m=1,t[l+4|0]=m;gb=d+16|0;break f}a=P()|0;O()|0;cN(g);S(a|0);L()}Hk(a,v[c+28>>2],e,v[f>>2]);b=ce(f);t[c+27|0]=1;cN(f)}Xj(k,yc(c+8|0,b),c+27|0);gb=c+32|0;a=ue(i);gb=h+32|0;return a+4|0}function jga(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0;i=a;if(!((e|0)>0|(e|0)>=0|(b|0)==(c|0))){t[b|0]=45;f=d;d=0-d|0;e=0-(((f|0)!=0)+e|0)|0;b=b+1|0}a:{b:{f=c-b|0;if((f|0)<=19){g=E(e);g=B(64-((g|0)==32?E(d|1)+32|0:g)|0,1233)>>>12|0;h=(g<<3)+27088|0;j=f;f=v[h+4>>2];if((j|0)<((g-((e|0)==(f|0)&d>>>0<y[h>>2]|e>>>0<f>>>0)|0)+1|0)){break b}}c=a;c:{if(!e&d>>>0<=99999999){a=by(b,d);break c}if((e|0)==2328306&d>>>0<=1874919423|e>>>0<2328306){a=nqa(d,e,1e8,0);e=jb;f=by(b,a);a=d-kqa(a,e,1e8,0)|0;b=(a>>>0)/1e4|0;a=vj(vj(f,b),a-B(b,1e4)|0);break c}a=nqa(d,e,1874919424,2328306);f=jb;g=ay(b,a);a=kqa(a,f,1874919424,2328306);b=d-a|0;a=nqa(b,e-(jb+(a>>>0>d>>>0)|0)|0,1e8,0);e=jb;f=(a>>>0)/1e4|0;d=vj(vj(g,f),a-B(f,1e4)|0);a=b-kqa(a,e,1e8,0)|0;b=(a>>>0)/1e4|0;a=vj(vj(d,b),a-B(b,1e4)|0)}v[c>>2]=a;a=0;break a}v[a>>2]=c;a=61}v[i+4>>2]=a}function wga(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=C(0),i=C(0),j=C(0),k=0,m=0;f=gb-16|0;gb=f;k=f,m=B(v[a>>2],fd(a)),v[k>>2]=m;qc(f,c>>>2|0);c=zb(b);h=z[e+4>>2];e=v[f>>2];if(e){while(1){g=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);j=C(D((l(2,g<<24|g<<8&16711680|(g>>>8&65280|g>>>24)),q())));h=h<j?j:h;c=c+4|0;e=e-1|0;if(e){continue}break}}c=h==C(0);a:{if(c){break a}e=v[f>>2];if(!e){break a}j=c?C(1):C(C(1)/h);c=v[a+20>>2];while(1){a=w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24);z[f+12>>2]=j*(l(2,a<<24|a<<8&16711680|(a>>>8&65280|a>>>24)),q());v[f+8>>2]=-1082130432;v[f+4>>2]=1065353216;i=C(z[zf(f+12|0,f+8|0,f+4|0)>>2]*C(32768));z[f+12>>2]=i;a=c;i=fe(i);b:{if(C(D(i))<C(2147483648)){g=~~i;break b}g=-2147483648}k=a,m=Uc(g),u[k>>1]=m;b=b+4|0;c=c+2|0;e=e-1|0;if(e){continue}break}}if(d){z[d>>2]=h}gb=f+16|0;return v[f>>2]<<2}function zia(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;g=gb-16|0;gb=g;i=v[a+40>>2];j=v[a+36>>2];l=v[a+16>>2];h=v[a+4>>2];e=h;f=v[a>>2];v[g+8>>2]=f;v[g+12>>2]=e;h=v[a+12>>2];v[g>>2]=v[a+8>>2];v[g+4>>2]=h;a:{if(d){while(1){k=v[a+32>>2];j=v[a+28>>2]+j|0;h=j>>12;e=(e<<1)+l|0;f=(((f>>>16|0)+4&131064)<<1)+b|0;e=(((((B(u[e+4>>1],u[f+34>>1])+B(u[e+2>>1],u[f+32>>1])|0)+B(u[e+6>>1],u[f+36>>1])|0)+B(u[e+8>>1],u[f+38>>1])|0)/2|0)+((((B(u[e-4>>1],u[f+26>>1])+B(u[e-6>>1],u[f+24>>1])|0)+B(u[e-2>>1],u[f+28>>1])|0)+B(u[e>>1],u[f+30>>1])|0)/2|0)|0)/16384|0;v[c>>2]=v[c>>2]+B(h,e);i=i+k|0;k=i>>12;v[c+4>>2]=v[c+4>>2]+B(e,k);Ub(g+8|0,g);d=d-1|0;if(d){c=c+8|0;f=v[g+8>>2];e=v[g+12>>2];continue}break}f=v[g+8>>2];e=v[g+12>>2];break a}k=i>>12;h=j>>12}v[a+40>>2]=i;v[a+20>>2]=h;v[a+36>>2]=j;v[a+24>>2]=k;v[a>>2]=f;v[a+4>>2]=e;gb=g+16|0}function Vpa(){var a=0,b=0,c=0;b=gb-16|0;gb=b;Kb(90636);a=gb-16|0;gb=a;v[a+12>>2]=0;v[22662]=v[a+12>>2];gb=a+16|0;t[90652]=0;a=gb-16|0;gb=a;v[a+12>>2]=0;v[22664]=v[a+12>>2];gb=a+16|0;v[22656]=0;a=ga(36)|0;c=v[22656];v[22656]=0;a:{b:{c:{d:{e:{if((c|0)!=1){v[b+8>>2]=a;a=b+8|0;QX(90648,ce(a));vD(a);t[90652]=0;a=0;break e}a=Ca(89116,89092)|0;c=O()|0;if((ea(89116)|0)==(c|0)){Z(a|0)|0;v[22656]=0;X(37);a=v[22656];v[22656]=0;if((a|0)==1){break c}L()}if((ea(89092)|0)!=(c|0)){break b}Z(a|0)|0;v[22656]=0;t[90652]=0;X(20);a=v[22656];v[22656]=0;if((a|0)==1){a=P()|0;O()|0;break b}a=w[90652]}if(a&255){break d}v[22656]=0;_(38,90632);a=v[22656];v[22656]=0;if((a|0)!=1){break d}a=P()|0;O()|0;break b}gb=b+16|0;return}a=P()|0;O()|0;v[22656]=0;X(20);b=v[22656];v[22656]=0;if((b|0)==1){break a}}ln(90656);vD(90648);vb(90636);S(a|0);L()}V(0)|0;O()|0;Bb();L()}function E8(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0;f=gb+-64|0;gb=f;v[f+56>>2]=d;d=pi(a,f+56|0);g=zh(a+4|0);h=zh(a+24|0);i=zh(a+32|0);j=dd(a+36|0);v[a+56>>2]=3;k=mc(a+68|0);v[22656]=0;R(2079,a|0,e|0);l=v[22656];v[22656]=0;a:{b:{c:{d:{if((l|0)!=1){v[22656]=0;bc(f+24|0,b,c);b=v[22656];v[22656]=0;if((b|0)==1){break d}b=Ud(f+16|0);v[22656]=0;c=v[f+28>>2];v[f+8>>2]=v[f+24>>2];v[f+12>>2]=c;c=v[b+4>>2];v[f>>2]=v[b>>2];v[f+4>>2]=c;U(2083,f+32|0,f+8|0,f|0);b=v[22656];v[22656]=0;if((b|0)==1){break d}v[22656]=0;U(2080,a|0,f+32|0,e|0);b=v[22656];v[22656]=0;if((b|0)==1){break c}xb(f+32|0);v[22656]=0;_(2081,a|0);b=v[22656];v[22656]=0;if((b|0)!=1){break a}}a=P()|0;O()|0;break b}a=P()|0;O()|0;break b}a=P()|0;O()|0;xb(f+32|0)}yd(k);Yf(j);iq(i);Di(h);Ci(g);eg(d);eg(f+56|0);S(a|0);L()}eg(f+56|0);gb=f- -64|0;return a|0}function t7(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;b=gb+-64|0;gb=b;d=v[a>>2];a=v[d>>2];e=v[a+4>>2];v[b+40>>2]=v[a+20>>2];c=v[a+16>>2];v[b+32>>2]=v[a+12>>2];v[b+36>>2]=c;Jf(b+48|0,b+32|0,e);a=v[d+4>>2];d=v[a+4>>2];e=v[a+8>>2];c=v[b+60>>2];v[b+24>>2]=v[b+56>>2];v[b+28>>2]=c;c=v[b+52>>2];v[b+16>>2]=v[b+48>>2];v[b+20>>2]=c;v[b+8>>2]=v[a+8>>2];c=v[a+4>>2];v[b>>2]=v[a>>2];v[b+4>>2]=c;h=b+16|0;a=b;a:{if(d>>>0<=y[b+4>>2]){if(d>>>0<=y[h+4>>2]){if(e>>>0<=y[a+8>>2]){if(If(h)>>>0>=e>>>0){if(e){while(1){c=0;if(d){while(1){f=id(v[Xg(a,c,g)>>2]+2048|0,12);if((f|0)<-32768){f=-32768}if((f|0)>32767){f=32767}i=fo(h,c,g),j=f,u[i>>1]=j;c=c+1|0;if((d|0)!=(c|0)){continue}break}}g=g+1|0;if((e|0)!=(g|0)){continue}break}}break a}aa(2959,6176,36,5889);L()}aa(2989,6176,35,5889);L()}aa(4211,6176,34,5889);L()}aa(4246,6176,33,5889);L()}gb=b- -64|0}function C7(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;b=gb+-64|0;gb=b;d=v[a>>2];a=v[d>>2];e=v[a+4>>2];v[b+40>>2]=v[a+20>>2];c=v[a+16>>2];v[b+32>>2]=v[a+12>>2];v[b+36>>2]=c;Jf(b+48|0,b+32|0,e);a=v[d+4>>2];d=v[a+4>>2];e=v[a+8>>2];c=v[b+60>>2];v[b+24>>2]=v[b+56>>2];v[b+28>>2]=c;c=v[b+52>>2];v[b+16>>2]=v[b+48>>2];v[b+20>>2]=c;v[b+8>>2]=v[a+8>>2];c=v[a+4>>2];v[b>>2]=v[a>>2];v[b+4>>2]=c;h=b+16|0;a=b;a:{if(d>>>0<=y[b+4>>2]){if(d>>>0<=y[h+4>>2]){if(e>>>0<=y[a+8>>2]){if(If(h)>>>0>=e>>>0){if(e){while(1){c=0;if(d){while(1){f=id(v[Xg(a,c,g)>>2]+2048|0,12);if((f|0)<-32768){f=-32768}if((f|0)>32767){f=32767}i=go(h,c,g),j=f,u[i>>1]=j;c=c+1|0;if((d|0)!=(c|0)){continue}break}}g=g+1|0;if((e|0)!=(g|0)){continue}break}}break a}aa(2959,6176,36,5889);L()}aa(2989,6176,35,5889);L()}aa(4211,6176,34,5889);L()}aa(4246,6176,33,5889);L()}gb=b- -64|0}function yp(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;f=gb-16|0;gb=f;a:{if(!b){break a}if(c){c=ne(f+8|0,a);a=gb-16|0;gb=a;v[a+12>>2]=b;d=v[c+4>>2];b:{if(!d){d=v[c>>2];break b}v[a+8>>2]=32-d;b=Fb(a+8|0,a+12|0);d=v[c>>2];b=v[b>>2];v[d>>2]=v[d>>2]|-1<<v[c+4>>2]&-1>>>v[a+8>>2]-b;b=v[a+12>>2]-b|0;v[a+12>>2]=b;d=d+4|0;v[c>>2]=d}e=d;d=b>>>5<<2;Qb(e,255,d);b=v[a+12>>2]-(b&-32)|0;v[a+12>>2]=b;if(b){e=c;c=d+v[c>>2]|0;v[e>>2]=c;v[c>>2]=v[c>>2]|-1>>>32-b}gb=a+16|0;break a}c=ne(f,a);a=gb-16|0;gb=a;v[a+12>>2]=b;d=v[c+4>>2];c:{if(!d){d=v[c>>2];break c}v[a+8>>2]=32-d;b=Fb(a+8|0,a+12|0);d=v[c>>2];b=v[b>>2];v[d>>2]=v[d>>2]&(-1<<v[c+4>>2]&-1>>>v[a+8>>2]-b^-1);b=v[a+12>>2]-b|0;v[a+12>>2]=b;d=d+4|0;v[c>>2]=d}e=d;d=b>>>5<<2;Qb(e,0,d);b=v[a+12>>2]-(b&-32)|0;v[a+12>>2]=b;if(b){e=c;c=d+v[c>>2]|0;v[e>>2]=c;v[c>>2]=v[c>>2]&(-1>>>32-b^-1)}gb=a+16|0}gb=f+16|0}function Cga(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=C(0),g=0,h=0,i=0,j=0;d=gb-16|0;gb=d;v[d+12>>2]=c>>>3;v[d+8>>2]=v[a>>2];c=v[Fb(d+12|0,d+8|0)>>2];b=zb(b);if(c){a=v[a+20>>2];h=c;while(1){e=w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24);v[d+12>>2]=e<<24|e<<8&16711680|(e>>>8&65280|e>>>24);v[d+8>>2]=-1082130432;v[d+4>>2]=1065353216;f=C(z[zf(d+12|0,d+8|0,d+4|0)>>2]*C(32768));z[d+12>>2]=f;e=a;f=fe(f);a:{if(C(D(f))<C(2147483648)){g=~~f;break a}g=-2147483648}i=e,j=Uc(g),u[i>>1]=j;e=w[b+4|0]|w[b+5|0]<<8|(w[b+6|0]<<16|w[b+7|0]<<24);v[d+12>>2]=e<<24|e<<8&16711680|(e>>>8&65280|e>>>24);v[d+8>>2]=-1082130432;v[d+4>>2]=1065353216;f=C(z[zf(d+12|0,d+8|0,d+4|0)>>2]*C(32768));z[d+12>>2]=f;e=a;f=fe(f);b:{if(C(D(f))<C(2147483648)){g=~~f;break b}g=-2147483648}i=e,j=Uc(g),u[i+2>>1]=j;a=a+4|0;b=b+8|0;h=h-1|0;if(h){continue}break}}gb=d+16|0;return c<<3}function oga(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;if(v[a+4>>2]!=v[wb(a)>>2]){c=gb-16|0;gb=c;v[c>>2]=a;d=v[a+4>>2];v[c+4>>2]=d;v[c+8>>2]=d+32;wb(a);eP(v[c+4>>2],b);v[c+4>>2]=v[c+4>>2]+32;$b(c);gb=c+16|0;return}g=gb-32|0;gb=g;f=wb(a);d=_q(a,ze(a)+1|0);i=ze(a);h=gb-16|0;gb=h;v[h+12>>2]=0;c=g+8|0;kf(c+12|0,f);if(d){e=d;if(d>>>0>=134217728){rd(8445);L()}e=Mc(e<<5,8)}v[c>>2]=e;f=(i<<5)+e|0;v[c+8>>2]=f;v[c+4>>2]=f;j=dc(c),k=(d<<5)+e|0,v[j>>2]=k;gb=h+16|0;eP(v[c+8>>2],b);v[c+8>>2]=v[c+8>>2]+32;hv(a);wb(a);b=c+4|0;ml(v[a>>2],v[a+4>>2],b);wc(a,b);wc(a+4|0,c+8|0);wc(wb(a),dc(c));v[c>>2]=v[c+4>>2];iB(a,ze(a));a=c;b=c;c=v[c+4>>2];a:{while(1){d=v[b+8>>2];if((d|0)==(c|0)){break a}v[b+8>>2]=d-32;v[22656]=0;d=v[22656];v[22656]=0;if((d|0)!=1){continue}break}V(0)|0;O()|0;Bb();L()}b=v[a>>2];if(b){lV(v[a+16>>2],b,HB(a))}gb=g+32|0}function cx(a){var b=0,c=0,d=0,e=0,f=0,g=0;o(+a);e=j(1)|0;j(0)|0;b=e;e=b>>>31|0;a:{b:{c:{d:{d=a;e:{f:{b=b&2147483647;g:{if(b>>>0>=1082532651){o(+a);b=j(1)|0;b=b&2147483647;if((b|0)==2146435072&(j(0)|0)!=0|b>>>0>2146435072){return a}if(a>709.782712893384){return a*8.98846567431158e307}if(!(a<-708.3964185322641)|!(a<-745.1332191019411)){break g}break b}if(b>>>0<1071001155){break d}if(b>>>0<1072734898){break f}}a=a*1.4426950408889634+A[(e<<3)+90048>>3];if(D(a)<2147483648){b=~~a;break e}b=-2147483648;break e}b=!e-e|0}c=+(b|0);a=d+c*-.6931471803691238;f=c*1.9082149292705877e-10;d=a-f;break c}if(b>>>0<=1043333120){break a}b=0;d=a}c=d;g=a;c=c*c;a=d-c*(c*(c*(c*(c*4.1381367970572385e-8+-16533902205465252e-22)+6613756321437934e-20)+-.0027777777777015593)+.16666666666666602);c=g+(d*a/(2-a)-f)+1;if(!b){break b}c=ii(c,b)}return c}return a+1}function z5(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;c=gb-32|0;gb=c;v[c+28>>2]=0;a:{b:{c:{if(w[uj(c+24|0,a,0)|0]){d=v[v[a>>2]-12>>2];v[22656]=0;Fc(c+16|0,a+d|0);d=v[22656];v[22656]=0;d:{e:{f:{if((d|0)!=1){v[22656]=0;d=T(2309,c+16|0)|0;e=v[22656];v[22656]=0;if((e|0)==1){break f}e=cj(c+8|0,a);f=Ui(c);g=v[v[a>>2]-12>>2];f=v[f>>2];e=v[e>>2];v[22656]=0;ka(2315,d|0,e|0,f|0,a+g|0,c+28|0,b|0);b=v[22656];v[22656]=0;if((b|0)==1){break f}Wb(c+16|0);break d}b=V(0)|0;O()|0;break e}b=V(0)|0;O()|0;Wb(c+16|0)}Z(b|0)|0;b=v[c+28>>2]|1;v[c+28>>2]=b;tj(v[v[a>>2]-12>>2]+a|0,b);if(v[(v[v[a>>2]-12>>2]+a|0)+20>>2]&1){v[22656]=0;X(2027);a=v[22656];v[22656]=0;if((a|0)!=1){break b}a=P()|0;O()|0;v[22656]=0;X(20);b=v[22656];v[22656]=0;if((b|0)==1){break c}S(a|0);L()}$()}ih(v[v[a>>2]-12>>2]+a|0,v[c+28>>2])}gb=c+32|0;break a}V(0)|0;O()|0;Bb()}L()}return a|0}function K5(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;c=gb-32|0;gb=c;v[c+28>>2]=0;a:{b:{c:{if(w[uj(c+24|0,a,0)|0]){d=v[v[a>>2]-12>>2];v[22656]=0;Fc(c+16|0,a+d|0);d=v[22656];v[22656]=0;d:{e:{f:{if((d|0)!=1){v[22656]=0;d=T(2309,c+16|0)|0;e=v[22656];v[22656]=0;if((e|0)==1){break f}e=cj(c+8|0,a);f=Ui(c);g=v[v[a>>2]-12>>2];f=v[f>>2];e=v[e>>2];v[22656]=0;ka(2310,d|0,e|0,f|0,a+g|0,c+28|0,b|0);b=v[22656];v[22656]=0;if((b|0)==1){break f}Wb(c+16|0);break d}b=V(0)|0;O()|0;break e}b=V(0)|0;O()|0;Wb(c+16|0)}Z(b|0)|0;b=v[c+28>>2]|1;v[c+28>>2]=b;tj(v[v[a>>2]-12>>2]+a|0,b);if(v[(v[v[a>>2]-12>>2]+a|0)+20>>2]&1){v[22656]=0;X(2027);a=v[22656];v[22656]=0;if((a|0)!=1){break b}a=P()|0;O()|0;v[22656]=0;X(20);b=v[22656];v[22656]=0;if((b|0)==1){break c}S(a|0);L()}$()}ih(v[v[a>>2]-12>>2]+a|0,v[c+28>>2])}gb=c+32|0;break a}V(0)|0;O()|0;Bb()}L()}return a|0}function H5(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;c=gb-32|0;gb=c;v[c+28>>2]=0;a:{b:{c:{if(w[uj(c+24|0,a,0)|0]){d=v[v[a>>2]-12>>2];v[22656]=0;Fc(c+16|0,a+d|0);d=v[22656];v[22656]=0;d:{e:{f:{if((d|0)!=1){v[22656]=0;d=T(2309,c+16|0)|0;e=v[22656];v[22656]=0;if((e|0)==1){break f}e=cj(c+8|0,a);f=Ui(c);g=v[v[a>>2]-12>>2];f=v[f>>2];e=v[e>>2];v[22656]=0;ka(2311,d|0,e|0,f|0,a+g|0,c+28|0,b|0);b=v[22656];v[22656]=0;if((b|0)==1){break f}Wb(c+16|0);break d}b=V(0)|0;O()|0;break e}b=V(0)|0;O()|0;Wb(c+16|0)}Z(b|0)|0;b=v[c+28>>2]|1;v[c+28>>2]=b;tj(v[v[a>>2]-12>>2]+a|0,b);if(v[(v[v[a>>2]-12>>2]+a|0)+20>>2]&1){v[22656]=0;X(2027);a=v[22656];v[22656]=0;if((a|0)!=1){break b}a=P()|0;O()|0;v[22656]=0;X(20);b=v[22656];v[22656]=0;if((b|0)==1){break c}S(a|0);L()}$()}ih(v[v[a>>2]-12>>2]+a|0,v[c+28>>2])}gb=c+32|0;break a}V(0)|0;O()|0;Bb()}L()}return a|0}function D5(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;c=gb-32|0;gb=c;v[c+28>>2]=0;a:{b:{c:{if(w[uj(c+24|0,a,0)|0]){d=v[v[a>>2]-12>>2];v[22656]=0;Fc(c+16|0,a+d|0);d=v[22656];v[22656]=0;d:{e:{f:{if((d|0)!=1){v[22656]=0;d=T(2309,c+16|0)|0;e=v[22656];v[22656]=0;if((e|0)==1){break f}e=cj(c+8|0,a);f=Ui(c);g=v[v[a>>2]-12>>2];f=v[f>>2];e=v[e>>2];v[22656]=0;ka(2313,d|0,e|0,f|0,a+g|0,c+28|0,b|0);b=v[22656];v[22656]=0;if((b|0)==1){break f}Wb(c+16|0);break d}b=V(0)|0;O()|0;break e}b=V(0)|0;O()|0;Wb(c+16|0)}Z(b|0)|0;b=v[c+28>>2]|1;v[c+28>>2]=b;tj(v[v[a>>2]-12>>2]+a|0,b);if(v[(v[v[a>>2]-12>>2]+a|0)+20>>2]&1){v[22656]=0;X(2027);a=v[22656];v[22656]=0;if((a|0)!=1){break b}a=P()|0;O()|0;v[22656]=0;X(20);b=v[22656];v[22656]=0;if((b|0)==1){break c}S(a|0);L()}$()}ih(v[v[a>>2]-12>>2]+a|0,v[c+28>>2])}gb=c+32|0;break a}V(0)|0;O()|0;Bb()}L()}return a|0}function B5(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;c=gb-32|0;gb=c;v[c+28>>2]=0;a:{b:{c:{if(w[uj(c+24|0,a,0)|0]){d=v[v[a>>2]-12>>2];v[22656]=0;Fc(c+16|0,a+d|0);d=v[22656];v[22656]=0;d:{e:{f:{if((d|0)!=1){v[22656]=0;d=T(2309,c+16|0)|0;e=v[22656];v[22656]=0;if((e|0)==1){break f}e=cj(c+8|0,a);f=Ui(c);g=v[v[a>>2]-12>>2];f=v[f>>2];e=v[e>>2];v[22656]=0;ka(2314,d|0,e|0,f|0,a+g|0,c+28|0,b|0);b=v[22656];v[22656]=0;if((b|0)==1){break f}Wb(c+16|0);break d}b=V(0)|0;O()|0;break e}b=V(0)|0;O()|0;Wb(c+16|0)}Z(b|0)|0;b=v[c+28>>2]|1;v[c+28>>2]=b;tj(v[v[a>>2]-12>>2]+a|0,b);if(v[(v[v[a>>2]-12>>2]+a|0)+20>>2]&1){v[22656]=0;X(2027);a=v[22656];v[22656]=0;if((a|0)!=1){break b}a=P()|0;O()|0;v[22656]=0;X(20);b=v[22656];v[22656]=0;if((b|0)==1){break c}S(a|0);L()}$()}ih(v[v[a>>2]-12>>2]+a|0,v[c+28>>2])}gb=c+32|0;break a}V(0)|0;O()|0;Bb()}L()}return a|0}function fda(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=C(0);c=gb-4112|0;gb=c;i=kb[v[v[a>>2]+116>>2]](a)|0;if(!i){kb[v[v[a>>2]+120>>2]](a)}v[c+12>>2]=0;f=gb-16|0;gb=f;h=a+44|0;if(Vf(h)){while(1){e=In(h,d);g=In(h,d);v[f+12>>2]=0;g=(g+2048|0)-e>>2;if((g|0)>0){while(1){z[e>>2]=z[f+12>>2];e=e+4|0;j=g>>>0>1;g=g-1|0;if(j){continue}break}}d=d+1|0;if(Vf(h)>>>0>d>>>0){continue}break}}gb=f+16|0;if(b){f=c+2064|0;while(1){v[c+8>>2]=b;qc(c+8|0,512);d=c+16|0;Yo(d);kb[v[v[a>>2]+60>>2]](a,d,f,v[c+8>>2]);e=0;d=0;if(v[c+8>>2]){while(1){e=(c+16|0)+(d<<2)|0;z[c+4>>2]=D(z[e>>2]);k=c,l=z[dz(c+12|0,c+4|0)>>2],z[k+12>>2]=l;z[c+4>>2]=D(z[e+2048>>2]);k=c,l=z[dz(c+12|0,c+4|0)>>2],z[k+12>>2]=l;e=v[c+8>>2];d=d+1|0;if(e>>>0>d>>>0){continue}break}}b=b-e|0;if(b){continue}break}}if(!i){kb[v[v[a>>2]+124>>2]](a)}gb=c+4112|0;return C(z[c+12>>2])}function bt(a){a=a|0;var b=0,c=0,d=0,e=0;d=gb-16|0;gb=d;c=v[v[a>>2]-12>>2];v[22656]=0;c=v[(a+c|0)+24>>2];b=v[22656];v[22656]=0;a:{b:{c:{d:{e:{if((b|0)!=1){if(!c){break b}v[22656]=0;c=Q(15,d+8|0,a|0)|0;b=v[22656];v[22656]=0;if((b|0)==1){break d}if(!w[c|0]){break e}b=v[v[a>>2]-12>>2];v[22656]=0;b=v[(a+b|0)+24>>2];e=v[22656];v[22656]=0;f:{if((e|0)==1){break f}v[22656]=0;b=T(2307,b|0)|0;e=v[22656];v[22656]=0;if((e|0)==1){break f}if((b|0)!=-1){break e}b=v[v[a>>2]-12>>2];v[22656]=0;R(18,a+b|0,1);b=v[22656];v[22656]=0;if((b|0)!=1){break e}}b=V(0)|0;O()|0;nl(c);break c}b=V(0)|0;O()|0;break c}nl(c);break b}b=V(0)|0;O()|0}Z(b|0)|0;c=v[v[a>>2]-12>>2];v[22656]=0;_(19,a+c|0);c=v[22656];v[22656]=0;if((c|0)==1){break a}$()}gb=d+16|0;return a|0}a=P()|0;O()|0;v[22656]=0;X(20);c=v[22656];v[22656]=0;if((c|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}function Dka(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;f=gb-32|0;gb=f;k=f,l=ar(b),v[k+16>>2]=l;e=gb-32|0;gb=e;g=b;d=a;b=Yd(d);c=fc(d);a:{b:{if(b){wb(d);c:{while(1){d:{d=b+13|0;e:{if(Qu(g,d)){if(!v[b>>2]){break b}c=b;break e}if(!Qu(d,g)){break c}c=b+4|0;if(!v[b+4>>2]){break d}b=c;c=b}b=v[b>>2];continue}break}v[e+28>>2]=b;b=c;break a}v[e+28>>2]=b;b=c;break a}b=fc(d)}v[e+28>>2]=b}g=b;b=v[b>>2];t[e+27|0]=0;if(!b){i=gb-16|0;gb=i;b=fc(a);d=e+8|0;j=Vj(d,qC(),Wj(i+8|0,b));b=v[j>>2];h=gb-16|0;gb=h;v[h+8>>2]=v[f+16>>2];c=v[h+8>>2];c=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);t[b+17|0]=0;t[b+13|0]=c;t[b+14|0]=c>>>8;t[b+15|0]=c>>>16;t[b+16|0]=c>>>24;gb=h+16|0;k=fc(j),l=1,t[k+4|0]=l;gb=i+16|0;Hk(a,v[e+28>>2],g,v[d>>2]);b=ce(d);t[e+27|0]=1;rC(d)}Xj(f+24|0,yc(e+8|0,b),e+27|0);gb=e+32|0;gb=f+32|0;return v[f+24>>2]+17|0}function Aia(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;g=gb-16|0;gb=g;i=v[a+40>>2];j=v[a+36>>2];l=v[a+16>>2];h=v[a+4>>2];e=h;f=v[a>>2];v[g+8>>2]=f;v[g+12>>2]=e;h=v[a+12>>2];v[g>>2]=v[a+8>>2];v[g+4>>2]=h;a:{if(d){while(1){k=v[a+32>>2];j=v[a+28>>2]+j|0;h=j>>12;e=e+l|0;f=(((f>>>16|0)+4&131064)<<1)+b|0;e=(((((B(t[e+2|0],u[f+34>>1])+B(t[e+1|0],u[f+32>>1])|0)+B(t[e+3|0],u[f+36>>1])|0)+B(t[e+4|0],u[f+38>>1])<<8)/2|0)+((((B(t[e-2|0],u[f+26>>1])+B(t[e-3|0],u[f+24>>1])|0)+B(t[e-1|0],u[f+28>>1])|0)+B(t[e|0],u[f+30>>1])<<8)/2|0)|0)/16384|0;v[c>>2]=v[c>>2]+B(h,e);i=i+k|0;k=i>>12;v[c+4>>2]=v[c+4>>2]+B(e,k);Ub(g+8|0,g);d=d-1|0;if(d){c=c+8|0;f=v[g+8>>2];e=v[g+12>>2];continue}break}f=v[g+8>>2];e=v[g+12>>2];break a}k=i>>12;h=j>>12}v[a+40>>2]=i;v[a+20>>2]=h;v[a+36>>2]=j;v[a+24>>2]=k;v[a>>2]=f;v[a+4>>2]=e;gb=g+16|0}function Fba(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=C(0),m=0,n=C(0),o=C(0),p=C(0),q=C(0),r=C(0),s=C(0),t=C(0),u=C(0),w=C(0);i=gb-16|0;gb=i;j=a+44|0;if(mi(j)){h=Nd(j,0);v[i+8>>2]=h;k=Nd(j,1);v[i+12>>2]=k;e=od(j,0);v[i>>2]=e;f=od(j,1);v[i+4>>2]=f;a:{if(z[a+4216>>2]!=C(.5)){if(!d){break a}h=d;while(1){f=0;k=1;while(1){f=f<<2;e=f+(i+8|0)|0;g=v[e>>2];v[e>>2]=g+4;e=a+f|0;m=e+4248|0;p=z[m>>2];l=z[g>>2];q=z[a+4236>>2];r=z[a+4232>>2];s=z[a+4228>>2];t=z[a+4220>>2];u=z[a+4224>>2];g=e+4240|0;n=z[g>>2];z[m>>2]=n;z[g>>2]=l;g=e+4264|0;w=z[g>>2];e=e+4256|0;o=z[e>>2];z[g>>2]=o;l=C(C(C(C(C(l*t)+C(u*n))+C(s*p))-C(r*o))-C(q*w));z[e>>2]=l;f=f+i|0;e=v[f>>2];v[f>>2]=e+4;z[e>>2]=l;e=k;k=0;f=1;if(e){continue}break}h=h-1|0;if(h){continue}break}break a}g=h;h=d<<2;hc(e,g,h);hc(f,k,h)}Ei(a,b,c,od(j,0),od(j,1),d)}gb=i+16|0}function kka(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;d=gb-80|0;gb=d;a:{b:{e=v[a+4>>2];if(e>>>0<b>>>0){h=Ud(d+72|0);f=b-e|0;b=Pu(a);if(!(f>>>0>b>>>0|e>>>0>b-f>>>0)){Vl(d+56|0,a);b=v[d+60>>2];v[d+72>>2]=v[d+56>>2];v[d+76>>2]=b;v[a+4>>2]=v[a+4>>2]+f;break b}wb(a);b=CB(d+56|0);e=v[a+4>>2];v[22656]=0;e=Q(951,a|0,e+f|0)|0;g=v[22656];v[22656]=0;c:{if((g|0)==1){break c}v[22656]=0;R(952,b|0,e|0);e=v[22656];v[22656]=0;if((e|0)==1){break c}v[b+4>>2]=v[a+4>>2]+f;Ak(d+40|0,a);Vl(d+32|0,a);e=d+24|0;Ak(e,b);v[22656]=0;g=v[d+44>>2];v[d+8>>2]=v[d+40>>2];v[d+12>>2]=g;g=v[d+36>>2];v[d>>2]=v[d+32>>2];v[d+4>>2]=g;Y(953,d+48|0,d+8|0,d|0,e|0);e=v[22656];v[22656]=0;if((e|0)==1){break c}e=v[d+52>>2];v[d+72>>2]=v[d+48>>2];v[d+76>>2]=e;BB(a,b);Ye(b);break b}a=P()|0;O()|0;Ye(b);S(a|0);L()}v[a+4>>2]=b;break a}yp(ne(d+16|0,h),f,c)}gb=d+80|0}function g4(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;i=gb-32|0;gb=i;a:{b:{c:{if((b|0)!=(c|0)){j=v[115137];v[115137]=0;g=gb-16|0;gb=g;xe();e=gb-16|0;gb=e;f=gb-16|0;gb=f;Gx(f,b,i+28|0,2);k=v[f>>2];h=v[f+4>>2];b=v[f+12>>2];v[e+8>>2]=v[f+8>>2];v[e+12>>2]=b;v[e>>2]=k;v[e+4>>2]=h;gb=f+16|0;h=v[e>>2];f=v[e+4>>2];b=v[e+12>>2];v[g+8>>2]=v[e+8>>2];v[g+12>>2]=b;v[g>>2]=h;v[g+4>>2]=f;gb=e+16|0;h=v[g>>2];f=v[g+4>>2];e=v[g+12>>2];b=i;v[b+16>>2]=v[g+8>>2];v[b+20>>2]=e;v[b+8>>2]=h;v[b+12>>2]=f;gb=g+16|0;h=v[b+16>>2];f=v[b+20>>2];g=v[b+8>>2];e=v[b+12>>2];b=v[115137];if(!b){break c}if(v[i+28>>2]!=(c|0)){break b}l=g;m=e;n=h;o=f;if((b|0)!=68){break a}break b}v[d>>2]=4;break a}v[115137]=j;if(v[i+28>>2]==(c|0)){break a}}v[d>>2]=4;g=l;e=m;h=n;f=o}v[a>>2]=g;v[a+4>>2]=e;v[a+8>>2]=h;v[a+12>>2]=f;gb=i+32|0}function QY(a,b){var c=0,d=0;d=w[a|0];if(d>>>0>=36){t[a|0]=0;return}c=w[d+28528|0];t[a|0]=c;a:{b:{c:{d:{e:{f:{if(c>>>0<=16){if(c-6>>>0>=2){if((c|0)==1){break f}if((c|0)!=11){break a}}c=w[b|0];a=c&240;if(!a|(a|0)==240|(c&15)==15){break a}t[b|0]=a;return}switch(c-17|0){case 1:case 3:case 4:case 5:break a;case 0:break c;case 2:break d;case 6:break e;default:break b}}if(w[b|0]){break a}t[a|0]=0;return}a=w[b|0];if(a>>>0<=64){t[b|0]=a<<1;return}t[b|0]=128;return}g:{h:{i:{j:{c=w[b|0];switch((c&240)-48>>>4|0){case 4:break g;case 2:break h;case 1:break i;case 0:break j;default:break a}}t[a|0]=20;t[b|0]=159;return}t[a|0]=20;t[b|0]=192;return}if(c&14){break a}t[a|0]=21;t[b|0]=(w[b|0]!=80)<<6;return}t[a|0]=20;t[b|0]=w[b|0]&15|160;return}if(w[b|0]>31){break a}t[a|0]=16;return}if((c|0)!=31){break a}t[b|0]=(d<<5|w[b|0]<<24>>>27)^128}}function Q9(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;e=gb-32|0;gb=e;v[22656]=0;_(1934,a|0);d=v[22656];v[22656]=0;a:{b:{c:{d:{e:{f:{g:{if((d|0)==1){break g}v[22656]=0;_(1960,b|0);d=v[22656];v[22656]=0;if((d|0)==1){break g}v[22656]=0;_(1960,c|0);d=v[22656];v[22656]=0;if((d|0)==1){break g}f=v[a+24>>2];v[22656]=0;d=Q(70,e+16|0,b|0)|0;b=v[22656];v[22656]=0;if((b|0)==1){break g}v[22656]=0;c=Q(70,e|0,c|0)|0;b=v[22656];v[22656]=0;if((b|0)==1){break f}v[22656]=0;Y(2e3,f|0,d|0,c|0,1);b=v[22656];v[22656]=0;if((b|0)==1){break e}vb(c);vb(d);b=1;break b}b=V(0)|0;O()|0;break c}b=V(0)|0;O()|0;break d}b=V(0)|0;O()|0;vb(c)}vb(d)}Z(b|0)|0;b=0;v[22656]=0;Y(1911,3466,a|0,0,0);a=v[22656];v[22656]=0;if((a|0)==1){break a}$()}gb=e+32|0;return b|0}a=P()|0;O()|0;v[22656]=0;X(20);b=v[22656];v[22656]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}function yq(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0,h=0;c=gb-16|0;gb=c;a:{b:{switch(w[a+480224|0]-1|0){default:b=v[a+24620>>2];d=b>>31;v[c+8>>2]=1;v[c>>2]=v[a+1074420>>2]<<1;d=kqa(b,d,5e4,0);e=jb;b=v[Lc(c+8|0,c)>>2];b=Ac(lqa(d,e,b,b>>31),jb);v[a+1074404>>2]=b;break a;case 1:b=v[a+24620>>2];v[c+8>>2]=1;v[c+12>>2]=0;g=c,h=kqa(v[a+1074420>>2],0,kqa(v[a+1074408>>2],0,v[a+1074416>>2],0),jb),v[g>>2]=h;v[c+4>>2]=jb;d=gb-16|0;gb=d;e=c+8|0;f=vw(e,c);gb=d+16|0;d=kqa(b,0,6e5,0);b=f?c:e;b=nqa(d,jb,v[b>>2],v[b+4>>2]);v[a+1074404>>2]=b;break a;case 0:break b}}b=v[a+24620>>2];d=b>>31;v[c+8>>2]=1;v[c>>2]=v[a+1074420>>2];d=kqa(b,d,1e4,0);e=jb;b=v[Lc(c+8|0,c)>>2];b=Ac(lqa(d,e,b,b>>31),jb);v[a+1074404>>2]=b}d=a+1074404|0;a=v[a+480244>>2];b=kqa(a,a>>31,b,b>>31)+32768|0;a=jb;a=Ac(lqa(b,b>>>0<32768?a+1|0:a,65536,0),jb);v[d>>2]=a?a:1;gb=c+16|0}function gaa(a,b){a=a|0;b=b|0;var c=0,d=0;d=gb-16|0;gb=d;v[22656]=0;_(1934,a|0);c=v[22656];v[22656]=0;a:{b:{c:{d:{e:{f:{g:{h:{i:{if((c|0)!=1){c=v[a+24>>2];v[22656]=0;R(1980,d|0,c|0);c=v[22656];v[22656]=0;if((c|0)==1){break i}if(Ec(d)>>>0<2147483647){break h}c=ba(8)|0;v[22656]=0;Q(1981,c|0,4473)|0;b=v[22656];v[22656]=0;if((b|0)==1){break g}v[22656]=0;U(186,c|0,89464,206);b=v[22656];v[22656]=0;if((b|0)!=1){break b}b=V(0)|0;O()|0;break f}b=V(0)|0;O()|0;break e}b=V(0)|0;O()|0;break e}a=18726;j:{if((b|0)<0){break j}if((Ec(d)|0)<=(b|0)){break j}a=Jb(Ad(d,b))}b=ie(a);yd(d);break d}b=V(0)|0;O()|0;ca(c|0)}yd(d)}Z(b|0)|0;b=0;v[22656]=0;Y(1911,9165,a|0,0,0);a=v[22656];v[22656]=0;if((a|0)==1){break c}$()}gb=d+16|0;return b|0}a=P()|0;O()|0;v[22656]=0;X(20);b=v[22656];v[22656]=0;if((b|0)!=1){break a}V(0)|0;O()|0;Bb()}L()}S(a|0);L()}function faa(a,b){a=a|0;b=b|0;var c=0,d=0;d=gb-16|0;gb=d;v[22656]=0;_(1934,a|0);c=v[22656];v[22656]=0;a:{b:{c:{d:{e:{f:{g:{h:{i:{if((c|0)!=1){c=v[a+24>>2];v[22656]=0;R(1982,d|0,c|0);c=v[22656];v[22656]=0;if((c|0)==1){break i}if(Ec(d)>>>0<2147483647){break h}c=ba(8)|0;v[22656]=0;Q(1981,c|0,4473)|0;b=v[22656];v[22656]=0;if((b|0)==1){break g}v[22656]=0;U(186,c|0,89464,206);b=v[22656];v[22656]=0;if((b|0)!=1){break b}b=V(0)|0;O()|0;break f}b=V(0)|0;O()|0;break e}b=V(0)|0;O()|0;break e}a=18726;j:{if((b|0)<0){break j}if((Ec(d)|0)<=(b|0)){break j}a=Jb(Ad(d,b))}b=ie(a);yd(d);break d}b=V(0)|0;O()|0;ca(c|0)}yd(d)}Z(b|0)|0;b=0;v[22656]=0;Y(1911,9133,a|0,0,0);a=v[22656];v[22656]=0;if((a|0)==1){break c}$()}gb=d+16|0;return b|0}a=P()|0;O()|0;v[22656]=0;X(20);b=v[22656];v[22656]=0;if((b|0)!=1){break a}V(0)|0;O()|0;Bb()}L()}S(a|0);L()}function eaa(a,b){a=a|0;b=b|0;var c=0,d=0;d=gb-16|0;gb=d;v[22656]=0;_(1934,a|0);c=v[22656];v[22656]=0;a:{b:{c:{d:{e:{f:{g:{h:{i:{if((c|0)!=1){c=v[a+24>>2];v[22656]=0;R(1983,d|0,c|0);c=v[22656];v[22656]=0;if((c|0)==1){break i}if(Ec(d)>>>0<2147483647){break h}c=ba(8)|0;v[22656]=0;Q(1981,c|0,4473)|0;b=v[22656];v[22656]=0;if((b|0)==1){break g}v[22656]=0;U(186,c|0,89464,206);b=v[22656];v[22656]=0;if((b|0)!=1){break b}b=V(0)|0;O()|0;break f}b=V(0)|0;O()|0;break e}b=V(0)|0;O()|0;break e}a=18726;j:{if((b|0)<0){break j}if((Ec(d)|0)<=(b|0)){break j}a=Jb(Ad(d,b))}b=ie(a);yd(d);break d}b=V(0)|0;O()|0;ca(c|0)}yd(d)}Z(b|0)|0;b=0;v[22656]=0;Y(1911,9071,a|0,0,0);a=v[22656];v[22656]=0;if((a|0)==1){break c}$()}gb=d+16|0;return b|0}a=P()|0;O()|0;v[22656]=0;X(20);b=v[22656];v[22656]=0;if((b|0)!=1){break a}V(0)|0;O()|0;Bb()}L()}S(a|0);L()}function daa(a,b){a=a|0;b=b|0;var c=0,d=0;d=gb-16|0;gb=d;v[22656]=0;_(1934,a|0);c=v[22656];v[22656]=0;a:{b:{c:{d:{e:{f:{g:{h:{i:{if((c|0)!=1){c=v[a+24>>2];v[22656]=0;R(1984,d|0,c|0);c=v[22656];v[22656]=0;if((c|0)==1){break i}if(Ec(d)>>>0<2147483647){break h}c=ba(8)|0;v[22656]=0;Q(1981,c|0,4473)|0;b=v[22656];v[22656]=0;if((b|0)==1){break g}v[22656]=0;U(186,c|0,89464,206);b=v[22656];v[22656]=0;if((b|0)!=1){break b}b=V(0)|0;O()|0;break f}b=V(0)|0;O()|0;break e}b=V(0)|0;O()|0;break e}a=18726;j:{if((b|0)<0){break j}if((Ec(d)|0)<=(b|0)){break j}a=Jb(Ad(d,b))}b=ie(a);yd(d);break d}b=V(0)|0;O()|0;ca(c|0)}yd(d)}Z(b|0)|0;b=0;v[22656]=0;Y(1911,9101,a|0,0,0);a=v[22656];v[22656]=0;if((a|0)==1){break c}$()}gb=d+16|0;return b|0}a=P()|0;O()|0;v[22656]=0;X(20);b=v[22656];v[22656]=0;if((b|0)!=1){break a}V(0)|0;O()|0;Bb()}L()}S(a|0);L()}function caa(a,b){a=a|0;b=b|0;var c=0,d=0;d=gb-16|0;gb=d;v[22656]=0;_(1934,a|0);c=v[22656];v[22656]=0;a:{b:{c:{d:{e:{f:{g:{h:{i:{if((c|0)!=1){c=v[a+24>>2];v[22656]=0;R(1985,d|0,c|0);c=v[22656];v[22656]=0;if((c|0)==1){break i}if(Ec(d)>>>0<2147483647){break h}c=ba(8)|0;v[22656]=0;Q(1981,c|0,4473)|0;b=v[22656];v[22656]=0;if((b|0)==1){break g}v[22656]=0;U(186,c|0,89464,206);b=v[22656];v[22656]=0;if((b|0)!=1){break b}b=V(0)|0;O()|0;break f}b=V(0)|0;O()|0;break e}b=V(0)|0;O()|0;break e}a=18726;j:{if((b|0)<0){break j}if((Ec(d)|0)<=(b|0)){break j}a=Jb(Ad(d,b))}b=ie(a);yd(d);break d}b=V(0)|0;O()|0;ca(c|0)}yd(d)}Z(b|0)|0;b=0;v[22656]=0;Y(1911,9036,a|0,0,0);a=v[22656];v[22656]=0;if((a|0)==1){break c}$()}gb=d+16|0;return b|0}a=P()|0;O()|0;v[22656]=0;X(20);b=v[22656];v[22656]=0;if((b|0)!=1){break a}V(0)|0;O()|0;Bb()}L()}S(a|0);L()}function baa(a,b){a=a|0;b=b|0;var c=0,d=0;d=gb-16|0;gb=d;v[22656]=0;_(1934,a|0);c=v[22656];v[22656]=0;a:{b:{c:{d:{e:{f:{g:{h:{i:{if((c|0)!=1){c=v[a+24>>2];v[22656]=0;R(1986,d|0,c|0);c=v[22656];v[22656]=0;if((c|0)==1){break i}if(Ec(d)>>>0<2147483647){break h}c=ba(8)|0;v[22656]=0;Q(1981,c|0,4473)|0;b=v[22656];v[22656]=0;if((b|0)==1){break g}v[22656]=0;U(186,c|0,89464,206);b=v[22656];v[22656]=0;if((b|0)!=1){break b}b=V(0)|0;O()|0;break f}b=V(0)|0;O()|0;break e}b=V(0)|0;O()|0;break e}a=18726;j:{if((b|0)<0){break j}if((Ec(d)|0)<=(b|0)){break j}a=Jb(Ad(d,b))}b=ie(a);yd(d);break d}b=V(0)|0;O()|0;ca(c|0)}yd(d)}Z(b|0)|0;b=0;v[22656]=0;Y(1911,9197,a|0,0,0);a=v[22656];v[22656]=0;if((a|0)==1){break c}$()}gb=d+16|0;return b|0}a=P()|0;O()|0;v[22656]=0;X(20);b=v[22656];v[22656]=0;if((b|0)!=1){break a}V(0)|0;O()|0;Bb()}L()}S(a|0);L()}function Dy(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=C(0);b=gb+-64|0;gb=b;d=v[a>>2];a=v[d>>2];e=v[a+4>>2];v[b+40>>2]=v[a+20>>2];c=v[a+16>>2];v[b+32>>2]=v[a+12>>2];v[b+36>>2]=c;Jf(b+48|0,b+32|0,e);a=v[d+4>>2];d=v[a+4>>2];e=v[a+8>>2];c=v[b+60>>2];v[b+24>>2]=v[b+56>>2];v[b+28>>2]=c;c=v[b+52>>2];v[b+16>>2]=v[b+48>>2];v[b+20>>2]=c;v[b+8>>2]=v[a+8>>2];c=v[a+4>>2];v[b>>2]=v[a>>2];v[b+4>>2]=c;g=b+16|0;a=b;a:{if(d>>>0<=y[b+4>>2]){if(d>>>0<=y[g+4>>2]){if(e>>>0<=y[a+8>>2]){if(If(g)>>>0>=e>>>0){if(e){while(1){c=0;if(d){while(1){h=_m(ee(A[Wg(a,c,f)>>3]*134217728));i=Ey(g,c,f),j=C(+(h|0)*7.450580596923828e-9),z[i>>2]=j;c=c+1|0;if((d|0)!=(c|0)){continue}break}}f=f+1|0;if((e|0)!=(f|0)){continue}break}}break a}aa(2959,6176,80,5856);L()}aa(2989,6176,79,5856);L()}aa(4211,6176,78,5856);L()}aa(4246,6176,77,5856);L()}gb=b- -64|0}function Ay(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=C(0);b=gb+-64|0;gb=b;d=v[a>>2];a=v[d>>2];e=v[a+4>>2];v[b+40>>2]=v[a+20>>2];c=v[a+16>>2];v[b+32>>2]=v[a+12>>2];v[b+36>>2]=c;Jf(b+48|0,b+32|0,e);a=v[d+4>>2];d=v[a+4>>2];e=v[a+8>>2];c=v[b+60>>2];v[b+24>>2]=v[b+56>>2];v[b+28>>2]=c;c=v[b+52>>2];v[b+16>>2]=v[b+48>>2];v[b+20>>2]=c;v[b+8>>2]=v[a+8>>2];c=v[a+4>>2];v[b>>2]=v[a>>2];v[b+4>>2]=c;g=b+16|0;a=b;a:{if(d>>>0<=y[b+4>>2]){if(d>>>0<=y[g+4>>2]){if(e>>>0<=y[a+8>>2]){if(If(g)>>>0>=e>>>0){if(e){while(1){c=0;if(d){while(1){h=_m(ee(A[Wg(a,c,f)>>3]*134217728));i=By(g,c,f),j=C(+(h|0)*7.450580596923828e-9),z[i>>2]=j;c=c+1|0;if((d|0)!=(c|0)){continue}break}}f=f+1|0;if((e|0)!=(f|0)){continue}break}}break a}aa(2959,6176,80,5856);L()}aa(2989,6176,79,5856);L()}aa(4211,6176,78,5856);L()}aa(4246,6176,77,5856);L()}gb=b- -64|0}function NL(a,b,c,d,e,f,g,h,i){a=a|0;b=b|0;c=+c;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0;j=gb+-64|0;gb=j;v[j+60>>2]=e;e=v[a+4>>2];k=v[a>>2];a=v[a+8>>2];v[j+40>>2]=b;v[j+52>>2]=a;v[j+44>>2]=k;v[j+48>>2]=e;v[22656]=0;v[j+20>>2]=d?d:1919;a=Q(1920,j+20|0,j+60|0)|0;b=v[22656];v[22656]=0;a:{b:{c:{d:{if((b|0)!=1){v[j+24>>2]=a;a=v[jq(j+32|0,j+24|0)>>2];b=v[j+52>>2];v[j+8>>2]=v[j+48>>2];v[j+12>>2]=b;v[22656]=0;b=v[j+44>>2];v[j>>2]=v[j+40>>2];v[j+4>>2]=b;c=+za(1921,j|0,+c,a|0);a=v[22656];v[22656]=0;if((a|0)==1){break d}Dj(j+24|0);break b}a=V(0)|0;O()|0;break c}a=V(0)|0;O()|0;Dj(j+24|0)}Z(a|0)|0;v[22656]=0;ja(1922,12252,d|0,v[j+60>>2],f|0,g|0,h|0,i|0);a=v[22656];v[22656]=0;if((a|0)==1){break a}$();c=0}gb=j- -64|0;return+c}a=P()|0;O()|0;v[22656]=0;X(20);b=v[22656];v[22656]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}function qJ(a,b,c,d){var e=0,f=0,g=C(0),h=0,i=C(0),j=0,k=0,l=C(0),m=C(0),n=C(0),o=0;e=gb-96|0;gb=e;if((d|0)>0){while(1){z[e+48>>2]=-z[a>>2];z[e>>2]=z[a+68>>2];f=0;while(1){j=(e+48|0)+(f<<3)|0;h=(f<<4)+a|0;i=z[h+4>>2];g=z[h+8>>2];z[j+4>>2]=i+g;k=f<<1;z[(8-k<<2)+e>>2]=i-g;i=z[h+16>>2];g=z[h+12>>2];z[(7-k<<2)+e>>2]=i-g;z[j+8>>2]=-C(i+g);f=f+1|0;if((f|0)!=4){continue}break}pJ(e+48|0);pJ(e);z[e+4>>2]=-z[e+4>>2];z[e+12>>2]=-z[e+12>>2];z[e+20>>2]=-z[e+20>>2];z[e+28>>2]=-z[e+28>>2];h=0;while(1){f=h<<2;j=f+b|0;i=z[j>>2];g=z[f+(e+48|0)>>2];l=z[f+68192>>2];m=z[f+68228>>2];n=z[e+f>>2];z[j>>2]=C(g*l)-C(m*n);j=a+f|0;f=c+f|0;g=C(C(g*m)+C(n*l));z[j>>2]=C(i*z[f>>2])-C(g*z[f+36>>2]);z[(17-h<<2)+a>>2]=C(i*z[f+36>>2])+C(g*z[f>>2]);h=h+1|0;if((h|0)!=9){continue}break}b=b+36|0;a=a+72|0;o=o+1|0;if((o|0)!=(d|0)){continue}break}}gb=e+96|0}function Ww(a,b,c,d){var e=0,f=0,g=0,h=0;e=gb+-64|0;gb=e;v[e+60>>2]=d;a:{f=v[b>>2];b:{if(!(kb[v[v[f>>2]+36>>2]](f,c,d)|0)){SF(a);break b}im(e+40|0,b);v[22656]=0;b=v[b>>2];d=v[22656];v[22656]=0;if((d|0)==1){break a}d=v[v[b>>2]+24>>2];v[22656]=0;b=T(d|0,b|0)|0;d=v[22656];v[22656]=0;if((d|0)==1){break a}v[22656]=0;v[e+36>>2]=b-c;b=Fb(e+60|0,e+36|0);d=v[22656];v[22656]=0;if((d|0)==1){break a}g=v[b>>2];b=v[e+44>>2];v[e+16>>2]=v[e+40>>2];v[e+20>>2]=b;b=gb-16|0;gb=b;d=e+16|0;f=im(b+8|0,d);v[22656]=0;h=v[f+4>>2];v[b>>2]=v[f>>2];v[b+4>>2]=h;Y(221,e+48|0,b|0,c|0,g|0);c=v[22656];v[22656]=0;c:{if((c|0)!=1){Kd(d);gb=b+16|0;break c}a=P()|0;O()|0;Kd(d);S(a|0);L()}b=Ud(e+24|0);c=v[e+52>>2];v[e+8>>2]=v[e+48>>2];v[e+12>>2]=c;c=v[b+4>>2];v[e>>2]=v[b>>2];v[e+4>>2]=c;Kw(a,e+8|0,e)}gb=e- -64|0;return}a=P()|0;O()|0;Kd(e+40|0);S(a|0);L()}function ZF(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0,j=0;d=gb-32|0;gb=d;v[22656]=0;g=Q(15,d+24|0,a|0)|0;e=v[22656];v[22656]=0;a:{b:{c:{if((e|0)!=1){d:{e:{if(!w[g|0]){break e}e=cj(d+8|0,a);f=v[v[a>>2]-12>>2];h=v[(f+a|0)+4>>2];v[22656]=0;f=a+f|0;i=T(16,f|0)|0;j=v[22656];v[22656]=0;if((j|0)==1){break d}e=v[e>>2];v[22656]=0;c=b+c|0;b=la(17,e|0,b|0,((h&176)==32?c:b)|0,c|0,f|0,i|0)|0;c=v[22656];v[22656]=0;if((c|0)==1){break d}v[d+16>>2]=b;if(!bw(d+16|0)){break e}b=v[v[a>>2]-12>>2];v[22656]=0;R(18,a+b|0,5);b=v[22656];v[22656]=0;if((b|0)!=1){break e}break d}nl(g);break b}b=V(0)|0;O()|0;nl(g);break c}b=V(0)|0;O()|0}Z(b|0)|0;b=v[v[a>>2]-12>>2];v[22656]=0;_(19,a+b|0);b=v[22656];v[22656]=0;if((b|0)==1){break a}$()}gb=d+32|0;return a}a=P()|0;O()|0;v[22656]=0;X(20);b=v[22656];v[22656]=0;if((b|0)==1){V(0)|0;O()|0;Bb();L()}S(a|0);L()}function Nma(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;e=gb-16|0;gb=e;i=8;t[e+15|0]=8;t[e+14|0]=0;u[e+12>>1]=0;if(d){m=B(c,d);while(1){if((m|0)>0){j=(k<<1)+b|0;o=j+(m<<1)|0;while(1){u[e+10>>1]=0;IV(a,e+14|0,e+12|0,e+15|0,e+10|0);a:{if(!i){g=x[e+10>>1];break a}g=x[e+10>>1];c=x[e+12>>1];h=i;while(1){f=c<<1;c=f&254;u[e+12>>1]=c;if(c){f=(f&65534)>>>0>255}else{if(!lf(a,e+9|0)){break a}f=w[e+9|0];c=f<<1&254|1;u[e+12>>1]=c;f=f>>>7|0}g=f|g<<1;h=h-1|0;if(h&255){continue}break}}c=1;f=g&65535;b:{if(f>>>0<4){break b}h=15;while(1){c=h;n=c&255;if(f>>>n&1){break b}h=c-1|0;if(n>>>0>1){continue}break}}i=(c+i&254)>>>1|0;t[e+15|0]=i;c=g&1;t[e+14|0]=c;l=(c-1^(g&65534)>>>1)+l|0;u[e+10>>1]=l;u[j>>1]=l;j=(d<<1)+j|0;if(o>>>0>j>>>0){continue}break}}k=k+1|0;if((k|0)!=(d|0)){continue}break}}gb=e+16|0}function HH(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0;h=gb-1040|0;gb=h;i=v[b>>2];v[h+12>>2]=i;g=a?d:256;j=a?a:h+16|0;d=0;a:{b:{c:{if(!i|!g){break c}f=c>>>2|0;k=g>>>0<=f>>>0;if(f>>>0<g>>>0&c>>>0<=131){break b}while(1){f=k?g:f;c=c-f|0;f=Ix(j,h+12|0,f,e);if((f|0)==-1){g=0;i=v[h+12>>2];d=-1;break c}i=(h+16|0)==(j|0)?0:f;g=g-i|0;j=(i<<2)+j|0;d=d+f|0;i=v[h+12>>2];if(!i|!g){break c}f=c>>>2|0;k=g>>>0<=f>>>0;if(c>>>0>131|f>>>0>=g>>>0){continue}break}break b}if(!i){break a}}if(!g|!c){break a}f=d;while(1){d:{d=aq(j,i,c,e);e:{if(d+2>>>0<=2){f:{switch(d+1|0){case 1:v[h+12>>2]=0;break e;case 0:break a;default:break f}}v[e>>2]=0;break e}i=v[h+12>>2]+d|0;v[h+12>>2]=i;f=f+1|0;g=g-1|0;if(g){break d}}d=f;break a}j=j+4|0;c=c-d|0;d=f;if(c){continue}break}}if(a){v[b>>2]=v[h+12>>2]}gb=h+1040|0;return d|0}function DK(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0;f=gb-16|0;gb=f;v[f+12>>2]=c;a:{if(!b){a=a+120|0;ho(a);c=v[f+12>>2];b=a;d=vh(b);b:{if(!c){break b}v[22656]=0;R(2112,b|0,c|0);e=v[22656];v[22656]=0;if((e|0)!=1){v[22656]=0;Bt(b,c);b=v[22656];v[22656]=0;if((b|0)!=1){break b}}a=P()|0;O()|0;Gy(d);S(a|0);L()}t[a+20|0]=0;break a}d=gb-16|0;gb=d;v[d+12>>2]=c;c:{if((b|0)==1){b=a+120|0;ho(b);nK(b,a,d+12|0);t[b+20|0]=1;break c}e=gb-16|0;gb=e;v[e+12>>2]=c;d:{if((b|0)==2){a=a+120|0;ho(a);c=v[e+12>>2];b=a;g=b;h=vh(b);e:{if(!c){break e}v[22656]=0;R(2114,g|0,c|0);i=v[22656];v[22656]=0;if((i|0)!=1){v[22656]=0;Bt(g,c);c=v[22656];v[22656]=0;if((c|0)!=1){break e}}a=P()|0;O()|0;Gy(h);S(a|0);L()}Ud(b+12|0);t[a+20|0]=2;break d}b=gb-16|0;gb=b;v[b+12>>2]=c;c=a+120|0;ho(c);nK(c,a,b+12|0);t[c+20|0]=3;gb=b+16|0}gb=e+16|0}gb=d+16|0}gb=f+16|0}function lk(a,b){var c=0,d=0,e=0,f=0;c=gb+-64|0;gb=c;d=v[v[a>>2]-12>>2]+a|0;f=v[d+16>>2]&-3;oo(d,f);a:{b:{if(w[uj(c+56|0,a,1)|0]){d=v[v[a>>2]-12>>2];v[22656]=0;d=v[(a+d|0)+24>>2];e=v[22656];v[22656]=0;c:{d:{if((e|0)==1){break d}v[22656]=0;e=v[b+12>>2];v[c+16>>2]=v[b+8>>2];v[c+20>>2]=e;e=v[b+4>>2];v[c+8>>2]=v[b>>2];v[c+12>>2]=e;Y(2319,c+40|0,d|0,c+8|0,8);b=v[22656];v[22656]=0;if((b|0)==1){break d}b=sh(c+24|0,-1,-1);v[22656]=0;b=LJ(c+40|0,b);d=v[22656];v[22656]=0;if((d|0)==1){break d}b=b?f|4:f;break c}b=V(0)|0;O()|0;Z(b|0)|0;b=f|1;tj(v[v[a>>2]-12>>2]+a|0,b);if(v[(v[v[a>>2]-12>>2]+a|0)+20>>2]&1){v[22656]=0;X(2027);a=v[22656];v[22656]=0;if((a|0)!=1){break a}a=P()|0;O()|0;v[22656]=0;X(20);b=v[22656];v[22656]=0;if((b|0)==1){break b}S(a|0);L()}$()}ih(v[v[a>>2]-12>>2]+a|0,b)}gb=c- -64|0;return}V(0)|0;O()|0;Bb()}L()}function mla(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;d=gb-32|0;gb=d;ud(c,2);t[d+16|0]=w[b+13|0];t[d|0]=64;e=d+16|0;g=c,h=w[ac(e,d)|0]<<2,u[g+30>>1]=h;f=b+14|0;v[c+24>>2]=(w[f|0]|w[f+1|0]<<8)<<1;Mk(d,2,b+1|0);Bc(e,d);v[22656]=0;Q(303,c+43|0,e|0)|0;e=v[22656];v[22656]=0;if((e|0)!=1){vb(d+16|0);e=Rc(a,8,1,0,2);a:{if((w[b|0]&3)!=1){break a}a=b+22|0;v[c>>2]=w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24);a=b+26|0;v[c+4>>2]=w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24);a=b+30|0;a=w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24);v[c+8>>2]=a;if(a>>>0>y[c+4>>2]){v[c+8>>2]=a-1}if(w[b|0]&4){u[c+34>>1]=x[c+34>>1]|2}if(w[b|0]&8){u[c+34>>1]=x[c+34>>1]|4}if(!(w[b|0]&16)){break a}Yi(e,16);Bf(e,9);v[c>>2]=v[c>>2]>>>1;v[c+4>>2]=v[c+4>>2]>>>1;v[c+8>>2]=v[c+8>>2]>>>1}gb=d+32|0;return}a=P()|0;O()|0;vb(d+16|0);S(a|0);L()}function Tna(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;g=gb-32|0;gb=g;l=g,m=aX(b),v[l+16>>2]=m;i=g+24|0;k=i;c=gb-32|0;gb=c;d=b;e=a;b=Yd(a);f=fc(a);a:{b:{if(b){e=wb(e);c:{while(1){d:{h=b+16|0;e:{if(SC(e,d,h)){if(!v[b>>2]){break b}f=b;break e}if(!RC(h,d)){break c}f=b+4|0;if(!v[b+4>>2]){break d}b=f;f=b}b=v[b>>2];continue}break}v[c+28>>2]=b;b=f;break a}v[c+28>>2]=b;b=f;break a}b=fc(e)}v[c+28>>2]=b}f=b;b=v[b>>2];t[c+27|0]=0;if(!b){e=gb-16|0;gb=e;b=fc(a);d=c+8|0;j=Vj(d,_W(),Wj(e+8|0,b));h=v[j>>2]+16|0;b=gb-16|0;gb=b;v[b+8>>2]=v[g+16>>2];u[h>>1]=x[v[b+8>>2]>>1];Kb(h+4|0);gb=b+16|0;l=fc(j),m=1,t[l+4|0]=m;gb=e+16|0;Hk(a,v[c+28>>2],f,v[d>>2]);b=ce(d);t[c+27|0]=1;a=v[d>>2];v[d>>2]=0;if(a){if(w[fc(d)+4|0]){Gk(a+16|0)}if(a){ZW(a)}}}Xj(k,yc(c+8|0,b),c+27|0);gb=c+32|0;a=ue(i);gb=g+32|0;return a+4|0}function kZ(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=gb-16|0;gb=d;ud(b,0);v[b>>2]=w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24);c=Sr(a+4|0,a);v[b+4>>2]=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);c=Sr(a+8|0,a);v[b+8>>2]=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);c=a+15|0;v[b+24>>2]=(w[c|0]|w[c+1|0]<<8)<<1;if(!(w[c|0]|w[c+1|0]<<8)){v[b+24>>2]=16726}c=a+14|0;e=b,f=(B(Mu(t[a+17|0],w[c|0]<<28>>24),v[b+24>>2])>>>0)/8363|0,v[e+24>>2]=f;t[d+15|0]=w[a+18|0];t[d+14|0]=127;e=b,f=(((w[ac(d+15|0,d+14|0)|0]<<8|64)&65344)>>>0)/127|0,u[e+30>>1]=f;if(w[c|0]>=16){c=w[c|0];u[b+34>>1]=32;u[b+28>>1]=c&240}a=a+19|0;if(w[a|0]&4){u[b+34>>1]=x[b+34>>1]|1}a:{if(!(w[a|0]&8)|y[b+4>>2]>=y[b+8>>2]){break a}u[b+34>>1]=x[b+34>>1]|2;if(w[a|0]&16){u[b+34>>1]=x[b+34>>1]|4}if(!(w[a|0]&64)){break a}u[b+34>>1]=x[b+34>>1]|128}gb=d+16|0}function Qda(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0;a:{b:{if((Vf(a)|0)==(b|0)){if((Vf(a+12|0)|0)==(c|0)){break b}}v[22656]=0;R(1534,a|0,b|0);d=v[22656];v[22656]=0;c:{d:{if((d|0)==1){break d}v[22656]=0;e=a+12|0;R(1534,e|0,c|0);d=v[22656];v[22656]=0;if((d|0)==1){break d}v[22656]=0;f=a+24|0;R(1535,f|0,b|0);d=v[22656];v[22656]=0;if((d|0)==1){break d}v[22656]=0;g=a+36|0;R(1535,g|0,c|0);d=v[22656];v[22656]=0;if((d|0)==1){break d}if(b){d=0;while(1){h=In(a,d);i=Mb(f,d),j=h,v[i>>2]=j;d=d+1|0;if((d|0)!=(b|0)){continue}break}}if(c){break c}return 1}b=V(89116)|0;if((O()|0)!=(ea(89116)|0)){break a}Z(b|0)|0;ZM(a);YM(a);b=a+12|0;ZM(b);YM(b);b=a+24|0;Gg(b);XM(b);a=a+36|0;Gg(a);XM(a);$();return 0}a=0;while(1){b=In(e,a);i=Mb(g,a),j=b,v[i>>2]=j;a=a+1|0;if((c|0)!=(a|0)){continue}break}}return 1}S(b|0);L()}function xt(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=C(0);b=gb+-64|0;gb=b;d=v[a>>2];a=v[d>>2];e=v[a+4>>2];v[b+40>>2]=v[a+20>>2];c=v[a+16>>2];v[b+32>>2]=v[a+12>>2];v[b+36>>2]=c;Jf(b+48|0,b+32|0,e);a=v[d+4>>2];d=v[a+4>>2];e=v[a+8>>2];c=v[b+60>>2];v[b+24>>2]=v[b+56>>2];v[b+28>>2]=c;c=v[b+52>>2];v[b+16>>2]=v[b+48>>2];v[b+20>>2]=c;v[b+8>>2]=v[a+8>>2];c=v[a+4>>2];v[b>>2]=v[a>>2];v[b+4>>2]=c;g=b+16|0;a=b;a:{if(d>>>0<=y[b+4>>2]){if(d>>>0<=y[g+4>>2]){if(e>>>0<=y[a+8>>2]){if(If(g)>>>0>=e>>>0){if(e){while(1){c=0;if(d){while(1){h=v[Xg(a,c,f)>>2];i=Ey(g,c,f),j=C(C(h|0)*C(7.450580596923828e-9)),z[i>>2]=j;c=c+1|0;if((d|0)!=(c|0)){continue}break}}f=f+1|0;if((e|0)!=(f|0)){continue}break}}break a}aa(2959,6176,36,5889);L()}aa(2989,6176,35,5889);L()}aa(4211,6176,34,5889);L()}aa(4246,6176,33,5889);L()}gb=b- -64|0}function iW(a){var b=0,c=0,d=0,e=0,f=0,g=0;b=gb-48|0;gb=b;f=b,g=Xb(w[a+8|0]|w[a+9|0]<<8|(w[a+10|0]<<16|w[a+11|0]<<24))+788|0,v[f+8>>2]=g;v[b+12>>2]=0;f=b,g=Xb(w[a+16|0]|w[a+17|0]<<8|(w[a+18|0]<<16|w[a+19|0]<<24)),v[f+16>>2]=g;v[b+20>>2]=0;d=b;c=b;if(Xb(w[a+24|0]|w[a+25|0]<<8|(w[a+26|0]<<16|w[a+27|0]<<24))){e=Xb(w[a+24|0]|w[a+25|0]<<8|(w[a+26|0]<<16|w[a+27|0]<<24))}else{e=52}v[c+24>>2]=e;v[d+28>>2]=0;a=Xb(w[a+32|0]|w[a+33|0]<<8|(w[a+34|0]<<16|w[a+35|0]<<24));v[b+44>>2]=4;v[b+32>>2]=a+80;v[b+36>>2]=0;v[b+40>>2]=b+8;a=v[b+44>>2];v[b>>2]=v[b+40>>2];v[b+4>>2]=a;d=gb-16|0;gb=d;a=v[b>>2];e=v[b>>2]+(v[b+4>>2]<<3)|0;a:{if((a|0)==(e|0)){break a}c=a+8|0;if((e|0)==(c|0)){break a}while(1){a=vw(a,c)?c:a;c=c+8|0;if((e|0)!=(c|0)){continue}break}}gb=d+16|0;gb=b+48|0;b=v[a>>2];d=b-52|0;jb=v[a+4>>2]-(b>>>0<52)|0;return d}function wt(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=C(0);b=gb+-64|0;gb=b;d=v[a>>2];a=v[d>>2];e=v[a+4>>2];v[b+40>>2]=v[a+20>>2];c=v[a+16>>2];v[b+32>>2]=v[a+12>>2];v[b+36>>2]=c;Jf(b+48|0,b+32|0,e);a=v[d+4>>2];d=v[a+4>>2];e=v[a+8>>2];c=v[b+60>>2];v[b+24>>2]=v[b+56>>2];v[b+28>>2]=c;c=v[b+52>>2];v[b+16>>2]=v[b+48>>2];v[b+20>>2]=c;v[b+8>>2]=v[a+8>>2];c=v[a+4>>2];v[b>>2]=v[a>>2];v[b+4>>2]=c;g=b+16|0;a=b;a:{if(d>>>0<=y[b+4>>2]){if(d>>>0<=y[g+4>>2]){if(e>>>0<=y[a+8>>2]){if(If(g)>>>0>=e>>>0){if(e){while(1){c=0;if(d){while(1){h=Xg(a,c,f);i=By(g,c,f),j=C(C(v[h>>2])*C(7.450580596923828e-9)),z[i>>2]=j;c=c+1|0;if((d|0)!=(c|0)){continue}break}}f=f+1|0;if((e|0)!=(f|0)){continue}break}}break a}aa(2959,6176,36,5889);L()}aa(2989,6176,35,5889);L()}aa(4211,6176,34,5889);L()}aa(4246,6176,33,5889);L()}gb=b- -64|0}function ufa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0;g=gb-16|0;gb=g;f=c+32|0;Wc(b,w[f|0]|w[f+1|0]<<8|(w[f+2|0]<<16|w[f+3|0]<<24));h=dd(a);f=c+28|0;a=f;e=w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24);a=0;v[22656]=0;R(1424,h|0,e|0);e=v[22656];v[22656]=0;if((e|0)!=1){a:{e=f;b:{if(!(w[e|0]|w[e+1|0]<<8|(w[e+2|0]<<16|w[e+3|0]<<24))){break b}e=c+4|0;while(1){v[22656]=0;c=Q(191,b|0,4)|0;i=v[22656];v[22656]=0;if((i|0)==1){break a}if(!c){break b}c=w[e|0]|w[e+1|0]<<8;v[22656]=0;c=Q(1425,b|0,c|0)|0;i=v[22656];v[22656]=0;c:{if((i|0)!=1){v[g+12>>2]=c;if(Ec(d)>>>0<=c>>>0){break c}v[22656]=0;R(1426,h|0,g+12|0);c=v[22656];v[22656]=0;if((c|0)!=1){break c}}break a}a=a+1|0;c=f;if(a>>>0<(w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24))>>>0){continue}break}}gb=g+16|0;return}}a=P()|0;O()|0;Nc(h);S(a|0);L()}function q8(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0;d=gb+-64|0;gb=d;a:{b:{if((b|0)>=0){e=a+24|0;if(Ri(Sb(v[e>>2]+484360|0))>>>0>b>>>0){break b}}a=a+16|0;break a}f=x[sc(Sb(v[e>>2]+484360|0),b)>>1];c:{if(!dm(v[e>>2]+484344|0,f)){break c}if((c|0)>=0){g=c;if((c|0)<v[_b(v[e>>2]+484344|0,f)+12>>2]){break c}}a=a+16|0;break a}u[v[e>>2]+1074448>>1]=b;c=b&65535;NO(v[e>>2],c);v[v[e>>2]+1074428>>2]=g;v[v[e>>2]+1074392>>2]=-2;e=v[e>>2];f=w[a+64|0];b=d+24|0;t[b+6|0]=255;v[b+16>>2]=0;u[b+4>>1]=0;v[b>>2]=0;if(!((c|0)==65535|(g|0)==-1)){v[b+8>>2]=g;v[b+16>>2]=2;u[b+12>>1]=c}c=v[b+20>>2];v[d+16>>2]=v[b+16>>2];v[d+20>>2]=c;c=v[b+12>>2];v[d+8>>2]=v[b+8>>2];v[d+12>>2]=c;c=v[b+4>>2];v[d>>2]=v[b>>2];v[d+4>>2]=c;b=d+48|0;vu(b,e,f?7:1,d);h=a,i=A[IO(b)>>3],A[h+16>>3]=i;en(b);a=a+16|0}gb=d- -64|0;return+A[a>>3]}function G3(a){a=a|0;var b=0,c=0,d=0,e=0;c=gb-192|0;gb=c;b=c+16|0;$f(b,a);v[22656]=0;R(99,c+32|0,b|0);a=v[22656];v[22656]=0;a:{b:{c:{d:{e:{if((a|0)!=1){v[22656]=0;a=W(100,c+48|0,c+32|0,8)|0;b=v[22656];v[22656]=0;if((b|0)==1){break e}vb(c+32|0);vb(c+16|0);b=v[v[a>>2]-12>>2];v[22656]=0;d=ga(79)|0;e=v[22656];v[22656]=0;if((e|0)==1){break c}v[22656]=0;U(80,c+8|0,b+(c+48|0)|0,d|0);b=v[22656];v[22656]=0;if((b|0)==1){break c}Wb(c+8|0);v[22656]=0;b=GN(a);d=v[22656];v[22656]=0;if((d|0)==1){break c}v[22656]=0;b=Q(105,b|0,c+32|0)|0;d=v[22656];v[22656]=0;if((d|0)==1){break c}d=v[v[b>>2]-12>>2];v[22656]=0;b=Fl(b+d|0);d=v[22656];v[22656]=0;if((d|0)==1){break c}d=v[c+32>>2];vf(a);gb=c+192|0;a=b?0:d;break a}b=P()|0;O()|0;break d}b=P()|0;O()|0;vb(c+32|0)}vb(c+16|0);break b}b=P()|0;O()|0;vf(a)}S(b|0);L()}return a|0}function efa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=gb-16|0;gb=d;ud(b,4);u[b+30>>1]=w[a+12|0]<<2;zg(b+30|0,256);c=w[a+15|0];u[b+34>>1]=32;u[b+28>>1]=c;t[b+37|0]=w[a+13|0];t[b+36|0]=w[a+16|0];v[b>>2]=w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24);c=a+4|0;e=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);v[b+4>>2]=e;c=a+8|0;v[b+8>>2]=e+(w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24));a=a+14|0;if(w[a|0]&16){v[b>>2]=v[b>>2]>>>1;v[b+4>>2]=v[b+4>>2]>>>1;v[b+8>>2]=v[b+8>>2]>>>1}if(w[a|0]&32){v[b>>2]=v[b>>2]>>>1;v[b+4>>2]=v[b+4>>2]>>>1;v[b+8>>2]=v[b+8>>2]>>>1}a:{if(!(w[a|0]&3)|y[b+8>>2]<=y[b+4>>2]){break a}u[b+34>>1]=x[b+34>>1]|2;if(!(w[a|0]&2)){break a}u[b+34>>1]=x[b+34>>1]|4}a=Tb(d,18726);v[22656]=0;Q(303,b+43|0,a|0)|0;b=v[22656];v[22656]=0;if((b|0)!=1){vb(a);gb=d+16|0;return}b=P()|0;O()|0;vb(a);S(b|0);L()}function a8(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;d=gb-32|0;gb=d;e=mc(a);f=b+24|0;a=v[f>>2];v[22656]=0;a=oq(a+484344|0);c=v[22656];v[22656]=0;a:{b:{c:{if((c|0)==1){break c}v[22656]=0;R(1421,e|0,a|0);a=v[22656];v[22656]=0;if((a|0)==1){break c}a=0;d:{e:{f:{g:{while(1){c=v[f>>2];v[22656]=0;c=oq(c+484344|0);g=v[22656];v[22656]=0;if((g|0)==1){break b}if(a>>>0>=c>>>0){break d}c=_b(v[f>>2]+484344|0,a);v[22656]=0;R(2098,d|0,c|0);c=v[22656];v[22656]=0;if((c|0)!=1){v[22656]=0;U(2092,d+16|0,b|0,d|0);c=v[22656];v[22656]=0;if((c|0)==1){break g}v[22656]=0;R(1423,e|0,d+16|0);c=v[22656];v[22656]=0;if((c|0)==1){break f}a=a+1|0;vb(d+16|0);vb(d);continue}break}a=P()|0;O()|0;break a}a=P()|0;O()|0;break e}a=P()|0;O()|0;vb(d+16|0)}vb(d);break a}gb=d+32|0;return}a=P()|0;O()|0;break a}a=P()|0;O()|0}yd(e);S(a|0);L()}function rga(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=C(0),g=0,h=0,i=C(0),j=0,k=0;e=gb-16|0;gb=e;v[e+12>>2]=c>>>3;v[e+8>>2]=v[a>>2];c=v[Fb(e+12|0,e+8|0)>>2];i=z[d>>2];b=zb(b);if(c){a=v[a+20>>2];d=c;while(1){z[e+12>>2]=i*(l(2,w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24)),q());v[e+8>>2]=-1082130432;v[e+4>>2]=1065353216;f=C(z[zf(e+12|0,e+8|0,e+4|0)>>2]*C(32768));z[e+12>>2]=f;h=a;f=fe(f);a:{if(C(D(f))<C(2147483648)){g=~~f;break a}g=-2147483648}j=h,k=Uc(g),u[j>>1]=k;z[e+12>>2]=i*(l(2,w[b+4|0]|w[b+5|0]<<8|(w[b+6|0]<<16|w[b+7|0]<<24)),q());v[e+8>>2]=-1082130432;v[e+4>>2]=1065353216;f=C(z[zf(e+12|0,e+8|0,e+4|0)>>2]*C(32768));z[e+12>>2]=f;h=a;f=fe(f);b:{if(C(D(f))<C(2147483648)){g=~~f;break b}g=-2147483648}j=h,k=Uc(g),u[j+2>>1]=k;a=a+4|0;b=b+8|0;d=d-1|0;if(d){continue}break}}gb=e+16|0;return c<<3}function T8(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;g=gb-16|0;gb=g;v[g+12>>2]=c;c=gb+-64|0;gb=c;m=c;j=c+16|0;k=gb-16|0;gb=k;n=cU(k+8|0);while(1){e=b;h=gb+-64|0;gb=h;d=n;f=v[d+4>>2]-v[d>>2]|0;a:{if(!f){d=v[d>>2];break a}f=f+1|0;if(!f){d=zK(AK(h+8|0,e,32));break a}i=e;e=E(f);e=AK(h+8|0,i,(f&-1>>>e+1?32:31)-e|0);while(1){i=zK(e);if(f>>>0<=i>>>0){continue}break}d=v[d>>2]+i|0}gb=h- -64|0;o=Fe(j,l),p=d,v[o>>2]=p;l=l+1|0;if((l|0)!=12){continue}break}gb=k+16|0;d=jU(m,j,qU(j));v[22656]=0;b=a;WB(b,d,0);e=v[22656];v[22656]=0;b:{if((e|0)!=1){Nc(d);gb=c- -64|0;break b}a=P()|0;O()|0;Nc(d);S(a|0);L()}c=b+120|0;yK(c,b,g+12|0);t[c+20|0]=1;v[22656]=0;R(2107,b|0,v[g+12>>2]);b=v[22656];v[22656]=0;c:{if((b|0)!=1){gb=g+16|0;break c}a=P()|0;O()|0;ho(c);S(a|0);L()}return a|0}function $M(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;d=gb-16|0;gb=d;a:{if(Nb(a)>>>0>511){break a}if(!_f(v[v[b>>2]-12>>2]+b|0)){break a}j=d;g=b;h=c;f=gb-16|0;gb=f;e=sf(64);v[22656]=0;i=T(1316,e|0)|0;k=v[22656];v[22656]=0;b:{c:{if((k|0)!=1){e=os(f,i);i=v[e>>2];v[22656]=0;g=W(1529,i|0,g|0,h|0)|0;h=v[22656];v[22656]=0;d:{e:{if((h|0)!=1){if((g|0)==1){break e}gA(f+8|0);break d}a=P()|0;O()|0;Jg(e);break c}pi(f+8|0,e)}Jg(e);gb=f+16|0;g=v[f+8>>2];break b}a=P()|0;O()|0;Yb(e)}S(a|0);L()}v[j+8>>2]=g;f:{g:{if(!Dd(d+8|0)){v[22656]=0;b=Q(1527,b|0,c|0)|0;c=v[22656];v[22656]=0;if((c|0)==1){break g}v[d>>2]=b;dX(d+8|0,ce(d));Jg(d)}if(!Dd(d+8|0)){break f}b=d+8|0;l=v[b>>2];v[22656]=0;R(1528,a|0,b|0);a=v[22656];v[22656]=0;if((a|0)!=1){break f}}a=P()|0;O()|0;Jg(d+8|0);S(a|0);L()}Jg(d+8|0)}gb=d+16|0;return l}function LH(a,b){var c=0,d=0,e=0;a:{if(w[b|0]){break a}b=Lx(11165);if(w[b|0]?b:0){break a}b=Lx(B(a,12)+77072|0);if(w[b|0]?b:0){break a}b=Lx(11412);if(w[b|0]?b:0){break a}b=11954}b:{while(1){e=w[b+c|0];if(!(!e|(e|0)==47)){e=15;c=c+1|0;if((c|0)!=15){continue}break b}break}e=c}d=11954;c:{d:{c=w[b|0];e:{f:{if(!(w[b+e|0]|(c|0)==46)){d=b;if((c|0)!=67){break f}}if(!w[d+1|0]){break e}}if(!wj(d,11954)){break e}if(wj(d,10846)){break d}}if(!a){c=76996;if(w[d+1|0]==46){break c}}return 0}c=v[115997];if(c){while(1){if(!wj(d,c+8|0)){break c}c=v[c+24>>2];if(c){continue}break}}c=v[115997];if(c){while(1){if(!wj(d,c+8|0)){return c}c=v[c+24>>2];if(c){continue}break}}c=Cd(28);g:{if(!c){c=0;break g}v[c+4>>2]=20;v[c>>2]=76976;b=c+8|0;hc(b,d,e);t[b+e|0]=0;v[c+24>>2]=v[115997];v[115997]=c}c=a|c?c:76996}return c}function mga(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;g=gb-32|0;gb=g;m=g,n=ar(b),v[m+16>>2]=n;j=g+24|0;l=j;d=gb-32|0;gb=d;f=b;c=a;b=Yd(c);e=fc(c);a:{b:{if(b){wb(c);c:{while(1){d:{c=b+14|0;e:{if(dP(f,c)){if(!v[b>>2]){break b}e=b;break e}if(!dP(c,f)){break c}e=b+4|0;if(!v[b+4>>2]){break d}b=e;e=b}b=v[b>>2];continue}break}v[d+28>>2]=b;b=e;break a}v[d+28>>2]=b;b=e;break a}b=fc(c)}v[d+28>>2]=b}e=b;b=v[b>>2];t[d+27|0]=0;if(!b){i=gb-16|0;gb=i;b=fc(a);f=d+8|0;k=Vj(f,qC(),Wj(i+8|0,b));b=v[k>>2];c=gb-16|0;gb=c;v[c+8>>2]=v[g+16>>2];h=v[c+8>>2];h=x[h>>1]|x[h+2>>1]<<16;u[b+18>>1]=0;u[b+14>>1]=h;u[b+16>>1]=h>>>16;gb=c+16|0;m=fc(k),n=1,t[m+4|0]=n;gb=i+16|0;Hk(a,v[d+28>>2],e,v[f>>2]);b=ce(f);t[d+27|0]=1;rC(f)}Xj(l,yc(d+8|0,b),d+27|0);gb=d+32|0;a=Yl(j);gb=g+32|0;return a+4|0}function Mma(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;e=gb-16|0;gb=e;t[e+15|0]=0;u[e+12>>1]=0;if(d){m=B(c,d);o=(m|0)<=0;j=4;while(1){if(!o){i=b+k|0;p=m+i|0;while(1){t[e+11|0]=0;HV(a,e+15|0,e+12|0,e+11|0);a:{if(!j){h=w[e+11|0];break a}h=w[e+11|0];c=x[e+12>>1];f=j;b:{while(1){g=c<<1;c=g&254;c:{if(c){g=(g&65534)>>>0>255;break c}if(!lf(a,e+10|0)){break b}c=w[e+10|0];g=c>>>7|0;c=c<<1&254|1}h=h<<1|g;f=f-1|0;if(f&255){continue}break}u[e+12>>1]=c;break a}u[e+12>>1]=0}c=1;g=h&255;d:{if(g>>>0<4){break d}f=7;while(1){c=f;n=c&255;if(g>>>n&1){break d}f=c-1|0;if(n>>>0>1){continue}break}}f=h&1;t[e+15|0]=f;l=(f-1^(h&254)>>>1)+l|0;t[e+11|0]=l;t[i|0]=l;j=(c+j&254)>>>1|0;i=d+i|0;if(p>>>0>i>>>0){continue}break}}k=k+1|0;if((k|0)!=(d|0)){continue}break}}gb=e+16|0}function Oy(a,b,c,d,e,f){var g=0,h=0,i=0,j=C(0);g=gb-96|0;gb=g;h=a+24|0;wq(v[h>>2]);t[v[h>>2]+1298380|0]=v[a+52>>2]!=0;v[g+92>>2]=f;v[g+88>>2]=e;v[g+84>>2]=d;v[g+80>>2]=c;c=g+80|0;c=mg(g+32|0,c,mL(c),b);e=v[a+32>>2];j=z[a+48>>2];v[g+8>>2]=v[c+8>>2];d=v[c+4>>2];v[g>>2]=v[c>>2];v[g+4>>2]=d;d=gb-16|0;gb=d;v[d+8>>2]=v[g+8>>2];c=v[g+4>>2];v[d>>2]=v[g>>2];v[d+4>>2]=c;f=g+48|0;c=f;At(c);v[c+8>>2]=e;v[c+4>>2]=0;v[c>>2]=56268;e=v[d+4>>2];v[c+12>>2]=v[d>>2];v[c+16>>2]=e;v[c+20>>2]=v[d+8>>2];z[c+24>>2]=j;v[c>>2]=55472;gb=d+16|0;a:{if(!b){break a}while(1){c=v[h>>2];v[g+24>>2]=b;v[g+28>>2]=0;v[g+16>>2]=134217727;v[g+20>>2]=0;c=Ht(c,v[Uk(g+24|0,g+16|0)>>2],f);i=c+i|0;if(!c){break a}b=b-c|0;if(b){continue}break}}if(!(v[a+52>>2]!=1|i)){a=v[h>>2];v[a+480208>>2]=v[a+480208>>2]&-513}gb=g+96|0;return i}function Ny(a,b,c,d,e,f){var g=0,h=0,i=0,j=C(0);g=gb-96|0;gb=g;h=a+24|0;wq(v[h>>2]);t[v[h>>2]+1298380|0]=v[a+52>>2]!=0;v[g+92>>2]=f;v[g+88>>2]=e;v[g+84>>2]=d;v[g+80>>2]=c;c=g+80|0;c=mg(g+32|0,c,mL(c),b);e=v[a+32>>2];j=z[a+48>>2];v[g+8>>2]=v[c+8>>2];d=v[c+4>>2];v[g>>2]=v[c>>2];v[g+4>>2]=d;d=gb-16|0;gb=d;v[d+8>>2]=v[g+8>>2];c=v[g+4>>2];v[d>>2]=v[g>>2];v[d+4>>2]=c;f=g+48|0;c=f;At(c);v[c+8>>2]=e;v[c+4>>2]=0;v[c>>2]=57112;e=v[d+4>>2];v[c+12>>2]=v[d>>2];v[c+16>>2]=e;v[c+20>>2]=v[d+8>>2];z[c+24>>2]=j;v[c>>2]=56348;gb=d+16|0;a:{if(!b){break a}while(1){c=v[h>>2];v[g+24>>2]=b;v[g+28>>2]=0;v[g+16>>2]=134217727;v[g+20>>2]=0;c=Ht(c,v[Uk(g+24|0,g+16|0)>>2],f);i=c+i|0;if(!c){break a}b=b-c|0;if(b){continue}break}}if(!(v[a+52>>2]!=1|i)){a=v[h>>2];v[a+480208>>2]=v[a+480208>>2]&-513}gb=g+96|0;return i}function wma(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=gb-528|0;gb=d;c=-1;a:{if(!Wf(a,1468)){break a}Wl(a,1464);b=d+524|0;DV(a,b);if(!je(b,33202)){c=0;if(!je(d+524|0,12635)){break a}}Wl(a,20);b=1;while(1){c=-1;if(!AV(a,d)){break a}e=lC(d)+e|0;c=b&65535;b=b+1|0;if(c>>>0<31){continue}break}c=0;if(e>>>0>40){break a}e=d+520|0;f=e;c=gb-32|0;gb=c;b=a;b:{if(!Wf(b,2)){t[c+16|0]=0;pE(f,c+16|0);break b}Cn(c+24|0,f);f=v[c+28>>2];v[c+8>>2]=v[c+24>>2];v[c+12>>2]=f;dC(c+16|0,b,c+8|0)}gb=c+32|0;f=qd(e);c=0;if(w[e|0]>128){break a}b=d;c=gb-32|0;gb=c;c:{if(!Wf(a,512)){iV(b);break c}Vv(c+24|0,b);e=v[c+28>>2];v[c+8>>2]=v[c+24>>2];v[c+12>>2]=e;dC(c+16|0,a,c+8|0)}gb=c+32|0;a=d+512|0;c=w[f|0];d:{while(1){if(c>>>0<w[b|0]){break d}b=b+1|0;if((a|0)!=(b|0)){continue}break}c=1;break a}c=0}gb=d+528|0;return c|0}function Cj(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0;f=gb-48|0;gb=f;d=a+24|0;g=v[v[d>>2]+24620>>2];a:{if(!((g|0)!=(b|0)|v[v[d>>2]+24624>>2]!=(c|0))){if(w[a+29|0]){break a}tO(v[d>>2],1);break a}e=f+8|0;hc(e,v[d>>2]+24604|0,40);h=v[e+32>>2];i=v[e+36>>2];v[f+28>>2]=c;v[f+24>>2]=b;Jt(e,h);Mo(e,i);$z(v[d>>2],e);if((b|0)==(g|0)){break a}b=v[d>>2];e=b+946300|0;c=b+906300|0;while(1){b=v[c>>2];b:{if(!b){break b}if(!(kb[v[v[b>>2]+116>>2]](b)|0)){break b}kb[v[v[b>>2]+108>>2]](b,0);kb[v[v[b>>2]+96>>2]](b);kb[v[v[b>>2]+124>>2]](b)}c=c+160|0;if((e|0)!=(c|0)){continue}break}b=v[d>>2];d=b+946300|0;c=b+906300|0;while(1){b=v[c>>2];c:{if(!b){break c}if(kb[v[v[b>>2]+116>>2]](b)|0){break c}kb[v[v[b>>2]+108>>2]](b,1);kb[v[v[b>>2]+120>>2]](b)}c=c+160|0;if((d|0)!=(c|0)){continue}break}}t[a+29|0]=1;gb=f+48|0}function $oa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;e=gb-304|0;gb=e;Se(b);if(Pb(a,1)){a:{while(1){d=e+48|0;td(e+24|0,d,d+256|0);d=v[e+28>>2];v[e+8>>2]=v[e+24>>2];v[e+12>>2]=d;d=gb-48|0;gb=d;f=v[a>>2];i=v[a+8>>2];g=v[e+12>>2];h=v[e+8>>2];v[d+16>>2]=h;v[d+20>>2]=g;v[d+24>>2]=h;v[d+28>>2]=g;rh(d+32|0,d+16|0);g=v[v[f>>2]+28>>2];h=v[d+36>>2];v[d+8>>2]=v[d+32>>2];v[d+12>>2]=h;kb[g|0](d+40|0,f,i,d+8|0);f=v[d+44>>2];v[d>>2]=v[d+40>>2];v[d+4>>2]=f;f=e+32|0;rh(f,d);gb=d+48|0;j=e,k=yb(f),v[j+44>>2]=k;j=e,k=c-Ab(b)|0,v[j+20>>2]=k;d=v[Fb(e+44|0,e+20|0)>>2];if(!d){break a}t[e+32|0]=0;h=d;d=e+48|0;g=h+d|0;i=e+32|0;f=Xm(d,g,i);j=e,k=gf(b),v[j+32>>2]=k;Fd(e+16|0,i);MX(b,v[e+16>>2],d,f);Rb(a,f-d|0);if(f>>>0>=g>>>0){continue}break}Rb(a,1)}d=(Ab(b)|0)!=0}gb=e+304|0;return d|0}function Rn(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;g=gb-16|0;gb=g;h=a;a=gb-16|0;gb=a;i=a;e=gb-32|0;gb=e;d=He(e+16|0,1,0);a:{b:{c:{while(1){c=Jb(d);f=Jb(d);j=Ab(d);k=v[b>>2];v[22656]=0;zu(e+8|0,c,f+j|0,k);c=v[22656];v[22656]=0;if((c|0)==1){break b}if(!v[e+12>>2]){break c}c=Ab(d);v[22656]=0;v[e+4>>2]=c;c=xf(e+4|0);f=v[22656];v[22656]=0;if((f|0)!=1){v[22656]=0;U(75,d|0,c|0,0);c=v[22656];v[22656]=0;if((c|0)!=1){continue}}break}break b}b=v[e+8>>2];c=Jb(d);v[22656]=0;R(76,d|0,b-c|0);b=v[22656];v[22656]=0;if((b|0)!=1){v[22656]=0;R(86,i|0,d|0);b=v[22656];v[22656]=0;if((b|0)==1){break b}vb(d);gb=e+32|0;break a}}a=P()|0;O()|0;vb(d);S(a|0);L()}v[22656]=0;R(85,h|0,a|0);b=v[22656];v[22656]=0;d:{if((b|0)!=1){vb(a);gb=a+16|0;break d}b=P()|0;O()|0;vb(a);S(b|0);L()}gb=g+16|0}function w7(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=C(0);b=gb+-64|0;gb=b;d=v[a>>2];a=v[d>>2];e=v[a+4>>2];v[b+40>>2]=v[a+20>>2];c=v[a+16>>2];v[b+32>>2]=v[a+12>>2];v[b+36>>2]=c;Jf(b+48|0,b+32|0,e);a=v[d+4>>2];d=v[a+4>>2];e=v[a+8>>2];c=v[b+60>>2];v[b+24>>2]=v[b+56>>2];v[b+28>>2]=c;c=v[b+52>>2];v[b+16>>2]=v[b+48>>2];v[b+20>>2]=c;v[b+8>>2]=v[a+8>>2];c=v[a+4>>2];v[b>>2]=v[a>>2];v[b+4>>2]=c;g=b+16|0;a=b;a:{if(d>>>0<=y[b+4>>2]){if(d>>>0<=y[g+4>>2]){if(e>>>0<=y[a+8>>2]){if(If(g)>>>0>=e>>>0){if(e){while(1){c=0;if(d){while(1){h=A[Wg(a,c,f)>>3];i=Ey(g,c,f),j=C(h),z[i>>2]=j;c=c+1|0;if((d|0)!=(c|0)){continue}break}}f=f+1|0;if((e|0)!=(f|0)){continue}break}}break a}aa(2959,6176,80,5856);L()}aa(2989,6176,79,5856);L()}aa(4211,6176,78,5856);L()}aa(4246,6176,77,5856);L()}gb=b- -64|0}function n7(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=C(0);b=gb+-64|0;gb=b;d=v[a>>2];a=v[d>>2];e=v[a+4>>2];v[b+40>>2]=v[a+20>>2];c=v[a+16>>2];v[b+32>>2]=v[a+12>>2];v[b+36>>2]=c;Jf(b+48|0,b+32|0,e);a=v[d+4>>2];d=v[a+4>>2];e=v[a+8>>2];c=v[b+60>>2];v[b+24>>2]=v[b+56>>2];v[b+28>>2]=c;c=v[b+52>>2];v[b+16>>2]=v[b+48>>2];v[b+20>>2]=c;v[b+8>>2]=v[a+8>>2];c=v[a+4>>2];v[b>>2]=v[a>>2];v[b+4>>2]=c;g=b+16|0;a=b;a:{if(d>>>0<=y[b+4>>2]){if(d>>>0<=y[g+4>>2]){if(e>>>0<=y[a+8>>2]){if(If(g)>>>0>=e>>>0){if(e){while(1){c=0;if(d){while(1){h=Wg(a,c,f);i=By(g,c,f),j=C(A[h>>3]),z[i>>2]=j;c=c+1|0;if((d|0)!=(c|0)){continue}break}}f=f+1|0;if((e|0)!=(f|0)){continue}break}}break a}aa(2959,6176,80,5856);L()}aa(2989,6176,79,5856);L()}aa(4211,6176,78,5856);L()}aa(4246,6176,77,5856);L()}gb=b- -64|0}function Kea(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;f=gb-32|0;gb=f;c=Ji(a);if(b){c=B(b,c);a:{b:{if(v[a+12>>2]!=(b|0)){break b}if((Kg(a)|0)!=(c|0)){break b}b=gb-16|0;gb=b;c=Vb(a);d=Zb(a);gi(b+8|0);a=gb-16|0;gb=a;v[a>>2]=d;v[a+8>>2]=c;d=Yt(a,a+8|0);g=gb-16|0;gb=g;v[g+8>>2]=c;if((d|0)>0){while(1){h=g+8|0;c=v[h>>2];e=w[b+8|0]|w[b+9|0]<<8|(w[b+10|0]<<16|w[b+11|0]<<24);t[c|0]=e;t[c+1|0]=e>>>8;t[c+2|0]=e>>>16;t[c+3|0]=e>>>24;e=w[b+12|0]|w[b+13|0]<<8;t[c+4|0]=e;t[c+5|0]=e>>>8;c=d>>>0>1;bk(h);d=d-1|0;if(c){continue}break}}gb=g+16|0;gb=a+16|0;gb=b+16|0;break a}d=f+8|0;gi(d);c=mX(f+16|0,c,d);DN(a);lp(a,c);v[a>>2]=v[c>>2];v[a+4>>2]=v[c+4>>2];d=v[wb(c)>>2];i=wb(a),j=d,v[i>>2]=j;i=wb(c),j=0,v[i>>2]=j;v[c>>2]=0;v[c+4>>2]=0;jn(c);v[a+12>>2]=b}a=1}else{a=0}gb=f+32|0;return a|0}function tV(a){var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;b=a;d=b+20|0;while(1){f=c;c=t[b|0];c=f+((c&255)!=0&(c|0)<32)|0;b=b+1|0;if((d|0)!=(b|0)){continue}break}a:{if(c>>>0>5){break a}while(1){b=0;d=B(g,30)+a|0;e=d+20|0;j=e+22|0;while(1){f=b;b=t[e|0];b=f+((b&255)!=0&(b|0)<32)|0;e=e+1|0;if((j|0)!=(e|0)){continue}break}c=b+c|0;if(w[d+44|0]|(c>>>0>48|w[d+45|0]>64)){break a}if(Ib(w[d+42|0]|w[d+43|0]<<8)>>>0>32768){break a}h=Ib(w[d+42|0]|w[d+43|0]<<8)+h|0;i=w[d+45|0]|i;g=g+1|0;if((g|0)!=15){continue}break}if(!h|!(i&255)|w[a+470|0]>128|w[a+471|0]>220){break a}b=a+472|0;d=b+128|0;b:{if((b|0)==(d|0)){break b}c=b+1|0;if((d|0)==(c|0)){break b}while(1){b=w[b|0]<w[c|0]?c:b;c=c+1|0;if((d|0)!=(c|0)){continue}break}}b=w[b|0];if(b>>>0>63|!(b|w[a+470|0]?1:w[a+471|0])){break a}k=1}return k}function sja(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;e=gb-32|0;gb=e;i=v[a+40>>2];j=v[a+36>>2];l=v[a+16>>2];b=v[a+4>>2];g=b;f=v[a>>2];v[e+24>>2]=f;v[e+28>>2]=b;b=v[a+12>>2];v[e+16>>2]=v[a+8>>2];v[e+20>>2]=b;a:{if(d){while(1){m=f>>>18|0;g=((((g&2147483647)<<1|f>>>31)&2147483646)<<1)+l|0;h=0;b=1;while(1){k=h<<1;f=u[k+g>>1];v[(e+8|0)+(h<<2)>>2]=f+((B(u[(k|4)+g>>1]-f|0,m)|0)/16384|0);f=b;b=0;h=1;if(f){continue}break}f=v[a+32>>2];j=v[a+28>>2]+j|0;b=j>>12;v[c>>2]=v[c>>2]+B(b,v[e+8>>2]);i=f+i|0;h=i>>12;v[c+4>>2]=v[c+4>>2]+B(h,v[e+12>>2]);Ub(e+24|0,e+16|0);d=d-1|0;if(d){c=c+8|0;f=v[e+24>>2];g=v[e+28>>2];continue}break}f=v[e+24>>2];g=v[e+28>>2];break a}h=i>>12;b=j>>12}v[a+40>>2]=i;v[a+20>>2]=b;v[a+36>>2]=j;v[a+24>>2]=h;v[a>>2]=f;v[a+4>>2]=g;gb=e+32|0}function L8(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;d=gb-96|0;gb=d;v[22656]=0;f=v[b+12>>2];v[d+40>>2]=v[b+8>>2];v[d+44>>2]=f;f=v[b+4>>2];v[d+32>>2]=v[b>>2];v[d+36>>2]=f;f=T(2075,d+32|0)|0;e=v[22656];v[22656]=0;if((e|0)!=1){a:{b:{if(f){v[22656]=0;R(2076,d+72|0,b|0);b=v[22656];v[22656]=0;if((b|0)!=1){b=d+80|0;f=d+72|0;Jw(b,f);e=Xf(d+88|0,b);g=Xf(d- -64|0,c);h=v[e+4>>2];v[d+8>>2]=v[e>>2];v[d+12>>2]=h;e=v[g+4>>2];v[d>>2]=v[g>>2];v[d+4>>2]=e;Kw(a,d+8|0,d);break b}break a}v[22656]=0;R(2077,d+72|0,b|0);b=v[22656];v[22656]=0;if((b|0)==1){break a}b=d+80|0;f=d+72|0;Jw(b,f);e=Xf(d+56|0,b);g=Xf(d+48|0,c);h=v[e+4>>2];v[d+24>>2]=v[e>>2];v[d+28>>2]=h;e=v[g+4>>2];v[d+16>>2]=v[g>>2];v[d+20>>2]=e;Kw(a,d+24|0,d+16|0)}Kd(b);Kd(f);Kd(c);gb=d+96|0;return}}a=P()|0;O()|0;Kd(c);S(a|0);L()}function Aga(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;d=gb-32|0;gb=d;v[d+24>>2]=c>>>3;v[d+16>>2]=v[a>>2];j=v[Fb(d+24|0,d+16|0)>>2];b=zb(b);if(j){a=v[a+20>>2];c=j;while(1){k=0;e=b;g=w[e+4|0]|w[e+5|0]<<8|(w[e+6|0]<<16|w[e+7|0]<<24);h=w[e|0]|w[e+1|0]<<8|(w[e+2|0]<<16|w[e+3|0]<<24);f=g<<24|h>>>8;e=0;l=f&65280;f=e;e=g<<8|h>>>24;f=f|k;k=e&255|l|(h<<24|h<<8&16711680);v[d+24>>2]=((g&255)<<24|h>>>8)&-16777216|((g&16777215)<<8|h>>>24)&16711680|(g>>>8&65280|g>>>24)|f;v[d+28>>2]=k;v[d+16>>2]=0;v[d+20>>2]=-1074790400;v[d+8>>2]=0;v[d+12>>2]=1072693248;i=A[bh(d+24|0,d+16|0,d+8|0)>>3]*32768;A[d+24>>3]=i;e=a;i=ee(i);a:{if(D(i)<2147483648){f=~~i;break a}f=-2147483648}m=e,n=Uc(f),u[m>>1]=n;a=a+2|0;b=b+8|0;c=c-1|0;if(c){continue}break}}gb=d+32|0;return j<<3}function rha(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;f=gb-16|0;gb=f;h=f;e=gb-32|0;gb=e;d=He(e+16|0,1,0);a:{b:{c:{while(1){g=Jb(d);i=Jb(d);j=Ab(d);k=v[b+4>>2];c=v[b>>2];v[22656]=0;Pa(78,e+8|0,g|0,i+j|0,c|0,k|0);c=v[22656];v[22656]=0;if((c|0)==1){break b}if(!v[e+12>>2]){break c}c=Ab(d);v[22656]=0;v[e+4>>2]=c;c=xf(e+4|0);g=v[22656];v[22656]=0;if((g|0)!=1){v[22656]=0;U(75,d|0,c|0,0);c=v[22656];v[22656]=0;if((c|0)!=1){continue}}break}break b}b=v[e+8>>2];c=Jb(d);v[22656]=0;R(76,d|0,b-c|0);b=v[22656];v[22656]=0;if((b|0)!=1){v[22656]=0;R(77,h|0,d|0);b=v[22656];v[22656]=0;if((b|0)==1){break b}vb(d);gb=e+32|0;break a}}a=P()|0;O()|0;vb(d);S(a|0);L()}v[22656]=0;R(72,a|0,f|0);a=v[22656];v[22656]=0;if((a|0)!=1){vb(f);gb=f+16|0;return}a=P()|0;O()|0;vb(f);S(a|0);L()}function oO(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;e=gb-16|0;gb=e;g=-1;a:{if(!Tz(a,b,2)){break a}i=v[b+656>>2];d=e+8|0;f=a+1074312|0;Db(d,f,31);b:{if(Cb(d)){d=v[b+740>>2];if(d){break b}break a}d=v[b+740>>2]}h=e+8|0;Db(h,f,31);f=d-Cb(h)|0;d=v[a+480180>>2];d=(d|0)==4096?64:(d|0)==16384?192:512;d=Vq(i+88|0,f,d,v[a+480180>>2]==4096?255:64)-(d>>>1|0)|0;if(w[b+746|0]&16){g=Jq(a,b,!(v[b+88>>2]&32768),d);break a}if(Mj(b)){if((d|0)==u[b+772>>1]){break a}j=b,k=Uc(d),u[j+772>>1]=k;t[b+851|0]=w[b+851|0]|32;break a}b=Hj(a);v[e+8>>2]=d;f=c;c:{if((d|0)<0){v[e+8>>2]=0-d;dk(e+8|0,255);a=(v[e+8>>2]<<2)+(b?44608:43584)|0;break c}dk(e+8|0,255);a=(v[e+8>>2]<<2)+(b?43584:44608)|0}a=v[a>>2];b=a;d=a>>31;a=v[c>>2];j=f,k=Ac(lqa(kqa(b,d,a,a>>31),jb,65536,0),jb),v[j>>2]=k}gb=e+16|0;return g}function oN(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=C(0),j=0,k=C(0),l=0,m=C(0);f=gb-16|0;gb=f;g=u[d>>1];e=u[d+2>>1];if(!(!x[b>>1]|(g|0)>(e|0)|(!(z[c>>2]>C(0))|(e-g|0)>32766))){u[a>>1]=3;h=a+4|0;Gg(h);u[a+28>>1]=65472;v[f+12>>2]=1065353216;qN(h,f+12|0);v[a+32>>2]=0;u[a+30>>1]=0;Gg(a+16|0);u[a+28>>1]=x[d>>1];g=a;e=gb-16|0;gb=e;u[e+14>>1]=x[b>>1];v[22656]=0;u[e+12>>1]=32767;b=Pc(e+14|0,e+12|0);j=v[22656];v[22656]=0;a:{if((j|0)!=1){gb=e+16|0;b=u[b>>1];break a}V(0)|0;O()|0;Bb();L()}u[g+30>>1]=b;i=C(D(z[c>>2]));z[a+32>>2]=i;i=oe(i,C(C(1)/C(u[a+30>>1])));j=1;El(h,(u[d+2>>1]-u[d>>1]|0)+1|0);b=u[d>>1];if((b|0)<=u[d+2>>1]){while(1){k=oe(i,C(b|0));l=Mb(h,b-u[a+28>>1]|0),m=k,z[l>>2]=m;c=u[d+2>>1]>(b|0);b=b+1|0;if(c){continue}break}}nq(a)}gb=f+16|0;return j|0}function Qp(a){var b=C(0),c=0,d=0,e=0,f=0;c=gb-16|0;gb=c;e=(p(a),j(2));d=e&2147483647;a:{if(d>>>0<=1061752794){b=C(1);if(d>>>0<964689920){break a}b=si(+a);break a}if(d>>>0<=1081824209){f=+a;if(d>>>0>=1075235812){b=C(-si(((e|0)>=0?-3.141592653589793:3.141592653589793)+f));break a}if((e|0)<0){b=ti(f+1.5707963267948966);break a}b=ti(1.5707963267948966-f);break a}if(d>>>0<=1088565717){if(d>>>0>=1085271520){b=si(((e|0)>=0?-6.283185307179586:6.283185307179586)+ +a);break a}if((e|0)<0){b=ti(-4.71238898038469-+a);break a}b=ti(+a+-4.71238898038469);break a}b=C(a-a);if(d>>>0>=2139095040){break a}b:{switch(hy(a,c+8|0)&3){case 0:b=si(A[c+8>>3]);break a;case 1:b=ti(-A[c+8>>3]);break a;case 2:b=C(-si(A[c+8>>3]));break a;default:break b}}b=ti(A[c+8>>3])}a=b;gb=c+16|0;return a}function Fi(a,b,c,d){var e=0,f=0,g=0,h=0;v[a+20>>2]=d;v[a+16>>2]=c;v[a+12>>2]=b;v[a+4>>2]=0;v[a+8>>2]=0;v[a>>2]=50156;c=a+24|0;v[c>>2]=0;v[c+4>>2]=0;v[c+16>>2]=0;v[c+8>>2]=0;v[c+12>>2]=0;b=a+44|0;h=dd(b);f=dd(b+12|0);g=dd(b+24|0);e=dd(b+36|0);v[22656]=0;W(1532,b|0,2,0)|0;d=v[22656];v[22656]=0;if((d|0)==1){a=P()|0;O()|0;Nc(e);Nc(g);Ot(f);Ot(h);S(a|0);L()}v[a+4196>>2]=1065353216;v[a+4200>>2]=0;u[a+4204>>1]=0;d=v[a+16>>2];v[d+946300>>2]=v[d+946300>>2]+1;v[22656]=0;e=T(1632,a+92|0)|0;d=v[22656];v[22656]=0;if((d|0)!=1){v[c>>2]=e;g=v[a+20>>2];f=v[a+16>>2];b=w[a+4200|0];if(!((g|0)==((f+B(b,160)|0)+906300|0)|b>>>0>248)){e=a+4200|0;while(1){c=b+1|0;if((g|0)!=((f+B(c,160)|0)+906300|0)){d=b>>>0<248;b=c;if(d){continue}}break}t[e|0]=c}return a}a=P()|0;O()|0;HM(b);S(a|0);L()}function IL(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;e=gb-48|0;gb=e;g=Jb(b);d=Ab(b);h=Jb(c);i=Ab(c);f=d+g|0;d=-1;a:{while(1){if((g|0)==(f|0)){break a}f=f-1|0;if(tp(h,i,f)){continue}break}d=f-g|0}f=d;b:{c:{if((d|0)!=-1){k=e,l=zd(b),v[k+16>>2]=l;k=e,l=we(e+16|0,f),v[k+24>>2]=l;k=e,l=we(e+24|0,1),v[k+32>>2]=l;c=Fd(e+40|0,e+32|0);k=e,l=gf(b),v[k>>2]=l;d=Fd(e+8|0,e);jG(b,v[c>>2],v[d>>2]);break c}if(!Ab(b)){break c}i=Jb(b);g=Ab(b);f=Jb(c);c=Ab(c);if(!c|!g){c=-1}else{j=c+f|0;d=i;g=g+d|0;d:{if((d|0)==(g|0)){break d}c=g;while(1){h=f;if((f|0)!=(j|0)){while(1){if(kb[26](t[d|0],t[h|0])|0){break d}h=h+1|0;if((j|0)!=(h|0)){continue}break}}d=d+1|0;if((c|0)!=(d|0)){continue}break}d=c}c=(d|0)==(g|0)?-1:d-i|0}if(c){break c}Kb(a);break b}Dc(a,b)}gb=e+48|0}function tja(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;e=gb-32|0;gb=e;i=v[a+40>>2];j=v[a+36>>2];k=v[a+16>>2];b=v[a+4>>2];h=b;f=v[a>>2];v[e+24>>2]=f;v[e+28>>2]=b;b=v[a+12>>2];v[e+16>>2]=v[a+8>>2];v[e+20>>2]=b;a:{if(d){while(1){l=f>>>10&4194048;h=(((h&2147483647)<<1|f>>>31)&-2)+k|0;g=0;b=1;while(1){f=t[h+g|0];v[(e+8|0)+(g<<2)>>2]=((B(t[(g|2)+h|0]-f|0,l)|0)/16384|0)+(f<<8);f=b;b=0;g=1;if(f){continue}break}f=v[a+32>>2];j=v[a+28>>2]+j|0;b=j>>12;v[c>>2]=v[c>>2]+B(b,v[e+8>>2]);i=f+i|0;g=i>>12;v[c+4>>2]=v[c+4>>2]+B(g,v[e+12>>2]);Ub(e+24|0,e+16|0);d=d-1|0;if(d){c=c+8|0;f=v[e+24>>2];h=v[e+28>>2];continue}break}f=v[e+24>>2];h=v[e+28>>2];break a}g=i>>12;b=j>>12}v[a+40>>2]=i;v[a+20>>2]=b;v[a+36>>2]=j;v[a+24>>2]=g;v[a>>2]=f;v[a+4>>2]=h;gb=e+32|0}function mZ(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0;e=gb-208|0;gb=e;d=a;if(!$v(c,a)){t[d|0]=0;t[d+1|0]=0;t[d+2|0]=0;t[d+3|0]=0;t[d+4|0]=0}ZD(c,e+16|0,B(w[a+4|0],3));a:{if(w[a+4|0]<2){break a}c=e;d=gb-16|0;gb=d;v[d+12>>2]=64;v[22656]=0;v[d+8>>2]=255;f=Fb(d+12|0,d+8|0);g=v[22656];v[22656]=0;b:{if((g|0)!=1){gb=d+16|0;d=w[f|0];break b}V(0)|0;O()|0;Bb();L()}t[c+12|0]=d;kh(b,w[ac(a+4|0,e+12|0)|0]);t[b+13|0]=w[a+2|0];t[b+14|0]=w[a+3|0];a=w[a+1|0];t[b+15|0]=a;t[b+16|0]=a;if(!Nb(b)){break a}a=0;while(1){if(a){c=x[Mb(b,a-1|0)>>1];v[e+12>>2]=1;d=(e+16|0)+B(a,3)|0;v[e+8>>2]=(t[d+1|0]&1)<<8|w[d|0];d=x[Gf(e+12|0,e+8|0)>>1];h=Mb(b,a),i=c+d|0,u[h>>1]=i}c=w[((e+16|0)+B(a,3)|0)+2|0];h=Mb(b,a),i=c,t[h+2|0]=i;a=a+1|0;if(Nb(b)>>>0>a>>>0){continue}break}}gb=e+208|0}function Do(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0;e=v[b+88>>2];c=e|2048;v[b+88>>2]=c;f=v[b+656>>2];if(!(!f|t[b+730|0]&1)){c=e|6144;v[b+88>>2]=c}a:{if(!v[b+76>>2]){break a}b:{if(!(c&8)){break b}d=v[b+104>>2];if(!d|e&2048){break b}e=x[d+34>>1];if(e&2){v[b+88>>2]=(e&4?c|4:c&-135)|2;c=v[d>>2];v[b+76>>2]=c;e=v[d+4>>2];v[b+80>>2]=e;d=v[d+8>>2];v[b+84>>2]=d;if(c>>>0>d>>>0){v[b+76>>2]=d;g=d}else{g=c}c=v[b+4>>2];if(g>>>0>=c>>>0){break b}v[b>>2]=0;v[b+4>>2]=((c-e>>>0)%(d-e>>>0)|0)+e;break b}v[b+88>>2]=c&-135;v[b+76>>2]=v[d>>2]}if(!f){break a}if(!(!(v[a+480180>>2]&1064964?1:w[f+60|0]&2)|!v[f>>2])){v[b+88>>2]=v[b+88>>2]|4096}if(w[f+65|0]==255|x[b+728>>1]!=65535){break a}a=f+48|0;h=b,i=Uc(Vq(a,v[b+724>>2],256,64)),u[h+728>>1]=i;h=b,i=x[Mb(a,w[f+65|0])>>1],v[h+724>>2]=i}}function fja(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;e=gb-32|0;gb=e;i=v[a+24>>2];j=v[a+20>>2];k=v[a+16>>2];g=v[a+4>>2];b=g;f=v[a>>2];v[e+24>>2]=f;v[e+28>>2]=b;g=v[a+12>>2];v[e+16>>2]=v[a+8>>2];v[e+20>>2]=g;if(d){while(1){g=((((b&2147483647)<<1|f>>>31)&2147483646)<<1)+k|0;b=f>>>21&2040;l=u[b+46166>>1];m=u[b+46164>>1];n=u[b+46162>>1];o=u[b+46160>>1];h=0;b=1;while(1){f=h<<1;v[(e+8|0)+(h<<2)>>2]=(((B(u[f+g>>1],n)+B(u[(f|-4)+g>>1],o)|0)+B(u[(f|4)+g>>1],m)|0)+B(u[(f|8)+g>>1],l)|0)/16384;f=b;b=0;h=1;if(f){continue}break}v[c>>2]=v[c>>2]+B(v[e+8>>2],j);v[c+4>>2]=v[c+4>>2]+B(v[e+12>>2],i);Ub(e+24|0,e+16|0);d=d-1|0;if(d){c=c+8|0;f=v[e+24>>2];b=v[e+28>>2];continue}break}f=v[e+24>>2];b=v[e+28>>2]}v[a>>2]=f;v[a+4>>2]=b;gb=e+32|0}function gna(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;g=gb-32|0;gb=g;m=g,n=aX(b),v[m+16>>2]=n;i=g+24|0;k=i;c=gb-32|0;gb=c;f=b;d=a;b=Yd(d);e=fc(d);a:{b:{if(b){d=wb(d);c:{while(1){d:{h=b+14|0;e:{if(SC(d,f,h)){if(!v[b>>2]){break b}e=b;break e}if(!RC(h,f)){break c}e=b+4|0;if(!v[b+4>>2]){break d}b=e;e=b}b=v[b>>2];continue}break}v[c+28>>2]=b;b=e;break a}v[c+28>>2]=b;b=e;break a}b=fc(d)}v[c+28>>2]=b}e=b;b=v[b>>2];t[c+27|0]=0;if(!b){d=gb-16|0;gb=d;b=fc(a);f=c+8|0;j=Vj(f,qC(),Wj(d+8|0,b));h=v[j>>2];b=gb-16|0;gb=b;v[b+8>>2]=v[g+16>>2];l=x[v[b+8>>2]>>1];u[h+16>>1]=0;u[h+14>>1]=l;gb=b+16|0;m=fc(j),n=1,t[m+4|0]=n;gb=d+16|0;Hk(a,v[c+28>>2],e,v[f>>2]);b=ce(f);t[c+27|0]=1;rC(f)}Xj(k,yc(c+8|0,b),c+27|0);gb=c+32|0;a=Yl(i);gb=g+32|0;return a+2|0}function Uda(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0;if(y[a+4>>2]<y[wb(a)>>2]){c=gb-16|0;gb=c;d=bA(c,a);wb(a);iz(v[d+4>>2],b);v[d+4>>2]=v[d+4>>2]+4;$b(d);gb=c+16|0;return}f=gb-32|0;gb=f;d=wb(a);d=xo(f+8|0,lr(a,Nb(a)+1|0),Nb(a),d);iz(v[d+8>>2],b);v[d+8>>2]=v[d+8>>2]+4;b=a;Fk(a);wb(a);c=d;h=c+4|0;e=h;i=v[a>>2];a=v[a+4>>2];if((i|0)!=(a|0)){g=v[e>>2];while(1){a=a-4|0;iz(g-4|0,a);g=v[e>>2]-4|0;v[e>>2]=g;if((a|0)!=(i|0)){continue}break}}wc(b,h);wc(b+4|0,c+8|0);wc(wb(b),dc(c));v[c>>2]=v[c+4>>2];dn(b,Nb(b));a=d;b=a;d=v[a+4>>2];a:{while(1){c=v[b+8>>2];if((c|0)==(d|0)){break a}e=v[b+16>>2];c=c-4|0;v[b+8>>2]=c;v[22656]=0;R(1326,e|0,c|0);c=v[22656];v[22656]=0;if((c|0)!=1){continue}break}V(0)|0;O()|0;Bb();L()}b=v[a>>2];if(b){ai(v[a+16>>2],b,Ck(a))}gb=f+32|0}function pba(){var a=0,b=0,c=0,d=0,e=0;b=gb-48|0;gb=b;c=Kb(b+32|0);v[22656]=0;_(1916,b+16|0);a=v[22656];v[22656]=0;a:{b:{c:{d:{if((a|0)!=1){a=b+16|0;d=b,e=Vb(a),v[d+8>>2]=e;d=b,e=Zb(a),v[d>>2]=e;if(!Gb(b+8|0,b)){break c}while(1){e:{a=v[b+8>>2];v[22656]=0;Q(1168,c|0,a|0)|0;a=v[22656];v[22656]=0;if((a|0)==1){break e}a=b+8|0;sr(a);d=b,e=Zb(b+16|0),v[d>>2]=e;if(!Gb(a,b)){break c}v[22656]=0;Q(1917,c|0,11821)|0;a=v[22656];v[22656]=0;if((a|0)!=1){continue}}break}a=V(0)|0;O()|0;yd(b+16|0);break d}a=V(0)|0;O()|0}vb(c);Z(a|0)|0;a=0;v[22656]=0;Y(1911,4042,0,0,0);c=v[22656];v[22656]=0;if((c|0)==1){break a}$();break b}a=ie(Jb(c));yd(b+16|0);vb(c)}gb=b+48|0;return a|0}b=P()|0;O()|0;v[22656]=0;X(20);c=v[22656];v[22656]=0;if((c|0)!=1){S(b|0);L()}V(0)|0;O()|0;Bb();L()}function pJ(a){var b=C(0),c=C(0),d=C(0),e=C(0),f=C(0),g=C(0),h=C(0),i=C(0),j=C(0),k=C(0),l=C(0),m=C(0),n=C(0),o=C(0);f=z[a>>2];i=z[a+24>>2];c=C(f-i);d=z[a+16>>2];b=z[a+32>>2];g=z[a+8>>2];e=C(d+C(b-g));z[a+16>>2]=c+e;j=C(c-C(e*C(.5)));c=z[a+4>>2];e=z[a+20>>2];h=z[a+28>>2];k=C(C(C(c-e)-h)*C(.8660253882408142));z[a+4>>2]=j+k;l=C(C(d-b)*C(.1736481785774231));f=C(f+C(i*C(.5)));i=C(C(g+b)*C(.7660444378852844));m=C(l+C(f-i));n=C(C(c+e)*C(.9848077297210693));b=C(z[a+12>>2]*C(.8660253882408142));c=C(C(c+h)*C(.6427876353263855));o=C(C(n-b)-c);z[a+12>>2]=m+o;z[a+20>>2]=m-o;z[a+28>>2]=j-k;d=C(C(g+d)*C(.9396926164627075));g=C(C(d+f)-l);e=C(C(e-h)*C(.3420201539993286));h=C(C(e-b)-n);z[a+32>>2]=g+h;d=C(C(f-d)+i);b=C(C(b+e)-c);z[a+24>>2]=d+b;z[a+8>>2]=d-b;z[a>>2]=g-h}function AG(a){var b=0,c=0,d=0,e=0;b=gb-16|0;gb=b;e=(p(a),j(2));c=e&2147483647;a:{if(c>>>0<=1061752794){if(c>>>0<964689920){break a}a=ti(+a);break a}if(c>>>0<=1081824209){d=+a;if(c>>>0<=1075235811){if((e|0)<0){a=C(-si(d+1.5707963267948966));break a}a=si(d+-1.5707963267948966);break a}a=ti(-(((e|0)>=0?-3.141592653589793:3.141592653589793)+d));break a}if(c>>>0<=1088565717){d=+a;if(c>>>0<=1085271519){if((e|0)<0){a=si(d+4.71238898038469);break a}a=C(-si(d+-4.71238898038469));break a}a=ti(((e|0)>=0?-6.283185307179586:6.283185307179586)+d);break a}if(c>>>0>=2139095040){a=C(a-a);break a}b:{switch(hy(a,b+8|0)&3){case 0:a=ti(A[b+8>>3]);break a;case 1:a=si(A[b+8>>3]);break a;case 2:a=ti(-A[b+8>>3]);break a;default:break b}}a=C(-si(A[b+8>>3]))}gb=b+16|0;return a}function ys(a,b){a=a|0;b=b|0;var c=0,d=0;d=gb-16|0;gb=d;a=Kb(a);a:{b:{c:{switch(b|0){case 0:v[22656]=0;b=Q(2,d|0,12963)|0;c=v[22656];v[22656]=0;if((c|0)==1){break a}Eb(a,b);vb(b);break b;case 1:v[22656]=0;b=Q(2,d|0,12988)|0;c=v[22656];v[22656]=0;if((c|0)!=1){Eb(a,b);vb(b);break b}break a;case 2:v[22656]=0;b=Q(2,d|0,12936)|0;c=v[22656];v[22656]=0;if((c|0)!=1){Eb(a,b);vb(b);break b}break a;case 3:v[22656]=0;b=Q(2,d|0,12910)|0;c=v[22656];v[22656]=0;if((c|0)!=1){Eb(a,b);vb(b);break b}break a;case 4:v[22656]=0;b=Q(2,d|0,10317)|0;c=v[22656];v[22656]=0;if((c|0)!=1){Eb(a,b);vb(b);break b}break a;case 5:break c;default:break b}}v[22656]=0;b=Q(2,d|0,4280)|0;c=v[22656];v[22656]=0;if((c|0)==1){break a}Eb(a,b);vb(b)}gb=d+16|0;return}b=P()|0;O()|0;vb(a);S(b|0);L()}function xga(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=C(0),h=C(0),i=C(0),j=0,k=0,m=0;f=gb-16|0;gb=f;k=f,m=B(v[a>>2],fd(a)),v[k>>2]=m;qc(f,c>>>2|0);c=zb(b);g=z[e+4>>2];e=v[f>>2];if(e){while(1){i=C(D((l(2,w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24)),q())));g=g<i?i:g;c=c+4|0;e=e-1|0;if(e){continue}break}}c=g==C(0);a:{if(c){break a}e=v[f>>2];if(!e){break a}i=c?C(1):C(C(1)/g);c=v[a+20>>2];while(1){z[f+12>>2]=i*(l(2,w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24)),q());v[f+8>>2]=-1082130432;v[f+4>>2]=1065353216;h=C(z[zf(f+12|0,f+8|0,f+4|0)>>2]*C(32768));z[f+12>>2]=h;a=c;h=fe(h);b:{if(C(D(h))<C(2147483648)){j=~~h;break b}j=-2147483648}k=a,m=Uc(j),u[k>>1]=m;b=b+4|0;c=c+2|0;e=e-1|0;if(e){continue}break}}if(d){z[d>>2]=g}gb=f+16|0;return v[f>>2]<<2}function gD(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;g=a;a=gb-16|0;gb=a;h=a;e=gb-32|0;gb=e;d=He(e+16|0,1,0);a:{b:{c:{while(1){c=Jb(d);f=Jb(d);i=Ab(d);j=v[b>>2];v[22656]=0;xA(e+8|0,c,f+i|0,j);c=v[22656];v[22656]=0;if((c|0)==1){break b}if(!v[e+12>>2]){break c}c=Ab(d);v[22656]=0;v[e+4>>2]=c;c=xf(e+4|0);f=v[22656];v[22656]=0;if((f|0)!=1){v[22656]=0;U(75,d|0,c|0,0);c=v[22656];v[22656]=0;if((c|0)!=1){continue}}break}break b}b=v[e+8>>2];c=Jb(d);v[22656]=0;R(76,d|0,b-c|0);b=v[22656];v[22656]=0;if((b|0)!=1){v[22656]=0;R(86,h|0,d|0);b=v[22656];v[22656]=0;if((b|0)==1){break b}vb(d);gb=e+32|0;break a}}a=P()|0;O()|0;vb(d);S(a|0);L()}v[22656]=0;R(85,g|0,a|0);b=v[22656];v[22656]=0;d:{if((b|0)!=1){vb(a);gb=a+16|0;break d}b=P()|0;O()|0;vb(a);S(b|0);L()}}function N2(a,b,c,d,e,f,g,h,i,j){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;var k=0,l=0,m=0;k=gb-16|0;gb=k;a:{if(a){a=dH(c);b:{if(b){gl(k,a);b=v[k>>2];t[d|0]=b;t[d+1|0]=b>>>8;t[d+2|0]=b>>>16;t[d+3|0]=b>>>24;fl(k,a);break b}Ls(k,a);b=v[k>>2];t[d|0]=b;t[d+1|0]=b>>>8;t[d+2|0]=b>>>16;t[d+3|0]=b>>>24;Oh(k,a)}nj(i,k);Hc(k);l=e,m=rj(a),v[l>>2]=m;l=f,m=qj(a),v[l>>2]=m;Ug(k,a);Eb(g,k);vb(k);Ph(k,a);nj(h,k);Hc(k);a=el(a);break a}a=cH(c);c:{if(b){gl(k,a);b=v[k>>2];t[d|0]=b;t[d+1|0]=b>>>8;t[d+2|0]=b>>>16;t[d+3|0]=b>>>24;fl(k,a);break c}Ls(k,a);b=v[k>>2];t[d|0]=b;t[d+1|0]=b>>>8;t[d+2|0]=b>>>16;t[d+3|0]=b>>>24;Oh(k,a)}nj(i,k);Hc(k);l=e,m=rj(a),v[l>>2]=m;l=f,m=qj(a),v[l>>2]=m;Ug(k,a);Eb(g,k);vb(k);Ph(k,a);nj(h,k);Hc(k);a=el(a)}v[j>>2]=a;gb=k+16|0}function Aw(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0,k=0;f=gb-16|0;gb=f;t[f+15|0]=d;t[b+12|0]=w[b+12|0]&240|w[a|0]&15;g=a+1|0;d=f+15|0;kh(b,w[ac(g,d)|0]);e=w[ac(a+2|0,d)|0];t[b+13|0]=e;j=b,k=Md(w[a+3|0],e,w[f+15|0]),t[j+14|0]=k;d=w[ac(a+4|0,d)|0];t[b+15|0]=d;j=b,k=Md(w[a+5|0],d,w[f+15|0]),t[j+16|0]=k;t[f+14|0]=25;if(w[ac(f+14|0,g)|0]){d=0;while(1){e=B(d,3)+a|0;h=Lb(w[e+6|0]+c<<24>>24,0,64);j=Mb(b,d),k=h,t[j+2|0]=k;e=e+7|0;e=w[e|0]|w[e+1|0]<<8;j=Mb(b,d),k=e,u[j>>1]=k;a:{if(!d){break a}e=d-1|0;if(x[Mb(b,d)>>1]>=x[Mb(b,e)>>1]){break a}if(x[Mb(b,d)>>1]>255){break a}h=w[Mb(b,e)+1|0];i=Mb(b,d);u[i>>1]=x[i>>1]|h<<8;if(x[Mb(b,d)>>1]>=x[Mb(b,e)>>1]){break a}e=Mb(b,d);u[e>>1]=x[e>>1]+256}t[f+14|0]=25;d=d+1|0;if(d>>>0<w[ac(f+14|0,g)|0]){continue}break}}gb=f+16|0}function nl(a){var b=0,c=0;b=v[a+4>>2];c=v[v[b>>2]-12>>2];v[22656]=0;b=v[(b+c|0)+24>>2];c=v[22656];v[22656]=0;a:{if((c|0)==1){break a}b:{if(!b){break b}b=v[a+4>>2];c=v[v[b>>2]-12>>2];v[22656]=0;b=_f(b+c|0);c=v[22656];v[22656]=0;if((c|0)==1){break a}if(!b){break b}b=v[a+4>>2];if(!(v[(v[v[b>>2]-12>>2]+b|0)+4>>2]&8192)){break b}if(II()){break b}b=v[a+4>>2];c=v[v[b>>2]-12>>2];v[22656]=0;b=v[(b+c|0)+24>>2];c=v[22656];v[22656]=0;c:{if((c|0)==1){break c}v[22656]=0;b=T(2307,b|0)|0;c=v[22656];v[22656]=0;if((c|0)==1){break c}if((b|0)!=-1){break b}a=v[a+4>>2];b=v[v[a>>2]-12>>2];v[22656]=0;R(18,a+b|0,1);a=v[22656];v[22656]=0;if((a|0)!=1){break b}}a=V(0)|0;O()|0;Z(a|0)|0;v[22656]=0;X(20);a=v[22656];v[22656]=0;if((a|0)==1){break a}}return}V(0)|0;O()|0;Bb();L()}function tla(a){a=a|0;var b=0,c=0,d=0,e=0;c=gb-192|0;gb=c;b=c+16|0;$f(b,a);v[22656]=0;R(99,c+32|0,b|0);a=v[22656];v[22656]=0;a:{b:{c:{d:{e:{if((a|0)!=1){v[22656]=0;a=W(100,c+48|0,c+32|0,8)|0;b=v[22656];v[22656]=0;if((b|0)==1){break e}vb(c+32|0);vb(c+16|0);b=v[v[a>>2]-12>>2];v[22656]=0;d=ga(79)|0;e=v[22656];v[22656]=0;if((e|0)==1){break c}v[22656]=0;U(80,c+8|0,b+(c+48|0)|0,d|0);b=v[22656];v[22656]=0;if((b|0)==1){break c}Wb(c+8|0);v[22656]=0;b=Q(101,a|0,c+32|0)|0;d=v[22656];v[22656]=0;if((d|0)==1){break c}d=v[v[b>>2]-12>>2];v[22656]=0;b=Fl(b+d|0);d=v[22656];v[22656]=0;if((d|0)==1){break c}d=x[c+32>>1];vf(a);gb=c+192|0;a=(b?0:d)&65535;break a}b=P()|0;O()|0;break d}b=P()|0;O()|0;vb(c+32|0)}vb(c+16|0);break b}b=P()|0;O()|0;vf(a)}S(b|0);L()}return a|0}function Xea(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;ud(c,0);u[c+28>>1]=w[a+36|0]<<2;d=w[a+37|0];u[c+32>>1]=64;u[c+30>>1]=d<<2;d=a+40|0;v[c>>2]=w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24);d=a+44|0;v[c+4>>2]=w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24);d=a+48|0;v[c+8>>2]=w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24);d=a+52|0;v[c+24>>2]=w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24);d=b+151|0;if(w[d|0]<=4){t[c+38|0]=w[w[d|0]+49066|0]}t[c+39|0]=w[b+152|0];d=b+156|0;t[c+41|0]=(w[d|0]|w[d+1|0]<<8)>>>4;b=b+154|0;b=(w[b|0]|w[b+1|0]<<8)>>>2|0;t[c+40|0]=b;if(w[c+41|0]|b&255){t[c+39|0]=w[c+39|0]^-1}a=a+38|0;if(w[a|0]&4){u[c+34>>1]=x[c+34>>1]|1}if(w[a|0]&8){u[c+34>>1]=x[c+34>>1]|2}if(w[a|0]&16){u[c+34>>1]=x[c+34>>1]|4}if(w[a|0]&32){u[c+34>>1]=x[c+34>>1]|32}}function Dga(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=C(0),f=0,g=0,h=0,i=0,j=0;d=gb-16|0;gb=d;v[d+12>>2]=c>>>3;v[d+8>>2]=v[a>>2];g=v[Fb(d+12|0,d+8|0)>>2];b=zb(b);if(g){a=v[a+20>>2];c=g;while(1){v[d+12>>2]=w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24);v[d+8>>2]=-1082130432;v[d+4>>2]=1065353216;e=C(z[zf(d+12|0,d+8|0,d+4|0)>>2]*C(32768));z[d+12>>2]=e;h=a;e=fe(e);a:{if(C(D(e))<C(2147483648)){f=~~e;break a}f=-2147483648}i=h,j=Uc(f),u[i>>1]=j;v[d+12>>2]=w[b+4|0]|w[b+5|0]<<8|(w[b+6|0]<<16|w[b+7|0]<<24);v[d+8>>2]=-1082130432;v[d+4>>2]=1065353216;e=C(z[zf(d+12|0,d+8|0,d+4|0)>>2]*C(32768));z[d+12>>2]=e;h=a;e=fe(e);b:{if(C(D(e))<C(2147483648)){f=~~e;break b}f=-2147483648}i=h,j=Uc(f),u[i+2>>1]=j;a=a+4|0;b=b+8|0;c=c-1|0;if(c){continue}break}}gb=d+16|0;return g<<3}function sca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=C(0),g=0,h=0,i=0,j=0,k=0,l=0,m=C(0),n=C(0),o=0,p=0;g=gb-16|0;gb=g;j=a+44|0;if(mi(j)){o=g,p=Nd(j,0),v[o+8>>2]=p;o=g,p=Nd(j,1),v[o+12>>2]=p;o=g,p=od(j,0),v[o>>2]=p;o=g,p=od(j,1),v[o+4>>2]=p;if(d){k=d;while(1){e=0;l=1;while(1){h=e<<2;i=h+(g+8|0)|0;e=v[i>>2];v[i>>2]=e+4;f=C(z[e>>2]*z[a+4240>>2]);e=a+h|0;i=e+4228|0;f=C(f+C(z[i>>2]*z[a+4236>>2]));z[i>>2]=f;f=nM(C(f*C(1073741824)),w[a+4272|0],w[a+4273|0]);i=e+4244|0;e=e+4252|0;m=z[e>>2];n=z[a+4264>>2];f=C(C(C(f*z[a+4260>>2])-C(z[i>>2]*z[a+4268>>2]))-C(m*n));z[e>>2]=f;z[i>>2]=m+C(n*f);e=g+h|0;h=v[e>>2];v[e>>2]=h+4;z[h>>2]=f*C(9.313225746154785e-10);h=l;l=0;e=1;if(h){continue}break}k=k-1|0;if(k){continue}break}}Ei(a,b,c,od(j,0),od(j,1),d)}gb=g+16|0}function R2(a,b,c,d,e,f,g,h,i,j){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;var k=0,l=0,m=0;k=gb-16|0;gb=k;a:{if(a){a=hH(c);b:{if(b){gl(k,a);b=v[k>>2];t[d|0]=b;t[d+1|0]=b>>>8;t[d+2|0]=b>>>16;t[d+3|0]=b>>>24;fl(k,a);break b}Ls(k,a);b=v[k>>2];t[d|0]=b;t[d+1|0]=b>>>8;t[d+2|0]=b>>>16;t[d+3|0]=b>>>24;Oh(k,a)}Eb(i,k);vb(k);l=e,m=rj(a),t[l|0]=m;l=f,m=qj(a),t[l|0]=m;Ug(k,a);Eb(g,k);vb(k);Ph(k,a);Eb(h,k);vb(k);a=el(a);break a}a=gH(c);c:{if(b){gl(k,a);b=v[k>>2];t[d|0]=b;t[d+1|0]=b>>>8;t[d+2|0]=b>>>16;t[d+3|0]=b>>>24;fl(k,a);break c}Ls(k,a);b=v[k>>2];t[d|0]=b;t[d+1|0]=b>>>8;t[d+2|0]=b>>>16;t[d+3|0]=b>>>24;Oh(k,a)}Eb(i,k);vb(k);l=e,m=rj(a),t[l|0]=m;l=f,m=qj(a),t[l|0]=m;Ug(k,a);Eb(g,k);vb(k);Ph(k,a);Eb(h,k);vb(k);a=el(a)}v[j>>2]=a;gb=k+16|0}function Pba(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;d=Fi(a,b,c,d);v[a+4260>>2]=0;v[a>>2]=52560;c=a+4960|0;e=a+4504|0;b=e;while(1){b=Io(b)+24|0;if((c|0)!=(b|0)){continue}break}t[a+5046|0]=1;u[a+5044>>1]=0;v[a+4208>>2]=1063675494;v[a+4212>>2]=1065185444;v[a+4256>>2]=1059760811;b=a+4248|0;v[b>>2]=1065353216;v[b+4>>2]=1048525618;b=a+4240|0;v[b>>2]=1038174126;v[b+4>>2]=1065353216;b=a+4232|0;v[b>>2]=1047457519;v[b+4>>2]=1062836634;b=a+4224|0;v[b>>2]=1053079357;v[b+4>>2]=1059859440;b=a+4216|0;v[b>>2]=0;v[b+4>>2]=1032805417;v[22656]=0;W(1532,a+44|0,2,2)|0;b=v[22656];v[22656]=0;a:{if((b|0)!=1){v[22656]=0;Th(d);b=v[22656];v[22656]=0;if((b|0)!=1){break a}}a=P()|0;O()|0;while(1){c=c-24|0;Nc(c);if((c|0)!=(e|0)){continue}break}Lf(d);S(a|0);L()}return a|0}function xha(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;f=gb-16|0;gb=f;h=f;e=gb-32|0;gb=e;d=He(e+16|0,1,0);a:{b:{c:{while(1){c=Jb(d);g=Jb(d);i=Ab(d);j=w[b|0];v[22656]=0;zu(e+8|0,c,g+i|0,j);c=v[22656];v[22656]=0;if((c|0)==1){break b}if(!v[e+12>>2]){break c}c=Ab(d);v[22656]=0;v[e+4>>2]=c;c=xf(e+4|0);g=v[22656];v[22656]=0;if((g|0)!=1){v[22656]=0;U(75,d|0,c|0,0);c=v[22656];v[22656]=0;if((c|0)!=1){continue}}break}break b}b=v[e+8>>2];c=Jb(d);v[22656]=0;R(76,d|0,b-c|0);b=v[22656];v[22656]=0;if((b|0)!=1){v[22656]=0;R(77,h|0,d|0);b=v[22656];v[22656]=0;if((b|0)==1){break b}vb(d);gb=e+32|0;break a}}a=P()|0;O()|0;vb(d);S(a|0);L()}v[22656]=0;R(72,a|0,f|0);a=v[22656];v[22656]=0;if((a|0)!=1){vb(f);gb=f+16|0;return}a=P()|0;O()|0;vb(f);S(a|0);L()}function Mq(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;f=gb-16|0;gb=f;h=f;e=gb-32|0;gb=e;d=He(e+16|0,1,0);a:{b:{c:{while(1){c=Jb(d);g=Jb(d);i=Ab(d);j=v[b>>2];v[22656]=0;zu(e+8|0,c,g+i|0,j);c=v[22656];v[22656]=0;if((c|0)==1){break b}if(!v[e+12>>2]){break c}c=Ab(d);v[22656]=0;v[e+4>>2]=c;c=xf(e+4|0);g=v[22656];v[22656]=0;if((g|0)!=1){v[22656]=0;U(75,d|0,c|0,0);c=v[22656];v[22656]=0;if((c|0)!=1){continue}}break}break b}b=v[e+8>>2];c=Jb(d);v[22656]=0;R(76,d|0,b-c|0);b=v[22656];v[22656]=0;if((b|0)!=1){v[22656]=0;R(77,h|0,d|0);b=v[22656];v[22656]=0;if((b|0)==1){break b}vb(d);gb=e+32|0;break a}}a=P()|0;O()|0;vb(d);S(a|0);L()}v[22656]=0;R(72,a|0,f|0);a=v[22656];v[22656]=0;if((a|0)!=1){vb(f);gb=f+16|0;return}a=P()|0;O()|0;vb(f);S(a|0);L()}function $t(a){a=a|0;var b=0;a:{b:{c:{if(w[a+3|0]!=19){break c}t[a+3|0]=20;d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{b=w[a+5|0];switch(b>>>4|0){case 6:break j;case 5:break k;case 4:break l;case 3:break m;case 2:break n;case 1:break o;case 0:break b;case 13:break d;case 12:break e;case 11:break f;case 10:break g;case 9:break h;case 7:break i;default:break c}}t[a+3|0]=2;break a}t[a+3|0]=3;break a}t[a+5|0]=b&15|16;return}t[a+5|0]=b&3|48;return}t[a+5|0]=b&15|32;return}t[a+5|0]=b&15|176;return}t[a+5|0]=b&3|64;return}t[a+3|0]=15;t[a+5|0]=b&15;return}if(b&15){t[a+3|0]=11;t[a+5|0]=b<<4|15;return}break b}if(b&15){t[a+3|0]=11;break a}break b}if((b|0)!=192){break c}t[a|0]=254;break b}if((b|0)!=208){break c}t[a+3|0]=0}return}t[a+3|0]=0;return}t[a+5|0]=b|240}function Qm(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;g=gb-16|0;gb=g;if(e){v[e>>2]=0}h=a+484344|0;a:{if(!me(h,b)){break a}d=Yc(_b(h,b),c,d);f=w[d+5|0];b:{c:{d:{e:{i=w[d+3|0];switch(i-10|0){case 1:case 3:case 5:case 6:break a;case 0:break c;case 2:case 4:case 7:break d;default:break e}}if(i-35>>>0>=2){break a}}v[g+12>>2]=1;j=0;if((i|0)!=17){break b}j=v[a+480180>>2]==4;break b}v[g+12>>2]=2;j=0}m=g,n=v[_b(h,b)+12>>2]+(c^-1)|0,v[m+8>>2]=n;c=0;a=v[Fb(g+8|0,g+12|0)>>2];f:{if(!a){break f}k=a;while(1){d=B(Ji(_b(h,b)),6)+d|0;if(w[d+3|0]!=34){break f}l=f<<8;f=w[d+5|0]|(j?f>>>0<256?l+-8192|0:l:l);c=c+1|0;k=k-1|0;if(k){continue}break}c=a}f=(i-35&255)>>>0>1?f:c?f:f<<8;if(!e){break a}v[e>>2]=c}gb=g+16|0;return f|0}function j8(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0;e=gb-32|0;gb=e;h=Kb(a);a=Kb(e+16|0);a:{b:{c:{d:{f=b+24|0;if(!x[v[f>>2]+480192>>1]){break d}b=1;while(1){c=v[f>>2];v[22656]=0;c=hA(c,b&65535);d=v[22656];v[22656]=0;if((d|0)==1){break c}v[22656]=0;c=Q(70,e|0,c|0)|0;d=v[22656];v[22656]=0;if((d|0)==1){break c}d=gd(c);v[22656]=0;Q(1168,a|0,c|0)|0;g=v[22656];v[22656]=0;if((g|0)==1){break b}v[22656]=0;Q(1917,a|0,18696)|0;g=v[22656];v[22656]=0;if((g|0)==1){break b}i=d^1|i;vb(c);b=b+1|0;if(x[v[f>>2]+480192>>1]>=(b&65535)>>>0){continue}break}if(!(i&1)){break d}v[22656]=0;Q(368,h|0,a|0)|0;b=v[22656];v[22656]=0;if((b|0)!=1){break d}b=P()|0;O()|0;break a}vb(a);gb=e+32|0;return}b=P()|0;O()|0;break a}b=P()|0;O()|0;vb(c)}vb(a);vb(h);S(b|0);L()}function i8(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0;e=gb-32|0;gb=e;h=Kb(a);a=Kb(e+16|0);a:{b:{c:{d:{f=b+24|0;if(!x[v[f>>2]+480190>>1]){break d}b=1;while(1){c=v[f>>2];v[22656]=0;c=iA(c,b&65535);d=v[22656];v[22656]=0;if((d|0)==1){break c}v[22656]=0;c=Q(70,e|0,c|0)|0;d=v[22656];v[22656]=0;if((d|0)==1){break c}d=gd(c);v[22656]=0;Q(1168,a|0,c|0)|0;g=v[22656];v[22656]=0;if((g|0)==1){break b}v[22656]=0;Q(1917,a|0,18696)|0;g=v[22656];v[22656]=0;if((g|0)==1){break b}i=d^1|i;vb(c);b=b+1|0;if(x[v[f>>2]+480190>>1]>=(b&65535)>>>0){continue}break}if(!(i&1)){break d}v[22656]=0;Q(368,h|0,a|0)|0;b=v[22656];v[22656]=0;if((b|0)!=1){break d}b=P()|0;O()|0;break a}vb(a);gb=e+32|0;return}b=P()|0;O()|0;break a}b=P()|0;O()|0;vb(c)}vb(a);vb(h);S(b|0);L()}function _ka(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0;c=Ec(a);if(c>>>0<b>>>0){f=gb-32|0;gb=f;a:{b:{e=b-c|0;c:{if(e>>>0<=(v[wb(a)>>2]-v[a+4>>2]|0)/12>>>0){c=gb-16|0;gb=c;d=Np(c,a,e);a=v[d+4>>2];b=v[d+8>>2];if((a|0)!=(b|0)){while(1){VT(a);a=a+12|0;v[d+4>>2]=a;if((a|0)!=(b|0)){continue}break}}$b(d);gb=c+16|0;break c}b=wb(a);d=Zu(f+8|0,UB(a,Ec(a)+e|0),Ec(a),b);v[22656]=0;YT(d,e);b=v[22656];v[22656]=0;if((b|0)==1){break b}c=d;e=c+4|0;g=e;b=a;i=v[a>>2];a=v[a+4>>2];if((i|0)!=(a|0)){h=v[g>>2];while(1){a=a-12|0;TB(h-12|0,a);h=v[g>>2]-12|0;v[g>>2]=h;if((a|0)!=(i|0)){continue}break}}wc(b,e);wc(b+4|0,c+8|0);wc(wb(b),dc(c));v[c>>2]=v[c+4>>2];XT(d)}gb=f+32|0;break a}a=P()|0;O()|0;XT(d);S(a|0);L()}return}if(b>>>0<c>>>0){_T(a,v[a>>2]+B(b,12)|0)}}function Lha(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0;f=gb-32|0;gb=f;h=fg(a,c);se(f+8|0,v[a+28>>2]);d=v[f+20>>2];v[f+24>>2]=v[f+16>>2];v[f+28>>2]=d;a:{if(!h){if(nd(a,5)){break a}}g=v[a+28>>2];d=gb-16|0;gb=d;v[d+12>>2]=0;_M(g,d+12|0,1);e=v[d+12>>2];i=e>>>2&3;t[d+11|0]=i;if(i){t[d+4|0]=3;e=w[ac(d+4|0,d+11|0)|0];t[d+4|0]=0;t[d|0]=0;t[d+10|0]=0;b:{if(!e){break b}Vh(g,d+4|0);if((e|0)==1){break b}Vh(g,d);if(e>>>0<3){break b}Vh(g,d+10|0);j=w[d+10|0]<<24}e=w[d+12|0]|w[d+4|0]<<8|w[d|0]<<16|j;v[d+12>>2]=e}v[d+4>>2]=e>>>4;v[d>>2]=1e6;xu(b,v[Fb(d+4|0,d)>>2]);if(Ab(b)){e=0;while(1){ll(g,pc(b,e),1);e=e+1|0;if(Ab(b)>>>0>e>>>0){continue}break}}b=(v[d+12>>2]>>>4|0)-Ab(b)|0;v[d+12>>2]=b;if(b){zm(g,b,-1)}gb=d+16|0}Zf(a,h,c,f+24|0);gb=f+32|0}function B2(a){a=a|0;var b=0,c=0,d=0,e=0;c=gb-192|0;gb=c;b=c+16|0;$f(b,a);v[22656]=0;R(99,c+32|0,b|0);a=v[22656];v[22656]=0;a:{b:{c:{d:{e:{if((a|0)!=1){v[22656]=0;a=W(100,c+48|0,c+32|0,8)|0;b=v[22656];v[22656]=0;if((b|0)==1){break e}vb(c+32|0);vb(c+16|0);b=v[v[a>>2]-12>>2];v[22656]=0;d=ga(79)|0;e=v[22656];v[22656]=0;if((e|0)==1){break c}v[22656]=0;U(80,c+8|0,b+(c+48|0)|0,d|0);b=v[22656];v[22656]=0;if((b|0)==1){break c}Wb(c+8|0);v[22656]=0;b=Q(103,a|0,c+32|0)|0;d=v[22656];v[22656]=0;if((d|0)==1){break c}d=v[v[b>>2]-12>>2];v[22656]=0;b=Fl(b+d|0);d=v[22656];v[22656]=0;if((d|0)==1){break c}d=v[c+32>>2];vf(a);gb=c+192|0;a=b?0:d;break a}b=P()|0;O()|0;break d}b=P()|0;O()|0;vb(c+32|0)}vb(c+16|0);break b}b=P()|0;O()|0;vf(a)}S(b|0);L()}return a|0}function yh(a,b,c){var d=0,e=0;a:{if((a|0)==(b|0)){break a}e=a+c|0;if(b-e>>>0<=0-(c<<1)>>>0){return hc(a,b,c)}d=(a^b)&3;b:{c:{if(a>>>0<b>>>0){if(d){d=a;break b}if(!(a&3)){d=a;break c}d=a;while(1){if(!c){break a}t[d|0]=w[b|0];b=b+1|0;c=c-1|0;d=d+1|0;if(d&3){continue}break}break c}d:{if(d){break d}if(e&3){while(1){if(!c){break a}c=c-1|0;d=c+a|0;t[d|0]=w[b+c|0];if(d&3){continue}break}}if(c>>>0<=3){break d}while(1){c=c-4|0;v[c+a>>2]=v[b+c>>2];if(c>>>0>3){continue}break}}if(!c){break a}while(1){c=c-1|0;t[c+a|0]=w[b+c|0];if(c){continue}break}break a}if(c>>>0<=3){break b}while(1){v[d>>2]=v[b>>2];b=b+4|0;d=d+4|0;c=c-4|0;if(c>>>0>3){continue}break}}if(!c){break a}while(1){t[d|0]=w[b|0];d=d+1|0;b=b+1|0;c=c-1|0;if(c){continue}break}}return a}function Cfa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;g=gb-16|0;gb=g;i=g+8|0;k=i;h=c;e=gb-32|0;gb=e;j=b;d=Yd(b);f=fc(b);a:{b:{if(d){c:{while(1){d:{b=d+16|0;e:{if(PA(c,b)){if(!v[d>>2]){break b}b=d;break e}if(!PA(b,c)){break c}b=d+4|0;if(!v[d+4>>2]){break d}d=b;b=d}f=b;d=v[d>>2];continue}break}v[e+28>>2]=d;break a}v[e+28>>2]=d;b=f;break a}d=fc(b)}v[e+28>>2]=d;b=d}d=v[b>>2];t[e+27|0]=0;if(!d){d=gb-16|0;gb=d;f=fc(j);c=e+8|0;f=Vj(c,Mc(28,4),Wj(d+8|0,f));l=v[f>>2];v[22656]=0;R(1417,l+16|0,h|0);h=v[22656];v[22656]=0;f:{if((h|0)!=1){m=fc(f),n=1,t[m+4|0]=n;gb=d+16|0;break f}a=P()|0;O()|0;_N(f);S(a|0);L()}Hk(j,v[e+28>>2],b,v[c>>2]);d=ce(c);t[e+27|0]=1;_N(c)}Xj(k,yc(e+8|0,d),e+27|0);gb=e+32|0;DS(a,i);gb=g+16|0}function gja(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;e=gb-32|0;gb=e;i=v[a+24>>2];j=v[a+20>>2];k=v[a+16>>2];b=v[a+4>>2];f=v[a>>2];v[e+24>>2]=f;v[e+28>>2]=b;g=v[a+12>>2];v[e+16>>2]=v[a+8>>2];v[e+20>>2]=g;if(d){while(1){h=(((b&2147483647)<<1|f>>>31)&-2)+k|0;b=f>>>21&2040;l=u[b+46166>>1];m=u[b+46164>>1];n=u[b+46162>>1];o=u[b+46160>>1];g=0;b=1;while(1){v[(e+8|0)+(g<<2)>>2]=(((B(t[g+h|0],n)+B(t[(g|-2)+h|0],o)|0)+B(t[(g|2)+h|0],m)|0)+B(t[(g|4)+h|0],l)<<8)/16384;f=b;b=0;g=1;if(f){continue}break}v[c>>2]=v[c>>2]+B(v[e+8>>2],j);v[c+4>>2]=v[c+4>>2]+B(v[e+12>>2],i);Ub(e+24|0,e+16|0);d=d-1|0;if(d){c=c+8|0;f=v[e+24>>2];b=v[e+28>>2];continue}break}f=v[e+24>>2];b=v[e+28>>2]}v[a>>2]=f;v[a+4>>2]=b;gb=e+32|0}function F7(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=gb-80|0;gb=d;a=v[a+4>>2];Bz(d+16|0,b);v[22656]=0;b=Q(2,d|0,14864)|0;e=v[22656];v[22656]=0;a:{b:{c:{d:{e:{f:{g:{h:{if((e|0)!=1){v[22656]=0;U(3,d+32|0,d+16|0,b|0);e=v[22656];v[22656]=0;if((e|0)==1){break h}v[22656]=0;U(652,d+48|0,d+32|0,c|0);c=v[22656];v[22656]=0;if((c|0)==1){break g}v[22656]=0;R(2039,d- -64|0,d+48|0);c=v[22656];v[22656]=0;if((c|0)==1){break f}c=v[v[a>>2]+8>>2];v[22656]=0;R(c|0,a|0,d- -64|0);a=v[22656];v[22656]=0;if((a|0)==1){break e}vb(d- -64|0);vb(d+48|0);vb(d+32|0);vb(b);vb(d+16|0);gb=d+80|0;return}a=P()|0;O()|0;break a}a=P()|0;O()|0;break b}a=P()|0;O()|0;break c}a=P()|0;O()|0;break d}a=P()|0;O()|0;vb(d- -64|0)}vb(d+48|0)}vb(d+32|0)}vb(b)}vb(d+16|0);S(a|0);L()}function _7(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;d=gb-32|0;gb=d;g=mc(a);f=b+24|0;a=x[v[f>>2]+480190>>1];v[22656]=0;R(1421,g|0,a|0);c=v[22656];v[22656]=0;a=1;a:{if((c|0)!=1){b:{c:{d:{e:{if(x[v[f>>2]+480190>>1]){while(1){c=v[f>>2];v[22656]=0;c=iA(c,a&65535);e=v[22656];v[22656]=0;if((e|0)==1){break e}v[22656]=0;c=Q(70,d|0,c|0)|0;e=v[22656];v[22656]=0;if((e|0)==1){break e}v[22656]=0;U(2092,d+16|0,b|0,c|0);e=v[22656];v[22656]=0;if((e|0)==1){break d}v[22656]=0;R(1423,g|0,d+16|0);e=v[22656];v[22656]=0;if((e|0)==1){break c}vb(d+16|0);vb(c);a=a+1|0;if(x[v[f>>2]+480190>>1]>=(a&65535)>>>0){continue}break}}gb=d+32|0;return}a=P()|0;O()|0;break a}a=P()|0;O()|0;break b}a=P()|0;O()|0;vb(d+16|0)}vb(c);break a}a=P()|0;O()|0}yd(g);S(a|0);L()}function $7(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;d=gb-32|0;gb=d;g=mc(a);f=b+24|0;a=x[v[f>>2]+480192>>1];v[22656]=0;R(1421,g|0,a|0);c=v[22656];v[22656]=0;a=1;a:{if((c|0)!=1){b:{c:{d:{e:{if(x[v[f>>2]+480192>>1]){while(1){c=v[f>>2];v[22656]=0;c=hA(c,a&65535);e=v[22656];v[22656]=0;if((e|0)==1){break e}v[22656]=0;c=Q(70,d|0,c|0)|0;e=v[22656];v[22656]=0;if((e|0)==1){break e}v[22656]=0;U(2092,d+16|0,b|0,c|0);e=v[22656];v[22656]=0;if((e|0)==1){break d}v[22656]=0;R(1423,g|0,d+16|0);e=v[22656];v[22656]=0;if((e|0)==1){break c}vb(d+16|0);vb(c);a=a+1|0;if(x[v[f>>2]+480192>>1]>=(a&65535)>>>0){continue}break}}gb=d+32|0;return}a=P()|0;O()|0;break a}a=P()|0;O()|0;break b}a=P()|0;O()|0;vb(d+16|0)}vb(c);break a}a=P()|0;O()|0}yd(g);S(a|0);L()}function fO(a,b){var c=C(0),d=C(0),e=C(0);a:{b:{c:{switch(b|0){case 0:uq(a,C(1));tq(a,C(3.725290298461914e-9));sq(a,C(268435456));rq(a,0);break b;case 1:uq(a,C(32));tq(a,C(4.656612873077393e-10));sq(a,C(2147483648));rq(a,0);break b;case 2:uq(a,C(2));tq(a,C(7.450580596923828e-9));sq(a,C(134217728));rq(a,1);break b;default:uq(a,C(1));tq(a,C(7.450580596923828e-9));sq(a,C(134217728));rq(a,1);Pz(a,0);Oz(a,1);Nz(a,1);d=C(256);c=C(128);e=C(128);b=0;break a;case 4:case 5:break c}}uq(a,C(.75));tq(a,C(7.450580596923828e-9));sq(a,C(134217728));rq(a,1);Pz(a,0);b=(b|0)==4;Oz(a,b?2:3);Nz(a,1);d=C(256);c=b?C(256):C(192);e=c;b=1;break a}Pz(a,1);Oz(a,0);Nz(a,0);d=C(128);e=C(100);c=C(256);b=4}z[a+16>>2]=c;z[a+20>>2]=e;z[a+24>>2]=d;v[a+28>>2]=b}function Tp(a){var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,k=0,m=0;o(+a);d=j(1)|0;f=j(0)|0;a:{b:{c:{b=d;d=b;if(!(b>>>0>=1048576&((b|0)>0|(b|0)>=0))){if(!(b&2147483647|f)){return-1/(a*a)}if((b|0)>0|(b|0)>=0){break c}return(a-a)/0}if(d>>>0>2146435071){break a}b=1072693248;g=-1023;if((d|0)!=1072693248){b=d;break b}if(f){break b}return 0}o(+(a*0x40000000000000));b=j(1)|0;f=j(0)|0;g=-1077}b=b+614242|0;e=+((b>>>20|0)+g|0);l(0,f|0);l(1,(b&1048575)+1072079006|0);a=+n()+-1;c=a/(a+2);h=e*.6931471803691238;i=a;k=e*1.9082149292705877e-10;m=c;e=a*(a*.5);c=c*c;a=c*c;a=h+(i+(k+m*(e+(a*(a*(a*.15313837699209373+.22222198432149784)+.3999999999940942)+c*(a*(a*(a*.14798198605116586+.1818357216161805)+.2857142874366239)+.6666666666666735)))-e))}return a}function n5(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;i=v[b+44>>2];g=v[b+24>>2];if(i>>>0<g>>>0){v[b+44>>2]=g;i=g}l=-1;g=-1;m=f&24;a:{if(!m|(m|0)==24&(e|0)==1){break a}if(i){h=i-Jb(b+32|0)|0;n=h;h=h>>31}b:{c:{switch(e|0){case 1:if(f&8){e=v[b+12>>2]-v[b+8>>2]|0;j=e;k=e>>31;break b}e=v[b+24>>2]-v[b+20>>2]|0;j=e;k=e>>31;break b;case 0:break b;case 2:break c;default:break a}}j=n;k=h}e=d+k|0;c=c+j|0;e=j>>>0>c>>>0?e+1|0:e;d=c;c=e;if((h|0)<=(e|0)&d>>>0>n>>>0|(e|0)>(h|0)|(e|0)<0){break a}e=f&8;d:{if(!(c|d)){break d}if(v[b+12>>2]?0:e){break a}if(!(f&16)){break d}if(!v[b+24>>2]){break a}}if(e){e=v[b+8>>2];$n(b,e,d+e|0,v[b+44>>2])}if(f&16){Ux(b,v[b+20>>2],v[b+28>>2]);$s(b,d)}l=d;g=c}sh(a,l,g)}function kL(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=C(0);e=gb-80|0;gb=e;f=a+24|0;wq(v[f>>2]);t[v[f>>2]+1298380|0]=v[a+52>>2]!=0;c=mg(e+32|0,d,c,b);g=v[a+32>>2];j=z[a+48>>2];v[e+8>>2]=v[c+8>>2];d=v[c+4>>2];v[e>>2]=v[c>>2];v[e+4>>2]=d;d=gb-16|0;gb=d;v[d+8>>2]=v[e+8>>2];c=v[e+4>>2];v[d>>2]=v[e>>2];v[d+4>>2]=c;i=e+48|0;c=i;At(c);v[c+8>>2]=g;v[c+4>>2]=0;v[c>>2]=57940;g=v[d+4>>2];v[c+12>>2]=v[d>>2];v[c+16>>2]=g;v[c+20>>2]=v[d+8>>2];z[c+24>>2]=j;v[c>>2]=57168;gb=d+16|0;a:{if(!b){break a}while(1){c=v[f>>2];v[e+24>>2]=b;v[e+28>>2]=0;v[e+16>>2]=134217727;v[e+20>>2]=0;c=Ht(c,v[Uk(e+24|0,e+16|0)>>2],i);h=c+h|0;if(!c){break a}b=b-c|0;if(b){continue}break}}if(!(v[a+52>>2]!=1|h)){a=v[f>>2];v[a+480208>>2]=v[a+480208>>2]&-513}gb=e+80|0;return h}function jL(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=C(0);e=gb-80|0;gb=e;f=a+24|0;wq(v[f>>2]);t[v[f>>2]+1298380|0]=v[a+52>>2]!=0;c=mg(e+32|0,d,c,b);g=v[a+32>>2];j=z[a+48>>2];v[e+8>>2]=v[c+8>>2];d=v[c+4>>2];v[e>>2]=v[c>>2];v[e+4>>2]=d;d=gb-16|0;gb=d;v[d+8>>2]=v[e+8>>2];c=v[e+4>>2];v[d>>2]=v[e>>2];v[d+4>>2]=c;i=e+48|0;c=i;At(c);v[c+8>>2]=g;v[c+4>>2]=0;v[c>>2]=58768;g=v[d+4>>2];v[c+12>>2]=v[d>>2];v[c+16>>2]=g;v[c+20>>2]=v[d+8>>2];z[c+24>>2]=j;v[c>>2]=57996;gb=d+16|0;a:{if(!b){break a}while(1){c=v[f>>2];v[e+24>>2]=b;v[e+28>>2]=0;v[e+16>>2]=134217727;v[e+20>>2]=0;c=Ht(c,v[Uk(e+24|0,e+16|0)>>2],i);h=c+h|0;if(!c){break a}b=b-c|0;if(b){continue}break}}if(!(v[a+52>>2]!=1|h)){a=v[f>>2];v[a+480208>>2]=v[a+480208>>2]&-513}gb=e+80|0;return h}function Iga(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;e=gb-80|0;gb=e;c=Qf(e+48|0);v[22656]=0;d=Q(1182,b|0,c|0)|0;f=v[22656];v[22656]=0;a:{b:{c:{if((f|0)!=1){if(d){break c}v[a>>2]=0;v[a+4>>2]=0;v[a+24>>2]=0;v[a+16>>2]=0;v[a+20>>2]=0;v[a+8>>2]=0;v[a+12>>2]=0;v[22656]=0;T(1183,a|0)|0;a=v[22656];v[22656]=0;if((a|0)!=1){break b}}break a}if(Xb(w[c+4|0]|w[c+5|0]<<8|(w[c+6|0]<<16|w[c+7|0]<<24))){d=Xb(w[c+4|0]|w[c+5|0]<<8|(w[c+6|0]<<16|w[c+7|0]<<24))}else{d=-1}v[22656]=0;U(288,e|0,b|0,d|0);f=v[22656];v[22656]=0;if((f|0)==1){break a}f=kc(e+24|0,e);Vc(c+8|0,f);xb(f);xb(e);d:{d=d&1;if(!d){break d}v[22656]=0;Q(318,b|0,2-d|0)|0;b=v[22656];v[22656]=0;if((b|0)!=1){break d}break a}$j(a,c)}ed(c);gb=e+80|0;return}a=P()|0;O()|0;ed(c);S(a|0);L()}function Wka(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;i=gb-112|0;gb=i;a:{if(!Jd(a)){break a}if(Ec(b)>>>0<2){break a}e=bp(i+8|0,a);v[e+20>>2]=0;v[e>>2]=0;c=Ec(b);b:{if(c){g=v[a>>2];c:{while(1){f=Ad(b,h);j=v[f>>2];if(g>>>0<=j>>>0){break c}f=v[f+4>>2];if(f>>>0>g-j>>>0|268435456-f>>>0<d>>>0){break c}d=d+f|0;v[e>>2]=d;h=h+1|0;if((c|0)!=(h|0)){continue}break}h=c}if(!Ql(e)){break a}if(!h){break b}f=e+68|0;c=0;d=0;while(1){g=Ad(b,c);hc(zb(v[e+20>>2])+d|0,zb(v[a+20>>2])+v[g>>2]|0,v[g+4>>2]);v[g>>2]=d;if(!(!c|c>>>0>9)){k=Fe(f,c-1|0),l=d,v[k>>2]=l}d=v[g+4>>2]+d|0;c=c+1|0;if((h|0)!=(c|0)){continue}break}break b}if(!Ql(e)){break a}}Pl(a);bp(a,e);v[a+4>>2]=0;v[a+8>>2]=v[a>>2];u[a+34>>1]=x[a+34>>1]|2}gb=i+112|0}function ula(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;d=gb-32|0;gb=d;ud(b,0);ki(d,1,a);c=d+16|0;Bc(c,d);v[22656]=0;Q(303,b+43|0,c|0)|0;c=v[22656];v[22656]=0;if((c|0)!=1){e=d+16|0;vb(e);c=a+48|0;v[b>>2]=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);c=a+52|0;v[b+4>>2]=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);c=a+56|0;v[b+8>>2]=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);c=a+62|0;v[b+24>>2]=w[c|0]|w[c+1|0]<<8;Qo(b,+((w[a+60|0]^8)-120|0)/192);t[d+16|0]=w[a+61|0];t[d|0]=64;f=b,g=w[ac(e,d)|0]<<2,u[f+30>>1]=g;u[b+34>>1]=0;a=a+47|0;if(w[a|0]&4){u[b+34>>1]=x[b+34>>1]|1;v[b>>2]=v[b>>2]>>>1}if(w[a|0]&32){u[b+34>>1]=x[b+34>>1]|4}if(t[a|0]<0){u[b+34>>1]=x[b+34>>1]|2}gb=d+32|0;return}a=P()|0;O()|0;vb(d+16|0);S(a|0);L()}function YL(a){var b=0,c=0,d=0,e=0,f=0,g=C(0),h=0,i=0,j=0,k=0,l=0,m=0,n=C(0);c=wf(v[a+16>>2]);g=C(C(z[a+4220>>2]*C(.9980000257492065))+C(.0010000000474974513));d=-3e3/+C(C(C(z[a+4216>>2]*C(2999.9990234375))+C(.0010000000474974513))*C(c>>>0));m=a,n=C(hk(10,d*+y[a+4288>>2])),z[m+4232>>2]=n;m=a+4236|0,n=C(hk(10,d*+y[a+4292>>2])),z[m>>2]=n;l=d*(1/+g+-1);c=0;h=a+4272|0;i=a+4232|0;while(1){j=v[(c<<2)+h>>2];e=c<<1&-4;f=hk(10,l*+(j+v[(e+h|0)+16>>2]>>>0));b=hk(10,d*+(j>>>0));g=z[e+i>>2];e=(c<<3)+i|0;f=(1-f)*.5;z[e+12>>2]=b*f;z[e+8>>2]=b*(1-f);b=b*+g;b=b*(b*(b*(b+1)+1)+1)+1;k=k+b*b;c=c+1|0;if((c|0)!=4){continue}break}d=hk(10,+XL(z[a+4208>>2])*.05);b=hk(10,+XL(z[a+4212>>2])*.1);z[a+4228>>2]=4/K(k)*d*K(b);z[a+4224>>2]=d*K(1-b)}function MX(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;e=gb-32|0;gb=e;v[e+24>>2]=b;k=e,l=zd(a),v[k+8>>2]=l;g=ck(e+24|0,e+8|0);b=Zh(c,d);a:{b:{if(!b){break b}if(hD(c,Jb(a),Jb(a)+Ab(a)|0)){b=Pj(e+8|0,c,d);c=v[e+24>>2];d=Jb(b);g=Jb(b);h=Ab(b);v[22656]=0;c=da(544,a|0,c|0,d|0,g+h|0)|0;a=v[22656];v[22656]=0;if((a|0)!=1){vb(b);break a}a=P()|0;O()|0;vb(b);S(a|0);L()}h=Ab(a);f=Kc(a);c:{if(b>>>0<=f-h>>>0){f=Jb(a);i=h-g|0;if(!i){break c}j=g+f|0;fm(b+j|0,j,i);break c}Ym(a,f,(b+h|0)-f|0,h,g,0,b);f=v[a>>2]}b=b+h|0;jh(a,b);t[e+8|0]=0;Bd(b+f|0,e+8|0);if((c|0)==(d|0)){break b}b=g+f|0;while(1){Bd(b,c);b=b+1|0;c=c+1|0;if((d|0)!=(c|0)){continue}break}}k=e,l=zd(a),v[k+8>>2]=l;c=we(e+8|0,g)}gb=e+32|0;return c|0}function zoa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;c=gb+-64|0;gb=c;a:{if(wv(a)){v[b>>2]=0;a=0;break a}NW(c+32|0,c+48|0);e=v[c+36>>2];v[c+16>>2]=v[c+32>>2];v[c+20>>2]=e;e=c+40|0;cc(e,a,c+16|0);g=yb(e);d=zb(w[c+48|0]);e=d&127;v[b>>2]=e;h=d<<24>>24;i=(h|0)<0;d=1;if(e){while(1){f=f+1|0;j=e>>>0>1;e=e>>>1|0;if(j){continue}break}}e=f;b:{if(g>>>0<2|(h|0)>=0){break b}while(1){f=zb(w[(c+48|0)+d|0]);v[b>>2]=f&127|v[b>>2]<<7;e=e+7|0;f=f<<24>>24;i=(f|0)<0;d=d+1|0;if((g|0)==(d|0)){Rb(a,g);NW(c+24|0,c+48|0);d=v[c+28>>2];v[c+8>>2]=v[c+24>>2];v[c+12>>2]=d;d=c+40|0;cc(d,a,c+8|0);g=yb(d);d=0}if(d>>>0>=g>>>0){break b}if((f|0)<0){continue}break}}Rb(a,d);if(e>>>0>=33){v[b>>2]=-1;a=0;break a}a=!i}gb=c- -64|0;return a|0}function ZP(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;h=gb-16|0;gb=h;v[h+12>>2]=c>>>4;v[h+8>>2]=v[a>>2];i=v[Fb(h+12|0,h+8|0)>>2];b=zb(b);if(i){a=v[a+20>>2];c=i;while(1){e=zb(w[b|0]);d=zb(w[b+1|0]);f=d>>>24|0;g=e|d<<8;e=zb(w[b+2|0]);d=e>>>16|0;e=g|e<<16;g=d|f;d=zb(w[b+3|0]);f=d>>>8|0;d=d<<24|e;f=zb(w[b+4|0])|(f|g);k=a,l=Jc(d|0,zb(w[b+5|0])<<8|f|zb(w[b+6|0])<<16|zb(w[b+7|0])<<24,48),u[k>>1]=l;e=zb(w[b+8|0]);d=zb(w[b+9|0]);f=d>>>24|0;g=e|d<<8;e=zb(w[b+10|0]);d=e>>>16|0;e=g|e<<16;g=d|f;d=zb(w[b+11|0]);f=d>>>8|0;d=d<<24|e;f=zb(w[b+12|0])|(f|g);k=a,l=Jc(d|j,zb(w[b+13|0])<<8|f|zb(w[b+14|0])<<16|zb(w[b+15|0])<<24,48),u[k+2>>1]=l;a=a+4|0;b=b+16|0;c=c-1|0;if(c){continue}break}}gb=h+16|0;return i<<4}function YP(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;h=gb-16|0;gb=h;v[h+12>>2]=c>>>4;v[h+8>>2]=v[a>>2];i=v[Fb(h+12|0,h+8|0)>>2];b=zb(b);if(i){a=v[a+20>>2];c=i;while(1){e=zb(w[b+7|0]);d=zb(w[b+6|0]);f=d>>>24|0;g=e|d<<8;e=zb(w[b+5|0]);d=e>>>16|0;e=g|e<<16;g=d|f;d=zb(w[b+4|0]);f=d>>>8|0;d=d<<24|e;f=zb(w[b+3|0])|(f|g);k=a,l=Jc(d|0,zb(w[b+2|0])<<8|f|zb(w[b+1|0])<<16|zb(w[b|0])<<24,48),u[k>>1]=l;e=zb(w[b+15|0]);d=zb(w[b+14|0]);f=d>>>24|0;g=e|d<<8;e=zb(w[b+13|0]);d=e>>>16|0;e=g|e<<16;g=d|f;d=zb(w[b+12|0]);f=d>>>8|0;d=d<<24|e;f=zb(w[b+11|0])|(f|g);k=a,l=Jc(d|j,zb(w[b+10|0])<<8|f|zb(w[b+9|0])<<16|zb(w[b+8|0])<<24,48),u[k+2>>1]=l;a=a+4|0;b=b+16|0;c=c-1|0;if(c){continue}break}}gb=h+16|0;return i<<4}function SH(a,b,c,d,e,f){var g=0;g=gb-80|0;gb=g;a:{if((f|0)>=16384){Ed(g+32|0,b,c,d,e,0,0,0,2147352576);d=v[g+40>>2];e=v[g+44>>2];b=v[g+32>>2];c=v[g+36>>2];if(f>>>0<32767){f=f-16383|0;break a}Ed(g+16|0,b,c,d,e,0,0,0,2147352576);f=(f>>>0<49149?f:49149)-32766|0;d=v[g+24>>2];e=v[g+28>>2];b=v[g+16>>2];c=v[g+20>>2];break a}if((f|0)>-16383){break a}Ed(g- -64|0,b,c,d,e,0,0,0,65536);d=v[g+72>>2];e=v[g+76>>2];b=v[g+64>>2];c=v[g+68>>2];if(f>>>0>4294934531){f=f+16382|0;break a}Ed(g+48|0,b,c,d,e,0,0,0,65536);f=(f>>>0>4294918150?f:-49146)+32764|0;d=v[g+56>>2];e=v[g+60>>2];b=v[g+48>>2];c=v[g+52>>2]}Ed(g,b,c,d,e,0,0,0,f+16383<<16);b=v[g+12>>2];v[a+8>>2]=v[g+8>>2];v[a+12>>2]=b;b=v[g+4>>2];v[a>>2]=v[g>>2];v[a+4>>2]=b;gb=g+80|0}function DJ(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;f=gb-16|0;gb=f;a:{b:{c:{d:{if((b|0)>=0){if((io(a+8|0)|0)>(b|0)){break d}}a=ba(8)|0;v[22656]=0;c=Q(70,f|0,7993)|0;b=v[22656];v[22656]=0;if((b|0)==1){break c}rc(a,c);v[22656]=0;U(186,a|0,54952,1936);a=v[22656];v[22656]=0;if((a|0)!=1){break a}b=P()|0;O()|0;vb(c);break b}d=a+32|0;a=(v[d>>2]+(b<<5)|0)+480280|0;c=c?134218752:0;v[a>>2]=c|v[a>>2]&-134218753;a=(v[d>>2]+B(b,872)|0)+1075080|0;v[a>>2]=c|v[a>>2]&-134218753;a=x[v[d>>2]+480188>>1];if(a>>>0<=255){b=b+1|0;while(1){e=B(a,872);if((b|0)==x[(e+v[d>>2]|0)+1075778>>1]){e=(e+v[d>>2]|0)+1075080|0;v[e>>2]=c|v[e>>2]&-134218753}a=a+1|0;if((a&65535)!=256){continue}break}}gb=f+16|0;return}b=P()|0;O()|0;ca(a|0)}S(b|0)}L()}function uA(a,b,c,d){var e=0,f=0;f=gb-16|0;gb=f;a:{if(!d){break a}if(c){t[b+815|0]=c;break a}c=w[b+815|0]}d=v[a+480180>>2]&1048580;c=d?(c&240?-16:15)&c:c;b:{c:{d:{if(!d){d=c&240;e:{f:{g:{h:{c=c&15;if((c|0)==15){e=v[a+480208>>2]&4096;if(!d){break h}if(!e){break b}c=0-(d>>>2|0)|0;break d}e=v[a+480208>>2]&4096;if(!c|(d|0)!=240){break g}if(!e){break b}c=c<<2;break c}d=0;if(!e){break f}break b}if(e){break b}if(!c){break e}}c=c<<2;if(!(v[a+480180>>2]&16777248)|!d){break c}break b}c=0-(d>>>2|0)|0;break d}if(w[a+480209|0]&16){break b}d=f+8|0;Db(d,a+1074312|0,56);a=c&240;a=a?a>>>2|0:0-(c<<2&60)|0;c=a;if(!Cb(d)){break d}c=(a|0)/4<<24>>24}if(!c){break b}}a=Lb(v[b+692>>2]+c|0,0,256);u[b+784>>1]=0;v[b+692>>2]=a}gb=f+16|0}function HF(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;c=rf(a);if(c>>>0<b>>>0){g=gb-32|0;gb=g;a:{b:{e=b-c|0;c:{if(e>>>0<=v[wb(a)>>2]-v[a+4>>2]>>3>>>0){c=gb-16|0;gb=c;b=gs(c,a,e);a=v[b+4>>2];d=v[b+8>>2];if((a|0)!=(d|0)){while(1){jm(a);a=a+8|0;v[b+4>>2]=a;if((a|0)!=(d|0)){continue}break}}$b(b);gb=c+16|0;break c}f=wb(a);b=hs(a,rf(a)+e|0);i=rf(a);c=0;h=gb-16|0;gb=h;v[h+12>>2]=0;d=g+8|0;kf(d+12|0,f);if(b){c=b;if(b>>>0>=536870912){rd(8445);L()}c=Mc(c<<3,1)}v[d>>2]=c;f=(i<<3)+c|0;v[d+8>>2]=f;v[d+4>>2]=f;j=dc(d),k=(b<<3)+c|0,v[j>>2]=k;gb=h+16|0;v[22656]=0;Mw(d,e);b=v[22656];v[22656]=0;if((b|0)==1){break b}Zk(a,d);FF(d)}gb=g+32|0;break a}a=P()|0;O()|0;FF(d);S(a|0);L()}return}if(b>>>0<c>>>0){_k(a,v[a>>2]+(b<<3)|0)}}function sV(a,b){var c=0,d=0,e=0;c=gb-32|0;gb=c;a:{if(!Pb(a,1024)){v[c+24>>2]=0;v[c+28>>2]=0;v[c+16>>2]=0;v[c+20>>2]=0;a=64;while(1){d=w[c+20|0]|w[c+21|0]<<8|(w[c+22|0]<<16|w[c+23|0]<<24);e=w[c+16|0]|w[c+17|0]<<8|(w[c+18|0]<<16|w[c+19|0]<<24);t[b|0]=e;t[b+1|0]=e>>>8;t[b+2|0]=e>>>16;t[b+3|0]=e>>>24;t[b+4|0]=d;t[b+5|0]=d>>>8;t[b+6|0]=d>>>16;t[b+7|0]=d>>>24;d=w[c+28|0]|w[c+29|0]<<8|(w[c+30|0]<<16|w[c+31|0]<<24);e=w[c+24|0]|w[c+25|0]<<8|(w[c+26|0]<<16|w[c+27|0]<<24);t[b+8|0]=e;t[b+9|0]=e>>>8;t[b+10|0]=e>>>16;t[b+11|0]=e>>>24;t[b+12|0]=d;t[b+13|0]=d>>>8;t[b+14|0]=d>>>16;t[b+15|0]=d>>>24;b=b+16|0;a=a-1|0;if(a){continue}break}break a}eC(c+8|0,b);b=v[c+12>>2];v[c>>2]=v[c+8>>2];v[c+4>>2]=b;kd(c+16|0,a,c)}gb=c+32|0}function N9(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=gb-32|0;gb=d;v[22656]=0;_(1934,a|0);e=v[22656];v[22656]=0;a:{b:{c:{if((e|0)==1){break c}v[22656]=0;_(1960,b|0);e=v[22656];v[22656]=0;if((e|0)==1){break c}v[22656]=0;_(1960,c|0);f=v[22656];v[22656]=0;e=1;if((f|0)==1){break c}f=v[a+24>>2];b=uc(d+24|0,b);c=uc(d+16|0,c);v[22656]=0;g=v[b+4>>2];v[d+8>>2]=v[b>>2];v[d+12>>2]=g;b=v[c+4>>2];v[d>>2]=v[c>>2];v[d+4>>2]=b;Y(2004,f|0,d+8|0,d|0,1);b=v[22656];v[22656]=0;if((b|0)!=1){break b}}b=V(0)|0;O()|0;Z(b|0)|0;v[22656]=0;Y(1911,2599,a|0,0,0);a=v[22656];v[22656]=0;if((a|0)==1){break a}$();e=0}gb=d+32|0;return e|0}a=P()|0;O()|0;v[22656]=0;X(20);b=v[22656];v[22656]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}function kR(a,b){var c=0,d=0,e=0,f=0,g=0,h=0;a:{f=gb-16|0;gb=f;g=f;d=gb-32|0;gb=d;c=He(d+16|0,1,0);KP(d+8|0,Jb(c),Jb(c)+Ab(c)|0,x[b>>1]);b:{c:{if(v[d+12>>2]){while(1){e=Ab(c);v[22656]=0;v[d+4>>2]=e;e=xf(d+4|0);h=v[22656];v[22656]=0;if((h|0)==1){break c}v[22656]=0;U(75,c|0,e|0,0);e=v[22656];v[22656]=0;if((e|0)==1){break c}KP(d+8|0,Jb(c),Jb(c)+Ab(c)|0,x[b>>1]);if(v[d+12>>2]){continue}break}}b=v[d+8>>2];e=Jb(c);v[22656]=0;R(76,c|0,b-e|0);b=v[22656];v[22656]=0;if((b|0)==1){break c}v[22656]=0;R(86,g|0,c|0);b=v[22656];v[22656]=0;if((b|0)!=1){break b}}a=P()|0;O()|0;vb(c);S(a|0);L()}vb(c);gb=d+32|0;v[22656]=0;R(85,a|0,f|0);a=v[22656];v[22656]=0;if((a|0)!=1){vb(f);gb=f+16|0;break a}a=P()|0;O()|0;vb(f);S(a|0);L()}}function Qb(a,b,c){var d=0,e=0,f=0;a:{if(!c){break a}f=a+c|0;t[f-1|0]=b;t[a|0]=b;if(c>>>0<3){break a}t[f-2|0]=b;t[a+1|0]=b;t[f-3|0]=b;t[a+2|0]=b;if(c>>>0<7){break a}t[f-4|0]=b;t[a+3|0]=b;if(c>>>0<9){break a}f=0-a&3;e=f+a|0;d=B(b&255,16843009);v[e>>2]=d;b=c-f&-4;c=b+e|0;v[c-4>>2]=d;if(b>>>0<9){break a}v[e+8>>2]=d;v[e+4>>2]=d;v[c-8>>2]=d;v[c-12>>2]=d;if(b>>>0<25){break a}v[e+24>>2]=d;v[e+20>>2]=d;v[e+16>>2]=d;v[e+12>>2]=d;v[c-16>>2]=d;v[c-20>>2]=d;v[c-24>>2]=d;v[c-28>>2]=d;c=b;b=e&4|24;c=c-b|0;if(c>>>0<32){break a}d=kqa(d,0,1,1);f=jb;b=b+e|0;while(1){v[b+24>>2]=d;e=f;v[b+28>>2]=e;v[b+16>>2]=d;v[b+20>>2]=e;v[b+8>>2]=d;v[b+12>>2]=e;v[b>>2]=d;v[b+4>>2]=e;b=b+32|0;c=c-32|0;if(c>>>0>31){continue}break}}return a}function tm(a,b,c,d,e,f,g,h,i,j){var k=0,l=0,m=0;k=gb-16|0;gb=k;t[k+15|0]=a;a:{b:{c:{if(v[d>>2]!=(c|0)){break c}l=43;m=a&255;if((m|0)!=w[j+24|0]){l=45;if(w[j+25|0]!=(m|0)){break c}}v[d>>2]=c+1;t[c|0]=l;break b}if(!(!Ab(g)|(a|0)!=(f|0))){a=0;b=v[i>>2];if((b-h|0)>159){break a}a=v[e>>2];v[i>>2]=b+4;v[b>>2]=a;break b}a=-1;f=Xm(j,j+26|0,k+15|0)-j|0;if((f|0)>23){break a}d:{e:{switch(b-8|0){case 0:case 2:if((b|0)>(f|0)){break d}break a;case 1:break d;default:break e}}if((b|0)!=16|(f|0)<22){break d}b=v[d>>2];if((b|0)==(c|0)|(b-c|0)>2|w[b-1|0]!=48){break a}a=0;v[e>>2]=0;v[d>>2]=b+1;t[b|0]=w[f+81024|0];break a}a=v[d>>2];v[d>>2]=a+1;t[a|0]=w[f+81024|0];v[e>>2]=v[e>>2]+1;a=0;break a}a=0;v[e>>2]=0}gb=k+16|0;return a}function rm(a,b,c,d,e,f,g,h,i,j){var k=0,l=0;k=gb-16|0;gb=k;v[k+12>>2]=a;a:{b:{c:{if(v[d>>2]!=(c|0)){break c}l=43;if(v[j+96>>2]!=(a|0)){l=45;if(v[j+100>>2]!=(a|0)){break c}}v[d>>2]=c+1;t[c|0]=l;break b}if(!(!Ab(g)|(a|0)!=(f|0))){a=0;b=v[i>>2];if((b-h|0)>159){break a}a=v[e>>2];v[i>>2]=b+4;v[b>>2]=a;break b}a=-1;g=yx(j,j+104|0,k+12|0)-j|0;if((g|0)>92){break a}f=g>>2;d:{e:{switch(b-8|0){case 0:case 2:if((b|0)>(f|0)){break d}break a;case 1:break d;default:break e}}if((b|0)!=16|(g|0)<88){break d}b=v[d>>2];if((b|0)==(c|0)|(b-c|0)>2|w[b-1|0]!=48){break a}a=0;v[e>>2]=0;v[d>>2]=b+1;t[b|0]=w[f+81024|0];break a}a=v[d>>2];v[d>>2]=a+1;t[a|0]=w[f+81024|0];v[e>>2]=v[e>>2]+1;a=0;break a}a=0;v[e>>2]=0}gb=k+16|0;return a}function j6(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0;d=gb-32|0;gb=d;e=v[a+28>>2];v[d+16>>2]=e;f=v[a+20>>2];v[d+28>>2]=c;v[d+24>>2]=b;b=f-e|0;v[d+20>>2]=b;e=b+c|0;j=2;a:{b:{b=d+16|0;c:{if(!ht(xa(v[a+60>>2],b|0,2,d+12|0)|0)){while(1){f=v[d+12>>2];if((f|0)==(e|0)){break c}if((f|0)<0){break b}g=v[b+4>>2];h=g>>>0<f>>>0;i=(h<<3)+b|0;g=f-(h?g:0)|0;v[i>>2]=g+v[i>>2];i=(h?12:4)+b|0;v[i>>2]=v[i>>2]-g;e=e-f|0;b=h?b+8|0:b;j=j-h|0;if(!ht(xa(v[a+60>>2],b|0,j|0,d+12|0)|0)){continue}break}}if((e|0)!=-1){break b}}b=v[a+44>>2];v[a+28>>2]=b;v[a+20>>2]=b;v[a+16>>2]=b+v[a+48>>2];a=c;break a}v[a+28>>2]=0;v[a+16>>2]=0;v[a+20>>2]=0;v[a>>2]=v[a>>2]|32;a=0;if((j|0)==2){break a}a=c-v[b+4>>2]|0}gb=d+32|0;return a|0}function Yna(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;d=gb-32|0;gb=d;v[d+28>>2]=0;Ik(a,d+28|0);a:{b:{e=v[d+28>>2];c:{if(e>>>0>500){break c}d:{e:{f:{if(e){while(1){e=Kb(d+16|0);v[22656]=0;u[d+14>>1]=0;f=W(653,a|0,e|0,255)|0;g=v[22656];v[22656]=0;if((g|0)==1){break b}if(!f){break d}v[22656]=0;Q(647,a|0,d+14|0)|0;f=v[22656];v[22656]=0;if((f|0)==1){break b}v[22656]=0;U(13,d|0,c|0,e|0);f=v[22656];v[22656]=0;if((f|0)==1){break f}v[22656]=0;f=Q(654,b|0,d+14|0)|0;g=v[22656];v[22656]=0;if((g|0)==1){break e}Eb(f,d);vb(d);vb(e);h=h+1|0;if(h>>>0<y[d+28>>2]){continue}break}}_f(v[v[a>>2]-12>>2]+a|0);break c}a=P()|0;O()|0;break a}a=P()|0;O()|0;vb(d);break a}vb(e)}gb=d+32|0;return}a=P()|0;O()|0}vb(e);S(a|0);L()}function Xna(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;d=gb-32|0;gb=d;u[d+30>>1]=0;ag(a,d+30|0);a:{b:{e=x[d+30>>1];c:{if(e>>>0>500){break c}d:{e:{f:{if(e){while(1){e=Kb(d+16|0);v[22656]=0;u[d+14>>1]=0;f=W(655,a|0,e|0,255)|0;g=v[22656];v[22656]=0;if((g|0)==1){break b}if(!f){break d}v[22656]=0;Q(647,a|0,d+14|0)|0;f=v[22656];v[22656]=0;if((f|0)==1){break b}v[22656]=0;U(13,d|0,c|0,e|0);f=v[22656];v[22656]=0;if((f|0)==1){break f}v[22656]=0;f=Q(654,b|0,d+14|0)|0;g=v[22656];v[22656]=0;if((g|0)==1){break e}Eb(f,d);vb(d);vb(e);h=h+1|0;if(h>>>0<x[d+30>>1]){continue}break}}_f(v[v[a>>2]-12>>2]+a|0);break c}a=P()|0;O()|0;break a}a=P()|0;O()|0;vb(d);break a}vb(e)}gb=d+32|0;return}a=P()|0;O()|0}vb(e);S(a|0);L()}function Sfa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;d=gb-32|0;gb=d;a:{b:{c:{d:{e:{if(rk(b)){break e}u[d+8>>1]=x[a+480190>>1];u[d+24>>1]=v[b+4>>2]-1;c=x[Pc(d+8|0,d+24|0)>>1];if(!c){break e}g=c;while(1){e=d+8|0;Ce(e,b,c);if(!Cb(e)){v[22656]=0;f=Q(1314,a|0,c&65535)|0;e=v[22656];v[22656]=0;if((e|0)==1){break b}if(f){v[22656]=0;f=Q(70,d+8|0,18726)|0;e=v[22656];v[22656]=0;if((e|0)==1){break d}v[22656]=0;Q(301,((c<<5)+a|0)+946304|0,f|0)|0;e=v[22656];v[22656]=0;if((e|0)==1){break c}vb(f);h=h+1|0}if(!(x[a+480190>>1]!=(c|0)|c>>>0<2)){u[a+480190>>1]=x[a+480190>>1]-1}}c=c-1|0;g=g-1|0;if(g&65535){continue}break}}gb=d+32|0;return h&65535}c=P()|0;O()|0;break a}c=P()|0;O()|0;vb(f);break a}c=P()|0;O()|0}S(c|0);L()}function rR(a,b){var c=0,d=0,e=0,f=0,g=0,h=0;a:{f=gb-16|0;gb=f;g=f;d=gb-32|0;gb=d;c=He(d+16|0,1,0);TP(d+8|0,Jb(c),Jb(c)+Ab(c)|0,w[b|0]);b:{c:{if(v[d+12>>2]){while(1){e=Ab(c);v[22656]=0;v[d+4>>2]=e;e=xf(d+4|0);h=v[22656];v[22656]=0;if((h|0)==1){break c}v[22656]=0;U(75,c|0,e|0,0);e=v[22656];v[22656]=0;if((e|0)==1){break c}TP(d+8|0,Jb(c),Jb(c)+Ab(c)|0,w[b|0]);if(v[d+12>>2]){continue}break}}b=v[d+8>>2];e=Jb(c);v[22656]=0;R(76,c|0,b-e|0);b=v[22656];v[22656]=0;if((b|0)==1){break c}v[22656]=0;R(86,g|0,c|0);b=v[22656];v[22656]=0;if((b|0)!=1){break b}}a=P()|0;O()|0;vb(c);S(a|0);L()}vb(c);gb=d+32|0;v[22656]=0;R(85,a|0,f|0);a=v[22656];v[22656]=0;if((a|0)!=1){vb(f);gb=f+16|0;break a}a=P()|0;O()|0;vb(f);S(a|0);L()}}function qA(a){var b=0,c=0,d=0,e=0;e=a+128e3|0;while(1){d=gb-32|0;gb=d;Uq(d);b=v[d+28>>2];c=v[d+24>>2];t[a+24|0]=c;t[a+25|0]=c>>>8;t[a+26|0]=c>>>16;t[a+27|0]=c>>>24;t[a+28|0]=b;t[a+29|0]=b>>>8;t[a+30|0]=b>>>16;t[a+31|0]=b>>>24;b=v[d+20>>2];c=v[d+16>>2];t[a+16|0]=c;t[a+17|0]=c>>>8;t[a+18|0]=c>>>16;t[a+19|0]=c>>>24;t[a+20|0]=b;t[a+21|0]=b>>>8;t[a+22|0]=b>>>16;t[a+23|0]=b>>>24;b=v[d+12>>2];c=v[d+8>>2];t[a+8|0]=c;t[a+9|0]=c>>>8;t[a+10|0]=c>>>16;t[a+11|0]=c>>>24;t[a+12|0]=b;t[a+13|0]=b>>>8;t[a+14|0]=b>>>16;t[a+15|0]=b>>>24;b=v[d+4>>2];c=v[d>>2];t[a|0]=c;t[a+1|0]=c>>>8;t[a+2|0]=c>>>16;t[a+3|0]=c>>>24;t[a+4|0]=b;t[a+5|0]=b>>>8;t[a+6|0]=b>>>16;t[a+7|0]=b>>>24;gb=d+32|0;a=a+32|0;if((e|0)!=(a|0)){continue}break}}function iL(a){a=a|0;var b=0,c=0,d=0,e=0,f=0;f=gb-16|0;gb=f;c=v[a+4>>2];d=f;a=v[a>>2];v[d>>2]=a;v[d+4>>2]=c;v[d+8>>2]=a;v[d+12>>2]=c;a=gb+-64|0;gb=a;a:{if(!v[d+4>>2]){break a}c=38480;b:{while(1){b=v[d+4>>2];v[a+56>>2]=v[d>>2];v[a+60>>2]=b;b=uc(a+48|0,v[c+8>>2]);e=v[a+60>>2];v[a+24>>2]=v[a+56>>2];v[a+28>>2]=e;e=v[b+4>>2];v[a+16>>2]=v[b>>2];v[a+20>>2]=e;if(cO(a+24|0,a+16|0)){break b}c=c+12|0;if((c|0)!=39044){continue}break}c=39056;while(1){b=v[d+4>>2];v[a+40>>2]=v[d>>2];v[a+44>>2]=b;b=uc(a+32|0,v[c+8>>2]);e=v[a+44>>2];v[a+8>>2]=v[a+40>>2];v[a+12>>2]=e;e=v[b+4>>2];v[a>>2]=v[b>>2];v[a+4>>2]=e;b=cO(a+8|0,a);if(b){break a}c=c+12|0;if((c|0)!=39104){continue}break}break a}b=1}gb=a- -64|0;gb=f+16|0;return b|0}function dja(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0;b=gb-16|0;gb=b;h=v[a+40>>2];i=v[a+36>>2];k=v[a+16>>2];g=v[a+4>>2];e=g;f=v[a>>2];v[b+8>>2]=f;v[b+12>>2]=e;g=v[a+12>>2];v[b>>2]=v[a+8>>2];v[b+4>>2]=g;a:{if(d){while(1){j=v[a+32>>2];i=v[a+28>>2]+i|0;g=i>>12;e=(e<<1)+k|0;f=f>>>21&2040;e=(((B(u[e>>1],u[f+46162>>1])+B(u[e-2>>1],u[f+46160>>1])|0)+B(u[e+2>>1],u[f+46164>>1])|0)+B(u[e+4>>1],u[f+46166>>1])|0)/16384|0;v[c>>2]=v[c>>2]+B(g,e);h=h+j|0;j=h>>12;v[c+4>>2]=v[c+4>>2]+B(e,j);Ub(b+8|0,b);d=d-1|0;if(d){c=c+8|0;f=v[b+8>>2];e=v[b+12>>2];continue}break}f=v[b+8>>2];e=v[b+12>>2];break a}j=h>>12;g=i>>12}v[a+40>>2]=h;v[a+20>>2]=g;v[a+36>>2]=i;v[a+24>>2]=j;v[a>>2]=f;v[a+4>>2]=e;gb=b+16|0}function Afa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0;d=gb-80|0;gb=d;f=1;g=JR(a,1<<b-1);v[a+12>>2]=b;c=1<<b;h=c>>>2|0;a:{if(b>>>0>1){i=-6.283185307179586/+(c>>>0);b=h;while(1){A[d+40>>3]=i*+(b>>>0);e=v[12055];c=d+48|0;v[c+8>>2]=v[12054];v[c+12>>2]=e;e=v[12053];v[c>>2]=v[12052];v[c+4>>2]=e;ZA(c,A[d+40>>3]);v[22656]=0;YA(d- -64|0,c);c=v[22656];v[22656]=0;if((c|0)==1){break a}c=Tc(g,f);e=v[d+76>>2];v[c+8>>2]=v[d+72>>2];v[c+12>>2]=e;e=v[d+68>>2];v[c>>2]=v[d+64>>2];v[c+4>>2]=e;f=f<<1;c=b>>>0<2;b=b>>>1|0;if(!c){continue}break}}b=Vm(d+24|0,1,0);c=v[b+12>>2];v[d+16>>2]=v[b+8>>2];v[d+20>>2]=c;c=v[b+4>>2];v[d+8>>2]=v[b>>2];v[d+12>>2]=c;Iz(a,0,h,d+8|0);gb=d+80|0;return a|0}a=P()|0;O()|0;Nq(g);S(a|0);L()}function Hma(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=C(0),g=0,h=0,i=0,j=0,k=C(0);c=gb-16|0;gb=c;if(v[b+8>>2]==v[a+8>>2]){if(v[b+4>>2]==v[a+4>>2]){v[c+12>>2]=v[b+8>>2];v[c+8>>2]=v[a+8>>2];h=v[Fb(c+12|0,c+8|0)>>2];v[c+12>>2]=v[b+4>>2];v[c+8>>2]=v[a+4>>2];d=Fb(c+12|0,c+8|0);if(h){i=v[d>>2];d=0;while(1){e=0;if(i){while(1){j=c,k=z[ir(b,e,d)>>2],z[j+12>>2]=k;v[c+8>>2]=-1082130432;v[c+4>>2]=1065353216;f=C(z[zf(c+12|0,c+8|0,c+4|0)>>2]*C(128));z[c+12>>2]=f;f=fe(f);a:{if(C(D(f))<C(2147483648)){g=~~f;break a}g=-2147483648}g=FV(g);t[v[a>>2]+(B(v[a+4>>2],d)+e|0)|0]=g;e=e+1|0;if((i|0)!=(e|0)){continue}break}}d=d+1|0;if((h|0)!=(d|0)){continue}break}}gb=c+16|0;return}aa(14360,6114,28,6667);L()}aa(14410,6114,27,6667);L()}function Eo(a,b,c){var d=0,e=0,f=0,g=0,h=0;a:{if(c){t[b+809|0]=c;break a}c=w[b+809|0]}d=v[a+480180>>2]&202376205?(c&240?-16:15)&c:c;c=v[b+688>>2];b:{if(v[a+480180>>2]&69206029){break b}e=d&240;f=d&15;if((f|0)==15){if(e){Gq(a,b,(d&240)>>>4|0,0);return}if(!(t[b+851|0]&1)){break b}c=w[a+480208|0]&2?c:c-60|0;break b}if((e|0)!=240){break b}if(f){Fq(a,b,f,0);return}if(!(t[b+851|0]&1)){break b}c=w[a+480208|0]&2?c:c+60|0}c:{if(!(!(t[b+851|0]&1)|w[a+480208|0]&2)&(v[a+1074416>>2]!=1|v[a+480180>>2]!=524288)){break c}e=d&255;d=d&15;d:{if(d){if(e&240?v[a+480180>>2]&16777248:0){break d}c=c-(d<<2)|0;break d}c=(e>>>2&60)+c|0}if(v[a+480180>>2]!=1){break c}v[b+88>>2]=v[b+88>>2]|2097152}g=b,h=Lb(c,0,256),v[g+688>>2]=h}function Dia(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0;g=gb-16|0;gb=g;i=v[a+24>>2];j=v[a+20>>2];k=v[a+16>>2];h=v[a+4>>2];e=h;f=v[a>>2];v[g+8>>2]=f;v[g+12>>2]=e;h=v[a+12>>2];v[g>>2]=v[a+8>>2];v[g+4>>2]=h;if(d){while(1){e=(e<<1)+k|0;f=(((f>>>16|0)+4&131064)<<1)+b|0;e=(((((B(u[e+4>>1],u[f+34>>1])+B(u[e+2>>1],u[f+32>>1])|0)+B(u[e+6>>1],u[f+36>>1])|0)+B(u[e+8>>1],u[f+38>>1])|0)/2|0)+((((B(u[e-4>>1],u[f+26>>1])+B(u[e-6>>1],u[f+24>>1])|0)+B(u[e-2>>1],u[f+28>>1])|0)+B(u[e>>1],u[f+30>>1])|0)/2|0)|0)/16384|0;v[c>>2]=v[c>>2]+B(e,j);v[c+4>>2]=v[c+4>>2]+B(e,i);Ub(g+8|0,g);d=d-1|0;if(d){c=c+8|0;f=v[g+8>>2];e=v[g+12>>2];continue}break}f=v[g+8>>2];e=v[g+12>>2]}v[a>>2]=f;v[a+4>>2]=e;gb=g+16|0}function DC(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;g=gb-32|0;gb=g;e=b;f=Nb(e);d=c;a:{if(f>>>0<d>>>0){j=gb-32|0;gb=j;b:{c:{h=d-f|0;d:{if(h>>>0<=v[wb(e)>>2]-v[e+4>>2]>>2>>>0){mr(e,h);break d}i=wb(e);k=lr(e,Nb(e)+h|0);m=Nb(e);f=0;l=gb-16|0;gb=l;v[l+12>>2]=0;d=j+8|0;kf(d+12|0,i);if(k){f=YV(k)}v[d>>2]=f;i=(m<<2)+f|0;v[d+8>>2]=i;v[d+4>>2]=i;n=dc(d),o=(k<<2)+f|0,v[n>>2]=o;gb=l+16|0;v[22656]=0;ov(d,h);f=v[22656];v[22656]=0;if((f|0)==1){break c}Zk(e,d);ZV(d)}gb=j+32|0;break b}a=P()|0;O()|0;ZV(d);S(a|0);L()}break a}if(d>>>0<f>>>0){_k(e,v[e>>2]+(d<<2)|0)}}if(Pb(a,c<<2)){bc(g+24|0,v[b>>2],Nb(b)<<2);b=v[g+28>>2];v[g+8>>2]=v[g+24>>2];v[g+12>>2]=b;kd(g+16|0,a,g+8|0)}gb=g+32|0}function Yha(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;g=gb-16|0;gb=g;h=g+8|0;j=h;k=c;e=gb-32|0;gb=e;i=b;d=b;b=Yd(b);f=fc(d);a:{b:{if(b){wb(d);c:{while(1){d:{d=b+14|0;e:{if(Hn(c,d)){if(!v[b>>2]){break b}f=b;break e}if(!Hn(d,c)){break c}f=b+4|0;if(!v[b+4>>2]){break d}b=f;f=b}b=v[b>>2];continue}break}v[e+28>>2]=b;b=f;break a}v[e+28>>2]=b;b=f;break a}b=fc(d)}v[e+28>>2]=b}f=b;b=v[b>>2];t[e+27|0]=0;if(!b){b=gb-16|0;gb=b;d=fc(i);c=e+8|0;d=Vj(c,Mc(16,4),Wj(b+8|0,d));To(v[d>>2]+14|0,k);l=fc(d),m=1,t[l+4|0]=m;gb=b+16|0;AS(i,v[e+28>>2],f,v[c>>2]);b=ce(c);t[e+27|0]=1;f=c;d=v[c>>2];v[c>>2]=0;if(d){c=fc(f);if(d){_n(v[c>>2],d,1)}}}Xj(j,yc(e+8|0,b),e+27|0);gb=e+32|0;DS(a,h);gb=g+16|0}function Ima(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=C(0),g=0,h=0,i=0,j=0,k=C(0),l=0;c=gb-16|0;gb=c;if(v[b+8>>2]==v[a+8>>2]){if(v[b+4>>2]==v[a+4>>2]){v[c+12>>2]=v[b+8>>2];v[c+8>>2]=v[a+8>>2];h=v[Fb(c+12|0,c+8|0)>>2];v[c+12>>2]=v[b+4>>2];v[c+8>>2]=v[a+4>>2];d=Fb(c+12|0,c+8|0);if(h){i=v[d>>2];d=0;while(1){e=0;if(i){while(1){j=c,k=z[ir(b,e,d)>>2],z[j+12>>2]=k;v[c+8>>2]=-1082130432;v[c+4>>2]=1065353216;f=C(z[zf(c+12|0,c+8|0,c+4|0)>>2]*C(32768));z[c+12>>2]=f;f=fe(f);a:{if(C(D(f))<C(2147483648)){g=~~f;break a}g=-2147483648}g=Uc(g);j=GV(a,e,d),l=g,u[j>>1]=l;e=e+1|0;if((i|0)!=(e|0)){continue}break}}d=d+1|0;if((h|0)!=(d|0)){continue}break}}gb=c+16|0;return}aa(14360,6114,28,6667);L()}aa(14410,6114,27,6667);L()}function c6(){var a=0,b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;d=gb-48|0;gb=d;if(wa(1,d+32|0)|0){Es(v[115137],10026);L()}a=d+32|0;c=ft(d+16|0,a);g=ft(d+8|0,a|4);e=gb-32|0;gb=e;b=gb-16|0;gb=b;h=gb-16|0;gb=h;a=gb-16|0;gb=a;i=a,j=kqa(v[c>>2],v[c+4>>2],1e9,0),v[i>>2]=j;v[a+4>>2]=jb;c=Zl(a+8|0,a);f=v[c+4>>2];c=v[c>>2];gb=a+16|0;gb=h+16|0;v[b+8>>2]=c;v[b+12>>2]=f;a=v[b+12>>2];v[e+8>>2]=v[b+8>>2];v[e+12>>2]=a;gb=b+16|0;f=v[e+8>>2];c=v[e+12>>2];a=v[g+4>>2];v[e>>2]=v[g>>2];v[e+4>>2]=a;a=e;c=v[a+4>>2]+c|0;b=v[a>>2];f=f+b|0;v[a+16>>2]=f;v[a+20>>2]=b>>>0>f>>>0?c+1|0:c;a=Zl(a+24|0,a+16|0);b=v[a+4>>2];a=v[a>>2];gb=e+32|0;v[d+24>>2]=a;v[d+28>>2]=b;a=Zl(d+40|0,d+24|0);b=v[a+4>>2];a=v[a>>2];gb=d+48|0;jb=b;return a|0}function TI(a,b,c,d){a:{if(b>>>0>20){break a}b:{switch(b-9|0){case 0:b=v[c>>2];v[c>>2]=b+4;v[a>>2]=v[b>>2];return;case 1:b=v[c>>2];v[c>>2]=b+4;b=v[b>>2];v[a>>2]=b;v[a+4>>2]=b>>31;return;case 2:b=v[c>>2];v[c>>2]=b+4;v[a>>2]=v[b>>2];v[a+4>>2]=0;return;case 3:b=v[c>>2]+7&-8;v[c>>2]=b+8;c=v[b+4>>2];v[a>>2]=v[b>>2];v[a+4>>2]=c;return;case 4:b=v[c>>2];v[c>>2]=b+4;b=u[b>>1];v[a>>2]=b;v[a+4>>2]=b>>31;return;case 5:b=v[c>>2];v[c>>2]=b+4;v[a>>2]=x[b>>1];v[a+4>>2]=0;return;case 6:b=v[c>>2];v[c>>2]=b+4;b=t[b|0];v[a>>2]=b;v[a+4>>2]=b>>31;return;case 7:b=v[c>>2];v[c>>2]=b+4;v[a>>2]=w[b|0];v[a+4>>2]=0;return;case 8:b=v[c>>2]+7&-8;v[c>>2]=b+8;A[a>>3]=A[b>>3];return;case 9:break b;default:break a}}kb[d|0](a,c)}}function nC(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0;g=gb-16|0;gb=g;if(t[a|0]&1){t[b+12|0]=w[b+12|0]|1}if(w[a|0]&2){t[b+12|0]=w[b+12|0]|4}if(w[a|0]&4){t[b+12|0]=w[b+12|0]|2}if(w[a|0]&16){t[b+12|0]=w[b+12|0]|16}if(w[a|0]&32){t[b+12|0]=w[b+12|0]|8}t[g+15|0]=w[a+1|0];t[g+14|0]=25;kh(b,w[ac(g+15|0,g+14|0)|0]);t[b+15|0]=w[a+2|0];t[b+16|0]=w[a+3|0];t[b+13|0]=w[a+4|0];t[b+14|0]=w[a+5|0];if(Nb(b)){while(1){f=(d<<2)+a|0;e=f+6|0;e=w[e|0]|w[e+1|0]<<8;h=Mb(b,d),i=e,u[h>>1]=i;a:{if(!d){break a}e=d-1|0;if(x[Mb(b,d)>>1]>=x[Mb(b,e)>>1]){break a}e=x[Mb(b,e)>>1];h=Mb(b,d),i=e+1|0,u[h>>1]=i}f=f+8|0;f=Lb((w[f|0]|w[f+1|0]<<8)<<16>>16>>c,0,64);h=Mb(b,d),i=f,t[h+2|0]=i;d=d+1|0;if(Nb(b)>>>0>d>>>0){continue}break}}gb=g+16|0}function eja(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0;e=gb-16|0;gb=e;h=v[a+40>>2];i=v[a+36>>2];k=v[a+16>>2];g=v[a+4>>2];b=g;f=v[a>>2];v[e+8>>2]=f;v[e+12>>2]=b;g=v[a+12>>2];v[e>>2]=v[a+8>>2];v[e+4>>2]=g;a:{if(d){while(1){j=v[a+32>>2];i=v[a+28>>2]+i|0;g=i>>12;b=b+k|0;f=f>>>21&2040;b=(((B(t[b|0],u[f+46162>>1])+B(t[b-1|0],u[f+46160>>1])|0)+B(t[b+1|0],u[f+46164>>1])|0)+B(t[b+2|0],u[f+46166>>1])<<8)/16384|0;v[c>>2]=v[c>>2]+B(g,b);h=h+j|0;j=h>>12;v[c+4>>2]=v[c+4>>2]+B(b,j);Ub(e+8|0,e);d=d-1|0;if(d){c=c+8|0;f=v[e+8>>2];b=v[e+12>>2];continue}break}f=v[e+8>>2];b=v[e+12>>2];break a}j=h>>12;g=i>>12}v[a+40>>2]=h;v[a+20>>2]=g;v[a+36>>2]=i;v[a+24>>2]=j;v[a>>2]=f;v[a+4>>2]=b;gb=e+16|0}function eba(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;g=gb-32|0;gb=g;c=gb-16|0;gb=c;d=a;k=d;h=b;e=Yd(d);i=fc(d);f=gb-16|0;gb=f;if(e){while(1){j=Bu(wb(k),e+16|0,h);i=j?i:e;e=v[(j?4:0)+e>>2];if(e){continue}break}}h=v[yc(f+8|0,i)>>2];gb=f+16|0;v[c+8>>2]=h;l=c,m=Ch(d),v[l>>2]=m;a:{b:{if(!Gb(c+8|0,c)){break b}if(Bu(wb(d),b,ue(c+8|0))){break b}b=v[c+8>>2];break a}b=Ch(d)}gb=c+16|0;v[g+24>>2]=b;l=g,m=Ch(a),v[l+16>>2]=m;if(!Sj(g+24|0,g+16|0)){b=v[yc(g+8|0,b)>>2];d=gb-16|0;gb=d;v[d+8>>2]=b;h=gb-16|0;gb=h;e=d+8|0;i=v[e>>2];c=i;f=yc(h+8|0,c);Uj(f);b=a;if((c|0)==v[b>>2]){v[b>>2]=v[f>>2]}f=wb(b);v[f>>2]=v[f>>2]-1;bN(v[fc(b)>>2],c);gb=h+16|0;fc(a);Sm(ue(e));MA(i);gb=d+16|0}gb=g+32|0}function MN(a,b,c,d,e,f,g){var h=0,i=0,j=0;h=gb-16|0;gb=h;t[h+15|0]=b;t[h+14|0]=10;kh(g,w[ac(h+15|0,h+14|0)|0]);t[g+15|0]=c;t[g+16|0]=c;t[g+14|0]=e;t[g+13|0]=d;if(Nb(g)){c=0;while(1){b=B(c,3)+f|0;d=w[b|0]|w[b+1|0]<<8;i=Mb(g,c),j=d>>>4|0,u[i>>1]=j;e=0;a:{if(c){d=c-1|0;if(x[Mb(g,c)>>1]>=x[Mb(g,d)>>1]){break a}e=x[Mb(g,d)>>1]+1|0}i=Mb(g,c),j=e,u[i>>1]=j}b=Md(w[b+2|0],0,64);i=Mb(g,c),j=b,t[i+2|0]=j;c=c+1|0;if(Nb(g)>>>0>c>>>0){continue}break}}b=w[g+12|0]&-2|a&1;t[g+12|0]=b;c=g;if(a&2){b=w[g+15|0];d=Nb(g);b=w[g+12|0]&-5|(b>>>0<=d>>>0)<<2}else{b=b&251}t[c+12|0]=b;c=g;b:{c:{if(a&4){a=w[g+13|0];if(a>>>0<=w[g+14|0]){break c}}a=b&253;break b}b=Nb(g);a=w[g+12|0]&-3|(a>>>0<=b>>>0)<<1}t[c+12|0]=a;gb=h+16|0}function Ica(a){a=a|0;var b=0,c=0;c=gb-16|0;gb=c;b=wf(v[a+16>>2]);b=Ac(lqa(kqa(b,b>>31,3840,0),jb,1e3,0),jb);v[a+4316>>2]=b;v[22656]=0;v[c+12>>2]=0;U(1540,a+4264|0,b|0,c+12|0);b=v[22656];v[22656]=0;a:{b:{c:{d:{if((b|0)!=1){e:{if(!w[a+4260|0]){break e}b=v[a+4316>>2];v[22656]=0;v[c+12>>2]=0;U(1540,a+4276|0,b|0,c+12|0);b=v[22656];v[22656]=0;if((b|0)!=1){break e}b=V(89116)|0;break c}v[22656]=0;v[c+12>>2]=0;az(a+4288|0,c+12|0);b=v[22656];v[22656]=0;if((b|0)==1){break d}v[22656]=0;v[c+12>>2]=0;az(a+4300|0,c+12|0);b=v[22656];v[22656]=0;if((b|0)!=1){break b}b=V(89116)|0;break c}b=V(89116)|0;break c}b=V(89116)|0}if((O()|0)!=(ea(89116)|0)){break a}Z(b|0)|0;v[a+4316>>2]=0;$()}gb=c+16|0;return}S(b|0);L()}function mba(a){a=a|0;var b=0;b=5149;a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{if((a|0)<=276){if(!a){break n}if((a|0)==257){break m}if((a|0)!=267){break a}b=14659;break a}switch(a-277|0){case 1:case 2:case 3:case 4:case 5:case 6:case 7:case 8:case 13:case 14:case 15:case 16:case 17:case 18:break a;case 10:break j;case 9:break k;case 0:break l;case 23:break c;case 22:break d;case 21:break e;case 20:break f;case 19:break g;case 12:break h;case 11:break i;default:break b}}b=18726;break a}b=5182;break a}b=2107;break a}b=5205;break a}b=5219;break a}b=2480;break a}b=2500;break a}b=5231;break a}b=5163;break a}b=10145;break a}b=9407;break a}b=3111;break a}if((a|0)!=357){break a}b=5116}return ie(b)|0}function WN(a){var b=0,c=0,d=0,e=0;b=gb-32|0;gb=b;v[b+12>>2]=B(w[a+12|0]|w[a+13|0]<<8|(w[a+14|0]<<16|w[a+15|0]<<24),5)+(w[a+16|0]|w[a+17|0]<<8|(w[a+18|0]<<16|w[a+19|0]<<24));v[b+16>>2]=(w[a+24|0]|w[a+25|0]<<8|(w[a+26|0]<<16|w[a+27|0]<<24))+((w[a+20|0]|w[a+21|0]<<8|(w[a+22|0]<<16|w[a+23|0]<<24))<<3);c=w[a+32|0]|w[a+33|0]<<8|(w[a+34|0]<<16|w[a+35|0]<<24);a=w[a+28|0]|w[a+29|0]<<8|(w[a+30|0]<<16|w[a+31|0]<<24);v[b+28>>2]=3;v[b+20>>2]=c+(a<<2);v[b+24>>2]=b+12;a=v[b+28>>2];v[b>>2]=v[b+24>>2];v[b+4>>2]=a;a=v[b>>2];d=lD(b);e=gb-16|0;gb=e;a:{if((a|0)==(d|0)){break a}c=a+4|0;if((d|0)==(c|0)){break a}while(1){a=zn(a,c)?c:a;c=c+4|0;if((d|0)!=(c|0)){continue}break}}gb=e+16|0;gb=b+32|0;return v[a>>2]-36|0}function ina(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0;g=gb-32|0;gb=g;d=b;f=tc(d);e=c;a:{if(f>>>0<e>>>0){h=gb-32|0;gb=h;b:{c:{f=e-f|0;d:{if(f>>>0<=v[wb(d)>>2]-v[d+4>>2]>>1>>>0){i=gb-16|0;gb=i;e=li(i,d,f);d=v[e+4>>2];f=v[e+8>>2];if((d|0)!=(f|0)){while(1){Pk(d);d=d+2|0;v[e+4>>2]=d;if((d|0)!=(f|0)){continue}break}}$b(e);gb=i+16|0;break d}e=wb(d);e=FD(h+8|0,MY(d,tc(d)+f|0),tc(d),e);v[22656]=0;RV(e,f);f=v[22656];v[22656]=0;if((f|0)==1){break c}Zk(d,e);rp(e)}gb=h+32|0;break b}a=P()|0;O()|0;rp(e);S(a|0);L()}break a}if(e>>>0<f>>>0){_k(d,v[d>>2]+(e<<1)|0)}}c=Pb(a,c<<1);if(c){bc(g+24|0,v[b>>2],tc(b)<<1);b=v[g+28>>2];v[g+8>>2]=v[g+24>>2];v[g+12>>2]=b;kd(g+16|0,a,g+8|0)}gb=g+32|0;return c|0}function LM(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;c=gb-48|0;gb=c;v[c+8>>2]=542066252;e=c+8|0;d=e|4;t[d|0]=0;t[d+1|0]=0;t[d+2|0]=0;t[d+3|0]=0;d=v[b+4220>>2];t[c+16|0]=d;t[c+17|0]=d>>>8;t[c+18|0]=d>>>16;t[c+19|0]=d>>>24;d=v[b+4224>>2];t[c+20|0]=d;t[c+21|0]=d>>>8;t[c+22|0]=d>>>16;t[c+23|0]=d>>>24;d=v[b+4228>>2];t[c+24|0]=d;t[c+25|0]=d>>>8;t[c+26|0]=d>>>16;t[c+27|0]=d>>>24;d=v[b+4232>>2];t[c+28|0]=d;t[c+29|0]=d>>>8;t[c+30|0]=d>>>16;t[c+31|0]=d>>>24;d=v[b+4236>>2];t[c+32|0]=d;t[c+33|0]=d>>>8;t[c+34|0]=d>>>16;t[c+35|0]=d>>>24;t[c+36|0]=w[b+4240|0];t[c+37|0]=w[b+4241|0];t[c+38|0]=w[b+4242|0];t[c+39|0]=w[b+4243|0];t[c+40|0]=w[b+4244|0];b=b+4208|0;Ok(b,33);hc(v[b>>2],e,33);Vd(c,b);ne(a,c);gb=c+48|0}function d6(){var a=0,b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0;b=gb-48|0;gb=b;if(wa(0,b+32|0)|0){Es(v[115137],9989);L()}d=ft(b+16|0,b+32|0);v[b+4>>2]=v[b+36>>2]/1e3;g=ft(b+8|0,b+4|0);e=gb-32|0;gb=e;c=gb-16|0;gb=c;a=gb-16|0;gb=a;h=a,i=kqa(v[d>>2],v[d+4>>2],1e6,0),v[h>>2]=i;v[a+4>>2]=jb;d=Zl(a+8|0,a);f=v[d+4>>2];d=v[d>>2];gb=a+16|0;v[c+8>>2]=d;v[c+12>>2]=f;a=v[c+12>>2];v[e+8>>2]=v[c+8>>2];v[e+12>>2]=a;gb=c+16|0;f=v[e+8>>2];d=v[e+12>>2];a=v[g+4>>2];v[e>>2]=v[g>>2];v[e+4>>2]=a;a=e;d=v[a+4>>2]+d|0;c=v[a>>2];f=f+c|0;v[a+16>>2]=f;v[a+20>>2]=c>>>0>f>>>0?d+1|0:d;a=Zl(a+24|0,a+16|0);c=v[a+4>>2];a=v[a>>2];gb=e+32|0;v[b+24>>2]=a;v[b+28>>2]=c;a=Zl(b+40|0,b+24|0);c=v[a+4>>2];a=v[a>>2];gb=b+48|0;jb=c;return a|0}function PZ(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;e=gb-32|0;gb=e;ud(b,0);ki(e,1,a+33|0);d=e+16|0;Bc(d,e);v[22656]=0;Q(303,b+43|0,d|0)|0;d=v[22656];v[22656]=0;if((d|0)!=1){f=e+16|0;vb(f);d=a+50|0;v[b>>2]=w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24);d=a+54|0;v[b+24>>2]=w[d|0]|w[d+1|0]<<8;t[e+16|0]=w[a+56|0];t[e|0]=64;g=b,h=w[ac(f,e)|0]<<2,u[g+30>>1]=h;d=a+57|0;v[b+4>>2]=w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24);d=a+61|0;v[b+8>>2]=w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24);if(!(!c|!v[b+4>>2])){v[b+8>>2]=v[b>>2]}a:{if(!w[a|0]){break a}a=v[b+8>>2];if(a>>>0<=v[b+4>>2]+2>>>0|a>>>0>y[b>>2]){break a}u[b+34>>1]=x[b+34>>1]|2}gb=e+32|0;return}a=P()|0;O()|0;vb(e+16|0);S(a|0);L()}function Eia(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0;g=gb-16|0;gb=g;i=v[a+24>>2];j=v[a+20>>2];k=v[a+16>>2];h=v[a+4>>2];e=h;f=v[a>>2];v[g+8>>2]=f;v[g+12>>2]=e;h=v[a+12>>2];v[g>>2]=v[a+8>>2];v[g+4>>2]=h;if(d){while(1){e=e+k|0;f=(((f>>>16|0)+4&131064)<<1)+b|0;e=(((((B(t[e+2|0],u[f+34>>1])+B(t[e+1|0],u[f+32>>1])|0)+B(t[e+3|0],u[f+36>>1])|0)+B(t[e+4|0],u[f+38>>1])<<8)/2|0)+((((B(t[e-2|0],u[f+26>>1])+B(t[e-3|0],u[f+24>>1])|0)+B(t[e-1|0],u[f+28>>1])|0)+B(t[e|0],u[f+30>>1])<<8)/2|0)|0)/16384|0;v[c>>2]=v[c>>2]+B(e,j);v[c+4>>2]=v[c+4>>2]+B(e,i);Ub(g+8|0,g);d=d-1|0;if(d){c=c+8|0;f=v[g+8>>2];e=v[g+12>>2];continue}break}f=v[g+8>>2];e=v[g+12>>2]}v[a>>2]=f;v[a+4>>2]=e;gb=g+16|0}function AZ(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;d=gb-16|0;gb=d;ud(b,0);v[b>>2]=w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24);c=Sr(a+4|0,a);v[b+4>>2]=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);c=Sr(a+8|0,a);v[b+8>>2]=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);t[d+15|0]=127;t[d+14|0]=w[a+15|0];f=b,g=(((w[ac(d+15|0,d+14|0)|0]<<8|64)&65344)>>>0)/127|0,u[f+30>>1]=g;e=a+12|0;if(w[e|0]>=16){c=w[e|0];u[b+34>>1]=32;u[b+28>>1]=c&240}c=a+13|0;v[b+24>>2]=(w[c|0]|w[c+1|0]<<8)<<1;if(!(w[c|0]|w[c+1|0]<<8)){v[b+24>>2]=16726}f=b,g=(B(Mu(0,w[e|0]<<28>>24),v[b+24>>2])>>>0)/8363|0,v[f+24>>2]=g;if(y[b+4>>2]<y[b+8>>2]){u[b+34>>1]=x[b+34>>1]|2}if(w[a+16|0]&132){u[b+34>>1]=x[b+34>>1]|1}gb=d+16|0}function zaa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=gb-32|0;gb=d;v[22656]=0;_(1934,a|0);c=v[22656];v[22656]=0;a:{b:{c:{d:{e:{f:{if((c|0)==1){break f}v[22656]=0;_(1960,b|0);c=v[22656];v[22656]=0;if((c|0)==1){break f}e=v[a+24>>2];v[22656]=0;c=Q(70,d|0,b|0)|0;b=v[22656];v[22656]=0;if((b|0)==1){break e}v[22656]=0;U(1961,d+16|0,e|0,c|0);b=v[22656];v[22656]=0;if((b|0)==1){break d}a=d+16|0;b=ie(Jb(a));vb(a);vb(c);break b}b=V(0)|0;O()|0;break c}b=V(0)|0;O()|0;break c}b=V(0)|0;O()|0;vb(c)}Z(b|0)|0;b=0;v[22656]=0;Y(1911,10643,a|0,0,0);a=v[22656];v[22656]=0;if((a|0)==1){break a}$()}gb=d+32|0;return b|0}a=P()|0;O()|0;v[22656]=0;X(20);b=v[22656];v[22656]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}function U9(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=gb-32|0;gb=d;v[22656]=0;_(1934,a|0);c=v[22656];v[22656]=0;a:{b:{c:{d:{e:{f:{if((c|0)==1){break f}v[22656]=0;_(1960,b|0);c=v[22656];v[22656]=0;if((c|0)==1){break f}e=v[a+24>>2];v[22656]=0;c=Q(70,d|0,b|0)|0;b=v[22656];v[22656]=0;if((b|0)==1){break e}v[22656]=0;Y(1995,d+16|0,e|0,c|0,1);b=v[22656];v[22656]=0;if((b|0)==1){break d}a=d+16|0;b=ie(Jb(a));vb(a);vb(c);break b}b=V(0)|0;O()|0;break c}b=V(0)|0;O()|0;break c}b=V(0)|0;O()|0;vb(c)}Z(b|0)|0;b=0;v[22656]=0;Y(1911,3489,a|0,0,0);a=v[22656];v[22656]=0;if((a|0)==1){break a}$()}gb=d+32|0;return b|0}a=P()|0;O()|0;v[22656]=0;X(20);b=v[22656];v[22656]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}function NM(a,b,c){a=a|0;b=b|0;c=C(c);var d=0,e=0,f=0,g=0;d=gb-16|0;gb=d;z[d+12>>2]=c;gz(a);Hi(d+12|0);a:{b:{switch(b|0){case 0:z[a+4220>>2]=z[d+12>>2];break a;case 1:z[a+4224>>2]=z[d+12>>2];break a;case 2:z[a+4228>>2]=z[d+12>>2];Rt(a);break a;case 3:t[a+4240|0]=z[d+12>>2]>=C(.5);Rt(a);break a;case 4:b=gb-16|0;gb=b;f=b,g=Xh(C(z[d+12>>2]*C(32))),v[f+12>>2]=g;v[b+8>>2]=0;v[b+4>>2]=5;e=v[dj(b+12|0,b+8|0,b+4|0)>>2];gb=b+16|0;v[a+4232>>2]=e;break a;case 5:t[a+4241|0]=z[d+12>>2]>=C(.5);break a;case 6:t[a+4242|0]=z[d+12>>2]>=C(.5);break a;case 7:t[a+4244|0]=z[d+12>>2]>=C(.5);break a;case 8:break b;default:break a}}b=a;c=z[d+12>>2];if(c==C(0)){ez(a);c=z[d+12>>2]}A[b+4256>>3]=c}gb=d+16|0}function kh(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;c=Nb(a);if(c>>>0<b>>>0){d=gb-32|0;gb=d;a:{b:{c=b-c|0;c:{if(c>>>0<=v[wb(a)>>2]-v[a+4>>2]>>2>>>0){e=gb-16|0;gb=e;d:{b=Fg(e,a,c);c=v[b+4>>2];f=v[b+8>>2];if((c|0)!=(f|0)){while(1){wb(a);v[22656]=0;Xr(c);g=v[22656];v[22656]=0;if((g|0)==1){break d}c=c+4|0;v[b+4>>2]=c;if((c|0)!=(f|0)){continue}break}}$b(b);gb=e+16|0;break c}a=P()|0;O()|0;$b(b);S(a|0);L()}b=wb(a);b=Ap(d+8|0,fh(a,Nb(a)+c|0),Nb(a),b);v[22656]=0;R(299,b|0,c|0);c=v[22656];v[22656]=0;if((c|0)==1){break b}v[22656]=0;R(300,a|0,b|0);a=v[22656];v[22656]=0;if((a|0)==1){break b}gj(b)}gb=d+32|0;break a}a=P()|0;O()|0;gj(b);S(a|0);L()}return}if(b>>>0<c>>>0){hj(a,v[a>>2]+(b<<2)|0)}}function dqa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0;e=gb-48|0;gb=e;g=a+8|0;a:{c=v[a+8>>2];i=dc(a);b:{if((c|0)!=v[i>>2]){break b}h=a+4|0;d=v[a+4>>2];f=v[a>>2];if(d>>>0>f>>>0){f=((d-f>>1)+1|0)/-2<<1;a=f+d|0;if((c|0)!=(d|0)){while(1){CY(a,d);a=a+2|0;d=d+2|0;if((d|0)!=(c|0)){continue}break}}c=a;v[g>>2]=a;v[h>>2]=f+v[h>>2];break b}v[e+24>>2]=c-f;v[e+44>>2]=1;d=e+24|0;c=v[Lc(d,e+44|0)>>2];c=FD(d,c,c>>>2|0,v[a+16>>2]);d=yc(e+16|0,v[a+4>>2]);f=v[yc(e+8|0,v[a+8>>2])>>2];d=v[d>>2];v[22656]=0;DY(c,d,f);d=v[22656];v[22656]=0;if((d|0)==1){break a}wc(a,c);wc(h,c+4|0);wc(g,c+8|0);wc(i,dc(c));rp(c);c=v[a+8>>2]}Fr(c,b);v[g>>2]=v[g>>2]+2;gb=e+48|0;return}a=P()|0;O()|0;rp(c);S(a|0);L()}function H3(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0;f=gb-48|0;gb=f;v[f+40>>2]=b;a:{b:{c:{d:{if(!(v[c+4>>2]&1)){b=kb[v[v[a>>2]+24>>2]](a,b,c,d,e)|0;break d}a=f+24|0;Fc(a,c);v[22656]=0;a=T(2453,a|0)|0;c=v[22656];v[22656]=0;if((c|0)==1){break c}Wb(f+24|0);e:{if(e){Ph(f+24|0,a);break e}Oh(f+24|0,a)}a=f+24|0;g=f,h=zd(a),v[g+16>>2]=h;g=f,h=ui(a),v[g+8>>2]=h;if(Gb(f+16|0,f+8|0)){while(1){a=v[v[f+16>>2]>>2];v[22656]=0;Q(2472,f+40|0,a|0)|0;a=v[22656];v[22656]=0;if((a|0)==1){break b}a=f+16|0;Qe(a);g=f,h=ui(f+24|0),v[g+8>>2]=h;if(Gb(a,f+8|0)){continue}break}b=v[f+40>>2]}Hc(f+24|0)}gb=f+48|0;return b|0}b=P()|0;O()|0;Wb(f+24|0);break a}b=P()|0;O()|0;Hc(f+24|0)}S(b|0);L()}function tI(a){a=a|0;var b=0,c=0,d=0,e=0;d=gb-16|0;gb=d;a:{b:{if(!v[(v[v[a>>2]-12>>2]+a|0)+24>>2]){break b}v[22656]=0;c=Q(2321,d+8|0,a|0)|0;b=v[22656];v[22656]=0;c:{if((b|0)!=1){d:{if(!w[c|0]){break d}b=v[(v[v[a>>2]-12>>2]+a|0)+24>>2];v[22656]=0;b=T(2322,b|0)|0;e=v[22656];v[22656]=0;if((e|0)!=1){if((b|0)!=-1){break d}b=v[v[a>>2]-12>>2];v[22656]=0;_(2323,a+b|0);b=v[22656];v[22656]=0;if((b|0)!=1){break d}}b=V(0)|0;O()|0;sI(c);break c}sI(c);break b}b=V(0)|0;O()|0}Z(b|0)|0;c=v[v[a>>2]-12>>2];v[22656]=0;_(19,a+c|0);c=v[22656];v[22656]=0;if((c|0)==1){break a}$()}gb=d+16|0;return a|0}a=P()|0;O()|0;v[22656]=0;X(20);c=v[22656];v[22656]=0;if((c|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}function se(a,b){var c=0,d=0,e=0;d=gb-32|0;gb=d;a=sh(a,-1,-1);a:{b:{if(w[uj(d+24|0,b,1)|0]){c=v[v[b>>2]-12>>2];v[22656]=0;c=v[(b+c|0)+24>>2];e=v[22656];v[22656]=0;c:{d:{if((e|0)==1){break d}v[22656]=0;Fa(2318,d+8|0,c|0,0,0,1,8);c=v[22656];v[22656]=0;if((c|0)==1){break d}c=v[d+12>>2];v[a>>2]=v[d+8>>2];v[a+4>>2]=c;c=v[d+20>>2];v[a+8>>2]=v[d+16>>2];v[a+12>>2]=c;a=0;break c}a=V(0)|0;O()|0;Z(a|0)|0;a=1;tj(v[v[b>>2]-12>>2]+b|0,1);if(v[(v[v[b>>2]-12>>2]+b|0)+20>>2]&1){v[22656]=0;X(2027);a=v[22656];v[22656]=0;if((a|0)!=1){break a}a=P()|0;O()|0;v[22656]=0;X(20);b=v[22656];v[22656]=0;if((b|0)==1){break b}S(a|0);L()}$()}ih(v[v[b>>2]-12>>2]+b|0,a)}gb=d+32|0;return}V(0)|0;O()|0;Bb()}L()}function jA(a){var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;c=gb-16|0;gb=c;if(!cd(a)){m=c,n=Vb(a),v[m+8>>2]=n;m=c,n=Zb(a),v[m>>2]=n;if(Gb(c+8|0,c)){while(1){d=c+8|0;b=v[d>>2];Gp(b,4194304,67108864);g=v[b>>2];f=g+f|0;b=h;b=f>>>0<g>>>0?b+1|0:b;h=b;Qe(d);if(Gb(d,c)){continue}break}}b=Nb(a);g=Nb(a);m=c,n=Vb(a),v[m+8>>2]=n;m=c,n=Zb(a),v[m>>2]=n;b=nqa(f,h,b,0);d=jb;f=g<<24;h=0;if(Gb(c+8|0,c)){g=b;d=((d&1)<<31|b>>>1)&2147483647;while(1){i=c+8|0;b=v[i>>2];j=b;e=v[b>>2];b=e>>>8|0;e=d+(e<<24)|0;b=b+k|0;b=Qc(nqa(e,d>>>0>e>>>0?b+1|0:b,g,l),jb);v[j>>2]=b;e=f;f=e-b|0;h=h-(b>>>0>e>>>0)|0;Qe(i);if(Gb(i,c)){continue}break}}if(!Nb(a)){mx();L()}a=v[a>>2];v[a>>2]=f+v[a>>2]}gb=c+16|0}function cl(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;d=gb-32|0;gb=d;a:{c=v[a+32>>2];if((c|0)>=(b|0)){f=v[a+28>>2];break a}i=a+36|0;g=v[a+24>>2];e=v[a+20>>2];h=c;while(1){b:{if(e>>>0>=g>>>0){td(d+16|0,i,i+1024|0);c=v[d+20>>2];v[d+8>>2]=v[d+16>>2];v[d+12>>2]=c;c=d+24|0;kd(c,a,d+8|0);g=yb(c);v[a+24>>2]=g;v[a+20>>2]=0;if(!g){break b}e=0;h=v[a+32>>2]}j=e+1|0;v[a+20>>2]=j;e=w[(a+e|0)+36|0];c=h+8|0;v[a+32>>2]=c;f=v[a+28>>2]|e<<h;v[a+28>>2]=f;h=c;e=j;if((b|0)>(c|0)){continue}break a}break}a=ba(8)|0;v[22656]=0;T(205,a|0)|0;b=v[22656];v[22656]=0;if((b|0)==1){b=P()|0;O()|0;ca(a|0);S(b|0);L()}ia(a|0,27364,206);L()}v[a+32>>2]=c-b;v[a+28>>2]=f>>>b;gb=d+32|0;return(-1<<b^-1)&f}function S3(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0;f=gb-48|0;gb=f;v[f+40>>2]=b;a:{b:{c:{d:{if(!(v[c+4>>2]&1)){b=kb[v[v[a>>2]+24>>2]](a,b,c,d,e)|0;break d}a=f+24|0;Fc(a,c);v[22656]=0;a=T(2424,a|0)|0;c=v[22656];v[22656]=0;if((c|0)==1){break c}Wb(f+24|0);e:{if(e){Ph(f+24|0,a);break e}Oh(f+24|0,a)}a=f+24|0;g=f,h=zd(a),v[g+16>>2]=h;g=f,h=gf(a),v[g+8>>2]=h;if(Gb(f+16|0,f+8|0)){while(1){a=t[v[f+16>>2]];v[22656]=0;Q(2326,f+40|0,a|0)|0;a=v[22656];v[22656]=0;if((a|0)==1){break b}a=f+16|0;Pe(a);g=f,h=gf(f+24|0),v[g+8>>2]=h;if(Gb(a,f+8|0)){continue}break}b=v[f+40>>2]}vb(f+24|0)}gb=f+48|0;return b|0}b=P()|0;O()|0;Wb(f+24|0);break a}b=P()|0;O()|0;vb(f+24|0)}S(b|0);L()}function o5(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;f=gb-16|0;gb=f;a:{b:{if(!Ie(b,-1)){h=v[a+12>>2];i=v[a+8>>2];g=v[a+24>>2];if((g|0)==v[a+28>>2]){c=-1;if(!(w[a+48|0]&16)){break a}e=v[a+20>>2];j=v[a+44>>2];v[22656]=0;c=a+32|0;R(61,c|0,0);d=v[22656];v[22656]=0;if((d|0)==1){break b}d=Kc(c);v[22656]=0;R(76,c|0,d|0);d=v[22656];v[22656]=0;if((d|0)==1){break b}d=Jb(c);Ux(a,d,Ab(c)+d|0);$s(a,g-e|0);v[a+44>>2]=v[a+20>>2]+(j-e|0)}v[f+12>>2]=v[a+24>>2]+1;c=a+44|0;e=f+12|0;k=a,l=v[(zn(e,c)?c:e)>>2],v[k+44>>2]=l;if(w[a+48|0]&8){c=Jb(a+32|0);$n(a,c,c+(h-i|0)|0,v[a+44>>2])}c=uI(a,Wh(b));break a}c=Zs(b);break a}a=V(0)|0;O()|0;Z(a|0)|0;$();c=-1}gb=f+16|0;return c|0}function aq(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0;h=gb-16|0;gb=h;f=d?d:463972;d=v[f>>2];a:{b:{c:{if(!b){if(d){break c}break a}e=-2;if(!c){break a}i=a?a:h+12|0;d:{if(d){a=c;break d}a=w[b|0];d=a<<24>>24;if((d|0)>=0){v[i>>2]=a;e=(d|0)!=0;break a}a=t[b|0];if(!v[v[115196]>>2]){v[i>>2]=a&57343;e=1;break a}a=(a&255)-194|0;if(a>>>0>50){break c}d=v[(a<<2)+76272>>2];a=c-1|0;if(!a){break b}b=b+1|0}g=w[b|0];j=g>>>3|0;if((j-16|(d>>26)+j)>>>0>7){break c}while(1){a=a-1|0;d=g-128|d<<6;if((d|0)>=0){v[f>>2]=0;v[i>>2]=d;e=c-a|0;break a}if(!a){break b}b=b+1|0;g=w[b|0];if((g&192)==128){continue}break}}v[f>>2]=0;v[115137]=25;e=-1;break a}v[f>>2]=d}gb=h+16|0;return e|0}function LP(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0;f=gb-112|0;gb=f;v[f+108>>2]=0;d=Qm(a,x[d+70>>1],v[d+48>>2],c,f+108|0);c=w[b+790|0];if(!v[f+108>>2]){e=(c|0)==15;h=e&!w[b+792|0];d=d<<8;a:{if(d){v[b+664>>2]=d;break a}d=0;if(e){break a}d=v[b+664>>2]}h=h?0:w[b+836|0]<<16}if((c|0)==15){c=w[b+792|0];b:{if(!c){c=v[b+76>>2];v[f>>2]=1;e=v[Lc(f,f+108|0)>>2]<<3;g=kqa(c,0,d,0);d=(256<<e>>>1|0)+g|0;c=jb;c=d>>>0<g>>>0?c+1|0:c;g=d;e=e+8|0;d=e&31;if((e&63)>>>0>=32){e=0;c=c>>>d|0}else{e=c>>>d|0;c=((1<<d)-1&c)<<32-d|g>>>d}d=Qc(c,e);break b}fU(f,0);if(c>>>0>9){break b}c=v[b+104>>2];if(!c){break b}d=v[Fe(c+68|0,w[b+792|0]-1|0)>>2]+d|0}v[b+664>>2]=d}Om(a,b,d+h|0);gb=f+112|0}function xZ(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=gb-16|0;gb=d;v[d+12>>2]=c;if(Ng(a,d+8|0)){v[d+4>>2]=w[d+8|0];f=v[Fb(d+4|0,d+12|0)>>2];c=gb+-64|0;gb=c;e=c+40|0;Re(e,a,f);a=v[e>>2];v[22656]=0;e=Sd(e);f=v[22656];v[22656]=0;a:{b:{c:{d:{if((f|0)==1){break d}e=zb(e);v[22656]=0;Xe(c+8|0,3,e,a);a=v[22656];v[22656]=0;if((a|0)==1){break d}v[22656]=0;R(324,c+24|0,c+8|0);a=v[22656];v[22656]=0;if((a|0)==1){break d}v[22656]=0;R(400,c|0,b|0);a=v[22656];v[22656]=0;if((a|0)==1){break c}v[22656]=0;Q(401,c|0,c+24|0)|0;a=v[22656];v[22656]=0;if((a|0)==1){break c}vb(c+24|0);zc(c+40|0);gb=c- -64|0;break a}a=P()|0;O()|0;break b}a=P()|0;O()|0;vb(c+24|0)}zc(c+40|0);S(a|0);L()}}gb=d+16|0}function iN(a,b,c){var d=0,e=0,f=0,g=0,h=0;f=gb-48|0;gb=f;e=Kb(f+32|0);v[22656]=0;Q(1517,a|0,f+24|0)|0;d=v[22656];v[22656]=0;a:{b:{if((d|0)!=1){g=v[f+28>>2];d=v[f+24>>2];Se(e);v[22656]=0;g=!g&d>>>0<255?d:255;R(76,e|0,g|0);d=v[22656];v[22656]=0;if((d|0)==1){break a}if(g){d=0;while(1){h=pc(e,d);v[22656]=0;Q(1518,a|0,h|0)|0;h=v[22656];v[22656]=0;if((h|0)==1){break a}d=d+1|0;if((g|0)!=(d|0)){continue}break}}if((KG(e)|0)!=-1){a=KG(e);v[22656]=0;R(76,e|0,a|0);a=v[22656];v[22656]=0;if((a|0)==1){break a}}v[22656]=0;U(13,f+8|0,c|0,e|0);a=v[22656];v[22656]=0;if((a|0)!=1){break b}break a}break a}a=f+8|0;Eb(b,a);vb(a);vb(e);gb=f+48|0;return}a=P()|0;O()|0;vb(e);S(a|0);L()}function Yga(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;if(v[a+4>>2]!=v[wb(a)>>2]){c=gb-16|0;gb=c;v[c>>2]=a;a=v[a+4>>2];v[c+4>>2]=a;v[c+8>>2]=a+7;LQ(v[c+4>>2],b);v[c+4>>2]=v[c+4>>2]+7;$b(c);gb=c+16|0;return}g=gb-32|0;gb=g;h=wb(a);i=g+8|0;j=a;f=QA(a)+1|0;d=gb-16|0;gb=d;v[d+12>>2]=f;e=gb-16|0;gb=e;v[e+12>>2]=613566756;v[22656]=0;v[e+8>>2]=2147483647;k=Fb(e+12|0,e+8|0);c=v[22656];v[22656]=0;a:{if((c|0)!=1){gb=e+16|0;c=v[k>>2];break a}V(0)|0;O()|0;Bb();L()}b:{if(c>>>0>=f>>>0){f=LA(j);if(f>>>0<c>>>1>>>0){v[d+8>>2]=f<<1;c=v[Lc(d+8|0,d+12|0)>>2]}gb=d+16|0;break b}Sc();L()}c=WQ(i,c,QA(a),h);LQ(v[c+8>>2],b);v[c+8>>2]=v[c+8>>2]+7;VQ(a,c);UQ(c);gb=g+32|0}function $2(a){a=a|0;var b=0,c=0,d=0,e=0,f=0;f=UF(v[v[a>>2]-12>>2]+a|0,10);e=gb-16|0;gb=e;v[22656]=0;c=a;d=Q(15,e+8|0,c|0)|0;b=v[22656];v[22656]=0;a:{b:{c:{d:{if((b|0)!=1){e:{if(!w[d|0]){break e}b=cj(e,c);v[22656]=0;Q(2326,b|0,f|0)|0;f=v[22656];v[22656]=0;if((f|0)!=1){if(!bw(b)){break e}b=v[v[c>>2]-12>>2];v[22656]=0;R(18,b+c|0,1);b=v[22656];v[22656]=0;if((b|0)!=1){break e}}b=V(0)|0;O()|0;nl(d);break d}nl(d);break c}b=V(0)|0;O()|0}Z(b|0)|0;d=v[v[c>>2]-12>>2];v[22656]=0;_(19,c+d|0);c=v[22656];v[22656]=0;if((c|0)==1){break b}$()}gb=e+16|0;break a}a=P()|0;O()|0;v[22656]=0;X(20);c=v[22656];v[22656]=0;if((c|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}bt(a);return a|0}function j3(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0;h=gb-416|0;gb=h;d=h+416|0;v[h+12>>2]=d;c=gb-144|0;gb=c;v[c+28>>2]=c+132;i=c+32|0;lH(a+8|0,i,c+28|0,e,f,g);v[c+16>>2]=0;v[c+20>>2]=0;v[c+12>>2]=i;e=h+16|0;i=e;j=UV(e,v[h+12>>2]);f=gb-16|0;gb=f;v[f+12>>2]=v[a+8>>2];g=vi(f+8|0,f+12|0);v[22656]=0;a=Ix(e,c+12|0,j,c+16|0);j=v[22656];v[22656]=0;a:{if((j|0)!=1){hf(g);gb=f+16|0;break a}a=P()|0;O()|0;hf(g);S(a|0);L()}if((a|0)==-1){Ns(9868);L()}v[h+12>>2]=i+(a<<2);gb=c+144|0;c=v[h+12>>2];a=gb-16|0;gb=a;v[a+8>>2]=b;if((c|0)!=(e|0)){while(1){kI(a+8|0,v[e>>2]);e=e+4|0;if((c|0)!=(e|0)){continue}break}b=v[a+8>>2]}gb=a+16|0;gb=d;return b|0}function _ha(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;e=gb-48|0;gb=e;a:{b:{if(v[a+8>>2]!=v[dc(a)>>2]){break b}g=a+8|0;h=a+4|0;c=v[a+4>>2];d=v[a>>2];if(c>>>0>d>>>0){f=c;c=((c-d>>2)+1|0)/-2<<2;i=g,j=Rg(f,v[g>>2],f+c|0),v[i>>2]=j;v[h>>2]=c+v[h>>2];break b}i=e,j=v[dc(a)>>2]-v[a>>2]>>1,v[i+24>>2]=j;v[e+44>>2]=1;d=e+24|0;c=v[Lc(d,e+44|0)>>2];c=Ap(d,c,c>>>2|0,v[a+16>>2]);d=yc(e+16|0,v[a+4>>2]);f=v[yc(e+8|0,v[a+8>>2])>>2];d=v[d>>2];v[22656]=0;U(1082,c|0,d|0,f|0);d=v[22656];v[22656]=0;if((d|0)==1){break a}xc(a,c);xc(h,c+4|0);xc(g,c+8|0);xc(dc(a),dc(c));gj(c)}hn(v[a+16>>2],v[a+8>>2],b);v[a+8>>2]=v[a+8>>2]+4;gb=e+48|0;return}a=P()|0;O()|0;gj(c);S(a|0);L()}function Yq(a,b,c){var d=0,e=0,f=0;d=Kb(a);a=Ab(b);v[22656]=0;R(60,d|0,a|0);a=v[22656];v[22656]=0;if((a|0)!=1){a:{if(Ab(b)){while(1){f=v[yk(b,e)>>2];a=32;b:{c:{while(1){if(v[(a<<2)+c>>2]!=(f|0)){a=a+1|0;if(a>>>0<256){continue}break c}break}v[22656]=0;R(61,d|0,a<<24>>24);a=v[22656];v[22656]=0;if((a|0)!=1){break b}break a}a=0;while(1){d:{if(v[(a<<2)+c>>2]==(f|0)){v[22656]=0;R(61,d|0,a<<24>>24);a=v[22656];v[22656]=0;if((a|0)!=1){break b}break a}if(a>>>0>30){break d}a=a+1|0;if(a>>>0<256){continue}}break}v[22656]=0;R(61,d|0,63);a=v[22656];v[22656]=0;if((a|0)!=1){break b}break a}e=e+1|0;if(Ab(b)>>>0>e>>>0){continue}break}}return}}a=P()|0;O()|0;vb(d);S(a|0);L()}function Mga(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=gb-80|0;gb=d;f=Qf(d+48|0);v[22656]=0;e=Q(1172,b|0,f|0)|0;g=v[22656];v[22656]=0;a:{b:{c:{if((g|0)!=1){if(e){break c}v[a>>2]=0;v[a+4>>2]=0;v[a+24>>2]=0;v[a+16>>2]=0;v[a+20>>2]=0;v[a+8>>2]=0;v[a+12>>2]=0;v[22656]=0;T(1173,a|0)|0;a=v[22656];v[22656]=0;if((a|0)!=1){break b}}break a}e=cn(f);v[22656]=0;U(288,d|0,b|0,e|0);g=v[22656];v[22656]=0;if((g|0)==1){break a}g=kc(d+24|0,d);Vc(f+8|0,g);xb(g);xb(d);d:{if(c>>>0<2){break d}e=(e>>>0)%(c>>>0)|0;if(!e){break d}v[22656]=0;Q(318,b|0,c-e|0)|0;b=v[22656];v[22656]=0;if((b|0)!=1){break d}break a}$j(a,f)}ed(f);gb=d+80|0;return}a=P()|0;O()|0;ed(f);S(a|0);L()}function b9(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0;if(y[a+4>>2]<y[wb(a)>>2]){c=gb-16|0;gb=c;a=cq(c,a,1);Jy(v[a+4>>2],b);v[a+4>>2]=v[a+4>>2]+16;$b(a);gb=c+16|0;return}e=gb-32|0;gb=e;c=wb(a);c=WI(e+8|0,fy(a,uf(a)+1|0),uf(a),c);Jy(v[c+8>>2],b);v[c+8>>2]=v[c+8>>2]+16;b=c;h=c+4|0;f=h;d=a;i=v[a>>2];a=v[a+4>>2];if((i|0)!=(a|0)){g=v[f>>2];while(1){a=a-16|0;Jy(g-16|0,a);g=v[f>>2]-16|0;v[f>>2]=g;if((a|0)!=(i|0)){continue}break}}wc(d,h);wc(d+4|0,b+8|0);wc(wb(d),dc(b));v[b>>2]=v[b+4>>2];a=c;b=a;d=v[a+8>>2];c=v[a+4>>2];if((d|0)!=(c|0)){while(1){d=d-16|0;v[b+8>>2]=d;Gk(d);d=v[b+8>>2];if((c|0)!=(d|0)){continue}break}}b=v[a>>2];if(b){CK(b,Wx(a))}gb=e+32|0}function th(a,b){var c=C(0),d=C(0),e=C(0),f=C(0),g=C(0);d=cM(a);c=C(C(z[a+4224>>2]*C(1.899999976158142))+C(.10000000149011612));f=z[a+4268>>2];e=oe(C(10),C(C(C(C(C(v[((b<<2)+a|0)+4292>>2])/f)*C(-60))/C(C(z[a+4220>>2]*C(19.899999618530273))+C(.10000000149011612)))/C(20)));c=C(C(oe(e,C(C(2)-C(C(2)/c)))+C(-1))/C(C(1)-Qp(c>C(1)?C(3.1415927410125732):C(d*C(C(6.2831854820251465)/f)))));a:{if(c==C(0)){break a}f=C(c+c);d=C(C(-2)-f);c=C(K(C(C(d*d)+C(C(c*c)*C(-4)))));g=C(C(c-d)/f);if(!(C(D(g))>C(1))){break a}g=C(C(C(-d)-c)/f)}b=(b<<3)+a|0;z[b+4404>>2]=g;z[b+4400>>2]=e;c=z[a+4272>>2];c=C(c*c);d=C(C(1)-c);e=C(e*e);return C(c+C(d*C(d*C(e/C(C(1)-C(e*c))))))}function wja(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;e=gb-32|0;gb=e;j=v[a+24>>2];k=v[a+20>>2];l=v[a+16>>2];g=v[a+4>>2];f=g;b=v[a>>2];v[e+24>>2]=b;v[e+28>>2]=f;g=v[a+12>>2];v[e+16>>2]=v[a+8>>2];v[e+20>>2]=g;if(d){while(1){m=b>>>18|0;h=((((f&2147483647)<<1|b>>>31)&2147483646)<<1)+l|0;g=0;b=1;while(1){i=g<<1;f=u[i+h>>1];v[(e+8|0)+(g<<2)>>2]=f+((B(u[(i|4)+h>>1]-f|0,m)|0)/16384|0);f=b;b=0;g=1;if(f){continue}break}v[c>>2]=v[c>>2]+B(v[e+8>>2],k);v[c+4>>2]=v[c+4>>2]+B(v[e+12>>2],j);Ub(e+24|0,e+16|0);d=d-1|0;if(d){c=c+8|0;b=v[e+24>>2];f=v[e+28>>2];continue}break}b=v[e+24>>2];f=v[e+28>>2]}v[a>>2]=b;v[a+4>>2]=f;gb=e+32|0}function $U(a){var b=0,c=0,d=0;a:{b:{if((w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24))!=1196314451){break b}b=a+4|0;if((w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24))>>>0<1108){break b}b=w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24);c=a+1104|0;if((b-1108|0)!=(w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24))|b>>>0>262144){break b}b=a+1094|0;if(w[b|0]|w[b+1|0]<<8){break b}b=a+1096|0;c=w[b+1|0]<<8;d=w[b+2|0]<<16|w[b+3|0]<<24;if(!(w[b|0]|c|d)|(d|(c|w[b|0]))>>>0>4){break b}if(!fv(a+8|0)){break b}c=a+1094|0;b=a+40|0;while(1){if(w[b+32|0]>15|w[b+33|0]>64){break b}if(!fv(b)){break b}a=1;b=b+34|0;if((c|0)!=(b|0)){continue}break}break a}a=0}return a}function yma(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;g=gb-608|0;gb=g;c=gb-32|0;gb=c;b=c+24|0;e=g+8|0;kV(b,e);f=yb(b);b=v[c+28>>2];d=v[c+24>>2];v[c+8>>2]=d;v[c+12>>2]=b;v[c>>2]=d;v[c+4>>2]=b;d=c+16|0;b=a;hd(d,b,c);d=yb(d);if((d|0)==(f|0)){bd(b,yb(c+24|0))}gb=c+32|0;c=(d|0)==(f|0);if(!c){jV(e)}b=-1;a:{if(!c){break a}b=0;if(!tV(g+8|0)){break a}b=-1;if(!Wf(a,1024)){break a}b=0;f=gb-1024|0;gb=f;c=gb-32|0;gb=c;e=c+24|0;eC(e,f);e=yb(e);d=v[c+28>>2];h=v[c+24>>2];v[c+8>>2]=h;v[c+12>>2]=d;v[c>>2]=h;v[c+4>>2]=d;d=c+16|0;hd(d,a,c);d=yb(d);if((d|0)==(e|0)){bd(a,yb(c+24|0))}gb=c+32|0;if((d|0)==(e|0)){b=hC(f,0)>>>0<17}gb=f+1024|0}gb=g+608|0;return b|0}function yla(a,b){a=a|0;b=b|0;var c=0,d=0;d=gb-32|0;gb=d;ud(b,0);cD(d,a+1|0);c=d+16|0;Bc(c,d);v[22656]=0;Q(303,b+43|0,c|0)|0;c=v[22656];v[22656]=0;if((c|0)!=1){vb(d+16|0);c=a+73|0;v[b+24>>2]=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);c=a+54|0;v[b>>2]=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);c=a+58|0;v[b+4>>2]=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);c=a+62|0;if(w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24)){v[b+8>>2]=(w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24))+1}u[b+30>>1]=(w[a+68|0]<<1)+2;u[b+34>>1]=x[b+34>>1]&65533|w[a|0]>>>6&2;qc(b+8|0,v[b>>2]);qc(b+4|0,v[b+8>>2]);gb=d+32|0;return}a=P()|0;O()|0;vb(d+16|0);S(a|0);L()}function L4(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0;a:{g=gb+-64|0;gb=g;Kh(g+16|0,c);v[22656]=0;R(144,g+28|0,d|0);d=v[22656];v[22656]=0;c=1;b:{c:{if((d|0)==1){break c}v[22656]=0;R(144,g+40|0,e|0);c=v[22656];v[22656]=0;if((c|0)==1){c=2;break c}v[22656]=0;R(144,g+52|0,f|0);c=v[22656];v[22656]=0;if((c|0)==1){c=3;break c}c=g+16|0;v[g+8>>2]=c;v[g+12>>2]=c+48;v[22656]=0;c=v[g+12>>2];v[g>>2]=v[g+8>>2];v[g+4>>2]=c;U(146,a|0,b|0,g|0);a=v[22656];v[22656]=0;if((a|0)==1){c=P()|0;O()|0;pG(g+16|0);break b}pG(g+16|0);gb=g- -64|0;break a}a=(g+16|0)+B(c,12)|0;c=P()|0;O()|0;while(1){a=vb(a-12|0);if((a|0)!=(g+16|0)){continue}break}}S(c|0);L()}}function wea(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;a:{d=gb-16|0;gb=d;c=b;wb(b);e=a;h=sN(a,d+8|0);b:{f=Kg(b);if(!f){break b}v[22656]=0;R(617,e|0,f|0);g=v[22656];v[22656]=0;if((g|0)!=1){g=v[c+4>>2];c=v[c>>2];v[22656]=0;Y(1496,e|0,c|0,g|0,f|0);c=v[22656];v[22656]=0;if((c|0)!=1){break b}}a=P()|0;O()|0;zv(h);S(a|0);L()}gb=d+16|0;v[a+20>>2]=v[b+20>>2];c=v[b+16>>2];v[a+12>>2]=v[b+12>>2];v[a+16>>2]=c;v[22656]=0;c=Q(1495,a+24|0,b+24|0)|0;d=v[22656];v[22656]=0;c:{d:{if((d|0)!=1){v[22656]=0;Q(69,a+36|0,b+36|0)|0;d=v[22656];v[22656]=0;if((d|0)==1){break d}v[a+48>>2]=v[b+48>>2];break a}a=P()|0;O()|0;break c}a=P()|0;O()|0;Nc(c)}jn(e);S(a|0);L()}}function pB(a,b,c){a=a|0;b=b|0;c=c|0;a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{b=b&15;switch(b-3|0){case 2:break j;case 1:break k;case 0:break l;case 10:case 11:break b;case 9:break c;case 8:break d;case 7:break e;case 6:break f;case 5:break g;case 4:break h;case 3:break i;default:break a}}t[a+798|0]=0;return}t[a+798|0]=1;return}t[a+798|0]=2;return}t[a+798|0]=3;return}t[a+730|0]=w[a+730|0]&254;return}t[a+730|0]=w[a+730|0]|1;return}t[a+738|0]=w[a+738|0]&254;return}t[a+738|0]=w[a+738|0]|1;return}t[a+746|0]=w[a+746|0]&254;return}t[a+746|0]=w[a+746|0]|1;return}if(v[c+480180>>2]!=16777216){break a}c=a;a=w[a+746|0];t[c+746|0]=(b|0)==13?a&238|1:a|17}}function gU(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;d=gb-16|0;gb=d;f=b,g=Xb(w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24)),v[f>>2]=g;t[d+15|0]=w[a+4|0];t[d+14|0]=64;f=b,g=w[ac(d+15|0,d+14|0)|0]<<2,u[f+30>>1]=g;c=a+6|0;f=b,g=Xb(w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24)),v[f+4>>2]=g;a=a+10|0;a=Xb(w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24))+Xb(w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24))|0;v[b+8>>2]=a;e=v[b+4>>2];c=v[b>>2];if(e>>>0>=c>>>0){e=c-1|0;v[b+4>>2]=e}if(a>>>0>c>>>0){v[b+8>>2]=c;a=c}a:{if(a>>>0<e>>>0){v[b+4>>2]=0;v[b+8>>2]=0;break a}if(a>>>0<=e>>>0){break a}u[b+34>>1]=x[b+34>>1]|2;f=Fe(b+68|0,0),g=e,v[f>>2]=g}gb=d+16|0}function FJ(a,b,c){a=a|0;b=b|0;c=+c;var d=0,e=0;d=gb-16|0;gb=d;a:{b:{c:{d:{if((b|0)>=0){if((io(a+8|0)|0)>(b|0)){break d}}a=ba(8)|0;v[22656]=0;d=Q(70,d|0,7993)|0;b=v[22656];v[22656]=0;if((b|0)==1){break c}rc(a,d);v[22656]=0;U(186,a|0,54952,1936);a=v[22656];v[22656]=0;if((a|0)!=1){break a}b=P()|0;O()|0;vb(d);break b}if(c<0|c>1){a=ba(8)|0;v[22656]=0;d=Q(70,d|0,9006)|0;b=v[22656];v[22656]=0;if((b|0)!=1){rc(a,d);v[22656]=0;U(186,a|0,54952,1936);a=v[22656];v[22656]=0;if((a|0)!=1){break a}b=P()|0;O()|0;vb(d);break b}b=P()|0;O()|0;ca(a|0);break b}e=Ro(c*64);v[(v[a+32>>2]+B(b,872)|0)+1075740>>2]=e;gb=d+16|0;return}b=P()|0;O()|0;ca(a|0)}S(b|0)}L()}function K4(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0;e=gb-32|0;gb=e;a:{if(KH(c)){while(1){if(a>>>d&1){i=(d<<2)+c|0,j=LH(d,b),v[i>>2]=j}d=d+1|0;if((d|0)!=6){continue}break}break a}while(1){h=(e+8|0)+(d<<2)|0;f=1<<d&a;if(f|!c){f=LH(d,f?b:18726)}else{f=v[(d<<2)+c>>2]}v[h>>2]=f;g=((f|0)!=0)+g|0;d=d+1|0;if((d|0)!=6){continue}break}c=77024;b:{c:{switch(g|0){case 0:break a;case 1:break c;default:break b}}if(v[e+8>>2]!=76996){break b}c=77048;break a}c=Cd(24);if(!c){break a}a=v[e+12>>2];v[c>>2]=v[e+8>>2];v[c+4>>2]=a;a=v[e+28>>2];v[c+16>>2]=v[e+24>>2];v[c+20>>2]=a;a=v[e+20>>2];v[c+8>>2]=v[e+16>>2];v[c+12>>2]=a}gb=e+32|0;return c|0}function q2(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;c=gb-32|0;gb=c;a:{b:{c:{d:{if(i=gd(b),j=1,k=v[b+12>>2],k?i:j){Kb(a);break d}f=gb-16|0;gb=f;e=Kb(c+16|0);d=Ab(b);g=Nf(11521);h=Jb(b);v[22656]=0;Y(116,e|0,h|0,d|0,d+g|0);d=v[22656];v[22656]=0;e:{if((d|0)!=1){v[22656]=0;W(117,e|0,11521,g|0)|0;d=v[22656];v[22656]=0;if((d|0)!=1){break e}}a=P()|0;O()|0;vb(e);S(a|0);L()}gb=f+16|0;v[22656]=0;R(153,c|0,b+12|0);b=v[22656];v[22656]=0;if((b|0)==1){break c}v[22656]=0;U(3,a|0,c+16|0,c|0);a=v[22656];v[22656]=0;if((a|0)==1){break b}vb(c);vb(c+16|0)}gb=c+32|0;return}b=P()|0;O()|0;break a}b=P()|0;O()|0;vb(c)}vb(c+16|0);S(b|0);L()}function Ula(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=gb-80|0;gb=d;e=Qf(d+48|0);v[22656]=0;c=Q(825,b|0,e|0)|0;f=v[22656];v[22656]=0;a:{b:{c:{if((f|0)!=1){if(c){break c}v[a>>2]=0;v[a+4>>2]=0;v[a+24>>2]=0;v[a+16>>2]=0;v[a+20>>2]=0;v[a+8>>2]=0;v[a+12>>2]=0;v[22656]=0;T(826,a|0)|0;a=v[22656];v[22656]=0;if((a|0)!=1){break b}}break a}c=e+4|0;if((w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24))>>>0>=9){c=(w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24))-8|0}else{c=0}v[22656]=0;U(288,d|0,b|0,c|0);b=v[22656];v[22656]=0;if((b|0)==1){break a}b=kc(d+24|0,d);Vc(e+8|0,b);xb(b);xb(d);$j(a,e)}ed(e);gb=d+80|0;return}a=P()|0;O()|0;ed(e);S(a|0);L()}function md(a){var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;a:{d=v[a+112>>2];b=v[a+116>>2];b:{if(d|b){g=v[a+124>>2];if((b|0)<=(g|0)&d>>>0<=y[a+120>>2]|(b|0)<(g|0)){break b}}h=Sx(a);if((h|0)>=0){break a}}v[a+104>>2]=0;return-1}i=v[a+4>>2];g=a;c=v[a+116>>2];j=c;b=v[a+8>>2];d=b;f=v[a+112>>2];c:{if(!(c|f)){break c}d=b;e=v[a+120>>2]^-1;f=e+f|0;c=(v[a+124>>2]^-1)+j|0;c=f>>>0<e>>>0?c+1|0:c;e=b-i|0;j=e;e=e>>31;if((e|0)<=(c|0)&f>>>0>=j>>>0|(c|0)>(e|0)){break c}d=f+i|0}v[g+104>>2]=d;if(b){d=a;g=(b-i|0)+1|0;c=g;b=c+v[a+120>>2]|0;a=v[a+124>>2]+(c>>31)|0;v[d+120>>2]=b;v[d+124>>2]=b>>>0<c>>>0?a+1|0:a}a=i-1|0;if(w[a|0]!=(h|0)){t[a|0]=h}return h}function xja(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;e=gb-32|0;gb=e;i=v[a+24>>2];j=v[a+20>>2];k=v[a+16>>2];b=v[a+4>>2];f=v[a>>2];v[e+24>>2]=f;v[e+28>>2]=b;g=v[a+12>>2];v[e+16>>2]=v[a+8>>2];v[e+20>>2]=g;if(d){while(1){l=f>>>10&4194048;h=(((b&2147483647)<<1|f>>>31)&-2)+k|0;g=0;b=1;while(1){f=t[g+h|0];v[(e+8|0)+(g<<2)>>2]=((B(t[(g|2)+h|0]-f|0,l)|0)/16384|0)+(f<<8);f=b;b=0;g=1;if(f){continue}break}v[c>>2]=v[c>>2]+B(v[e+8>>2],j);v[c+4>>2]=v[c+4>>2]+B(v[e+12>>2],i);Ub(e+24|0,e+16|0);d=d-1|0;if(d){c=c+8|0;f=v[e+24>>2];b=v[e+28>>2];continue}break}f=v[e+24>>2];b=v[e+28>>2]}v[a>>2]=f;v[a+4>>2]=b;gb=e+32|0}function vja(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;b=gb-16|0;gb=b;g=v[a+40>>2];h=v[a+36>>2];l=v[a+16>>2];f=v[a+4>>2];e=f;i=v[a>>2];v[b+8>>2]=i;v[b+12>>2]=e;f=v[a+12>>2];v[b>>2]=v[a+8>>2];v[b+4>>2]=f;a:{if(d){while(1){j=v[a+32>>2];k=e+l|0;e=t[k|0];h=v[a+28>>2]+h|0;f=h>>12;e=((B(t[k+1|0]-e|0,i>>>10&4194048)|0)/16384|0)+(e<<8)|0;v[c>>2]=v[c>>2]+B(f,e);g=g+j|0;j=g>>12;v[c+4>>2]=v[c+4>>2]+B(e,j);Ub(b+8|0,b);d=d-1|0;if(d){c=c+8|0;i=v[b+8>>2];e=v[b+12>>2];continue}break}i=v[b+8>>2];e=v[b+12>>2];break a}j=g>>12;f=h>>12}v[a+40>>2]=g;v[a+20>>2]=f;v[a+36>>2]=h;v[a+24>>2]=j;v[a>>2]=i;v[a+4>>2]=e;gb=b+16|0}function Xda(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;a:{e=gb+-64|0;gb=e;d=v[a+28>>2];oo(v[v[d>>2]-12>>2]+d|0,0);d=v[v[b>>2]+4>>2];if(d){h=v[a+28>>2];f=v[a+12>>2];g=d;d=v[a+8>>2]+d|0;f=g>>>0>d>>>0?f+1|0:f;d=sh(e+48|0,d,f);f=v[d+12>>2];v[e+16>>2]=v[d+8>>2];v[e+20>>2]=f;g=v[d+4>>2];v[e+8>>2]=v[d>>2];v[e+12>>2]=g;lk(h,e+8|0)}d=e+24|0;se(d,v[a+28>>2]);g=v[d+12>>2];v[e+40>>2]=v[d+8>>2];v[e+44>>2]=g;kS(v[a+28>>2],c,v[v[b>>2]+8>>2]);c=v[b>>2];b=qo(d,lc(a+32|0,v[v[b>>2]>>2]),x[v[b>>2]+12>>1]);v[22656]=0;da(1526,a|0,c|0,b|0,e+40|0)|0;a=v[22656];v[22656]=0;if((a|0)!=1){Hb(b);gb=e- -64|0;break a}a=P()|0;O()|0;Hb(b);S(a|0);L()}}function M8(a,b,c){a=a|0;b=+b;c=c|0;var d=0,e=0,f=0;d=gb-96|0;gb=d;v[d+88>>2]=c;c=v[a>>2];e=v[a+4>>2];f=v[a+12>>2];v[d+56>>2]=v[a+8>>2];v[d+60>>2]=f;v[d+48>>2]=c;v[d+52>>2]=e;a=Ud(d+40|0);c=v[d+60>>2];v[d+24>>2]=v[d+56>>2];v[d+28>>2]=c;v[22656]=0;c=v[d+52>>2];v[d+16>>2]=v[d+48>>2];v[d+20>>2]=c;c=v[a+4>>2];v[d+8>>2]=v[a>>2];v[d+12>>2]=c;U(2073,d- -64|0,d+16|0,d+8|0);a=v[22656];v[22656]=0;a:{b:{if((a|0)!=1){a=v[pi(d+32|0,d+88|0)>>2];v[22656]=0;b=+za(2074,d- -64|0,+b,a|0);a=v[22656];v[22656]=0;if((a|0)==1){break b}xb(d- -64|0);eg(d+88|0);gb=d+96|0;return+b}a=P()|0;O()|0;break a}a=P()|0;O()|0;xb(d- -64|0)}eg(d+88|0);S(a|0);L()}function zpa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;d=gb-32|0;gb=d;ud(b,0);ki(d,1,a);c=d+16|0;Bc(c,d);v[22656]=0;Q(303,b+43|0,c|0)|0;c=v[22656];v[22656]=0;if((c|0)!=1){e=d+16|0;vb(e);c=a+32|0;v[b+24>>2]=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);c=a+13|0;u[b+34>>1]=x[b+34>>1]&65533|(w[c|0]|w[c+1|0]<<8)<<1&2;c=a+16|0;v[b>>2]=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);c=a+20|0;v[b+4>>2]=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);c=a+24|0;v[b+8>>2]=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);t[d+16|0]=w[a+15|0];t[d|0]=64;f=b,g=w[ac(e,d)|0]<<2,u[f+30>>1]=g;gb=d+32|0;return}a=P()|0;O()|0;vb(d+16|0);S(a|0);L()}function ll(a,b,c){var d=0,e=0,f=0;e=gb-16|0;gb=e;v[a+4>>2]=0;d=4;a:{b:{c:{if(!w[uj(e+8|0,a,1)|0]){break c}d=v[v[a>>2]-12>>2];v[22656]=0;d=v[(a+d|0)+24>>2];f=v[22656];v[22656]=0;d:{if((f|0)==1){break d}v[22656]=0;b=W(2317,d|0,b|0,c|0)|0;d=v[22656];v[22656]=0;if((d|0)==1){break d}v[a+4>>2]=b;d=(b|0)==(c|0)?0:6;break c}b=V(0)|0;O()|0;Z(b|0)|0;d=1;tj(v[v[a>>2]-12>>2]+a|0,1);if(v[(v[v[a>>2]-12>>2]+a|0)+20>>2]&1){v[22656]=0;X(2027);a=v[22656];v[22656]=0;if((a|0)!=1){break a}a=P()|0;O()|0;v[22656]=0;X(20);b=v[22656];v[22656]=0;if((b|0)==1){break b}S(a|0);L()}$()}ih(v[v[a>>2]-12>>2]+a|0,d);gb=e+16|0;return}V(0)|0;O()|0;Bb()}L()}function bga(a){a=a|0;var b=0,c=0,d=0;c=a+1298224|0;b=a+1074992|0;while(1){v[b+104>>2]=0;v[b+656>>2]=0;v[b+76>>2]=0;v[b+16>>2]=0;b=b+872|0;if((c|0)!=(b|0)){continue}break}BN(a+484344|0);Se(a+1298268|0);Se(a+1298280|0);Se(a+1298292|0);xD(a+1298368|0);c=a+900380|0;b=a+484380|0;while(1){Pl(b);b=b+104|0;if((c|0)!=(b|0)){continue}break}c=a+901404|0;b=a+900380|0;while(1){d=v[b>>2];if(d){Yb(sv(d))}v[b>>2]=0;b=b+4|0;if((c|0)!=(b|0)){continue}break}c=a+946300|0;b=a+906300|0;while(1){DM(b);b=b+160|0;if((c|0)!=(b|0)){continue}break}v[a+480180>>2]=0;v[a+480184>>2]=0;a=a+480186|0;u[a>>1]=0;u[a+2>>1]=0;u[a+4>>1]=0;u[a+6>>1]=0;return 1}function uja(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;b=gb-16|0;gb=b;g=v[a+40>>2];h=v[a+36>>2];l=v[a+16>>2];f=v[a+4>>2];e=f;i=v[a>>2];v[b+8>>2]=i;v[b+12>>2]=e;f=v[a+12>>2];v[b>>2]=v[a+8>>2];v[b+4>>2]=f;a:{if(d){while(1){j=v[a+32>>2];k=(e<<1)+l|0;e=u[k>>1];h=v[a+28>>2]+h|0;f=h>>12;e=e+((B(u[k+2>>1]-e|0,i>>>18|0)|0)/16384|0)|0;v[c>>2]=v[c>>2]+B(f,e);g=g+j|0;j=g>>12;v[c+4>>2]=v[c+4>>2]+B(e,j);Ub(b+8|0,b);d=d-1|0;if(d){c=c+8|0;i=v[b+8>>2];e=v[b+12>>2];continue}break}i=v[b+8>>2];e=v[b+12>>2];break a}j=g>>12;f=h>>12}v[a+40>>2]=g;v[a+20>>2]=f;v[a+36>>2]=h;v[a+24>>2]=j;v[a>>2]=i;v[a+4>>2]=e;gb=b+16|0}function Yda(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0;e=gb+-64|0;gb=e;v[e+56>>2]=d;d=v[a+28>>2];oo(v[v[d>>2]-12>>2]+d|0,0);d=v[v[b>>2]+4>>2];if(d){g=v[a+28>>2];h=v[a+12>>2];f=v[a+8>>2]+d|0;h=f>>>0<d>>>0?h+1|0:h;f=sh(e+40|0,f,h);d=v[f+12>>2];v[e+8>>2]=v[f+8>>2];v[e+12>>2]=d;d=v[f+4>>2];v[e>>2]=v[f>>2];v[e+4>>2]=d;lk(g,e)}g=e+16|0;se(g,v[a+28>>2]);d=v[g+12>>2];v[e+32>>2]=v[g+8>>2];v[e+36>>2]=d;iN(v[a+28>>2],c,v[e+56>>2]);c=v[b>>2];b=qo(g,lc(a+32|0,v[v[b>>2]>>2]),x[v[b>>2]+12>>1]);v[22656]=0;da(1526,a|0,c|0,b|0,e+32|0)|0;a=v[22656];v[22656]=0;if((a|0)!=1){Hb(b);gb=e- -64|0;return}a=P()|0;O()|0;Hb(b);S(a|0);L()}function Wda(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0;e=gb+-64|0;gb=e;v[e+56>>2]=d;d=v[a+28>>2];oo(v[v[d>>2]-12>>2]+d|0,0);d=v[v[b>>2]+4>>2];if(d){g=v[a+28>>2];h=v[a+12>>2];f=v[a+8>>2]+d|0;h=f>>>0<d>>>0?h+1|0:h;f=sh(e+40|0,f,h);d=v[f+12>>2];v[e+8>>2]=v[f+8>>2];v[e+12>>2]=d;d=v[f+4>>2];v[e>>2]=v[f>>2];v[e+4>>2]=d;lk(g,e)}g=e+16|0;se(g,v[a+28>>2]);d=v[g+12>>2];v[e+32>>2]=v[g+8>>2];v[e+36>>2]=d;$M(c,v[a+28>>2],v[e+56>>2]);c=v[b>>2];b=qo(g,lc(a+32|0,v[v[b>>2]>>2]),x[v[b>>2]+12>>1]);v[22656]=0;da(1526,a|0,c|0,b|0,e+32|0)|0;a=v[22656];v[22656]=0;if((a|0)!=1){Hb(b);gb=e- -64|0;return}a=P()|0;O()|0;Hb(b);S(a|0);L()}function Pea(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=gb-80|0;gb=d;e=Qf(d+48|0);v[22656]=0;g=Q(1472,b|0,e|0)|0;f=v[22656];v[22656]=0;a:{b:{c:{if((f|0)!=1){if(g){break c}v[a>>2]=0;v[a+4>>2]=0;v[a+24>>2]=0;v[a+16>>2]=0;v[a+20>>2]=0;v[a+8>>2]=0;v[a+12>>2]=0;v[22656]=0;T(1473,a|0)|0;a=v[22656];v[22656]=0;if((a|0)!=1){break b}}break a}g=cn(e);v[22656]=0;U(288,d|0,b|0,g|0);f=v[22656];v[22656]=0;if((f|0)==1){break a}f=kc(d+24|0,d);Vc(e+8|0,f);xb(f);xb(d);d:{if(!(g&1)|c>>>0<2){break d}v[22656]=0;Q(318,b|0,1)|0;b=v[22656];v[22656]=0;if((b|0)!=1){break d}break a}$j(a,e)}ed(e);gb=d+80|0;return}a=P()|0;O()|0;ed(e);S(a|0);L()}function xG(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;e=gb-48|0;gb=e;f=Jb(b);g=Ab(b);i=Jb(c);j=Ab(c);h=-1;a:{if(!g){break a}d=f;g=g+d|0;while(1){if(tp(i,j,d)){d=d+1|0;if((g|0)!=(d|0)){continue}break a}break}h=d-f|0}b:{c:{if((h|0)!=-1){k=e,l=zd(b),v[k+32>>2]=l;c=Fd(e+40|0,e+32|0);k=e,l=zd(b),v[k+8>>2]=l;k=e,l=we(e+8|0,h),v[k+16>>2]=l;d=Fd(e+24|0,e+16|0);jG(b,v[c>>2],v[d>>2]);break c}if(!Ab(b)){break c}f=Jb(b);h=Ab(b);g=Jb(c);d=-1;i=Ab(c);if(i){c=f+h|0;d:{while(1){if((c|0)==(f|0)){break d}c=c-1|0;if(!tp(g,i,c)){continue}break}d=c-f|0}}if((Ab(b)-1|0)!=(d|0)){break c}Kb(a);break b}Dc(a,b)}gb=e+48|0}function VI(a,b,c,d,e){var f=0,g=0,h=0,i=0;f=gb-208|0;gb=f;v[f+204>>2]=c;c=f+160|0;Qb(c,0,40);v[f+200>>2]=v[f+204>>2];a:{if((dy(0,b,f+200|0,f+80|0,c,d,e)|0)<0){b=-1;break a}h=v[a+76>>2]>=0;c=v[a>>2];if(t[a+74|0]<=0){v[a>>2]=c&-33}i=c&32;b:{if(v[a+48>>2]){b=dy(a,b,f+200|0,f+80|0,f+160|0,d,e);break b}v[a+48>>2]=80;g=f+80|0;v[a+16>>2]=g;v[a+28>>2]=f;v[a+20>>2]=f;c=v[a+44>>2];v[a+44>>2]=f;d=dy(a,b,f+200|0,g,f+160|0,d,e);b=d;if(!c){break b}kb[v[a+36>>2]](a,0,0)|0;v[a+48>>2]=0;v[a+44>>2]=c;v[a+28>>2]=0;v[a+16>>2]=0;b=v[a+20>>2];v[a+20>>2]=0;b=b?d:-1}c=a;a=v[a>>2];v[c>>2]=a|i;b=a&32?-1:b;if(!h){break a}}gb=f+208|0;return b}function Ija(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0;b=gb-16|0;gb=b;h=v[a+40>>2];i=v[a+36>>2];k=v[a+16>>2];e=v[a+4>>2];f=e;g=v[a>>2];v[b+8>>2]=g;v[b+12>>2]=e;e=v[a+12>>2];v[b>>2]=v[a+8>>2];v[b+4>>2]=e;a:{if(d){while(1){f=((((f&2147483647)<<1|g>>>31)&2147483646)<<1)+k|0;g=u[f+2>>1];j=v[a+32>>2];i=v[a+28>>2]+i|0;e=i>>12;v[c>>2]=v[c>>2]+B(e,u[f>>1]);h=h+j|0;j=h>>12;v[c+4>>2]=v[c+4>>2]+B(g,j);Ub(b+8|0,b);d=d-1|0;if(d){c=c+8|0;g=v[b+8>>2];f=v[b+12>>2];continue}break}g=v[b+8>>2];f=v[b+12>>2];break a}j=h>>12;e=i>>12}v[a+40>>2]=h;v[a+20>>2]=e;v[a+36>>2]=i;v[a+24>>2]=j;v[a>>2]=g;v[a+4>>2]=f;gb=b+16|0}function RZ(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;d=gb-32|0;gb=d;ud(b,0);ki(d,1,a+33|0);c=d+16|0;Bc(c,d);v[22656]=0;Q(303,b+43|0,c|0)|0;c=v[22656];v[22656]=0;a:{b:{if((c|0)!=1){c=d+16|0;vb(c);e=a+50|0;v[b>>2]=w[e|0]|w[e+1|0]<<8;e=a+52|0;v[b+24>>2]=w[e|0]|w[e+1|0]<<8;t[d+16|0]=w[a+54|0];t[d|0]=64;f=b,g=w[ac(c,d)|0]<<2,u[f+30>>1]=g;c=a+55|0;v[b+4>>2]=w[c|0]|w[c+1|0]<<8;c=a+57|0;c=w[c|0]|w[c+1|0]<<8;v[b+8>>2]=c;if((c|0)!=65535){break b}v[b+4>>2]=0;v[b+8>>2]=0;break a}a=P()|0;O()|0;vb(d+16|0);S(a|0);L()}if(!w[a|0]){break a}a=v[b+8>>2];if(a>>>0<=v[b+4>>2]+2>>>0|a>>>0>y[b>>2]){break a}u[b+34>>1]=x[b+34>>1]|2}gb=d+32|0}function $A(a,b,c,d,e){var f=0,g=0,h=0,i=0;g=gb-16|0;gb=g;h=Ol(a,b);a:{if((h|0)==255){break a}if(wk(a)){break a}b:{if(c>>>0>6208431){i=7;c=1023;break b}f=7;c:{if(c>>>0>3104215){break c}f=6;if(c>>>0>1552107){break c}f=5;if(c>>>0>776053){break c}f=4;if(c>>>0>388026){break c}f=3;if(c>>>0>194013){break c}f=2;if(c>>>0>97006){break c}f=c>>>0>48503}i=f;c=kqa(1<<20-f,0,c,0)+24858e3|0;f=jb;c=Qc(nqa(c,c>>>0<24858e3?f+1|0:f,49716e3,0),jb)}if(e){u[g+14>>1]=(b&3)+c;u[g+12>>1]=1023;c=x[Pc(g+14|0,g+12|0)>>1]}e=Hu(h);b=ic(a+4|0,h);t[b|0]=(i<<10|c)>>>8|(d?0:32);Yh(v[a>>2],e|160,c&255);Yh(v[a>>2],e|176,w[b|0]);t[a+530|0]=1}gb=g+16|0}function pY(a,b,c,d,e){var f=0,g=0,h=0,i=0,j=0,k=0;a:{if(!d){break a}i=w[e|0];if(!i|!b){break a}g=d-6|0;j=35>>>g&(g&255)>>>0<6;h=B(c,-6);k=(d-2&255)>>>0>2;while(1){g=a+h|0;f=w[g+3|0];b:{if(!((f-2&255)>>>0>2|k)){c=1;if(w[(a+h|0)+5|0]<224){break b}break a}c=(d|0)==(f|0);if(!(1<<f&2240)|(!j|f>>>0>11)){break b}c=1}c:{if(k){break c}f=a+h|0;if((w[f+2|0]-11&255)>>>0>2){break c}if(w[f+4|0]){break a}}d:{if(!j){break d}f=a+h|0;if((w[f+2|0]-3&255)>>>0>3){break d}if(w[f+4|0]){break a}}e:{if(!c){break e}c=i;a=w[(a+h|0)+5|0];if(a?(c|0)!=(a|0):0){break a}if((a|0)!=(c|0)){break e}t[e|0]=0;return}a=g;b=b-1|0;if(b){continue}break}}}function Vq(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0,k=0;f=gb-16|0;gb=f;g=Nb(a)-1|0;a:{if((Nb(a)|0)==1){break a}while(1){if(x[Cc(a,e)>>1]>=(b|0)){g=e;break a}e=e+1|0;if(e>>>0<Nb(a)-1>>>0){continue}break}}h=x[Cc(a,g)>>1];v[f+12>>2]=0;b:{if((b|0)>=(h|0)){j=f,k=(w[Cc(a,g)+2|0]<<16)/(d|0)|0,v[j+12>>2]=k;break b}e=0;if(g){e=g-1|0;i=(w[Cc(a,e)+2|0]<<16)/(d|0)|0;v[f+12>>2]=i;e=x[Cc(a,e)>>1]}if((b|0)<=(e|0)|e>>>0>=h>>>0){break b}a=((w[Cc(a,g)+2|0]<<16)/(d|0)|0)-i|0;d=a;g=a>>31;a=b-e|0;b=kqa(d,g,a,a>>31);a=h-e|0;j=f,k=Ac(lqa(b,jb,a,a>>31),jb)+i|0,v[j+12>>2]=k}Zd(f+12|0,0,65536);gb=f+16|0;return(B(v[f+12>>2],c)+32768|0)/65536|0}function BJ(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;e=gb-16|0;gb=e;a:{b:{c:{d=a+8|0;d:{if(!wl(d)){if((b|0)<0|(hq(d)|0)<=(b|0)){break d}a=Bk(v[a+32>>2],b+1&65535);u[a+34>>1]=x[a+34>>1]&64511|(c?1024:0);break b}d=wl(d);if((b|0)<0){break d}if((b|0)<(d|0)){break c}}a=ba(8)|0;v[22656]=0;b=Q(70,e|0,3092)|0;c=v[22656];v[22656]=0;e:{if((c|0)!=1){rc(a,b);v[22656]=0;U(186,a|0,54952,1936);a=v[22656];v[22656]=0;if((a|0)!=1){break a}c=P()|0;O()|0;vb(b);break e}c=P()|0;O()|0;ca(a|0)}S(c|0);L()}b=b+1<<2;a=a+32|0;if(!v[(b+v[a>>2]|0)+900380>>2]){break b}a=v[(b+v[a>>2]|0)+900380>>2];t[a+15|0]=w[a+15|0]&253|(c?2:0)}gb=e+16|0;return}L()}function GH(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=gb-16|0;gb=d;gb=d+16|0;e=0;a:{if(!b){break a}b:{if(!c){break b}a=a?a:d+12|0;d=w[b|0];e=d<<24>>24;if((e|0)>=0){v[a>>2]=d;e=(e|0)!=0;break a}d=t[b|0];if(!v[v[115196]>>2]){v[a>>2]=d&57343;e=1;break a}d=(d&255)-194|0;if(d>>>0>50){break b}d=v[(d<<2)+76272>>2];if(d<<B(c,6)-6<0&c>>>0<=3){break b}c=w[b+1|0];e=c>>>3|0;if((e-16|e+(d>>26))>>>0>7){break b}c=c-128|d<<6;if((c|0)>=0){v[a>>2]=c;e=2;break a}d=w[b+2|0]-128|0;if(d>>>0>63){break b}c=d|c<<6;if((c|0)>=0){v[a>>2]=c;e=3;break a}b=w[b+3|0]-128|0;if(b>>>0>63){break b}v[a>>2]=b|c<<6;e=4;break a}v[115137]=25;e=-1}return e|0}function yV(a,b,c,d,e,f,g){var h=0,i=0,j=0,k=0,l=0,m=0,n=0;while(1){m=x[sc(b,l)>>1];n=m+1|0;i=(h&65535)>>>0>m>>>0|m>>>0>127;j=i?j:c>>>0>l>>>0?n:j;k=(k&65535)>>>0>m>>>0?k:n;h=i?h:n;l=l+1|0;if((l|0)!=128){continue}break}Af(b,c);i=v[a+8>>2];a:{b:{c:{if(!f){break c}c=h&65535;if((i+((c<<11)+f|0)|0)!=(lm(a)&-2)){break c}Wc(a,i+(c<<10)|0);if(!jC(a,16,1)){break b}u[e>>1]=8;break b}if(!g|(h&65535)==(j&65535)){break a}Wc(a,i+((j&65535)<<10)|0);h=jC(a,64,1)?h:j}Wc(a,i)}c=k&65535;d:{if(c>>>0>(h&65535)>>>0){if(((d+i|0)+(B(c,x[e>>1])<<8)|0)==(lm(a)|0)){break d}}if(c>>>0>=255){iv(b,254,65534);iv(b,255,65535)}k=h}return k&65535}function sn(a,b,c,d,e,f,g,h){var i=0,j=0,k=0,l=0,m=0,n=0,o=0;k=1;j=d&2147483647;n=j;i=(j|0)==2147418112;l=c;a:{if(i&!c?a|b:i&(c|0)!=0|j>>>0>2147418112){break a}i=h&2147483647;o=i;m=(i|0)==2147418112;j=g;if(m&!g?e|f:m&(g|0)!=0|i>>>0>2147418112){break a}if(!(a|e|(j|l)|(b|f|(n|o)))){return 0}l=d&h;if((l|0)>0|(l|0)>=0){k=-1;if((c|0)==(g|0)&(d|0)==(h|0)?(b|0)==(f|0)&a>>>0<e>>>0|b>>>0<f>>>0:c>>>0<g>>>0&(d|0)<=(h|0)|(d|0)<(h|0)){break a}return(a^e|c^g)!=0|(b^f|d^h)!=0}k=-1;if((c|0)==(g|0)&(d|0)==(h|0)?(b|0)==(f|0)&a>>>0>e>>>0|b>>>0>f>>>0:c>>>0>g>>>0&(d|0)>=(h|0)|(d|0)>(h|0)){break a}k=(a^e|c^g)!=0|(b^f|d^h)!=0}return k}function z$(a,b,c,d,e,f,g,h,i,j){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;var k=0,l=0,m=0,n=0;l=gb-32|0;gb=l;n=v[c>>2];m=v[c+8>>2];k=l;c=v[c+4>>2];v[k+8>>2]=c;v[k+12>>2]=m;v[k+24>>2]=c;v[k+28>>2]=m;v[k+20>>2]=n;v[k+16>>2]=d;v[22656]=0;c=v[k+20>>2];v[k>>2]=v[k+16>>2];v[k+4>>2]=c;a=Ka(1927,a|0,b|0,k|0)|0;b=v[22656];v[22656]=0;a:{b:{if((b|0)==1){a=V(0)|0;O()|0;Z(a|0)|0;v[22656]=0;ja(1922,7685,e|0,f|0,g|0,h|0,i|0,j|0);a=v[22656];v[22656]=0;if((a|0)==1){break b}$();a=-255}gb=l+32|0;break a}a=P()|0;O()|0;v[22656]=0;X(20);b=v[22656];v[22656]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}return a|0}function Jja(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0;b=gb-16|0;gb=b;h=v[a+40>>2];i=v[a+36>>2];k=v[a+16>>2];e=v[a+4>>2];f=e;g=v[a>>2];v[b+8>>2]=g;v[b+12>>2]=e;e=v[a+12>>2];v[b>>2]=v[a+8>>2];v[b+4>>2]=e;a:{if(d){while(1){f=(((f&2147483647)<<1|g>>>31)&-2)+k|0;g=t[f+1|0];j=v[a+32>>2];i=v[a+28>>2]+i|0;e=i>>12;v[c>>2]=v[c>>2]+(B(e,t[f|0])<<8);h=h+j|0;j=h>>12;v[c+4>>2]=v[c+4>>2]+(B(g,j)<<8);Ub(b+8|0,b);d=d-1|0;if(d){c=c+8|0;g=v[b+8>>2];f=v[b+12>>2];continue}break}g=v[b+8>>2];f=v[b+12>>2];break a}j=h>>12;e=i>>12}v[a+40>>2]=h;v[a+20>>2]=e;v[a+36>>2]=i;v[a+24>>2]=j;v[a>>2]=g;v[a+4>>2]=f;gb=b+16|0}function $C(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0;e=gb-16|0;gb=e;d=(c<<3)+a|0;f=w[d+356|0];t[b+12|0]=w[b+12|0]&248|f&1|f<<1&4|f>>>1&2;kh(b,Md(w[d+352|0],2,16));t[b+13|0]=w[d+354|0];t[b+14|0]=w[d+355|0];d=w[d+353|0];t[b+15|0]=d;t[b+16|0]=d;d=0;u[e+14>>1]=0;if(Nb(b)){f=((c|0)!=0)<<1;a=(c<<6)+a|0;while(1){c=a+(d<<2)|0;g=c+160|0;u[e+12>>1]=w[g|0]|w[g+1|0]<<8;g=x[Le(e+14|0,e+12|0)>>1];u[e+14>>1]=g;h=Mb(b,d),i=g,u[h>>1]=i;u[e+14>>1]=x[e+14>>1]+1;c=c+162|0;v[e+8>>2]=(w[c|0]|w[c+1|0]<<8)>>>f;v[e+4>>2]=64;c=v[pd(e+8|0,e+4|0)>>2];h=Mb(b,d),i=c,t[h+2|0]=i;d=d+1|0;if(Nb(b)>>>0>d>>>0){continue}break}}oB(b,4,32);gb=e+16|0}function joa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;c=gb-48|0;gb=c;f=c+24|0;d=f;g=mc(d+8|0);v[22656]=0;e=T(467,b|0)|0;h=v[22656];v[22656]=0;a:{b:{if((h|0)==1){break b}v[22656]=0;U(393,d|0,b|0,e|0);e=v[22656];v[22656]=0;if((e|0)==1){break b}d=v[d>>2];v[22656]=0;Q(318,b|0,d|0)|0;b=v[22656];v[22656]=0;if((b|0)!=1){break a}}a=P()|0;O()|0;gc(g);S(a|0);L()}v[22656]=0;Or(c+16|0,f);b=v[22656];v[22656]=0;c:{if((b|0)==1){break c}v[22656]=0;b=v[c+20>>2];v[c+8>>2]=v[c+16>>2];v[c+12>>2]=b;R(640,a|0,c+8|0);a=v[22656];v[22656]=0;if((a|0)==1){break c}zc(c+24|0);gb=c+48|0;return}a=P()|0;O()|0;zc(c+24|0);S(a|0);L()}function Jga(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=gb-80|0;gb=c;d=Qf(c+48|0);v[22656]=0;f=Q(1179,b|0,d|0)|0;e=v[22656];v[22656]=0;a:{b:{c:{if((e|0)!=1){if(f){break c}v[a>>2]=0;v[a+4>>2]=0;v[a+24>>2]=0;v[a+16>>2]=0;v[a+20>>2]=0;v[a+8>>2]=0;v[a+12>>2]=0;v[22656]=0;T(1180,a|0)|0;a=v[22656];v[22656]=0;if((a|0)!=1){break b}}break a}f=CD(d);v[22656]=0;U(288,c|0,b|0,f|0);e=v[22656];v[22656]=0;if((e|0)==1){break a}e=kc(c+24|0,c);Vc(d+8|0,e);xb(e);xb(c);d:{if(!(f&1)){break d}v[22656]=0;Q(318,b|0,1)|0;b=v[22656];v[22656]=0;if((b|0)!=1){break d}break a}$j(a,d)}ed(d);gb=c+80|0;return}a=P()|0;O()|0;ed(d);S(a|0);L()}function Eoa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=Zj(a);if(c>>>0<b>>>0){d=gb-32|0;gb=d;a:{b:{c=b-c|0;c:{if(c>>>0<=(v[wb(a)>>2]-v[a+4>>2]|0)/48>>>0){e=gb-16|0;gb=e;c=jY(e,a,c);b=v[c+4>>2];f=v[c+8>>2];if((b|0)!=(f|0)){while(1){wb(a);PW(b);b=b+48|0;v[c+4>>2]=b;if((b|0)!=(f|0)){continue}break}}$b(c);gb=e+16|0;break c}b=wb(a);b=hY(d+8|0,iY(a,Zj(a)+c|0),Zj(a),b);v[22656]=0;QW(b,c);c=v[22656];v[22656]=0;if((c|0)==1){break b}v[22656]=0;R(485,a|0,b|0);a=v[22656];v[22656]=0;if((a|0)==1){break b}Kv(b)}gb=d+32|0;break a}a=P()|0;O()|0;Kv(b);S(a|0);L()}return}if(b>>>0<c>>>0){b=v[a>>2]+B(b,48)|0;Zj(a);kY(a,b);rY(a)}}function CS(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;qc(a,65536);qc(a+4|0,64);qc(a+8|0,256);zg(a+28|0,16384);yf(a+30|0,128);yf(a+31|0,17);if(w[a+16|0]>=4){t[a+16|0]=0}if(w[a+17|0]>=5){t[a+17|0]=0}if(w[a+18|0]>=3){t[a+18|0]=0}yf(a+19|0,64);yf(a+20|0,100);c=224;d=t[a+26|0];a:{if((d|0)>=-32){c=32;if((d|0)<33){break a}}t[a+26|0]=c}yf(a+23|0,64);yf(a+24|0,64);nB(a+48|0,64);nB(a+68|0,64);nB(a+88|0,(b|0)==4096?255:64);c=a+108|0;b=0;while(1){b:{if(w[ic(c,b)|0]){if(w[ic(c,b)|0]<121){break b}}e=ic(c,b),f=b+1|0,t[e|0]=f}b=b+1|0;if(b>>>0<128){continue}break}if(!vp(w[a+14|0])){t[a+14|0]=5}if(w[a+34|0]>=251){t[a+34|0]=0}}function pR(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;e=gb-32|0;gb=e;n=e,o=ar(b),v[n+16>>2]=o;i=e+24|0;l=i;c=gb-32|0;gb=c;j=dR(a,c+28|0,b);b=v[j>>2];t[c+27|0]=0;if(!b){g=gb-16|0;gb=g;b=fc(a);f=c+8|0;h=Vj(f,cR(),Wj(g+8|0,b));b=v[h>>2];v[22656]=0;b=b+16|0;d=v[22656];v[22656]=0;a:{if((d|0)!=1){d=gb-16|0;gb=d;v[d+8>>2]=v[e+16>>2];k=v[d+8>>2];m=v[k+4>>2];v[b>>2]=v[k>>2];v[b+4>>2]=m;dd(b+8|0);gb=d+16|0;n=fc(h),o=1,t[n+4|0]=o;gb=g+16|0;break a}a=P()|0;O()|0;SA(h);S(a|0);L()}Hk(a,v[c+28>>2],j,v[f>>2]);b=ce(f);t[c+27|0]=1;SA(f)}Xj(l,yc(c+8|0,b),c+27|0);gb=c+32|0;a=ue(i);gb=e+32|0;return a+8|0}function R9(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=gb-32|0;gb=c;v[22656]=0;_(1934,a|0);d=v[22656];v[22656]=0;a:{b:{c:{if((d|0)==1){break c}v[22656]=0;_(1960,b|0);d=v[22656];v[22656]=0;if((d|0)==1){break c}d=v[a+24>>2];b=uc(c+8|0,b);v[22656]=0;e=v[b+4>>2];v[c>>2]=v[b>>2];v[c+4>>2]=e;Y(1999,c+16|0,d|0,c|0,1);b=v[22656];v[22656]=0;if((b|0)==1){break c}a=c+16|0;b=ie(Jb(a));vb(a);break b}b=V(0)|0;O()|0;Z(b|0)|0;b=0;v[22656]=0;Y(1911,2627,a|0,0,0);a=v[22656];v[22656]=0;if((a|0)==1){break a}$()}gb=c+32|0;return b|0}a=P()|0;O()|0;v[22656]=0;X(20);b=v[22656];v[22656]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}function x$(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;e=gb-16|0;gb=e;v[22656]=0;_(1934,a|0);f=v[22656];v[22656]=0;a:{b:{c:{d:{if((f|0)==1){break d}v[22656]=0;_(1960,b|0);f=v[22656];v[22656]=0;if((f|0)==1){break d}f=v[a+24>>2];b=uc(e+8|0,b);v[22656]=0;g=v[b+4>>2];v[e>>2]=v[b>>2];v[e+4>>2]=g;Ha(2002,f|0,e|0,c|0,d|0,1);c=v[22656];v[22656]=0;b=1;if((c|0)!=1){break c}}b=V(0)|0;O()|0;Z(b|0)|0;v[22656]=0;Y(1911,5773,a|0,0,0);a=v[22656];v[22656]=0;if((a|0)==1){break b}$();b=0}gb=e+16|0;break a}a=P()|0;O()|0;v[22656]=0;X(20);b=v[22656];v[22656]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}return b|0}function uj(a,b,c){var d=0,e=0,f=0,g=0,h=0;e=gb-32|0;gb=e;t[a|0]=0;f=_f(v[v[b>>2]-12>>2]+b|0);d=v[v[b>>2]-12>>2]+b|0;a:{b:{if(f){d=v[d+72>>2];if(d){bt(d)}c:{if(!(v[(v[v[b>>2]-12>>2]+b|0)+4>>2]&4096)|c){break c}c=e+24|0;Fc(c,v[v[b>>2]-12>>2]+b|0);v[22656]=0;f=T(21,c|0)|0;c=v[22656];v[22656]=0;if((c|0)==1){break a}Wb(e+24|0);c=cj(e+16|0,b);d=Ui(e+8|0);d:{if(!nk(c,d)){break d}while(1){if(!nh(f,8192,pl(c))){break d}ol(c);if(nk(c,d)){continue}break}}if(!mk(c,d)){break c}ih(v[v[b>>2]-12>>2]+b|0,6)}g=a,h=_f(v[v[b>>2]-12>>2]+b|0),t[g|0]=h;break b}ih(d,4)}gb=e+32|0;return a}a=P()|0;O()|0;Wb(e+24|0);S(a|0);L()}function xda(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;b=Fi(a,b,c,d);v[a>>2]=49924;c=mc(a+4208|0);v[a+4236>>2]=2147483647;v[a+4240>>2]=0;v[a+4228>>2]=1049926264;v[a+4232>>2]=0;v[a+4220>>2]=1056964608;v[a+4224>>2]=1056964608;t[a+4244|0]=0;Qb(a+4248|0,0,48);v[22656]=0;d=ga(1284)|0;e=v[22656];v[22656]=0;a:{if((e|0)==1){break a}v[22656]=0;d=T(1285,d|0)|0;e=v[22656];v[22656]=0;if((e|0)==1){break a}v[a+4296>>2]=d;Rt(a);Qt(a);v[22656]=0;W(1532,a+44|0,2,2)|0;d=v[22656];v[22656]=0;if((d|0)==1){break a}v[22656]=0;Th(b);d=v[22656];v[22656]=0;if((d|0)==1){break a}return a|0}a=P()|0;O()|0;gc(c);Lf(b);S(a|0);L()}function Y2(a,b,c,d,e,f,g,h,i,j){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;var k=0,l=0,m=0;k=gb-16|0;gb=k;a:{if(a){a=dH(b);gl(k,a);b=v[k>>2];t[c|0]=b;t[c+1|0]=b>>>8;t[c+2|0]=b>>>16;t[c+3|0]=b>>>24;fl(k,a);nj(i,k);Hc(k);Oh(k,a);nj(h,k);Hc(k);l=d,m=rj(a),v[l>>2]=m;l=e,m=qj(a),v[l>>2]=m;Ug(k,a);Eb(f,k);vb(k);Ph(k,a);nj(g,k);Hc(k);a=el(a);break a}a=cH(b);gl(k,a);b=v[k>>2];t[c|0]=b;t[c+1|0]=b>>>8;t[c+2|0]=b>>>16;t[c+3|0]=b>>>24;fl(k,a);nj(i,k);Hc(k);Oh(k,a);nj(h,k);Hc(k);l=d,m=rj(a),v[l>>2]=m;l=e,m=qj(a),v[l>>2]=m;Ug(k,a);Eb(f,k);vb(k);Ph(k,a);nj(g,k);Hc(k);a=el(a)}v[j>>2]=a;gb=k+16|0}function hJ(a){var b=0,c=0,d=0,e=0,f=0,g=0;if(Ne(a)){ec(a,31);return 0}f=a,g=Ne(a),t[f+1375|0]=g;d=yj(a);b=yj(a);yj(a);f=a,g=yj(a),v[f+1112>>2]=g;yj(a);c=Ne(a);v[a+1116>>2]=c;if(!my(a,a+1120|0,c)){ec(a,10);return 0}v[a+1404>>2]=-2;a:{if((d|0)==-1&(b|0)==-1){break a}b=v[a+1116>>2];while(1){if((b|0)<=0){break a}b=b-1|0;if(w[(b+a|0)+1120|0]==255){continue}break}v[a+1408>>2]=d;v[a+1404>>2]=b}if(w[a+1377|0]){e=v[a+1116>>2];if((e|0)<=0){b=27}else{c=0;b=0;while(1){c=w[(a+b|0)+1120|0]+c|0;b=b+1|0;if((e|0)!=(b|0)){continue}break}b=c+27|0}v[a- -64>>2]=d;v[a+60>>2]=v[a+56>>2]+(b+e|0)}v[a+1380>>2]=0;return 1}function kX(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=gb+-64|0;gb=d;e=d+40|0;Re(e,a,c);a=v[e>>2];v[22656]=0;e=Sd(e);f=v[22656];v[22656]=0;a:{b:{c:{d:{if((f|0)==1){break d}e=zb(e);v[22656]=0;Xe(d+8|0,2,e,a);e=v[22656];v[22656]=0;if((e|0)==1){break d}v[22656]=0;R(324,d+24|0,d+8|0);e=v[22656];v[22656]=0;if((e|0)==1){break d}v[22656]=0;R(444,d|0,b|0);b=v[22656];v[22656]=0;if((b|0)==1){break c}v[22656]=0;Q(401,d|0,d+24|0)|0;b=v[22656];v[22656]=0;if((b|0)==1){break c}vb(d+24|0);zc(d+40|0);gb=d- -64|0;a=!c|(a|0)!=0;break a}a=P()|0;O()|0;break b}a=P()|0;O()|0;vb(d+24|0)}zc(d+40|0);S(a|0);L()}return a|0}function st(a,b,c){var d=0,e=0;d=a,e=zj(C(C(z[c+1792>>2]*C(75038))+C(C(C(C(C(C(C(C(z[c+3584>>2]-z[c>>2])*C(29))+C(C(z[c+256>>2]+z[c+3328>>2])*C(213)))+C(C(z[c+3072>>2]-z[c+512>>2])*C(459)))+C(C(z[c+768>>2]+z[c+2816>>2])*C(2037)))+C(C(z[c+2560>>2]-z[c+1024>>2])*C(5153)))+C(C(z[c+1280>>2]+z[c+2304>>2])*C(6574)))+C(C(z[c+2048>>2]-z[c+1536>>2])*C(37489))))),u[d>>1]=e;d=(b<<5)+a|0,e=zj(C(C(C(C(C(C(C(C(z[c+3592>>2]*C(104))+C(z[c+3080>>2]*C(1567)))+C(z[c+2568>>2]*C(9727)))+C(z[c+2056>>2]*C(64019)))+C(z[c+1544>>2]*C(-9975)))+C(z[c+1032>>2]*C(-45)))+C(z[c+520>>2]*C(146)))+C(z[c+8>>2]*C(-5)))),u[d>>1]=e}function f3(a,b,c,d,e,f,g,h,i,j){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;var k=0,l=0,m=0;k=gb-16|0;gb=k;a:{if(a){a=hH(b);gl(k,a);b=v[k>>2];t[c|0]=b;t[c+1|0]=b>>>8;t[c+2|0]=b>>>16;t[c+3|0]=b>>>24;fl(k,a);Eb(i,k);vb(k);Oh(k,a);Eb(h,k);vb(k);l=d,m=rj(a),t[l|0]=m;l=e,m=qj(a),t[l|0]=m;Ug(k,a);Eb(f,k);vb(k);Ph(k,a);Eb(g,k);vb(k);a=el(a);break a}a=gH(b);gl(k,a);b=v[k>>2];t[c|0]=b;t[c+1|0]=b>>>8;t[c+2|0]=b>>>16;t[c+3|0]=b>>>24;fl(k,a);Eb(i,k);vb(k);Oh(k,a);Eb(h,k);vb(k);l=d,m=rj(a),t[l|0]=m;l=e,m=qj(a),t[l|0]=m;Ug(k,a);Eb(f,k);vb(k);Ph(k,a);Eb(g,k);vb(k);a=el(a)}v[j>>2]=a;gb=k+16|0}function oea(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;d=gb-16|0;gb=d;b=x[b>>1];e=d;f=x[a+30>>1];if(f){b=to(b<<16>>16,f<<16>>16)}u[e+14>>1]=b;a:{if(!gd(c)){ik(nN(a+52|0,d+14|0),c);break a}a=a+52|0;b=lz(a,d+14|0);v[d+8>>2]=b;m=d,n=Dh(a),v[m>>2]=n;if(!og(d+8|0,d)){break a}c=gb-16|0;gb=c;l=c+8|0;b=v[yc(c,b)>>2];e=gb-16|0;gb=e;v[e+8>>2]=b;f=gb-16|0;gb=f;j=e+8|0;k=v[j>>2];h=k;i=yc(f+8|0,h);Uj(i);b=a;g=b;if(v[b>>2]==(h|0)){v[g>>2]=v[i>>2]}g=wb(b);v[g>>2]=v[g>>2]-1;bN(v[fc(b)>>2],h);b=v[i>>2];gb=f+16|0;a=fc(a);Gk(ue(j));Yk(a,k,1);gb=e+16|0;yc(l,b);gb=c+16|0}gb=d+16|0}function Lfa(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0;g=gb-32|0;gb=g;a:{if(x[a+480192>>1]<b>>>0){break a}h=v[((b<<2)+a|0)+900380>>2];if(!h){break a}b=g+16|0;ES(b,h);i=g,j=zC(b),v[i+8>>2]=j;i=g,j=Ch(b),v[i>>2]=j;while(1){b:{v[22656]=0;b=Gb(g+8|0,g);h=v[22656];v[22656]=0;if((h|0)==1){break b}if(!b){nr(g+16|0);break a}v[22656]=0;b=Yl(g+8|0);h=v[22656];v[22656]=0;if((h|0)==1){break b}b=x[b>>1];if(b>>>0<=x[a+480190>>1]){b=B(b,104)+a|0;t[b+484421|0]=f;t[b+484418|0]=c;t[b+484420|0]=e;t[b+484419|0]=d}Uj(g+8|0);continue}break}a=P()|0;O()|0;nr(g+16|0);S(a|0);L()}gb=g+32|0}function ila(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0;f=gb+-64|0;gb=f;g=f+24|0;Kh(g,c);v[22656]=0;R(160,f+36|0,d|0);c=v[22656];v[22656]=0;a:{b:{c:{if((c|0)!=1){v[22656]=0;R(144,f+48|0,e|0);c=v[22656];v[22656]=0;if((c|0)!=1){break c}a=2}else{a=1}a=B(a,12)+g|0;b=P()|0;O()|0;while(1){a=vb(a-12|0);if((a|0)!=(f+24|0)){continue}break}break b}v[22656]=0;vs(f+16|0,f+24|0);c=v[22656];v[22656]=0;if((c|0)!=1){v[22656]=0;c=v[f+20>>2];v[f+8>>2]=v[f+16>>2];v[f+12>>2]=c;U(146,a|0,b|0,f+8|0);a=v[22656];v[22656]=0;if((a|0)!=1){break a}}b=P()|0;O()|0;dl(f+24|0)}S(b|0);L()}dl(f+24|0);gb=f- -64|0}function Uga(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=gb-32|0;gb=c;e=gb-16|0;gb=e;d=c+24|0;bc(d,b,24);gb=e+16|0;e=yb(d);d=v[c+28>>2];f=v[c+24>>2];v[c+8>>2]=f;v[c+12>>2]=d;v[c>>2]=f;v[c+4>>2]=d;d=c+16|0;cc(d,a,c);d=yb(d);if((d|0)==(e|0)){Rb(a,yb(c+24|0))}gb=c+32|0;a=(d|0)==(e|0);if(!a){c=gb-16|0;gb=c;t[b|0]=0;t[b+1|0]=0;t[b+2|0]=0;t[b+3|0]=0;t[b+4|0]=0;t[b+5|0]=0;t[b+6|0]=0;t[b+7|0]=0;t[b+16|0]=0;t[b+17|0]=0;t[b+18|0]=0;t[b+19|0]=0;t[b+20|0]=0;t[b+21|0]=0;t[b+22|0]=0;t[b+23|0]=0;t[b+8|0]=0;t[b+9|0]=0;t[b+10|0]=0;t[b+11|0]=0;t[b+12|0]=0;t[b+13|0]=0;t[b+14|0]=0;t[b+15|0]=0;gb=c+16|0}return a|0}function Loa(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0;f=gb+-64|0;gb=f;g=f+24|0;Kh(g,c);v[22656]=0;R(144,f+36|0,d|0);c=v[22656];v[22656]=0;a:{b:{c:{if((c|0)!=1){v[22656]=0;R(144,f+48|0,e|0);c=v[22656];v[22656]=0;if((c|0)!=1){break c}a=2}else{a=1}a=B(a,12)+g|0;b=P()|0;O()|0;while(1){a=vb(a-12|0);if((a|0)!=(f+24|0)){continue}break}break b}v[22656]=0;vs(f+16|0,f+24|0);c=v[22656];v[22656]=0;if((c|0)!=1){v[22656]=0;c=v[f+20>>2];v[f+8>>2]=v[f+16>>2];v[f+12>>2]=c;U(146,a|0,b|0,f+8|0);a=v[22656];v[22656]=0;if((a|0)!=1){break a}}b=P()|0;O()|0;dl(f+24|0)}S(b|0);L()}dl(f+24|0);gb=f- -64|0}function wh(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;e=gb+-64|0;gb=e;a:{b:{if(c-1>>>0>1023){break b}if(me(a,b)){break b}c:{d:{if(Sf(a)>>>0<=b>>>0){d=pz(e+8|0,a);v[22656]=0;U(1489,a|0,b+1|0,d|0);f=v[22656];v[22656]=0;if((f|0)==1){break d}Km(d)}d=bf(a,b);v[22656]=0;Q(1490,d|0,c|0)|0;c=v[22656];v[22656]=0;e:{if((c|0)!=1){c=bf(a,b);v[c+16>>2]=0;v[c+20>>2]=0;c=bf(a,b);v[22656]=0;_(1491,c|0);c=v[22656];v[22656]=0;if((c|0)!=1){break e}}a=V(89116)|0;b=O()|0;break c}g=hi(bf(a,b));break b}a=V(89116)|0;b=O()|0;Km(d)}if((ea(89116)|0)!=(b|0)){break a}Z(a|0)|0;$()}gb=e- -64|0;return g|0}S(a|0);L()}function n0(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0;f=gb+-64|0;gb=f;g=f+24|0;Rn(g,c);v[22656]=0;R(160,f+36|0,d|0);c=v[22656];v[22656]=0;a:{b:{c:{if((c|0)!=1){v[22656]=0;R(160,f+48|0,e|0);c=v[22656];v[22656]=0;if((c|0)!=1){break c}a=2}else{a=1}a=B(a,12)+g|0;b=P()|0;O()|0;while(1){a=vb(a-12|0);if((a|0)!=(f+24|0)){continue}break}break b}v[22656]=0;vs(f+16|0,f+24|0);c=v[22656];v[22656]=0;if((c|0)!=1){v[22656]=0;c=v[f+20>>2];v[f+8>>2]=v[f+16>>2];v[f+12>>2]=c;U(146,a|0,b|0,f+8|0);a=v[22656];v[22656]=0;if((a|0)!=1){break a}}b=P()|0;O()|0;dl(f+24|0)}S(b|0);L()}dl(f+24|0);gb=f- -64|0}function y$(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=gb-16|0;gb=d;v[22656]=0;_(1934,a|0);c=v[22656];v[22656]=0;a:{b:{c:{d:{if((c|0)==1){break d}v[22656]=0;_(1960,b|0);c=v[22656];v[22656]=0;if((c|0)==1){break d}c=v[a+24>>2];e=uc(d+8|0,b);v[22656]=0;b=v[e+4>>2];v[d>>2]=v[e>>2];v[d+4>>2]=b;b=vG(c,d,1);e=v[22656];v[22656]=0;c=jb;if((e|0)!=1){break c}}b=V(0)|0;O()|0;Z(b|0)|0;v[22656]=0;Y(1911,5804,a|0,0,0);a=v[22656];v[22656]=0;if((a|0)==1){break b}$();b=0;c=0}gb=d+16|0;a=c;break a}b=P()|0;O()|0;v[22656]=0;X(20);a=v[22656];v[22656]=0;if((a|0)!=1){S(b|0);L()}V(0)|0;O()|0;Bb();L()}ma(a|0);return b|0}function vZ(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;g=gb-32|0;gb=g;d=b;f=oc(d);e=c;a:{if(f>>>0<e>>>0){h=gb-32|0;gb=h;b:{c:{f=e-f|0;d:{if(f>>>0<=v[wb(d)>>2]-v[d+4>>2]>>>0){gq(d,f);break d}e=wb(d);e=Zg(h+8|0,qh(d,oc(d)+f|0),oc(d),e);v[22656]=0;R(295,e|0,f|0);f=v[22656];v[22656]=0;if((f|0)==1){break c}v[22656]=0;R(296,d|0,e|0);d=v[22656];v[22656]=0;if((d|0)==1){break c}be(e)}gb=h+32|0;break b}a=P()|0;O()|0;be(e);S(a|0);L()}break a}if(e>>>0<f>>>0){Em(d,e+v[d>>2]|0)}}c=Pb(a,c);if(c){QD(g+24|0,b);b=v[g+28>>2];v[g+8>>2]=v[g+24>>2];v[g+12>>2]=b;kd(g+16|0,a,g+8|0)}gb=g+32|0;return c|0}function QS(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;f=gb-16|0;gb=f;v[f+8>>2]=e;v[f+12>>2]=d;a:{if(!d){break a}Se(a);Rq(a,c);if(!c){break a}e=0;while(1){j=c-g|0;v[f+4>>2]=j;h=v[Fb(f+12|0,f+4|0)>>2];Cp(a,zb(b)+g|0,h);xs(a,1,13);i=e+h|0;if(i>>>0>e>>>0){while(1){b:{c:{d:{k=t[pc(a,e)|0];switch(k-10|0){case 1:case 2:break b;case 0:case 3:break c;default:break d}}if(k){break b}}l=pc(a,e),m=32,t[l|0]=m}e=e+1|0;if((i|0)!=(e|0)){continue}break}}v[f+4>>2]=j-h;e=i+1|0;g=v[Fb(f+8|0,f+4|0)>>2]+(h+g|0)|0;if(g>>>0<c>>>0){continue}break}}gb=f+16|0;return(d|0)!=0|0}function P9(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=gb-16|0;gb=d;v[22656]=0;_(1934,a|0);e=v[22656];v[22656]=0;a:{b:{c:{if((e|0)==1){break c}v[22656]=0;_(1960,b|0);e=v[22656];v[22656]=0;if((e|0)==1){break c}e=v[a+24>>2];b=uc(d+8|0,b);v[22656]=0;f=v[b+4>>2];v[d>>2]=v[b>>2];v[d+4>>2]=f;Y(2001,e|0,d|0,(c|0)!=0|0,1);c=v[22656];v[22656]=0;b=1;if((c|0)!=1){break b}}b=V(0)|0;O()|0;Z(b|0)|0;v[22656]=0;Y(1911,7275,a|0,0,0);a=v[22656];v[22656]=0;if((a|0)==1){break a}$();b=0}gb=d+16|0;return b|0}a=P()|0;O()|0;v[22656]=0;X(20);b=v[22656];v[22656]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}function Pm(a,b,c,d){var e=0,f=0,g=0;e=gb-16|0;gb=e;f=e+8|0;g=a+1074312|0;Db(f,g,84);a:{if(Cb(f)){break a}b:{if(v[a+480208>>2]&16384){break b}if((d|0)!=8){f=e+8|0;Db(f,g,10);if(!Cb(f)){break b}}v[b+88>>2]=v[b+88>>2]&-257}c:{d:{e:{switch(d-4|0){case 0:c=((c<<8|8)>>>0)/15|0;break d;case 2:c=(c>>>0<64?c:64)<<2;break d;default:break e}}if(!(v[a+480180>>2]&2107410)){break d}if(c>>>0<=128){c=c<<1;break d}if((c|0)!=164){break c}v[b+88>>2]=v[b+88>>2]|256;c=128}v[b+692>>2]=c}u[b+784>>1]=0;v[b+88>>2]=v[b+88>>2]|2097152;a=e+8|0;Db(a,g,10);if(!Cb(a)){break a}t[b+831|0]=0;u[b+778>>1]=0}gb=e+16|0}function g$(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;a:{if((w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24))>>>0>=c>>>0){break a}d=a+4|0;e=w[d+1|0]<<8;f=w[d+2|0]<<16|w[d+3|0]<<24;if((w[d|0]|e|f)>>>0>c>>>0|c-(w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24))>>>0<(f|(e|w[d|0]))>>>0|!(w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24))){break a}g=1;if(oc(b)>>>0>=(w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24))+(w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24))>>>0){break a}Ty(b,(w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24))+(w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24))|0)}return g|0}function AJ(a,b){a=a|0;b=b|0;var c=0,d=0;d=gb-16|0;gb=d;a:{b:{c:{c=a+8|0;d:{if(!wl(c)){if((b|0)<0|(hq(c)|0)<=(b|0)){break d}c=(w[Bk(v[a+32>>2],b+1&65535)+35|0]&4)>>>2|0;break b}c=wl(c);if((b|0)<0){break d}if((b|0)<(c|0)){break c}}a=ba(8)|0;v[22656]=0;b=Q(70,d|0,3092)|0;c=v[22656];v[22656]=0;e:{if((c|0)!=1){rc(a,b);v[22656]=0;U(186,a|0,54952,1936);a=v[22656];v[22656]=0;if((a|0)!=1){break a}c=P()|0;O()|0;vb(b);break e}c=P()|0;O()|0;ca(a|0)}S(c|0);L()}b=b+1<<2;a=a+32|0;c=1;if(!v[(b+v[a>>2]|0)+900380>>2]){break b}c=(w[v[(b+v[a>>2]|0)+900380>>2]+15|0]&2)>>>1|0}gb=d+16|0;return c|0}L()}function Ax(a,b,c,d,e){var f=0,g=0;f=gb-16|0;gb=f;g=f+8|0;Fc(g,b);v[22656]=0;b=T(2452,g|0)|0;g=v[22656];v[22656]=0;a:{if((g|0)==1){break a}v[22656]=0;Y(2464,b|0,81024,81056,c|0);b=v[22656];v[22656]=0;if((b|0)==1){break a}v[22656]=0;b=T(2453,f+8|0)|0;c=v[22656];v[22656]=0;if((c|0)==1){break a}v[22656]=0;c=T(2465,b|0)|0;g=v[22656];v[22656]=0;if((g|0)==1){break a}v[d>>2]=c;v[22656]=0;c=T(2462,b|0)|0;d=v[22656];v[22656]=0;if((d|0)==1){break a}v[e>>2]=c;v[22656]=0;R(2463,a|0,b|0);a=v[22656];v[22656]=0;if((a|0)==1){break a}Wb(f+8|0);gb=f+16|0;return}a=P()|0;O()|0;Wb(f+8|0);S(a|0);L()}function Jpa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;ud(b,0);v[b>>2]=w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24);c=a+4|0;v[b+12>>2]=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);c=a+8|0;v[b+16>>2]=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);c=a+12|0;c=w[c|0]|w[c+1|0]<<8;u[b+32>>1]=64;v[b+24>>2]=c;e=b;c=a+14|0;if(w[c|0]){d=w[c|0]+1|0}else{d=256}u[e+30>>1]=d;u[b+34>>1]=x[b+34>>1]&32767|!w[c|0]<<15;a=a+15|0;if(!(!(t[a|0]&1)|y[b+16>>2]<=y[b+12>>2])){u[b+34>>1]=x[b+34>>1]|8}if(w[a|0]&2){u[b+34>>1]=x[b+34>>1]|1;v[b>>2]=v[b>>2]>>>1;v[b+12>>2]=v[b+12>>2]>>>1;v[b+16>>2]=v[b+16>>2]>>>1}}function Yea(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0;e=gb-32|0;gb=e;Nk(e,2,a+2|0);d=e+16|0;Bc(d,e);v[22656]=0;Q(301,b+492|0,d|0)|0;d=v[22656];v[22656]=0;if((d|0)!=1){vb(e+16|0);d=b+236|0;c=c+1|0;while(1){g=w[(a+f|0)+31|0];h=vd(d,f),i=c+g|0,u[h>>1]=i;f=f+1|0;if(f>>>0<120){continue}break}v[b>>2]=(w[a+223|0]|w[a+224|0]<<8)<<5;a=a+158|0;c=a+1|0;f=a+2|0;d=a+3|0;g=a+4|0;MN(w[a|0]&15,w[c|0]&15,w[f|0]&15,w[d|0]&15,w[g|0]&15,a+5|0,b+48|0);MN(w[a|0]>>>4|0,w[c|0]>>>4|0,w[f|0]>>>4|0,w[d|0]>>>4|0,w[g|0]>>>4|0,a+35|0,b+68|0);gb=e+32|0;return}a=P()|0;O()|0;vb(e+16|0);S(a|0);L()}function O9(a,b,c){a=a|0;b=b|0;c=+c;var d=0,e=0,f=0;e=gb-16|0;gb=e;v[22656]=0;_(1934,a|0);d=v[22656];v[22656]=0;a:{b:{c:{if((d|0)==1){break c}v[22656]=0;_(1960,b|0);d=v[22656];v[22656]=0;if((d|0)==1){break c}d=v[a+24>>2];b=uc(e+8|0,b);v[22656]=0;f=v[b+4>>2];v[e>>2]=v[b>>2];v[e+4>>2]=f;Xa(2003,d|0,e|0,+c,1);d=v[22656];v[22656]=0;b=1;if((d|0)!=1){break b}}b=V(0)|0;O()|0;Z(b|0)|0;v[22656]=0;Y(1911,3018,a|0,0,0);a=v[22656];v[22656]=0;if((a|0)==1){break a}$();b=0}gb=e+16|0;return b|0}a=P()|0;O()|0;v[22656]=0;X(20);b=v[22656];v[22656]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}function I$(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0;if(Sg(a,v[b+8>>2],f)){gx(b,c,d,e);return}h=w[b+53|0];g=v[a+12>>2];t[b+53|0]=0;i=w[b+52|0];t[b+52|0]=0;j=a+16|0;ex(j,b,c,d,e,f);k=w[b+53|0];h=h|k;l=w[b+52|0];i=i|l;a:{if((g|0)<2){break a}j=j+(g<<3)|0;g=a+24|0;while(1){if(w[b+54|0]){break a}b:{if(l){if(v[b+24>>2]==1){break a}if(w[a+8|0]&2){break b}break a}if(!k){break b}if(!(t[a+8|0]&1)){break a}}u[b+52>>1]=0;ex(g,b,c,d,e,f);k=w[b+53|0];h=k|h;l=w[b+52|0];i=l|i;g=g+8|0;if(j>>>0>g>>>0){continue}break}}t[b+53|0]=(h&255)!=0;t[b+52|0]=(i&255)!=0}function Bga(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0;d=gb-32|0;gb=d;v[d+24>>2]=c>>>3;v[d+16>>2]=v[a>>2];f=v[Fb(d+24|0,d+16|0)>>2];b=zb(b);if(f){a=v[a+20>>2];c=f;while(1){g=w[b+4|0]|w[b+5|0]<<8|(w[b+6|0]<<16|w[b+7|0]<<24);v[d+24>>2]=w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24);v[d+28>>2]=g;v[d+16>>2]=0;v[d+20>>2]=-1074790400;v[d+8>>2]=0;v[d+12>>2]=1072693248;e=A[bh(d+24|0,d+16|0,d+8|0)>>3]*32768;A[d+24>>3]=e;g=a;e=ee(e);a:{if(D(e)<2147483648){h=~~e;break a}h=-2147483648}i=g,j=Uc(h),u[i>>1]=j;a=a+2|0;b=b+8|0;c=c-1|0;if(c){continue}break}}gb=d+32|0;return f<<3}function sga(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=C(0),g=0,h=0,i=C(0),j=0,k=0;e=gb-16|0;gb=e;v[e+12>>2]=c>>>2;v[e+8>>2]=v[a>>2];g=v[Fb(e+12|0,e+8|0)>>2];i=z[d>>2];b=zb(b);if(g){d=v[a+20>>2];c=g;while(1){a=w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24);z[e+12>>2]=i*(l(2,a<<24|a<<8&16711680|(a>>>8&65280|a>>>24)),q());v[e+8>>2]=-1082130432;v[e+4>>2]=1065353216;f=C(z[zf(e+12|0,e+8|0,e+4|0)>>2]*C(32768));z[e+12>>2]=f;a=d;f=fe(f);a:{if(C(D(f))<C(2147483648)){h=~~f;break a}h=-2147483648}j=a,k=Uc(h),u[j>>1]=k;d=d+2|0;b=b+4|0;c=c-1|0;if(c){continue}break}}gb=e+16|0;return g<<2}function Dx(a,b,c,d,e){var f=0,g=0;f=gb-16|0;gb=f;g=f+8|0;Fc(g,b);v[22656]=0;b=T(21,g|0)|0;g=v[22656];v[22656]=0;a:{if((g|0)==1){break a}v[22656]=0;Y(2444,b|0,81024,81056,c|0);b=v[22656];v[22656]=0;if((b|0)==1){break a}v[22656]=0;b=T(2424,f+8|0)|0;c=v[22656];v[22656]=0;if((c|0)==1){break a}v[22656]=0;c=T(2445,b|0)|0;g=v[22656];v[22656]=0;if((g|0)==1){break a}t[d|0]=c;v[22656]=0;c=T(2436,b|0)|0;d=v[22656];v[22656]=0;if((d|0)==1){break a}t[e|0]=c;v[22656]=0;R(2437,a|0,b|0);a=v[22656];v[22656]=0;if((a|0)==1){break a}Wb(f+8|0);gb=f+16|0;return}a=P()|0;O()|0;Wb(f+8|0);S(a|0);L()}function tY(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;if(v[a+4>>2]!=v[wb(a)>>2]){c=gb-16|0;gb=c;d=jY(c,a,1);a=wb(a);e=v[d+4>>2];v[22656]=0;U(484,a|0,e|0,b|0);a=v[22656];v[22656]=0;a:{if((a|0)!=1){v[d+4>>2]=v[d+4>>2]+48;$b(d);gb=c+16|0;break a}a=P()|0;O()|0;$b(d);S(a|0);L()}return}c=gb-32|0;gb=c;d=a;e=wb(a);a=hY(c+8|0,iY(a,Zj(a)+1|0),Zj(a),e);f=v[a+8>>2];v[22656]=0;U(484,e|0,f|0,b|0);b=v[22656];v[22656]=0;b:{c:{if((b|0)==1){break c}v[a+8>>2]=v[a+8>>2]+48;v[22656]=0;R(485,d|0,a|0);b=v[22656];v[22656]=0;if((b|0)==1){break c}Kv(a);gb=c+32|0;break b}b=P()|0;O()|0;Kv(a);S(b|0);L()}}function a5(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;c=gb-32|0;gb=c;e=Ie(b,-1);d=w[a+52|0];a:{if(e){if(d){break a}b=v[a+48>>2];f=a,g=Ie(b,-1)^1,t[f+52|0]=g;break a}b:{if(!d){break b}f=c,g=Wh(v[a+48>>2]),t[f+19|0]=g;c:{d:{e:{d=c+20|0;switch(Ys(v[a+36>>2],v[a+40>>2],c+19|0,d,c+12|0,c+24|0,c+32|0,d)-1|0){case 0:case 1:break c;case 2:break e;default:break d}}d=v[a+48>>2];v[c+20>>2]=c+25;t[c+24|0]=d}while(1){d=v[c+20>>2];if(d>>>0<=c+24>>>0){break b}d=d-1|0;v[c+20>>2]=d;if((Vs(t[d|0],v[a+32>>2])|0)!=-1){continue}break}}b=-1;break a}t[a+52|0]=1;v[a+48>>2]=b}gb=c+32|0;return b|0}function w_(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;if(y[a+4>>2]<y[wb(a)>>2]){c=gb-16|0;gb=c;d=Nw(c,a,1);a=wb(a);e=v[d+4>>2];v[22656]=0;U(278,a|0,e|0,b|0);a=v[22656];v[22656]=0;a:{if((a|0)!=1){v[d+4>>2]=v[d+4>>2]+36;$b(d);gb=c+16|0;break a}a=P()|0;O()|0;$b(d);S(a|0);L()}return}c=gb-32|0;gb=c;d=a;e=wb(a);a=VF(c+8|0,WF(a,bl(a)+1|0),bl(a),e);f=v[a+8>>2];v[22656]=0;U(278,e|0,f|0,b|0);b=v[22656];v[22656]=0;b:{c:{if((b|0)==1){break c}v[a+8>>2]=v[a+8>>2]+36;v[22656]=0;R(209,d|0,a|0);b=v[22656];v[22656]=0;if((b|0)==1){break c}ms(a);gb=c+32|0;break b}b=P()|0;O()|0;ms(a);S(b|0);L()}}function No(a){var b=0,c=0,d=0,e=0,f=0,g=0;e=x[a+24>>1];c=v[a+4>>2];d=!w[a+77|0]<<1;b=(e<<2)+(x[c+28>>1]>>>d|0)|0;v[a+40>>2]=((b&3)<<4)+34128;f=b>>>2|0;b=b>>>0<48;g=b?12-f|0:0;u[a+32>>1]=g;u[a+36>>1]=b?1:1<<f-12;u[a+34>>1]=-1<<g^-1;if((e|0)==15){u[a+36>>1]=4095}b=(x[a+26>>1]<<2)+(x[c+28>>1]>>>d|0)|0;v[a+52>>2]=((b&3)<<4)+34128;e=b>>>2|0;b=b>>>0<48;f=b?12-e|0:0;u[a+44>>1]=f;u[a+48>>1]=b?1:1<<e-12;u[a+46>>1]=-1<<f^-1;c=(x[a+30>>1]<<2)+(x[c+28>>1]>>>d|0)|0;v[a+64>>2]=((c&3)<<4)+34128;d=c>>>2|0;c=c>>>0<48;b=c?12-d|0:0;u[a+56>>1]=b;u[a+60>>1]=c?1:1<<d-12;u[a+58>>1]=-1<<b^-1}function S9(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=gb-16|0;gb=c;v[22656]=0;_(1934,a|0);d=v[22656];v[22656]=0;a:{b:{c:{if((d|0)==1){break c}v[22656]=0;_(1960,b|0);d=v[22656];v[22656]=0;if((d|0)==1){break c}d=v[a+24>>2];b=uc(c+8|0,b);v[22656]=0;f=v[b+4>>2];v[c>>2]=v[b>>2];v[c+4>>2]=f;e=+oa(1998,d|0,c|0,1);b=v[22656];v[22656]=0;if((b|0)!=1){break b}}b=V(0)|0;O()|0;Z(b|0)|0;v[22656]=0;Y(1911,3055,a|0,0,0);a=v[22656];v[22656]=0;if((a|0)==1){break a}$();e=0}gb=c+16|0;return+e}a=P()|0;O()|0;v[22656]=0;X(20);b=v[22656];v[22656]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}function Bea(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0;e=gb-16|0;gb=e;v[e+12>>2]=b;a:{if(qk(a)>>>0>=b>>>0){h=e,i=Sf(a),v[h+8>>2]=i;d=v[a>>2];b=c;f=v[Fb(e+12|0,e+8|0)>>2];if(f){while(1){IN(d,b);d=d+52|0;f=f-1|0;if(f){continue}break}}b=v[e+12>>2];d=v[e+8>>2];if(b>>>0>d>>>0){oz(a,b-d|0,c);break a}zN(a,v[a>>2]+B(b,52)|0);break a}d=a;if(v[d>>2]){Sf(d);CO(d);wN(d);dA(wb(d),v[d>>2],qk(d));h=wb(d),i=0,v[h>>2]=i;v[d>>2]=0;v[d+4>>2]=0}f=yN(a,b);if(vN()>>>0<f>>>0){Sc();L()}wb(d);g=uN(f);v[d>>2]=g;v[d+4>>2]=g;h=wb(d),i=B(f,52)+g|0,v[h>>2]=i;tN(d,0);oz(a,b,c)}gb=e+16|0}function zna(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;a:{c=gb+-64|0;gb=c;d=c+40|0;Re(d,a,16);a=v[d>>2];v[22656]=0;d=Sd(d);e=v[22656];v[22656]=0;b:{c:{d:{if((e|0)==1){break d}d=zb(d);v[22656]=0;Xe(c+8|0,3,d,a);a=v[22656];v[22656]=0;if((a|0)==1){break d}v[22656]=0;R(324,c+24|0,c+8|0);a=v[22656];v[22656]=0;if((a|0)==1){break d}v[22656]=0;R(684,c|0,b|0);a=v[22656];v[22656]=0;if((a|0)==1){break c}v[22656]=0;Q(401,c|0,c+24|0)|0;a=v[22656];v[22656]=0;if((a|0)==1){break c}vb(c+24|0);zc(c+40|0);gb=c- -64|0;break a}a=P()|0;O()|0;break b}a=P()|0;O()|0;vb(c+24|0)}zc(c+40|0);S(a|0);L()}}function ypa(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;a:{d=gb+-64|0;gb=d;k=d;g=d+16|0;h=gb-16|0;gb=h;l=cU(h+8|0);while(1){e=gb-48|0;gb=e;b=l;c=v[b+4>>2]-v[b>>2]|0;b:{if(!c){b=v[b>>2];break b}c=c+1|0;if(!c){b=PT(RT(e+8|0,32));break b}f=E(c);f=RT(e+8|0,(c&-1>>>f+1?32:31)-f|0);while(1){j=PT(f);if(c>>>0<=j>>>0){continue}break}b=v[b>>2]+j|0}gb=e+48|0;m=Fe(g,i),n=b,v[m>>2]=n;i=i+1|0;if((i|0)!=12){continue}break}gb=h+16|0;b=jU(k,g,qU(g));v[22656]=0;WB(a,b,0);a=v[22656];v[22656]=0;if((a|0)!=1){Nc(b);gb=d- -64|0;break a}a=P()|0;O()|0;Nc(b);S(a|0);L()}}function hja(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0;b=gb-16|0;gb=b;h=v[a+24>>2];i=v[a+20>>2];j=v[a+16>>2];g=v[a+4>>2];e=g;f=v[a>>2];v[b+8>>2]=f;v[b+12>>2]=e;g=v[a+12>>2];v[b>>2]=v[a+8>>2];v[b+4>>2]=g;if(d){while(1){e=(e<<1)+j|0;f=f>>>21&2040;e=(((B(u[e>>1],u[f+46162>>1])+B(u[e-2>>1],u[f+46160>>1])|0)+B(u[e+2>>1],u[f+46164>>1])|0)+B(u[e+4>>1],u[f+46166>>1])|0)/16384|0;v[c>>2]=v[c>>2]+B(e,i);v[c+4>>2]=v[c+4>>2]+B(e,h);Ub(b+8|0,b);d=d-1|0;if(d){c=c+8|0;f=v[b+8>>2];e=v[b+12>>2];continue}break}f=v[b+8>>2];e=v[b+12>>2]}v[a>>2]=f;v[a+4>>2]=e;gb=b+16|0}function mq(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0;e=gb-32|0;gb=e;zi(e+16|0,b);c=v[e+20>>2];v[e>>2]=v[e+16>>2];v[e+4>>2]=c;d=gb-32|0;gb=d;c=v[e+4>>2];f=v[e>>2];v[d+8>>2]=f;v[d+12>>2]=c;v[d+16>>2]=f;v[d+20>>2]=c;f=gb-16|0;gb=f;g=v[d+12>>2];c=f;h=v[d+8>>2];v[c>>2]=h;v[c+4>>2]=g;v[c+8>>2]=h;v[c+12>>2]=g;g=gb-16|0;gb=g;h=v[c>>2];i=v[c>>2];c=yb(c);v[22656]=0;lo(d+24|0,h,c+i|0);c=v[22656];v[22656]=0;a:{if((c|0)!=1){gb=g+16|0;break a}V(0)|0;O()|0;Bb();L()}gb=f+16|0;c=v[d+28>>2];v[d>>2]=v[d+24>>2];v[d+4>>2]=c;c=e+24|0;sy(c,a,d);gb=d+32|0;yb(c);a=e+8|0;zi(a,b);yb(a);gb=e+32|0}function ZY(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;a:{c=gb+-64|0;gb=c;d=c+40|0;Re(d,a,44);a=v[d>>2];v[22656]=0;d=Sd(d);e=v[22656];v[22656]=0;b:{c:{d:{if((e|0)==1){break d}d=zb(d);v[22656]=0;Xe(c+8|0,2,d,a);a=v[22656];v[22656]=0;if((a|0)==1){break d}v[22656]=0;R(324,c+24|0,c+8|0);a=v[22656];v[22656]=0;if((a|0)==1){break d}v[22656]=0;R(450,c|0,b|0);a=v[22656];v[22656]=0;if((a|0)==1){break c}v[22656]=0;Q(401,c|0,c+24|0)|0;a=v[22656];v[22656]=0;if((a|0)==1){break c}vb(c+24|0);zc(c+40|0);gb=c- -64|0;break a}a=P()|0;O()|0;break b}a=P()|0;O()|0;vb(c+24|0)}zc(c+40|0);S(a|0);L()}}function T9(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=gb-16|0;gb=d;v[22656]=0;_(1934,a|0);c=v[22656];v[22656]=0;a:{b:{c:{if((c|0)==1){break c}v[22656]=0;_(1960,b|0);c=v[22656];v[22656]=0;if((c|0)==1){break c}c=v[a+24>>2];b=uc(d+8|0,b);v[22656]=0;e=v[b+4>>2];v[d>>2]=v[b>>2];v[d+4>>2]=e;b=W(1996,c|0,d|0,1)|0;c=v[22656];v[22656]=0;if((c|0)!=1){break b}}b=V(0)|0;O()|0;Z(b|0)|0;v[22656]=0;Y(1911,7306,a|0,0,0);a=v[22656];v[22656]=0;if((a|0)==1){break a}$();b=0}gb=d+16|0;return b|0}a=P()|0;O()|0;v[22656]=0;X(20);b=v[22656];v[22656]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}function tQ(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;e=gb-16|0;gb=e;v[e+12>>2]=c;v[e+8>>2]=v[a>>2]<<1;c=e+8|0;d=v[Fb(c,e+12|0)>>2];v[e+8>>2]=v[a>>2]<<1;v[e+4>>2]=v[e+12>>2]-d;g=d>>>1|0;h=v[Fb(c,e+4|0)>>2];c=zb(b);if(d>>>0>=2){f=v[a+20>>2];d=g;while(1){j=f,k=(zb(w[c|0])|zb(w[c+1|0])<<8)^32768,u[j>>1]=k;f=f+4|0;c=c+2|0;d=d-1|0;if(d){continue}break}}i=h>>>1|0;b=zb(b);if(h>>>0>=2){f=v[a+20>>2]+2|0;c=b+(v[a>>2]<<1)|0;d=i;while(1){j=f,k=(zb(w[c|0])|zb(w[c+1|0])<<8)^32768,u[j>>1]=k;f=f+4|0;c=c+2|0;d=d-1|0;if(d){continue}break}}gb=e+16|0;return g+i<<1}function sQ(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0;f=gb-16|0;gb=f;v[f+12>>2]=c;v[f+8>>2]=v[a>>2]<<1;c=f+8|0;e=v[Fb(c,f+12|0)>>2];v[f+8>>2]=v[a>>2]<<1;v[f+4>>2]=v[f+12>>2]-e;i=e>>>1|0;j=v[Fb(c,f+4|0)>>2];c=zb(b);if(e>>>0>=2){g=v[a+20>>2];e=i;h=d;while(1){h=(zb(w[c|0])+h|0)+(zb(w[c+1|0])<<8)|0;u[g>>1]=h;g=g+4|0;c=c+2|0;e=e-1|0;if(e){continue}break}}h=j>>>1|0;b=zb(b);if(j>>>0>=2){g=v[a+20>>2]+2|0;c=b+(v[a>>2]<<1)|0;e=h;while(1){d=(zb(w[c|0])+d|0)+(zb(w[c+1|0])<<8)|0;u[g>>1]=d;g=g+4|0;c=c+2|0;e=e-1|0;if(e){continue}break}}gb=f+16|0;return h+i<<1}function pQ(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;e=gb-16|0;gb=e;v[e+12>>2]=c;v[e+8>>2]=v[a>>2]<<1;c=e+8|0;d=v[Fb(c,e+12|0)>>2];v[e+8>>2]=v[a>>2]<<1;v[e+4>>2]=v[e+12>>2]-d;g=d>>>1|0;h=v[Fb(c,e+4|0)>>2];c=zb(b);if(d>>>0>=2){f=v[a+20>>2];d=g;while(1){j=f,k=(zb(w[c+1|0])|zb(w[c|0])<<8)^32768,u[j>>1]=k;f=f+4|0;c=c+2|0;d=d-1|0;if(d){continue}break}}i=h>>>1|0;b=zb(b);if(h>>>0>=2){f=v[a+20>>2]+2|0;c=b+(v[a>>2]<<1)|0;d=i;while(1){j=f,k=(zb(w[c+1|0])|zb(w[c|0])<<8)^32768,u[j>>1]=k;f=f+4|0;c=c+2|0;d=d-1|0;if(d){continue}break}}gb=e+16|0;return g+i<<1}function oQ(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0;f=gb-16|0;gb=f;v[f+12>>2]=c;v[f+8>>2]=v[a>>2]<<1;c=f+8|0;e=v[Fb(c,f+12|0)>>2];v[f+8>>2]=v[a>>2]<<1;v[f+4>>2]=v[f+12>>2]-e;i=e>>>1|0;j=v[Fb(c,f+4|0)>>2];c=zb(b);if(e>>>0>=2){g=v[a+20>>2];e=i;h=d;while(1){h=(zb(w[c+1|0])+h|0)+(zb(w[c|0])<<8)|0;u[g>>1]=h;g=g+4|0;c=c+2|0;e=e-1|0;if(e){continue}break}}h=j>>>1|0;b=zb(b);if(j>>>0>=2){g=v[a+20>>2]+2|0;c=b+(v[a>>2]<<1)|0;e=h;while(1){d=(zb(w[c+1|0])+d|0)+(zb(w[c|0])<<8)|0;u[g>>1]=d;g=g+4|0;c=c+2|0;e=e-1|0;if(e){continue}break}}gb=f+16|0;return h+i<<1}function T4(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;c=gb-32|0;gb=c;a:{b:{c:{if(Ie(b,-1)){break c}i=c,j=Wh(b),t[i+23|0]=j;if(w[a+44|0]){if((Lk(c+23|0,1,1,v[a+32>>2])|0)!=1){break b}break c}f=c+24|0;v[c+16>>2]=f;h=c+32|0;d=c+23|0;while(1){e=Ys(v[a+36>>2],v[a+40>>2],d,f,c+12|0,c+24|0,h,c+16|0);if(v[c+12>>2]==(d|0)){break b}if((e|0)==3){if((Lk(d,1,1,v[a+32>>2])|0)==1){break c}break b}if(e>>>0>1){break b}g=c+24|0;d=v[c+16>>2]-g|0;if((Lk(g,1,d,v[a+32>>2])|0)!=(d|0)){break b}d=v[c+12>>2];if((e|0)==1){continue}break}}a=Zs(b);break a}a=-1}gb=c+32|0;return a|0}function zM(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;b=Fi(a,b,c,d);t[a+4260|0]=e;v[a>>2]=50968;c=mc(a+4264|0);d=mc(a+4276|0);v[a+4232>>2]=1061997773;e=a+4224|0;v[e>>2]=1061158912;v[e+4>>2]=1059082943;e=a+4216|0;v[e>>2]=1038174126;v[e+4>>2]=1065353216;v[a+4208>>2]=1056964608;v[a+4212>>2]=1036831949;v[a+4328>>2]=0;e=a+4320|0;v[e>>2]=0;v[e+4>>2]=0;v[a+4312>>2]=0;v[a+4316>>2]=0;v[22656]=0;W(1532,a+44|0,2,2)|0;e=v[22656];v[22656]=0;a:{if((e|0)==1){break a}v[22656]=0;Th(b);e=v[22656];v[22656]=0;if((e|0)==1){break a}return a|0}a=P()|0;O()|0;Nc(d);Nc(c);Lf(b);S(a|0);L()}function uka(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0;f=gb+-64|0;gb=f;g=f+24|0;Kh(g,c);v[22656]=0;R(777,f+36|0,d|0);c=v[22656];v[22656]=0;a:{b:{c:{if((c|0)!=1){v[22656]=0;R(777,f+48|0,e|0);c=v[22656];v[22656]=0;if((c|0)!=1){break c}a=2}else{a=1}a=B(a,12)+g|0;b=P()|0;O()|0;while(1){a=vb(a-12|0);if((a|0)!=(f+24|0)){continue}break}break b}c=f+24|0;v[f+16>>2]=c;v[f+20>>2]=c+36;v[22656]=0;c=v[f+20>>2];v[f+8>>2]=v[f+16>>2];v[f+12>>2]=c;U(453,a|0,b|0,f+8|0);a=v[22656];v[22656]=0;if((a|0)!=1){break a}b=P()|0;O()|0;dl(f+24|0)}S(b|0);L()}dl(f+24|0);gb=f- -64|0}function U7(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;b=gb-32|0;gb=b;e=mc(a);Ld(b+24|0);a=0;c=v[b+28>>2];d=v[b+24>>2];v[22656]=0;R(1421,e|0,Ly(d,c)|0);c=v[22656];v[22656]=0;a:{if((c|0)!=1){b:{c:{c=v[b+24>>2];if((Ly(c,v[b+28>>2])|0)>0){while(1){c=v[(a<<3)+c>>2];v[22656]=0;c=Q(70,b+8|0,c|0)|0;d=v[22656];v[22656]=0;if((d|0)==1){break c}v[22656]=0;R(1423,e|0,c|0);d=v[22656];v[22656]=0;if((d|0)==1){break b}vb(c);c=v[b+24>>2];a=a+1|0;if((Ly(c,v[b+28>>2])|0)>(a|0)){continue}break}}gb=b+32|0;return}a=P()|0;O()|0;break a}a=P()|0;O()|0;vb(c);break a}a=P()|0;O()|0}yd(e);S(a|0);L()}function Y4(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;c=gb-32|0;gb=c;e=Ie(b,-1);d=w[a+52|0];a:{if(e){if(d){break a}b=v[a+48>>2];f=a,g=Ie(b,-1)^1,t[f+52|0]=g;break a}b:{if(!d){break b}v[c+16>>2]=v[a+48>>2];c:{d:{e:{d=c+20|0;switch(Ys(v[a+36>>2],v[a+40>>2],c+16|0,d,c+12|0,c+24|0,c+32|0,d)-1|0){case 0:case 1:break c;case 2:break e;default:break d}}d=v[a+48>>2];v[c+20>>2]=c+25;t[c+24|0]=d}while(1){d=v[c+20>>2];if(d>>>0<=c+24>>>0){break b}d=d-1|0;v[c+20>>2]=d;if((Vs(t[d|0],v[a+32>>2])|0)!=-1){continue}break}}b=-1;break a}t[a+52|0]=1;v[a+48>>2]=b}gb=c+32|0;return b|0}function xla(a,b){a=a|0;b=b|0;var c=0,d=0;d=gb-32|0;gb=d;ud(b,0);cD(d,a+1|0);c=d+16|0;Bc(c,d);v[22656]=0;Q(303,b+43|0,c|0)|0;c=v[22656];v[22656]=0;if((c|0)!=1){vb(d+16|0);c=a+78|0;v[b+24>>2]=w[c|0]|w[c+1|0]<<8;c=a+58|0;v[b>>2]=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);c=a+62|0;v[b+4>>2]=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);c=a+66|0;v[b+8>>2]=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);u[b+30>>1]=(w[a+73|0]<<1)+2;u[b+34>>1]=x[b+34>>1]&65533|w[a|0]>>>6&2;qc(b+8|0,v[b>>2]);qc(b+4|0,v[b+8>>2]);gb=d+32|0;return}a=P()|0;O()|0;vb(d+16|0);S(a|0);L()}function kD(a,b,c){var d=0,e=0,f=0,g=0;g=b;d=v[c+16>>2];a:{if(!d){d=c;e=w[d+74|0];t[d+74|0]=e-1|e;e=v[d>>2];b:{if(e&8){v[d>>2]=e|32;d=-1;break b}v[d+4>>2]=0;v[d+8>>2]=0;e=v[d+44>>2];v[d+28>>2]=e;v[d+20>>2]=e;v[d+16>>2]=e+v[d+48>>2];d=0}if(d){break a}d=v[c+16>>2]}f=g;g=v[c+20>>2];if(f>>>0>d-g>>>0){return kb[v[c+36>>2]](c,a,b)|0}c:{if(t[c+75|0]<0){d=0;break c}f=b;while(1){d=f;if(!d){d=0;break c}f=d-1|0;if(w[f+a|0]!=10){continue}break}f=kb[v[c+36>>2]](c,a,d)|0;if(f>>>0<d>>>0){break a}a=a+d|0;b=b-d|0;g=v[c+20>>2]}hc(g,a,b);v[c+20>>2]=v[c+20>>2]+b;f=b+d|0}return f}function ija(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0;b=gb-16|0;gb=b;h=v[a+24>>2];i=v[a+20>>2];j=v[a+16>>2];g=v[a+4>>2];e=g;f=v[a>>2];v[b+8>>2]=f;v[b+12>>2]=e;g=v[a+12>>2];v[b>>2]=v[a+8>>2];v[b+4>>2]=g;if(d){while(1){e=e+j|0;f=f>>>21&2040;e=(((B(t[e|0],u[f+46162>>1])+B(t[e-1|0],u[f+46160>>1])|0)+B(t[e+1|0],u[f+46164>>1])|0)+B(t[e+2|0],u[f+46166>>1])<<8)/16384|0;v[c>>2]=v[c>>2]+B(e,i);v[c+4>>2]=v[c+4>>2]+B(e,h);Ub(b+8|0,b);d=d-1|0;if(d){c=c+8|0;f=v[b+8>>2];e=v[b+12>>2];continue}break}f=v[b+8>>2];e=v[b+12>>2]}v[a>>2]=f;v[a+4>>2]=e;gb=b+16|0}function sI(a){var b=0,c=0;a:{b=v[a+4>>2];b:{if(!v[(v[v[b>>2]-12>>2]+b|0)+24>>2]){break b}b=v[a+4>>2];if(!_f(v[v[b>>2]-12>>2]+b|0)){break b}b=v[a+4>>2];if(!(v[(v[v[b>>2]-12>>2]+b|0)+4>>2]&8192)){break b}if(II()){break b}b=v[a+4>>2];b=v[(v[v[b>>2]-12>>2]+b|0)+24>>2];v[22656]=0;b=T(2322,b|0)|0;c=v[22656];v[22656]=0;if((c|0)!=1){if((b|0)!=-1){break b}a=v[a+4>>2];b=v[v[a>>2]-12>>2];v[22656]=0;_(2323,a+b|0);a=v[22656];v[22656]=0;if((a|0)!=1){break b}}a=V(0)|0;O()|0;Z(a|0)|0;v[22656]=0;X(20);a=v[22656];v[22656]=0;if((a|0)==1){break a}}return}V(0)|0;O()|0;Bb();L()}function e8(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=gb-32|0;gb=c;f=mc(a);a:{b:{c:{d:{e:{e=b+24|0;if(x[v[e>>2]+480188>>1]){a=0;while(1){d=v[e>>2];v[22656]=0;R(2099,c|0,(d+(a<<5)|0)+480289|0);d=v[22656];v[22656]=0;if((d|0)==1){break e}v[22656]=0;U(2092,c+16|0,b|0,c|0);d=v[22656];v[22656]=0;if((d|0)==1){break d}v[22656]=0;R(1423,f|0,c+16|0);d=v[22656];v[22656]=0;if((d|0)==1){break c}vb(c+16|0);vb(c);a=a+1|0;if(a>>>0<x[v[e>>2]+480188>>1]){continue}break}}gb=c+32|0;return}a=P()|0;O()|0;break a}a=P()|0;O()|0;break b}a=P()|0;O()|0;vb(c+16|0)}vb(c)}yd(f);S(a|0);L()}function kt(a,b,c,d,e,f){var g=0,h=0,i=0,j=0;h=gb-240|0;gb=h;g=v[c>>2];v[h+232>>2]=g;c=v[c+4>>2];v[h>>2]=a;v[h+236>>2]=c;a:{b:{c:{d:{if((g|0)!=1){g=a;i=1;break d}g=a;i=1;if(c){break d}c=a;break c}while(1){c=g-v[(d<<2)+f>>2]|0;if((kb[b|0](c,a)|0)<=0){c=g;break c}e:{if(!((d|0)<2|e)){e=v[((d<<2)+f|0)-8>>2];j=g-4|0;if((kb[b|0](j,c)|0)>=0){break e}if((kb[b|0](j-e|0,c)|0)>=0){break e}}v[(i<<2)+h>>2]=c;g=h+232|0;e=QI(g);lt(g,e);i=i+1|0;d=d+e|0;e=0;g=c;if(v[h+236>>2]|v[h+232>>2]!=1){continue}break b}break}c=g;break b}if(e){break a}}PI(h,i);cy(c,b,d,f)}gb=h+240|0}function dea(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;if(v[a+4>>2]!=v[wb(a)>>2]){c=gb-16|0;gb=c;d=Fg(c,a,1);a=wb(a);e=v[d+4>>2];v[22656]=0;lq(a,e,b);a=v[22656];v[22656]=0;a:{if((a|0)!=1){v[d+4>>2]=v[d+4>>2]+4;$b(d);gb=c+16|0;break a}a=P()|0;O()|0;$b(d);S(a|0);L()}return}c=gb-32|0;gb=c;d=a;e=wb(a);a=fn(c+8|0,fh(a,Nb(a)+1|0),Nb(a),e);f=v[a+8>>2];v[22656]=0;lq(e,f,b);b=v[22656];v[22656]=0;b:{c:{if((b|0)==1){break c}v[a+8>>2]=v[a+8>>2]+4;v[22656]=0;R(1501,d|0,a|0);b=v[22656];v[22656]=0;if((b|0)==1){break c}eh(a);gb=c+32|0;break b}b=P()|0;O()|0;eh(a);S(b|0);L()}}function Kja(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0;b=gb-16|0;gb=b;g=v[a+40>>2];h=v[a+36>>2];k=v[a+16>>2];e=v[a+4>>2];f=e;j=v[a>>2];v[b+8>>2]=j;v[b+12>>2]=e;e=v[a+12>>2];v[b>>2]=v[a+8>>2];v[b+4>>2]=e;a:{if(d){while(1){i=v[a+32>>2];f=u[(f<<1)+k>>1];h=v[a+28>>2]+h|0;e=h>>12;v[c>>2]=v[c>>2]+B(f,e);g=g+i|0;i=g>>12;v[c+4>>2]=v[c+4>>2]+B(f,i);Ub(b+8|0,b);d=d-1|0;if(d){c=c+8|0;f=v[b+12>>2];continue}break}j=v[b+8>>2];f=v[b+12>>2];break a}i=g>>12;e=h>>12}v[a+40>>2]=g;v[a+20>>2]=e;v[a+36>>2]=h;v[a+24>>2]=i;v[a>>2]=j;v[a+4>>2]=f;gb=b+16|0}function vna(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=gb-80|0;gb=d;e=Qf(d+48|0);v[22656]=0;c=Q(687,b|0,e|0)|0;f=v[22656];v[22656]=0;a:{b:{c:{if((f|0)!=1){if(c){break c}v[a>>2]=0;v[a+4>>2]=0;v[a+24>>2]=0;v[a+16>>2]=0;v[a+20>>2]=0;v[a+8>>2]=0;v[a+12>>2]=0;v[22656]=0;T(688,a|0)|0;a=v[22656];v[22656]=0;if((a|0)!=1){break b}}break a}c=e+2|0;c=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);v[22656]=0;U(288,d|0,b|0,c|0);b=v[22656];v[22656]=0;if((b|0)==1){break a}b=kc(d+24|0,d);Vc(e+8|0,b);xb(b);xb(d);nW(a,e)}ed(e);gb=d+80|0;return}a=P()|0;O()|0;ed(e);S(a|0);L()}function LU(a,b){var c=0,d=0,e=0;a:{c=gb+-64|0;gb=c;d=c+40|0;Re(d,a,4);a=v[d>>2];v[22656]=0;d=Sd(d);e=v[22656];v[22656]=0;b:{c:{d:{if((e|0)==1){break d}d=zb(d);v[22656]=0;Xe(c+8|0,3,d,a);a=v[22656];v[22656]=0;if((a|0)==1){break d}v[22656]=0;R(324,c+24|0,c+8|0);a=v[22656];v[22656]=0;if((a|0)==1){break d}v[22656]=0;R(869,c|0,b|0);a=v[22656];v[22656]=0;if((a|0)==1){break c}v[22656]=0;Q(401,c|0,c+24|0)|0;a=v[22656];v[22656]=0;if((a|0)==1){break c}vb(c+24|0);zc(c+40|0);gb=c- -64|0;break a}a=P()|0;O()|0;break b}a=P()|0;O()|0;vb(c+24|0)}zc(c+40|0);S(a|0);L()}}function _w(a){var b=0,c=0,d=0,e=0,f=0;a:{if(y[a+4>>2]<y[wb(a)>>2]){b=gb-16|0;gb=b;c=Nw(b,a,1);d=wb(a);e=v[c+4>>2];v[22656]=0;R(208,d|0,e|0);d=v[22656];v[22656]=0;if((d|0)!=1){v[c+4>>2]=v[c+4>>2]+36;$b(c);gb=b+16|0;break a}a=P()|0;O()|0;$b(c);S(a|0);L()}d=gb-32|0;gb=d;c=a;e=wb(a);b=VF(d+8|0,WF(a,bl(a)+1|0),bl(a),e);f=v[b+8>>2];v[22656]=0;R(208,e|0,f|0);e=v[22656];v[22656]=0;b:{c:{if((e|0)==1){break c}v[b+8>>2]=v[b+8>>2]+36;v[22656]=0;R(209,c|0,b|0);c=v[22656];v[22656]=0;if((c|0)==1){break c}ms(b);gb=d+32|0;break b}a=P()|0;O()|0;ms(b);S(a|0);L()}}lj(a)}function _D(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;if(v[a+4>>2]!=v[wb(a)>>2]){c=gb-16|0;gb=c;d=li(c,a,1);a=wb(a);e=v[d+4>>2];v[22656]=0;xn(a,e,b);a=v[22656];v[22656]=0;a:{if((a|0)!=1){v[d+4>>2]=v[d+4>>2]+2;$b(d);gb=c+16|0;break a}a=P()|0;O()|0;$b(d);S(a|0);L()}return}c=gb-32|0;gb=c;d=a;e=wb(a);a=Gn(c+8|0,Vk(a,tc(a)+1|0),tc(a),e);f=v[a+8>>2];v[22656]=0;xn(e,f,b);b=v[22656];v[22656]=0;b:{c:{if((b|0)==1){break c}v[a+8>>2]=v[a+8>>2]+2;v[22656]=0;R(313,d|0,a|0);b=v[22656];v[22656]=0;if((b|0)==1){break c}Hh(a);gb=c+32|0;break b}b=P()|0;O()|0;Hh(a);S(b|0);L()}}function Wna(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;if(v[a+4>>2]!=v[wb(a)>>2]){c=gb-16|0;gb=c;d=Np(c,a,1);wb(a);a=v[d+4>>2];v[22656]=0;R(657,a|0,b|0);a=v[22656];v[22656]=0;a:{if((a|0)!=1){v[d+4>>2]=v[d+4>>2]+12;$b(d);gb=c+16|0;break a}a=P()|0;O()|0;$b(d);S(a|0);L()}return}c=gb-32|0;gb=c;d=a;e=wb(a);a=us(c+8|0,bx(a,Ec(a)+1|0),Ec(a),e);e=v[a+8>>2];v[22656]=0;R(657,e|0,b|0);b=v[22656];v[22656]=0;b:{c:{if((b|0)==1){break c}v[a+8>>2]=v[a+8>>2]+12;v[22656]=0;On(d,a);b=v[22656];v[22656]=0;if((b|0)==1){break c}ts(a);gb=c+32|0;break b}b=P()|0;O()|0;ts(a);S(b|0);L()}}function Et(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0;f=gb-16|0;gb=f;v[f+12>>2]=b;u[f+10>>1]=0;u[f+8>>1]=65535;a:{b:{if(Ft(f+12|0,f+10|0,f+8|0)){a=a+24|0;if(!me(v[a>>2]+484344|0,b&65535)){break a}b=_b(v[a>>2]+484344|0,b);if((d|0)<0|v[b+12>>2]<=(c|0)|(c|0)<0){break a}if(x[v[a>>2]+480188>>1]>d>>>0){break b}}break a}if(e>>>0>5){break a}a=Yc(b,c,d&65535);c:{switch(e-1|0){default:g=w[a|0];break a;case 0:g=w[a+1|0];break a;case 1:g=w[a+2|0];break a;case 2:g=w[a+3|0];break a;case 3:g=w[a+4|0];break a;case 4:break c}}g=w[a+5|0]}gb=f+16|0;return g|0}function Lja(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0;b=gb-16|0;gb=b;g=v[a+40>>2];h=v[a+36>>2];k=v[a+16>>2];e=v[a+4>>2];f=e;j=v[a>>2];v[b+8>>2]=j;v[b+12>>2]=e;e=v[a+12>>2];v[b>>2]=v[a+8>>2];v[b+4>>2]=e;a:{if(d){while(1){i=v[a+32>>2];f=t[f+k|0]<<8;h=v[a+28>>2]+h|0;e=h>>12;v[c>>2]=v[c>>2]+B(f,e);g=g+i|0;i=g>>12;v[c+4>>2]=v[c+4>>2]+B(f,i);Ub(b+8|0,b);d=d-1|0;if(d){c=c+8|0;f=v[b+12>>2];continue}break}j=v[b+8>>2];f=v[b+12>>2];break a}i=g>>12;e=h>>12}v[a+40>>2]=g;v[a+20>>2]=e;v[a+36>>2]=h;v[a+24>>2]=i;v[a>>2]=j;v[a+4>>2]=f;gb=b+16|0}function fD(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;if(y[a+4>>2]<y[wb(a)>>2]){c=gb-16|0;gb=c;d=Fg(c,a,1);a=wb(a);e=v[d+4>>2];v[22656]=0;ep(a,e,b);a=v[22656];v[22656]=0;a:{if((a|0)!=1){v[d+4>>2]=v[d+4>>2]+4;$b(d);gb=c+16|0;break a}a=P()|0;O()|0;$b(d);S(a|0);L()}return}c=gb-32|0;gb=c;d=a;e=wb(a);a=fn(c+8|0,fh(a,Nb(a)+1|0),Nb(a),e);f=v[a+8>>2];v[22656]=0;ep(e,f,b);b=v[22656];v[22656]=0;b:{c:{if((b|0)==1){break c}v[a+8>>2]=v[a+8>>2]+4;v[22656]=0;R(52,d|0,a|0);b=v[22656];v[22656]=0;if((b|0)==1){break c}eh(a);gb=c+32|0;break b}b=P()|0;O()|0;eh(a);S(b|0);L()}}function R0(){var a=0;a:{if(t[465376]&1){break a}if(!Qd(465376)){break a}a=465088;while(1){a=Kb(a)+12|0;if((a|0)!=465376){continue}break}Pd(465376)}ld(465088,86024);ld(465100,86056);ld(465112,86092);ld(465124,86116);ld(465136,86140);ld(465148,86156);ld(465160,86176);ld(465172,86196);ld(465184,86224);ld(465196,86264);ld(465208,86296);ld(465220,86332);ld(465232,86368);ld(465244,86384);ld(465256,86400);ld(465268,86416);ld(465280,86140);ld(465292,86432);ld(465304,86448);ld(465316,86464);ld(465328,86480);ld(465340,86496);ld(465352,86512);ld(465364,86528)}function zP(a,b){var c=0,d=0,e=0,f=0,g=0;g=gb-16|0;gb=g;a:{if(!w[b+846|0]|v[a+480180>>2]!=1){break a}c=v[b+104>>2];if(!c){break a}if(!Jd(c)){break a}d=x[c+34>>1];if(!(d&10)){break a}e=w[b+847|0]+w[(w[b+846|0]&15)+39680|0]|0;t[b+847|0]=e;if(e<<24>>24>=0){break a}t[b+847|0]=0;e=d&2;d=v[(e?4:12)+c>>2];f=v[b+760>>2]+1|0;v[b+760>>2]=f>>>0<v[(e?8:16)+c>>2]-d>>>0?f:0;e=jj(c);f=g+8|0;bc(f,zb(zb(v[c+20>>2]))+B(e,v[b+760>>2]+d|0)|0,e);b=v[f>>2];d=v[f+4>>2];if((b|0)!=(d|0)){while(1){t[b|0]=w[b|0]^-1;b=b+1|0;if((d|0)!=(b|0)){continue}break}}_h(c,a,0)}gb=g+16|0}function qy(a,b,c){var d=0,e=0,f=C(0),g=C(0),h=0,i=C(0),j=C(0),k=C(0),l=C(0);e=gb-32|0;gb=e;oJ(C(-z[a>>2]),C(z[a+24>>2]+z[a+12>>2]),C(z[a+48>>2]+z[a+36>>2]),e+20|0);oJ(z[a+60>>2],C(z[a+48>>2]-z[a+36>>2]),C(z[a+24>>2]-z[a+12>>2]),e+8|0);z[e+12>>2]=-z[e+12>>2];a=0;while(1){d=a<<2;h=d+c|0;i=z[h>>2];f=z[d+(e+20|0)>>2];g=z[d+68272>>2];j=z[d+68284>>2];k=z[d+(e+8|0)>>2];z[h>>2]=C(f*g)-C(j*k);h=b+d|0;l=z[(0-a<<2)+68280>>2];f=C(C(f*j)+C(k*g));d=5-a<<2;g=z[d+68272>>2];z[h>>2]=C(i*l)-C(f*g);z[b+d>>2]=C(f*l)+C(i*g);a=a+1|0;if((a|0)!=3){continue}break}gb=e+32|0}function gma(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=gb-32|0;gb=c;e=c+24|0;bc(e,b,26);e=yb(e);d=v[c+28>>2];f=v[c+24>>2];v[c+8>>2]=f;v[c+12>>2]=d;v[c>>2]=f;v[c+4>>2]=d;d=c+16|0;cc(d,a,c);d=yb(d);if((d|0)==(e|0)){Rb(a,yb(c+24|0))}gb=c+32|0;if((d|0)!=(e|0)){t[b|0]=0;t[b+1|0]=0;t[b+2|0]=0;t[b+3|0]=0;t[b+4|0]=0;t[b+5|0]=0;t[b+6|0]=0;t[b+7|0]=0;t[b+24|0]=0;t[b+25|0]=0;t[b+16|0]=0;t[b+17|0]=0;t[b+18|0]=0;t[b+19|0]=0;t[b+20|0]=0;t[b+21|0]=0;t[b+22|0]=0;t[b+23|0]=0;t[b+8|0]=0;t[b+9|0]=0;t[b+10|0]=0;t[b+11|0]=0;t[b+12|0]=0;t[b+13|0]=0;t[b+14|0]=0;t[b+15|0]=0}}function uQ(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;e=gb-16|0;gb=e;v[e+12>>2]=c;v[e+8>>2]=v[a>>2]<<1;c=e+8|0;d=v[Fb(c,e+12|0)>>2];v[e+8>>2]=v[a>>2]<<1;v[e+4>>2]=v[e+12>>2]-d;g=d>>>1|0;h=v[Fb(c,e+4|0)>>2];c=zb(b);if(d>>>0>=2){f=v[a+20>>2];d=g;while(1){j=f,k=zb(w[c|0])|zb(w[c+1|0])<<8,u[j>>1]=k;f=f+4|0;c=c+2|0;d=d-1|0;if(d){continue}break}}i=h>>>1|0;b=zb(b);if(h>>>0>=2){f=v[a+20>>2]+2|0;c=b+(v[a>>2]<<1)|0;d=i;while(1){j=f,k=zb(w[c|0])|zb(w[c+1|0])<<8,u[j>>1]=k;f=f+4|0;c=c+2|0;d=d-1|0;if(d){continue}break}}gb=e+16|0;return g+i<<1}function qQ(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;e=gb-16|0;gb=e;v[e+12>>2]=c;v[e+8>>2]=v[a>>2]<<1;c=e+8|0;d=v[Fb(c,e+12|0)>>2];v[e+8>>2]=v[a>>2]<<1;v[e+4>>2]=v[e+12>>2]-d;g=d>>>1|0;h=v[Fb(c,e+4|0)>>2];c=zb(b);if(d>>>0>=2){f=v[a+20>>2];d=g;while(1){j=f,k=zb(w[c+1|0])|zb(w[c|0])<<8,u[j>>1]=k;f=f+4|0;c=c+2|0;d=d-1|0;if(d){continue}break}}i=h>>>1|0;b=zb(b);if(h>>>0>=2){f=v[a+20>>2]+2|0;c=b+(v[a>>2]<<1)|0;d=i;while(1){j=f,k=zb(w[c+1|0])|zb(w[c|0])<<8,u[j>>1]=k;f=f+4|0;c=c+2|0;d=d-1|0;if(d){continue}break}}gb=e+16|0;return g+i<<1}function Ek(a){var b=0,c=0,d=0,e=0;a:{o(+a);b=j(1)|0;j(0)|0;d=b;b=b&2147483647;b:{if(b>>>0>=1083174912){if(!((d|0)<0|b>>>0<1083179008)){return a*8.98846567431158e307}if(b>>>0>=2146435072){return-1/a}if(!(a<=-1075)){break a}c=0;if((d|0)<0){break b}break a}if(b>>>0>1016070143){break a}c=a+1}return c}e=a+26388279066624;o(+e);j(1)|0;b=(j(0)|0)+128|0;d=b<<4&4080;c=A[d+29040>>3];a=a-(e+-26388279066624)-A[d+29048>>3];return ii(c+c*a*(a*(a*(a*(a*.0013333559164630223+.009618129842126066)+.0555041086648214)+.2402265069591)+.6931471805599453),(b&-256)/256|0)}function Zoa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;if(y[a+4>>2]<y[wb(a)>>2]){c=gb-16|0;gb=c;d=gw(c,a,1);a=wb(a);e=v[d+4>>2];v[22656]=0;Fv(a,e,b);a=v[22656];v[22656]=0;a:{if((a|0)!=1){v[d+4>>2]=v[d+4>>2]+20;$b(d);gb=c+16|0;break a}a=P()|0;O()|0;$b(d);S(a|0);L()}return}c=gb-32|0;gb=c;d=a;e=wb(a);a=iD(c+8|0,jD(a,Je(a)+1|0),Je(a),e);f=v[a+8>>2];v[22656]=0;Fv(e,f,b);b=v[22656];v[22656]=0;b:{c:{if((b|0)==1){break c}v[a+8>>2]=v[a+8>>2]+20;v[22656]=0;Ev(d,a);b=v[22656];v[22656]=0;if((b|0)==1){break c}jp(a);gb=c+32|0;break b}b=P()|0;O()|0;jp(a);S(b|0);L()}}function Ena(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;e=gb-48|0;gb=e;v[22656]=0;c=Q(191,a|0,1)|0;d=v[22656];v[22656]=0;a:{if((d|0)==1){break a}b:{c:{if(!c){break c}v[22656]=0;_(679,b|0);c=v[22656];v[22656]=0;if((c|0)==1){break a}v[22656]=0;c=T(374,a|0)|0;d=v[22656];v[22656]=0;if((d|0)==1){break b}if(!c){break c}while(1){v[22656]=0;d=Q(680,a|0,e+8|0)|0;f=v[22656];v[22656]=0;if((f|0)==1){break b}c=c-1|0;d:{if(!d){break d}d=w[e+8|0];if(d>>>0>63){break d}hc(xW(b,d),e+8|0,33)}if(c&255){continue}break}}xb(a);gb=e+48|0;return}}b=P()|0;O()|0;xb(a);S(b|0);L()}function jW(a){var b=0,c=0;a:{if(sd(a,11493,3)){break a}b=a+3|0;if(w[b|0]<48|w[b|0]>51){break a}b=a+8|0;if(Xb(w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24))>>>0<52){break a}if(Xb(w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24))>>>0>4294966507){break a}b=a+16|0;if(Xb(w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24))>>>0<52){break a}b=a+24|0;if(Xb(w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24))){if(Xb(w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24))>>>0<52){break a}}a=a+32|0;c=Xb(w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24))>>>0<4294967216}return c}function Yz(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0;e=gb-16|0;gb=e;a:{if(w[b+791|0]!=27){a=t[b+831|0];break a}c=e+8|0;f=a+1074312|0;Db(c,f,21);d=Cb(c);g=a;a=w[b+821|0];a=Uz(g,w[b+828|0],d?a:a+16>>>2|0);Db(c,f,45);b:{if(!(!Cb(c)|w[b+828|0]!=3)){g=b;d=w[b+821|0];c:{if(!(!d|d>>>0>=w[b+829|0])){a=w[b+832|0];c=d+1|0;break c}t[b+832|0]=a;c=1}t[g+821|0]=c;a=a<<24>>24;break b}t[b+821|0]=w[b+821|0]+w[b+829|0]}c=e+8|0;Db(c,f,47);if(!Cb(c)){break a}t[b+831|0]=a}if(a){h=b,i=Lb(v[b+684>>2]+((B(w[b+830|0],a)+2|0)/8|0)|0,0,256),v[h+684>>2]=i}gb=e+16|0}function m0(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;d=gb-16|0;gb=d;v[d+12>>2]=b;if(b>>>0<=1073741807){i=d,j=Ab(a),v[i+8>>2]=j;e=om(v[Lc(d+12|0,d+8|0)>>2]);if((e|0)!=(Xp(a)|0)){a:{f=1;g=Xp(a);h=Ab(a);b:{if((e|0)==1){b=a;c=v[a>>2];break b}c=e+1|0;b=a;c:{if(e>>>0>g>>>0){b=Si(b,c);break c}v[22656]=0;b=Q(2809,b|0,c|0)|0;c=v[22656];v[22656]=0;if((c|0)!=1){break c}a=V(0)|0;O()|0;Z(a|0)|0;$();break a}f=De(a);c=Jb(a)}yi(b,c,Ab(a)+1|0);if(f){ai(a,c,g+1|0)}d:{if((e|0)!=1){rg(a,e+1|0);de(a,h);ef(a,b);break d}_e(a,h)}}}gb=d+16|0;return}vg();L()}function Rq(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;d=gb-16|0;gb=d;v[d+12>>2]=b;if(b>>>0<=4294967279){i=d,j=Ab(a),v[i+8>>2]=j;e=Xk(v[Lc(d+12|0,d+8|0)>>2]);if((e|0)!=(Kc(a)|0)){a:{f=Kc(a);g=Ab(a);b:{if((e|0)==10){h=1;b=a;c=v[a>>2];break b}c=e+1|0;b=a;c:{if(e>>>0>f>>>0){b=oi(b,c);break c}v[22656]=0;b=Q(67,b|0,c|0)|0;c=v[22656];v[22656]=0;if((c|0)!=1){break c}a=V(0)|0;O()|0;Z(a|0)|0;$();break a}h=De(a);c=Jb(a)}Qg(b,c,Ab(a)+1|0);if(h){al(a,c,f+1|0)}d:{if((e|0)!=10){rg(a,e+1|0);de(a,g);ef(a,b);break d}_e(a,g)}}}gb=d+16|0;return}vg();L()}function Q4(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;c=gb-32|0;gb=c;a:{b:{c:{if(Ie(b,-1)){break c}v[c+20>>2]=b;if(w[a+44|0]){if((Lk(c+20|0,4,1,v[a+32>>2])|0)!=1){break b}break c}f=c+24|0;v[c+16>>2]=f;h=c+32|0;d=c+20|0;while(1){e=Ys(v[a+36>>2],v[a+40>>2],d,f,c+12|0,c+24|0,h,c+16|0);if(v[c+12>>2]==(d|0)){break b}if((e|0)==3){if((Lk(d,1,1,v[a+32>>2])|0)==1){break c}break b}if(e>>>0>1){break b}g=c+24|0;d=v[c+16>>2]-g|0;if((Lk(g,1,d,v[a+32>>2])|0)!=(d|0)){break b}d=v[c+12>>2];if((e|0)==1){continue}break}}a=Zs(b);break a}a=-1}gb=c+32|0;return a|0}function Fka(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=vh(a);a:{if(b){v[22656]=0;R(936,a|0,b|0);d=v[22656];v[22656]=0;if((d|0)==1){break a}e=gb-16|0;gb=e;d=Nw(e,a,b);b=v[d+4>>2];f=v[d+8>>2];if((b|0)!=(f|0)){while(1){c=Qb(b,0,36);v[c>>2]=0;v[c+4>>2]=0;u[c+22>>1]=0;u[c+24>>1]=0;u[c+26>>1]=0;u[c+28>>1]=0;t[c+21|0]=64;t[c+19|0]=64;t[c+20|0]=100;t[c+15|0]=0;t[c+16|0]=0;t[c+17|0]=0;t[c+18|0]=0;v[c+8>>2]=0;v[c+12>>2]=0;u[c+30>>1]=0;u[c+32>>1]=0;b=b+36|0;v[d+4>>2]=b;if((b|0)!=(f|0)){continue}break}}$b(d);gb=e+16|0}return a|0}a=P()|0;O()|0;PB(c);S(a|0);L()}function sj(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,k=0;f=gb-16|0;gb=f;o(+b);h=j(1)|0;e=j(0)|0;g=h&2147483647;c=g;d=e;g=c+-1048576|0;a:{if((g|0)==2145386495|g>>>0<2145386495){i=d<<28;e=c>>>4|0;c=(c&15)<<28|d>>>4;d=e+1006632960|0;break a}if((c|0)==2146435072|c>>>0>2146435072){i=e<<28;c=h;e=c>>>4|0;c=(c&15)<<28|d>>>4;d=e|2147418112;break a}if(!(c|d)){c=0;d=0;break a}g=c;c=c?E(c):E(e)+32|0;Kf(f,d,g,0,0,c+49|0);k=v[f>>2];i=v[f+4>>2];e=15372-c<<16;c=v[f+8>>2];d=e|v[f+12>>2]^65536}v[a>>2]=k;v[a+4>>2]=i;v[a+8>>2]=c;v[a+12>>2]=h&-2147483648|d;gb=f+16|0}function Ega(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=C(0),g=0,h=0,i=0,j=0;d=gb-16|0;gb=d;v[d+12>>2]=c>>>2;v[d+8>>2]=v[a>>2];g=v[Fb(d+12|0,d+8|0)>>2];b=zb(b);if(g){c=v[a+20>>2];a=g;while(1){e=w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24);v[d+12>>2]=e<<24|e<<8&16711680|(e>>>8&65280|e>>>24);v[d+8>>2]=-1082130432;v[d+4>>2]=1065353216;f=C(z[zf(d+12|0,d+8|0,d+4|0)>>2]*C(32768));z[d+12>>2]=f;e=c;f=fe(f);a:{if(C(D(f))<C(2147483648)){h=~~f;break a}h=-2147483648}i=e,j=Uc(h),u[i>>1]=j;c=c+2|0;b=b+4|0;a=a-1|0;if(a){continue}break}}gb=d+16|0;return g<<2}function Cz(a,b,c,d,e,f,g,h){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0;j=gb-16|0;gb=j;v[j+12>>2]=d;d=a+12|0;i=d;a:{if(!(w[i|0]|w[i+1|0]<<8|(w[i+2|0]<<16|w[i+3|0]<<24))){break a}i=a+8|0;v[j+8>>2]=w[i|0]|w[i+1|0]<<8|(w[i+2|0]<<16|w[i+3|0]<<24);k=b,l=v[Fb(j+8|0,j+12|0)>>2],v[k>>2]=l;b=Md(w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24),v[b>>2],v[j+12>>2]);v[c>>2]=b;if(!(b>>>0>=y[j+12>>2]|h)){v[c>>2]=b+1}u[e>>1]=x[e>>1]|f;a=a+4|0;if((w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24))!=1){break a}u[e>>1]=x[e>>1]|g}gb=j+16|0}function Af(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=gb-16|0;gb=d;u[d+12>>1]=65535;u[d+14>>1]=b;f=d+12|0;b=x[Pc(28400,d+14|0)>>1];c=tc(a);a:{if(b>>>0>c>>>0){e=gb-32|0;gb=e;b:{c:{c=b-c|0;d:{if(c>>>0<=v[wb(a)>>2]-v[a+4>>2]>>1>>>0){up(a,c,f);break d}b=wb(a);b=Gn(e+8|0,Vk(a,tc(a)+c|0),tc(a),b);v[22656]=0;U(312,b|0,c|0,f|0);c=v[22656];v[22656]=0;if((c|0)==1){break c}v[22656]=0;R(313,a|0,b|0);a=v[22656];v[22656]=0;if((a|0)==1){break c}Hh(b)}gb=e+32|0;break b}a=P()|0;O()|0;Hh(b);S(a|0);L()}break a}if(b>>>0<c>>>0){yn(a,v[a>>2]+(b<<1)|0)}}gb=d+16|0}function dF(a,b){var c=0,d=0,e=0,f=0,g=0,h=0;f=w[a+8|0];g=v[a>>2];a=v[a+4>>2];d=Jb(b);b=Ab(b);c=gb-16|0;gb=c;v[c+8>>2]=b;v[c+12>>2]=a;e=v[Fb(c+12|0,c+8|0)>>2];a:{b:{if(!e){a=g;break b}b=e;a=g;while(1){h=w[d|0];t[a|0]=h;if(!h){break a}d=d+1|0;a=a+1|0;b=b-1|0;if(b){continue}break}}b=0}c:{if((f-1&255)>>>0<=1){d=v[c+12>>2];t[c+7|0]=0;Lo(a,((a+d|0)-e|0)+b|0,c+7|0);break c}if((f-3&255)>>>0>1){break c}d=v[c+12>>2];t[c+6|0]=32;Lo(a,((a+d|0)-e|0)+b|0,c+6|0)}d:{switch(f-1|0){case 0:case 3:t[(v[c+12>>2]+g|0)-1|0]=0;break;default:break d}}gb=c+16|0}function q_(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=gb-16|0;gb=d;v[d+12>>2]=v[v[a+1060>>2]>>2]-v[a+1064>>2];v[d+8>>2]=16384;e=v[Fb(d+12|0,d+8|0)>>2];v[a+1072>>2]=e;c=17;v[d+4>>2]=17;a:{if(!e){break a}while(1){f=1<<c-1;e=cl(a,c);b:{c:{d:{if((c|0)<=6){if((e|0)!=(f|0)){break d}bs(d+4|0,cl(a,4));break b}if(c>>>0>16){break c}c=f-8|0;if((c|0)>(e|0)|(e|0)>(f+7|0)){break d}bs(d+4|0,e-c|0);break b}mF(a,e,f,b);break b}c=e&(f^-1);if(e&f){v[d+4>>2]=c+1;break b}mF(a,c,0,b)}if(!v[a+1072>>2]){break a}c=v[d+4>>2];if((c|0)<18){continue}break}}gb=d+16|0}function F3(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0;a=gb-32|0;gb=a;u[a+28>>1]=w[81061]|w[81062]<<8;v[a+24>>2]=w[81057]|w[81058]<<8|(w[81059]<<16|w[81060]<<24);g=a+24|0;il(g|1,8041,1,v[c+4>>2]);i=v[c+4>>2];f=a-16|0;gb=f;h=xe();v[a>>2]=e;e=i>>>9&1;g=Ff(f,e+13|0,h,g,a)+f|0;i=Tg(f,g,c);e=f-((e<<3)+107&112)|0;gb=e;h=a+8|0;Fc(h,c);v[22656]=0;ja(2473,f|0,i|0,g|0,e|0,a+20|0,a+16|0,h|0);f=v[22656];v[22656]=0;if((f|0)!=1){Wb(a+8|0);b=Un(b,e,v[a+20>>2],v[a+16>>2],c,d);gb=a+32|0;return b|0}b=P()|0;O()|0;Wb(a+8|0);S(b|0);L()}function tga(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=C(0),g=0,h=C(0),i=0,j=0,k=0;e=gb-16|0;gb=e;v[e+12>>2]=c>>>2;v[e+8>>2]=v[a>>2];c=v[Fb(e+12|0,e+8|0)>>2];h=z[d>>2];b=zb(b);if(c){a=v[a+20>>2];d=c;while(1){z[e+12>>2]=h*(l(2,w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24)),q());v[e+8>>2]=-1082130432;v[e+4>>2]=1065353216;f=C(z[zf(e+12|0,e+8|0,e+4|0)>>2]*C(32768));z[e+12>>2]=f;i=a;f=fe(f);a:{if(C(D(f))<C(2147483648)){g=~~f;break a}g=-2147483648}j=i,k=Uc(g),u[j>>1]=k;a=a+2|0;b=b+4|0;d=d-1|0;if(d){continue}break}}gb=e+16|0;return c<<2}function p_(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=gb-16|0;gb=d;v[d+12>>2]=v[v[a+1060>>2]>>2]-v[a+1064>>2];v[d+8>>2]=32768;e=v[Fb(d+12|0,d+8|0)>>2];v[a+1072>>2]=e;c=9;v[d+4>>2]=9;a:{if(!e){break a}while(1){f=1<<c-1;e=cl(a,c);b:{c:{d:{if((c|0)<=6){if((e|0)!=(f|0)){break d}bs(d+4|0,cl(a,3));break b}if(c>>>0>8){break c}c=f-4|0;if((c|0)>(e|0)|(e|0)>(f+3|0)){break d}bs(d+4|0,e-c|0);break b}lF(a,e,f,b);break b}c=e&(f^-1);if(e&f){v[d+4>>2]=c+1;break b}lF(a,c,0,b)}if(!v[a+1072>>2]){break a}c=v[d+4>>2];if((c|0)<10){continue}break}}gb=d+16|0}function Oka(a,b){a=a|0;b=b|0;var c=0,d=0;c=gb-80|0;gb=c;d=c- -64|0;an(d,b);v[22656]=0;Vd(c+32|0,d);b=v[22656];v[22656]=0;a:{b:{if((b|0)==1){break b}b=Ud(c+24|0);v[22656]=0;d=v[c+36>>2];v[c+16>>2]=v[c+32>>2];v[c+20>>2]=d;d=v[b+4>>2];v[c+8>>2]=v[b>>2];v[c+12>>2]=d;b=W(203,c+40|0,c+16|0,c+8|0)|0;d=v[22656];v[22656]=0;if((d|0)==1){break b}d=dd(a);a=oc(c- -64|0);v[22656]=0;U(926,b|0,d|0,a>>>5|0);a=v[22656];v[22656]=0;if((a|0)==1){a=P()|0;O()|0;Xu(d);xb(b);break a}xb(b);gc(c- -64|0);gb=c+80|0;return}a=P()|0;O()|0}gc(c- -64|0);S(a|0);L()}function Lka(a,b){a=a|0;b=b|0;var c=0,d=0;c=gb-80|0;gb=c;d=c- -64|0;an(d,b);v[22656]=0;Vd(c+32|0,d);b=v[22656];v[22656]=0;a:{b:{if((b|0)==1){break b}b=Ud(c+24|0);v[22656]=0;d=v[c+36>>2];v[c+16>>2]=v[c+32>>2];v[c+20>>2]=d;d=v[b+4>>2];v[c+8>>2]=v[b>>2];v[c+12>>2]=d;b=W(203,c+40|0,c+16|0,c+8|0)|0;d=v[22656];v[22656]=0;if((d|0)==1){break b}d=dd(a);a=oc(c- -64|0);v[22656]=0;U(927,b|0,d|0,a>>>2|0);a=v[22656];v[22656]=0;if((a|0)==1){a=P()|0;O()|0;ci(d);xb(b);break a}xb(b);gc(c- -64|0);gb=c+80|0;return}a=P()|0;O()|0}gc(c- -64|0);S(a|0);L()}function LR(a,b){a=a|0;b=+b;var c=0,d=0,e=0,f=0,g=0,h=0,i=0;f=qq(b);d=a;e=vh(a);v[22656]=0;R(1117,a|0,2048);a=v[22656];v[22656]=0;a:{if((a|0)!=1){v[22656]=0;DR(d);a=v[22656];v[22656]=0;if((a|0)!=1){break a}}a=P()|0;O()|0;Mf(e);S(a|0);L()}a=0;b:{while(1){c=1;if((a|0)!=1024){v[22656]=0;c=+(a-1024|0);g=qq(K(c*c*-9.5367431640625e-7+1)*b);e=v[22656];v[22656]=0;if((e|0)==1){break b}c=c*.0372006759294457;c=ri(c)*g/(f*c)}h=ye(d,a),i=c*.011841342921061943,A[h>>3]=i;a=a+1|0;if((a|0)!=2048){continue}break}return}a=P()|0;O()|0;Mf(d);S(a|0);L()}function Kka(a,b){a=a|0;b=b|0;var c=0,d=0;c=gb-80|0;gb=c;d=c- -64|0;an(d,b);v[22656]=0;Vd(c+32|0,d);b=v[22656];v[22656]=0;a:{b:{if((b|0)==1){break b}b=Ud(c+24|0);v[22656]=0;d=v[c+36>>2];v[c+16>>2]=v[c+32>>2];v[c+20>>2]=d;d=v[b+4>>2];v[c+8>>2]=v[b>>2];v[c+12>>2]=d;b=W(203,c+40|0,c+16|0,c+8|0)|0;d=v[22656];v[22656]=0;if((d|0)==1){break b}d=dd(a);a=oc(c- -64|0);v[22656]=0;U(928,b|0,d|0,a>>>8|0);a=v[22656];v[22656]=0;if((a|0)==1){a=P()|0;O()|0;Vu(d);xb(b);break a}xb(b);gc(c- -64|0);gb=c+80|0;return}a=P()|0;O()|0}gc(c- -64|0);S(a|0);L()}function Jka(a,b){a=a|0;b=b|0;var c=0,d=0;c=gb-80|0;gb=c;d=c- -64|0;an(d,b);v[22656]=0;Vd(c+32|0,d);b=v[22656];v[22656]=0;a:{b:{if((b|0)==1){break b}b=Ud(c+24|0);v[22656]=0;d=v[c+36>>2];v[c+16>>2]=v[c+32>>2];v[c+20>>2]=d;d=v[b+4>>2];v[c+8>>2]=v[b>>2];v[c+12>>2]=d;b=W(203,c+40|0,c+16|0,c+8|0)|0;d=v[22656];v[22656]=0;if((d|0)==1){break b}d=dd(a);a=oc(c- -64|0);v[22656]=0;U(929,b|0,d|0,a>>>4|0);a=v[22656];v[22656]=0;if((a|0)==1){a=P()|0;O()|0;Uu(d);xb(b);break a}xb(b);gc(c- -64|0);gb=c+80|0;return}a=P()|0;O()|0}gc(c- -64|0);S(a|0);L()}function mfa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=gb-48|0;gb=d;c=d+24|0;Tm(c,b,1819307379);Vc(a+40|0,c);xb(c);Tm(c,b,1953721961);Vc(a+60|0,c);xb(c);Tm(c,b,543520099);Vc(a+120|0,c);xb(c);Tm(c,b,1414744396);v[22656]=0;c=Q(555,c|0,11095)|0;e=v[22656];v[22656]=0;a:{if((e|0)!=1){b:{if(c){v[22656]=0;U(1429,d|0,d+24|0,2);c=v[22656];v[22656]=0;if((c|0)==1){break b}TN(a+140|0,d);zB(d)}v[22656]=0;U(1430,d|0,b|0,1634890872);b=v[22656];v[22656]=0;if((b|0)!=1){break a}}}a=P()|0;O()|0;xb(d+24|0);S(a|0);L()}Vc(a+80|0,d);xb(d);xb(d+24|0);gb=d+48|0}function rma(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;a:{d=gb-80|0;gb=d;Se(b);e=d+56|0;Re(e,a,c);a=v[e>>2];v[22656]=0;c=Sd(e);e=v[22656];v[22656]=0;b:{c:{d:{if((e|0)==1){break d}c=zb(c);v[22656]=0;Xe(d+8|0,2,c,a);a=v[22656];v[22656]=0;if((a|0)==1){break d}v[22656]=0;R(324,d+24|0,d+8|0);a=v[22656];v[22656]=0;if((a|0)==1){break d}v[22656]=0;U(13,d+40|0,2,d+24|0);a=v[22656];v[22656]=0;if((a|0)==1){break c}a=d+40|0;Eb(b,a);vb(a);vb(d+24|0);zc(d+56|0);gb=d+80|0;break a}a=P()|0;O()|0;break b}a=P()|0;O()|0;vb(d+24|0)}zc(d+56|0);S(a|0);L()}}function Sga(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=gb+-64|0;gb=d;e=d+40|0;Re(e,a,c);a=v[e>>2];v[22656]=0;e=Sd(e);f=v[22656];v[22656]=0;a:{b:{c:{d:{if((f|0)==1){break d}e=zb(e);v[22656]=0;Xe(d+8|0,1,e,a);e=v[22656];v[22656]=0;if((e|0)==1){break d}v[22656]=0;R(324,d+24|0,d+8|0);e=v[22656];v[22656]=0;if((e|0)==1){break d}v[22656]=0;Q(301,b|0,d+24|0)|0;b=v[22656];v[22656]=0;if((b|0)==1){break c}vb(d+24|0);zc(d+40|0);gb=d- -64|0;a=!c|(a|0)!=0;break a}a=P()|0;O()|0;break b}a=P()|0;O()|0;vb(d+24|0)}zc(d+40|0);S(a|0);L()}return a|0}function Ipa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=gb+-64|0;gb=d;e=d+40|0;Re(e,a,c);a=v[e>>2];v[22656]=0;e=Sd(e);f=v[22656];v[22656]=0;a:{b:{c:{d:{if((f|0)==1){break d}e=zb(e);v[22656]=0;Xe(d+8|0,3,e,a);e=v[22656];v[22656]=0;if((e|0)==1){break d}v[22656]=0;R(324,d+24|0,d+8|0);e=v[22656];v[22656]=0;if((e|0)==1){break d}v[22656]=0;Q(303,b|0,d+24|0)|0;b=v[22656];v[22656]=0;if((b|0)==1){break c}vb(d+24|0);zc(d+40|0);gb=d- -64|0;a=!c|(a|0)!=0;break a}a=P()|0;O()|0;break b}a=P()|0;O()|0;vb(d+24|0)}zc(d+40|0);S(a|0);L()}return a|0}function Gma(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;a:{d=gb-80|0;gb=d;Se(b);e=d+56|0;Re(e,a,c);a=v[e>>2];v[22656]=0;c=Sd(e);e=v[22656];v[22656]=0;b:{c:{d:{if((e|0)==1){break d}c=zb(c);v[22656]=0;Xe(d+8|0,3,c,a);a=v[22656];v[22656]=0;if((a|0)==1){break d}v[22656]=0;R(324,d+24|0,d+8|0);a=v[22656];v[22656]=0;if((a|0)==1){break d}v[22656]=0;U(13,d+40|0,5,d+24|0);a=v[22656];v[22656]=0;if((a|0)==1){break c}a=d+40|0;Eb(b,a);vb(a);vb(d+24|0);zc(d+56|0);gb=d+80|0;break a}a=P()|0;O()|0;break b}a=P()|0;O()|0;vb(d+24|0)}zc(d+56|0);S(a|0);L()}}function Coa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=gb+-64|0;gb=d;e=d+40|0;Re(e,a,c);a=v[e>>2];v[22656]=0;e=Sd(e);f=v[22656];v[22656]=0;a:{b:{c:{d:{if((f|0)==1){break d}e=zb(e);v[22656]=0;Xe(d+8|0,2,e,a);e=v[22656];v[22656]=0;if((e|0)==1){break d}v[22656]=0;R(324,d+24|0,d+8|0);e=v[22656];v[22656]=0;if((e|0)==1){break d}v[22656]=0;Q(399,b|0,d+24|0)|0;b=v[22656];v[22656]=0;if((b|0)==1){break c}vb(d+24|0);zc(d+40|0);gb=d- -64|0;a=!c|(a|0)!=0;break a}a=P()|0;O()|0;break b}a=P()|0;O()|0;vb(d+24|0)}zc(d+40|0);S(a|0);L()}return a|0}function zl(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;d=gb-16|0;gb=d;v[b>>2]=0;v[b+4>>2]=0;t[d+15|0]=0;i=Uh(a,d+15|0);h=w[d+15|0];v[b>>2]=(h&252)>>>2;v[b+4>>2]=0;c=h&3;if(c){c=-1<<c;l=(c>>>0<4294967294?c:-2)^-1;while(1){t[d+15|0]=0;m=Uh(a,d+15|0);c=b;f=v[c>>2];n=v[c+4>>2];j=w[d+15|0];e=g;g=k+1|0;e=g?e:e+1|0;k=g;g=e;h=c;o=c;p=f;c=(k<<3)-2|0;f=c&31;if((c&63)>>>0>=32){e=j<<f;c=0}else{e=(1<<f)-1&j>>>32-f;c=j<<f}v[o>>2]=p|c;v[h+4>>2]=e|n;i=i&m;if((k|0)!=(l|0)|g){continue}break}}gb=d+16|0;return i|0}function AY(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=gb+-64|0;gb=d;e=d+40|0;Re(e,a,c);a=v[e>>2];v[22656]=0;e=Sd(e);f=v[22656];v[22656]=0;a:{b:{c:{d:{if((f|0)==1){break d}e=zb(e);v[22656]=0;Xe(d+8|0,2,e,a);e=v[22656];v[22656]=0;if((e|0)==1){break d}v[22656]=0;R(324,d+24|0,d+8|0);e=v[22656];v[22656]=0;if((e|0)==1){break d}v[22656]=0;Q(301,b|0,d+24|0)|0;b=v[22656];v[22656]=0;if((b|0)==1){break c}vb(d+24|0);zc(d+40|0);gb=d- -64|0;a=!c|(a|0)!=0;break a}a=P()|0;O()|0;break b}a=P()|0;O()|0;vb(d+24|0)}zc(d+40|0);S(a|0);L()}return a|0}function qF(a,b){var c=0,d=0,e=0,f=0,g=0,h=0;e=gb-16|0;gb=e;c=v[b+16>>2];v[a+4>>2]=0;v[a>>2]=c;a:{if(!c){break a}d=b+80|0;f=a;c=v[b+84>>2];if(c>>>0<=15){c=v[d>>2]}else{v[e+12>>2]=c-16;c=v[Lc(d,e+12|0)>>2]}v[f+8>>2]=c;if(!(w[b+88|0]&2)|!w[b+794|0]){break a}b:{c:{d:{if(!pF(b)){c=v[b+104>>2];break d}c=v[b+104>>2];if(v[b+80>>2]!=v[c+12>>2]){break d}d=v[b+84>>2];if((d|0)==v[c+16>>2]){break c}}b=v[b+84>>2];if((b|0)!=v[c+8>>2]){break a}b=(v[c>>2]-b|0)+48|0;break b}b=(v[c>>2]-d|0)+112|0}g=a,h=v[a>>2]+B(jj(c),b)|0,v[g+4>>2]=h}gb=e+16|0}function U0(){var a=0;a:{if(t[465072]&1){break a}if(!Qd(465072)){break a}a=464784;while(1){a=Kb(a)+12|0;if((a|0)!=465072){continue}break}Pd(465072)}Xc(464784,2130);Xc(464796,2121);Xc(464808,8108);Xc(464820,7877);Xc(464832,2357);Xc(464844,8906);Xc(464856,2214);Xc(464868,2701);Xc(464880,6017);Xc(464892,6e3);Xc(464904,6008);Xc(464916,6027);Xc(464928,7343);Xc(464940,10599);Xc(464952,6090);Xc(464964,4778);Xc(464976,2357);Xc(464988,6904);Xc(465e3,7748);Xc(465012,8120);Xc(465024,6406);Xc(465036,3520);Xc(465048,2584);Xc(465060,10508)}function Rha(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;c=gb-16|0;gb=c;f=x[fj(a,b)>>1];a:{if(!Po(a,b)){break a}d=v[a+24>>2]+484360|0;j=c,k=Vb(d),v[j+8>>2]=k;j=c,k=Zb(d),v[j>>2]=k;if(!Gb(c+8|0,c)){break a}h=f&65535;while(1){b:{g=v[c+8>>2];i=am(g);if(i){e=0;while(1){if(!((b|0)==(e|0)&(a|0)==(g|0)|x[sc(g,e)>>1]!=(h|0))){d=xN(v[a+24>>2]+484344|0,h,0);if((d|0)!=65535){break b}}e=e+1|0;if((i|0)!=(e|0)){continue}break}}d=c+8|0;nS(d);if(Gb(d,c)){continue}break a}break}j=fj(a,b),k=d,u[j>>1]=k;f=d}gb=c+16|0;return f&65535}function wP(a,b,c){var d=0,e=0,f=0;d=gb-16|0;gb=d;a:{if(b){t[c|0]=b;break a}b=w[c|0]}b=v[a+480180>>2]&1048580?(b&240?-16:15)&b:b;c=b&240;e=b&255;b=b&15;b:{c:{d:{if(!(!c|(b|0)!=15)){if(!(w[a+480209|0]&16)){break b}b=e>>>3&30;break d}f=v[a+480208>>2]&4096;if(!(!b|(c|0)!=240)){if(!f){break b}b=0-(b<<1)|0;break c}if(f){break b}if(c){if(b?v[a+480180>>2]&59314208:0){break b}b=e>>>3&30;break d}b=0-(b<<1)|0}if(!b){break b}}c=a+1074456|0;v[d+12>>2]=v[c>>2]+(b<<!(v[a+480180>>2]&59314208));Zd(d+12|0,0,256);v[c>>2]=v[d+12>>2]}gb=d+16|0}function jx(a,b,c){var d=0,e=0,f=0;d=gb+-64|0;gb=d;f=v[a>>2];e=v[f-4>>2];f=v[f-8>>2];v[d+20>>2]=0;v[d+16>>2]=b;v[d+12>>2]=a;v[d+8>>2]=c;b=0;Qb(d+24|0,0,39);a=a+f|0;a:{if(Sg(e,c,0)){v[d+56>>2]=1;kb[v[v[e>>2]+20>>2]](e,d+8|0,a,a,1,0);b=v[d+32>>2]==1?a:0;break a}kb[v[v[e>>2]+24>>2]](e,d+8|0,a,1,0);b:{switch(v[d+44>>2]){case 0:b=v[d+48>>2]==1?v[d+36>>2]==1?v[d+40>>2]==1?v[d+28>>2]:0:0:0;break a;case 1:break b;default:break a}}if(v[d+32>>2]!=1){if(v[d+48>>2]|v[d+36>>2]!=1|v[d+40>>2]!=1){break a}}b=v[d+24>>2]}gb=d- -64|0;return b}function $W(a,b){var c=0,d=0;c=(a|0)==(b|0);t[b+12|0]=c;a:{if(c){break a}while(1){if(w[v[b+8>>2]+12|0]){break a}d=ng(v[b+8>>2]);c=v[b+8>>2];b:{if(d){c=v[v[c+8>>2]+4>>2];if(!(!c|w[c+12|0])){break b}if(!ng(b)){b=v[b+8>>2];ur(b)}a=v[b+8>>2];t[a+12|0]=1;a=v[a+8>>2];t[a+12|0]=0;tr(a);return}c=v[v[c+8>>2]>>2];if(!(!c|w[c+12|0])){break b}if(ng(b)){b=v[b+8>>2];tr(b)}a=v[b+8>>2];t[a+12|0]=1;a=v[a+8>>2];t[a+12|0]=0;ur(a);break a}b=v[b+8>>2];t[b+12|0]=1;b=v[b+8>>2];t[b+12|0]=(a|0)==(b|0);t[c+12|0]=1;if((a|0)!=(b|0)){continue}break}}}function qba(a){a=a|0;var b=0,c=0,d=0;b=gb-32|0;gb=b;a:{b:{if(!a){a=ie(18726);break b}v[22656]=0;c=Q(70,b|0,a|0)|0;a=v[22656];v[22656]=0;c:{d:{if((a|0)!=1){v[22656]=0;R(1915,b+16|0,c|0);a=v[22656];v[22656]=0;if((a|0)==1){break d}d=b+16|0;a=ie(Jb(d));vb(d);vb(c);break b}a=V(0)|0;O()|0;break c}a=V(0)|0;O()|0;vb(c)}Z(a|0)|0;a=0;v[22656]=0;Y(1911,8248,0,0,0);c=v[22656];v[22656]=0;if((c|0)==1){break a}$()}gb=b+32|0;return a|0}a=P()|0;O()|0;v[22656]=0;X(20);b=v[22656];v[22656]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}function bfa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;a:{e=gb-32|0;gb=e;a=hh(a);b:{c:{d:{e:{while(1){v[22656]=0;f=Q(191,b|0,8)|0;g=v[22656];v[22656]=0;if((g|0)==1){break c}if(f){v[22656]=0;U(1467,e|0,b|0,c|0);f=v[22656];v[22656]=0;if((f|0)==1){break e}v[22656]=0;R(1468,a|0,e|0);f=v[22656];v[22656]=0;if((f|0)==1){break d}ed(e);Zi(e,IU(a));if((w[e|0]|w[e+1|0]<<8|(w[e+2|0]<<16|w[e+3|0]<<24))!=(d|0)){continue}}break}gb=e+32|0;break a}b=P()|0;O()|0;break b}b=P()|0;O()|0;ed(e);break b}b=P()|0;O()|0}ke(a);S(b|0);L()}}function ik(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;if((a|0)!=(b|0)){if(!De(a)){if(!De(b)){v[a+8>>2]=v[b+8>>2];d=v[b+4>>2];v[a>>2]=v[b>>2];v[a+4>>2]=d;return a|0}e=Jb(b);b=Ab(b);d=gb-16|0;gb=d;a:{if(b>>>0<=10){_e(a,b);Qg(a,e,b);t[d+15|0]=0;Bd(a+b|0,d+15|0);break a}c=w[a+11|0];wp(a,10,b-10|0,c,0,c,b,e)}gb=d+16|0;return a|0}e=Jb(b);b=Ab(b);d=gb-16|0;gb=d;c=gk(a);b:{if(c>>>0>b>>>0){c=v[a>>2];de(a,b);Qg(c,e,b);t[d+15|0]=0;Bd(b+c|0,d+15|0);break b}f=c-1|0;g=(b-c|0)+1|0;c=v[a+4>>2];wp(a,f,g,c,0,c,b,e)}gb=d+16|0}return a|0}function hea(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0;f=gb-32|0;gb=f;h=fg(a,c);se(f+8|0,v[a+28>>2]);d=v[f+20>>2];v[f+24>>2]=v[f+16>>2];v[f+28>>2]=d;a:{b:{if(!h){d=-1;if(!nd(a,5)){break b}break a}d=v[h+8>>2]}g=v[a+28>>2];c:{d:{switch(d+1|0){case 0:case 3:fB(g,b);break c;default:break d}}e=gb-32|0;gb=e;v[e+28>>2]=d;u[e+26>>1]=0;v[e+12>>2]=2;d=e+16|0;i=g;g=e+28|0;eo(d,i,e+26|0,v[Fb(g,e+12|0)>>2]);yb(d);v[e+16>>2]=2;Fb(g,d);u[e+16>>1]=x[e+26>>1];u[b>>1]=w[d|0]|w[d+1|0]<<8;gb=e+32|0}}Zf(a,h,c,f+24|0);gb=f+32|0}function R3(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0;a=gb-32|0;gb=a;u[a+28>>1]=w[81061]|w[81062]<<8;v[a+24>>2]=w[81057]|w[81058]<<8|(w[81059]<<16|w[81060]<<24);g=a+24|0;il(g|1,8041,1,v[c+4>>2]);i=v[c+4>>2];f=a-16|0;gb=f;h=xe();v[a>>2]=e;g=Ff(f,(i>>>9&1)+13|0,h,g,a)+f|0;i=Tg(f,g,c);e=f-32|0;gb=e;h=a+8|0;Fc(h,c);v[22656]=0;ja(2466,f|0,i|0,g|0,e|0,a+20|0,a+16|0,h|0);f=v[22656];v[22656]=0;if((f|0)!=1){Wb(a+8|0);b=vn(b,e,v[a+20>>2],v[a+16>>2],c,d);gb=a+32|0;return b|0}b=P()|0;O()|0;Wb(a+8|0);S(b|0);L()}function X9(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0;g=gb-16|0;gb=g;v[22656]=0;_(1934,a|0);h=v[22656];v[22656]=0;a:{b:{if((h|0)!=1){c:{h=v[a+24>>2];v[22656]=0;ja(1992,g|0,h|0,b|0,c|0,d|0,e|0,(f|0)!=0|0);b=v[22656];v[22656]=0;if((b|0)==1){break c}b=ie(Jb(g));vb(g);break b}}b=V(0)|0;O()|0;Z(b|0)|0;b=0;v[22656]=0;Y(1911,7951,a|0,0,0);a=v[22656];v[22656]=0;if((a|0)==1){break a}$()}gb=g+16|0;return b|0}a=P()|0;O()|0;v[22656]=0;X(20);b=v[22656];v[22656]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}function W9(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0;g=gb-16|0;gb=g;v[22656]=0;_(1934,a|0);h=v[22656];v[22656]=0;a:{b:{if((h|0)!=1){c:{h=v[a+24>>2];v[22656]=0;ja(1993,g|0,h|0,b|0,c|0,d|0,e|0,(f|0)!=0|0);b=v[22656];v[22656]=0;if((b|0)==1){break c}b=ie(Jb(g));vb(g);break b}}b=V(0)|0;O()|0;Z(b|0)|0;b=0;v[22656]=0;Y(1911,7906,a|0,0,0);a=v[22656];v[22656]=0;if((a|0)==1){break a}$()}gb=g+16|0;return b|0}a=P()|0;O()|0;v[22656]=0;X(20);b=v[22656];v[22656]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}function Tla(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=gb-16|0;gb=d;b=-1;a:{if(!Wf(a,8)){break a}c=gb-32|0;gb=c;v[c+24>>2]=0;v[c+28>>2]=0;b=wd(c+8|0,c+24|0,8);e=v[b+4>>2];v[c>>2]=v[b>>2];v[c+4>>2]=e;b=a;e=c+16|0;hd(e,a,c);e=(yb(e)|0)==8&(v[c+24>>2]==1096043343&v[c+28>>2]==1196314451);if(e){bd(b,8)}gb=c+32|0;b=0;if(!e){break a}b=-1;if(!ek(a,d+8|0)){break a}a=d+8|4;b=0;if(!Xb(w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24))){break a}b=!(Xb(w[d+8|0]|w[d+9|0]<<8|(w[d+10|0]<<16|w[d+11|0]<<24))&-2139062144)}gb=d+16|0;return b|0}function O3(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0;a=gb-32|0;gb=a;u[a+28>>1]=w[81061]|w[81062]<<8;v[a+24>>2]=w[81057]|w[81058]<<8|(w[81059]<<16|w[81060]<<24);g=a+24|0;il(g|1,8041,0,v[c+4>>2]);i=v[c+4>>2];f=a-16|0;gb=f;h=xe();v[a>>2]=e;g=Ff(f,i>>>9&1|12,h,g,a)+f|0;i=Tg(f,g,c);e=f-32|0;gb=e;h=a+8|0;Fc(h,c);v[22656]=0;ja(2466,f|0,i|0,g|0,e|0,a+20|0,a+16|0,h|0);f=v[22656];v[22656]=0;if((f|0)!=1){Wb(a+8|0);b=vn(b,e,v[a+20>>2],v[a+16>>2],c,d);gb=a+32|0;return b|0}b=P()|0;O()|0;Wb(a+8|0);S(b|0);L()}function C3(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0;a=gb-32|0;gb=a;u[a+28>>1]=w[81061]|w[81062]<<8;v[a+24>>2]=w[81057]|w[81058]<<8|(w[81059]<<16|w[81060]<<24);g=a+24|0;il(g|1,8041,0,v[c+4>>2]);i=v[c+4>>2];f=a-16|0;gb=f;h=xe();v[a>>2]=e;g=Ff(f,i>>>9&1|12,h,g,a)+f|0;i=Tg(f,g,c);e=f-96|0;gb=e;h=a+8|0;Fc(h,c);v[22656]=0;ja(2473,f|0,i|0,g|0,e|0,a+20|0,a+16|0,h|0);f=v[22656];v[22656]=0;if((f|0)!=1){Wb(a+8|0);b=Un(b,e,v[a+20>>2],v[a+16>>2],c,d);gb=a+32|0;return b|0}b=P()|0;O()|0;Wb(a+8|0);S(b|0);L()}function nB(a,b){var c=0,d=0,e=0,f=0,g=0;c=gb-16|0;gb=c;a:{if(cd(a)){break a}u[v[a>>2]>>1]=0;yf(v[a>>2]+2|0,b);f=c,g=Vb(a),v[f>>2]=g;f=c,g=$o(c,1),v[f+8>>2]=g;f=c,g=Zb(a),v[f>>2]=g;if(!Gb(c+8|0,c)){break a}while(1){d=c+8|0;e=v[d>>2];f=c,g=$o(d,-1),v[f>>2]=g;e=Le(e,v[c>>2]);u[v[c+8>>2]>>1]=x[e>>1];yf(v[c+8>>2]+2|0,b);Qe(d);f=c,g=Zb(a),v[f>>2]=g;if(Gb(d,c)){continue}break}}yf(a+14|0,Nb(a)-1&255);yf(a+13|0,w[a+14|0]);yf(a+16|0,Nb(a)-1&255);yf(a+15|0,w[a+16|0]);if(w[a+17|0]!=255){yf(a+17|0,Nb(a)-1&255)}gb=c+16|0}function K$(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;if(Sg(a,v[b+8>>2],e)){fx(b,c,d);return}a:{if(Sg(a,v[b>>2],e)){if(!(v[b+16>>2]!=(c|0)&v[b+20>>2]!=(c|0))){if((d|0)!=1){break a}v[b+32>>2]=1;return}v[b+32>>2]=d;b:{if(v[b+44>>2]==4){break b}u[b+52>>1]=0;a=v[a+8>>2];kb[v[v[a>>2]+20>>2]](a,b,c,c,1,e);if(w[b+53|0]){v[b+44>>2]=3;if(!w[b+52|0]){break b}break a}v[b+44>>2]=4}v[b+20>>2]=c;v[b+40>>2]=v[b+40>>2]+1;if(v[b+36>>2]!=1|v[b+24>>2]!=2){break a}t[b+54|0]=1;return}a=v[a+8>>2];kb[v[v[a>>2]+24>>2]](a,b,c,d,e)}}function v4(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;e=gb-16|0;gb=e;a:{b:{c:{d:{e:{if((a|0)!=(b|0)){g=v[115137];v[115137]=0;a=AH(a,e+12|0,d,xe());d=jb;f=v[115137];f:{if(f){if(v[e+12>>2]!=(b|0)){break f}if((f|0)==68){break d}break e}v[115137]=g;if(v[e+12>>2]==(b|0)){break e}}}v[c>>2]=4;a=0;break a}if((d|0)<0&a>>>0<=2147483647|(d|0)<-1){v[c>>2]=4;break c}if((d|0)<=0&a>>>0<=2147483647|(d|0)<0){break a}}v[c>>2]=4;if(!!a&(d|0)>=0|(d|0)>0){break b}}a=-2147483648;break a}a=2147483647}gb=e+16|0;return a|0}function rla(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=gb-80|0;gb=c;d=Qf(c+48|0);v[22656]=0;e=Q(870,b|0,d|0)|0;f=v[22656];v[22656]=0;a:{b:{c:{if((f|0)!=1){if(e){break c}v[a>>2]=0;v[a+4>>2]=0;v[a+24>>2]=0;v[a+16>>2]=0;v[a+20>>2]=0;v[a+8>>2]=0;v[a+12>>2]=0;v[22656]=0;T(871,a|0)|0;a=v[22656];v[22656]=0;if((a|0)!=1){break b}}break a}e=cn(d);v[22656]=0;U(288,c|0,b|0,e|0);b=v[22656];v[22656]=0;if((b|0)==1){break a}b=kc(c+24|0,c);Vc(d+8|0,b);xb(b);xb(c);$j(a,d)}ed(d);gb=c+80|0;return}a=P()|0;O()|0;ed(d);S(a|0);L()}function pm(a,b,c,d,e,f){var g=0,h=0,i=0,j=0;a:{if(f&64){c=f+-64|0;b=c&31;if((c&63)>>>0>=32){c=0;b=e>>>b|0}else{c=e>>>b|0;b=((1<<b)-1&e)<<32-b|d>>>b}d=0;e=0;break a}if(!f){break a}h=e;i=d;j=64-f|0;g=j&31;if((j&63)>>>0>=32){h=i<<g;j=0}else{h=(1<<g)-1&i>>>32-g|h<<g;j=i<<g}i=b;g=f;b=g&31;if((g&63)>>>0>=32){g=0;b=c>>>b|0}else{g=c>>>b|0;b=((1<<b)-1&c)<<32-b|i>>>b}b=j|b;c=g|h;g=d;d=f&31;if((f&63)>>>0>=32){h=0;d=e>>>d|0}else{h=e>>>d|0;d=((1<<d)-1&e)<<32-d|g>>>d}e=h}v[a>>2]=b;v[a+4>>2]=c;v[a+8>>2]=d;v[a+12>>2]=e}function cqa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=gb-80|0;gb=c;d=Qf(c+48|0);v[22656]=0;e=Q(454,b|0,d|0)|0;f=v[22656];v[22656]=0;a:{b:{c:{if((f|0)!=1){if(e){break c}v[a>>2]=0;v[a+4>>2]=0;v[a+24>>2]=0;v[a+16>>2]=0;v[a+20>>2]=0;v[a+8>>2]=0;v[a+12>>2]=0;v[22656]=0;T(455,a|0)|0;a=v[22656];v[22656]=0;if((a|0)!=1){break b}}break a}e=CD(d);v[22656]=0;U(288,c|0,b|0,e|0);b=v[22656];v[22656]=0;if((b|0)==1){break a}b=kc(c+24|0,c);Vc(d+8|0,b);xb(b);xb(c);$j(a,d)}ed(d);gb=c+80|0;return}a=P()|0;O()|0;ed(d);S(a|0);L()}function Yoa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=gb-80|0;gb=c;d=Qf(c+48|0);v[22656]=0;e=Q(540,b|0,d|0)|0;f=v[22656];v[22656]=0;a:{b:{c:{if((f|0)!=1){if(e){break c}v[a>>2]=0;v[a+4>>2]=0;v[a+24>>2]=0;v[a+16>>2]=0;v[a+20>>2]=0;v[a+8>>2]=0;v[a+12>>2]=0;v[22656]=0;T(541,a|0)|0;a=v[22656];v[22656]=0;if((a|0)!=1){break b}}break a}e=CD(d);v[22656]=0;U(288,c|0,b|0,e|0);b=v[22656];v[22656]=0;if((b|0)==1){break a}b=kc(c+24|0,c);Vc(d+8|0,b);xb(b);xb(c);$j(a,d)}ed(d);gb=c+80|0;return}a=P()|0;O()|0;ed(d);S(a|0);L()}function UO(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;e=gb-16|0;gb=e;v[e+12>>2]=c;g=e+12|0;c=a;d=Nb(c);a:{if(d>>>0<b>>>0){f=gb-32|0;gb=f;b:{d=b-d|0;c:{if(d>>>0<=v[wb(c)>>2]-v[c+4>>2]>>2>>>0){yE(c,d,g);break c}b=wb(c);b=fn(f+8|0,fh(c,Nb(c)+d|0),Nb(c),b);v[22656]=0;U(1327,b|0,d|0,g|0);d=v[22656];v[22656]=0;if((d|0)==1){break b}v[22656]=0;R(52,c|0,b|0);c=v[22656];v[22656]=0;if((c|0)==1){break b}eh(b)}gb=f+32|0;break a}a=P()|0;O()|0;eh(b);S(a|0);L()}if(b>>>0<d>>>0){hj(c,v[c>>2]+(b<<2)|0)}}jA(a);gb=e+16|0}function rZ(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;f=gb-16|0;gb=f;a:{b:{if(!Wf(a,7)){break b}c=0;if(!gE(a,14913)){break a}if(!Wf(a,1)){break b}c=-1;if(!bd(a,ew(a))){break a}d=gb-32|0;gb=d;c=d+24|0;g=f+8|0;tn(c,g);h=yb(c);c=v[d+28>>2];e=v[d+24>>2];v[d+8>>2]=e;v[d+12>>2]=c;v[d>>2]=e;v[d+4>>2]=c;c=a;e=d+16|0;hd(e,a,d);e=yb(e);if((e|0)==(h|0)){bd(c,yb(d+24|0))}gb=d+32|0;d=(e|0)==(h|0);if(!d){Xv(g)}c=-1;if(!d){break a}c=0;if(!cE(f+8|0)){break a}c=Oe(a,b,bE(f+8|0),jb);break a}c=-1}gb=f+16|0;return c|0}function gfa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;a:{d=gb+-64|0;gb=d;e=d+40|0;Re(e,a,c);a=v[e>>2];v[22656]=0;c=Sd(e);e=v[22656];v[22656]=0;b:{c:{d:{if((e|0)==1){break d}c=zb(c);v[22656]=0;Xe(d+8|0,1,c,a);a=v[22656];v[22656]=0;if((a|0)==1){break d}v[22656]=0;R(324,d+24|0,d+8|0);a=v[22656];v[22656]=0;if((a|0)==1){break d}v[22656]=0;Q(303,b|0,d+24|0)|0;a=v[22656];v[22656]=0;if((a|0)==1){break c}vb(d+24|0);zc(d+40|0);gb=d- -64|0;break a}a=P()|0;O()|0;break b}a=P()|0;O()|0;vb(d+24|0)}zc(d+40|0);S(a|0);L()}}function Uz(a,b,c){var d=0,e=0;e=gb-16|0;gb=e;d=e+8|0;Db(d,a+1074312|0,21);a:{if(Cb(d)){c=c&255;b:{switch((b&3)-1|0){default:d=t[c+39888|0];break a;case 0:d=64-(c+1>>>1|0)|0;break a;case 1:d=(c>>>0<128)<<6;break a;case 2:break b}}d=lO(Co(a))+-64|0;break a}d=t[(c>>>1&31)+38384|0];if(v[a+480180>>2]&67633152){break a}a=c&63;c:{switch((b&3)-1|0){default:d=t[a+39760|0];break a;case 0:d=(a>>>0<32?0:255)-(a<<2)|0;break a;case 1:d=a>>>0<32?127:-127;break a;case 2:break c}}d=t[a+39824|0]}a=d;gb=e+16|0;return a}function Mka(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;d=gb-4112|0;gb=d;an(a,b);if(oc(a)>>>0>4095){while(1){f=e<<12;b=0;c=0;while(1){b=zb(w[lc(a,c+f|0)|0])+b|0;g=zb(b&255);i=ic(d+16|0,c<<1|1),j=g,t[i|0]=j;c=c+1|0;if((c|0)!=2048){continue}break}g=f|2048;c=0;while(1){b=zb(w[lc(a,c+g|0)|0])+b|0;h=zb(b&255);i=ic(d+16|0,c<<1),j=h,t[i|0]=j;c=c+1|0;if((c|0)!=2048){continue}break}i=d,j=Vb(a),v[i+8>>2]=j;b=d+16|0;Wu(b,b+4096|0,we(d+8|0,f));e=e+1|0;if(e>>>0<oc(a)>>>12>>>0){continue}break}}gb=d+4112|0}function Iha(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0;f=gb-32|0;gb=f;h=fg(a,c);se(f+8|0,v[a+28>>2]);e=v[f+20>>2];v[f+24>>2]=v[f+16>>2];v[f+28>>2]=e;a:{b:{if(!h){e=-1;if(!nd(a,5)){break b}break a}e=v[h+8>>2]}g=v[a+28>>2];c:{d:{switch(e+1|0){case 0:case 2:Vh(g,b);break c;default:break d}}d=gb-32|0;gb=d;v[d+28>>2]=e;t[d+24|0]=0;v[d+12>>2]=1;e=d+16|0;i=g;g=d+28|0;eo(e,i,d+24|0,v[Fb(g,d+12|0)>>2]);yb(e);v[d+16>>2]=1;Fb(g,e);t[d+16|0]=w[d+24|0];t[b|0]=w[e|0];gb=d+32|0}}Zf(a,h,c,f+24|0);gb=f+32|0}function Hla(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;a:{c=gb-32|0;gb=c;a=hh(a);b:{c:{d:{e:{while(1){v[22656]=0;d=Q(191,b|0,8)|0;e=v[22656];v[22656]=0;if((e|0)==1){break c}if(d){v[22656]=0;R(863,c|0,b|0);d=v[22656];v[22656]=0;if((d|0)==1){break e}v[22656]=0;R(864,a|0,c|0);d=v[22656];v[22656]=0;if((d|0)==1){break d}ed(c);Zi(c,IU(a));if((w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24))!=1413891155){continue}}break}gb=c+32|0;break a}b=P()|0;O()|0;break b}b=P()|0;O()|0;ed(c);break b}b=P()|0;O()|0}ke(a);S(b|0);L()}}function iea(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=C(0),j=0,k=0,l=C(0);e=gb-32|0;gb=e;h=fg(a,c);d=e+8|0;se(d,v[a+28>>2]);f=v[d+12>>2];v[e+24>>2]=v[d+8>>2];v[e+28>>2]=f;a:{if(!h){if(nd(a,5)){break a}}d=gb-32|0;gb=d;f=v[a+28>>2];zl(f,d+24|0);j=d,k=Qc(v[d+24>>2],v[d+28>>2]),v[j+16>>2]=k;v[d+12>>2]=256;El(b,v[Fb(d+16|0,d+12|0)>>2]);if(Nb(b)){while(1){v[d+16>>2]=0;mq(f,d+16|0);i=z[d+16>>2];j=Mb(b,g),l=i,z[j>>2]=l;g=g+1|0;if(Nb(b)>>>0>g>>>0){continue}break}}gb=d+32|0}Zf(a,h,c,e+24|0);gb=e+32|0}function DM(a){a=a|0;var b=0,c=0,d=0,e=0;b=v[a>>2];if(b){kb[v[v[b>>2]+8>>2]](b);v[a>>2]=0}a=a+4|0;yr(a);c=gb-32|0;gb=c;a:{b:{c:{if(dg(a)>>>0<=oc(a)>>>0){break c}b=wb(a);d=oc(a);e=oc(a);v[22656]=0;b=da(1635,c+8|0,d|0,e|0,b|0)|0;d=v[22656];v[22656]=0;d:{e:{if((d|0)!=1){v[22656]=0;R(396,a|0,b|0);a=v[22656];v[22656]=0;if((a|0)==1){break e}be(b);break c}a=V(0)|0;O()|0;break d}a=V(0)|0;O()|0;be(b)}Z(a|0)|0;v[22656]=0;X(20);a=v[22656];v[22656]=0;if((a|0)==1){break b}}gb=c+32|0;break a}V(0)|0;O()|0;Bb();L()}}function una(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0;if(y[a+4>>2]<y[wb(a)>>2]){c=gb-16|0;gb=c;a=KY(c,a);FC(v[a+4>>2],b);v[a+4>>2]=v[a+4>>2]+28;$b(a);gb=c+16|0;return}f=gb-32|0;gb=f;c=wb(a);d=IY(f+8|0,JY(a,_i(a)+1|0),_i(a),c);FC(v[d+8>>2],b);v[d+8>>2]=v[d+8>>2]+28;c=d;h=c+4|0;g=h;b=a;e=v[a+4>>2];i=v[a>>2];if((e|0)!=(i|0)){a=v[g>>2];while(1){e=e-28|0;FC(a-28|0,e);a=v[g>>2]-28|0;v[g>>2]=a;if((e|0)!=(i|0)){continue}break}}wc(b,h);wc(b+4|0,c+8|0);wc(wb(b),dc(c));v[c>>2]=v[c+4>>2];HY(d);gb=f+32|0}function Qz(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0;h=gb-16|0;gb=h;a:{if((c|0)<2){break a}j=c-2>>>1|0;f=d-a|0;if((j|0)<f>>1){break a}g=f+1|0;e=(g<<1)+a|0;f=f+2|0;if((f|0)<(c|0)){i=vq(b,x[e>>1],x[e+2>>1]);e=i?e+2|0:e;g=i?f:g}if(vq(b,x[e>>1],x[d>>1])){break a}u[h+14>>1]=x[d>>1];while(1){b:{f=e;u[d>>1]=x[e>>1];if((g|0)>(j|0)){break b}d=g<<1;g=d|1;e=(g<<1)+a|0;d=d+2|0;if((d|0)<(c|0)){i=vq(b,x[e>>1],x[e+2>>1]);e=i?e+2|0:e;g=i?d:g}d=f;if(!vq(b,x[e>>1],x[h+14>>1])){continue}}break}u[f>>1]=x[h+14>>1]}gb=h+16|0}function vS(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;j=b?33:32;c=w[a+16|0];k=c?-1:1;l=c?1:-1;e=v[a+8>>2]-1|0;m=c?e-(w[a+17|0]!=0&(e|0)!=0)|0:0;n=c?0:e;f=v[a+12>>2];h=v[a>>2]+B(f,62)|0;d=b?1:-1;o=B(f,d)<<1;c=e;while(1){if((f|0)>0){g=B(c,f);p=v[a+4>>2];b=0;while(1){u[(b<<1)+h>>1]=x[p+(b+g<<1)>>1];b=b+1|0;if((f|0)!=(b|0)){continue}break}}h=h+o|0;a:{if((c|0)==(e|0)){b=m;g=k;if((d|0)>0){break a}}b=c+d|0;c=!c&(d|0)<0;b=c?n:b;g=c?l:d}d=g;c=b;i=i+1|0;if((j|0)!=(i|0)){continue}break}}function bm(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0;if(y[a+4>>2]<y[wb(a)>>2]){c=gb-16|0;gb=c;a=KY(c,a);BD(v[a+4>>2],b);v[a+4>>2]=v[a+4>>2]+28;$b(a);gb=c+16|0;return}f=gb-32|0;gb=f;c=wb(a);d=IY(f+8|0,JY(a,_i(a)+1|0),_i(a),c);BD(v[d+8>>2],b);v[d+8>>2]=v[d+8>>2]+28;c=d;h=c+4|0;g=h;b=a;e=v[a+4>>2];i=v[a>>2];if((e|0)!=(i|0)){a=v[g>>2];while(1){e=e-28|0;BD(a-28|0,e);a=v[g>>2]-28|0;v[g>>2]=a;if((e|0)!=(i|0)){continue}break}}wc(b,h);wc(b+4|0,c+8|0);wc(wb(b),dc(c));v[c>>2]=v[c+4>>2];HY(d);gb=f+32|0}function Fga(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=C(0),f=0,g=0,h=0,i=0,j=0;d=gb-16|0;gb=d;v[d+12>>2]=c>>>2;v[d+8>>2]=v[a>>2];f=v[Fb(d+12|0,d+8|0)>>2];b=zb(b);if(f){a=v[a+20>>2];c=f;while(1){v[d+12>>2]=w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24);v[d+8>>2]=-1082130432;v[d+4>>2]=1065353216;e=C(z[zf(d+12|0,d+8|0,d+4|0)>>2]*C(32768));z[d+12>>2]=e;h=a;e=fe(e);a:{if(C(D(e))<C(2147483648)){g=~~e;break a}g=-2147483648}i=h,j=Uc(g),u[i>>1]=j;a=a+2|0;b=b+4|0;c=c-1|0;if(c){continue}break}}gb=d+16|0;return f<<2}function $ka(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;a:{c=gb+-64|0;gb=c;d=c+40|0;Re(d,a,31);a=v[d>>2];v[22656]=0;d=Sd(d);e=v[22656];v[22656]=0;b:{c:{d:{if((e|0)==1){break d}d=zb(d);v[22656]=0;Xe(c+8|0,2,d,a);a=v[22656];v[22656]=0;if((a|0)==1){break d}v[22656]=0;R(324,c+24|0,c+8|0);a=v[22656];v[22656]=0;if((a|0)==1){break d}v[22656]=0;Q(303,b|0,c+24|0)|0;a=v[22656];v[22656]=0;if((a|0)==1){break c}vb(c+24|0);zc(c+40|0);gb=c- -64|0;break a}a=P()|0;O()|0;break b}a=P()|0;O()|0;vb(c+24|0)}zc(c+40|0);S(a|0);L()}}function uS(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;k=b?33:32;f=v[a+8>>2];c=f-1|0;d=v[a+12>>2];g=v[a>>2]+B(d,31)|0;h=b?1:-1;e=h;while(1){b=0;if((d|0)>0){while(1){t[b+g|0]=w[v[a+4>>2]+(B(c,d)+b|0)|0];b=b+1|0;d=v[a+12>>2];if((b|0)<(d|0)){continue}break}f=v[a+8>>2]}b=B(d,h);i=f-1|0;a:{if(!((i|0)!=(c|0)|(e|0)<=0)){if(!w[a+16|0]){e=1;c=0;break a}e=-1;c=c-(w[a+17|0]!=0&(c|0)!=0)|0;break a}if(!((e|0)>=0|c)){c=w[a+16|0];e=c?1:-1;c=c?0:i;break a}c=c+e|0}g=b+g|0;j=j+1|0;if((k|0)!=(j|0)){continue}break}}function s8(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0;b=gb-32|0;gb=b;a:{b:{if(Bj(a)){zh(b+24|0);break b}c=b+8|0;po(c,a);v[22656]=0;c=T(2084,c|0)|0;e=v[22656];v[22656]=0;if((e|0)==1){break a}v[b+24>>2]=c;Yf(b+8|0)}if(Bj(a)){c=a+36|0}else{c=v[b+24>>2]}a=v[a+8>>2];c:{if((a|0)==-1){f=b,g=Vb(c),v[f+8>>2]=g;f=b,g=Zb(c),v[f>>2]=g;if(!Gb(b+8|0,b)){break c}while(1){a=b+8|0;d=d+A[v[a>>2]>>3];eL(a);if(Gb(a,b)){continue}break}break c}d=A[Xl(c,a)>>3]}xl(b+24|0);gb=b+32|0;return+d}a=P()|0;O()|0;Yf(b+8|0);S(a|0);L()}function So(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=x[a+34>>1];if(!b){b=a;if(d&512){Lu(a);d=x[a+34>>1]}u[b+34>>1]=d&65023;return}v[a>>2]=4;u[a+34>>1]=d&64958|512;Ql(a);b=w[c+8|0]|w[c+9|0]<<8|(w[c+10|0]<<16|w[c+11|0]<<24);t[a+76|0]=b;t[a+77|0]=b>>>8;t[a+78|0]=b>>>16;t[a+79|0]=b>>>24;b=w[c+4|0]|w[c+5|0]<<8|(w[c+6|0]<<16|w[c+7|0]<<24);c=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);t[a+68|0]=c;t[a+69|0]=c>>>8;t[a+70|0]=c>>>16;t[a+71|0]=c>>>24;t[a+72|0]=b;t[a+73|0]=b>>>8;t[a+74|0]=b>>>16;t[a+75|0]=b>>>24}function Z9(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0;f=gb-16|0;gb=f;v[22656]=0;_(1934,a|0);g=v[22656];v[22656]=0;a:{b:{if((g|0)!=1){c:{g=v[a+24>>2];v[22656]=0;ka(1990,f|0,g|0,b|0,c|0,d|0,e|0);b=v[22656];v[22656]=0;if((b|0)==1){break c}b=ie(Jb(f));vb(f);break b}}b=V(0)|0;O()|0;Z(b|0)|0;b=0;v[22656]=0;Y(1911,9709,a|0,0,0);a=v[22656];v[22656]=0;if((a|0)==1){break a}$()}gb=f+16|0;return b|0}a=P()|0;O()|0;v[22656]=0;X(20);b=v[22656];v[22656]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}function Y9(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0;f=gb-16|0;gb=f;v[22656]=0;_(1934,a|0);g=v[22656];v[22656]=0;a:{b:{if((g|0)!=1){c:{g=v[a+24>>2];v[22656]=0;ka(1991,f|0,g|0,b|0,c|0,d|0,e|0);b=v[22656];v[22656]=0;if((b|0)==1){break c}b=ie(Jb(f));vb(f);break b}}b=V(0)|0;O()|0;Z(b|0)|0;b=0;v[22656]=0;Y(1911,9609,a|0,0,0);a=v[22656];v[22656]=0;if((a|0)==1){break a}$()}gb=f+16|0;return b|0}a=P()|0;O()|0;v[22656]=0;X(20);b=v[22656];v[22656]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}function Vea(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0;d=gb-32|0;gb=d;Ke(d,2,a+6|0);e=d+16|0;Bc(e,d);v[22656]=0;Q(301,b+492|0,e|0)|0;e=v[22656];v[22656]=0;if((e|0)!=1){e=b+236|0;c=c+1|0;vb(d+16|0);while(1){g=w[(a+f|0)+38|0];h=vd(e,f),i=c+g|0,u[h>>1]=i;f=f+1|0;if((f|0)!=128){continue}break}c=a+226|0;v[b>>2]=(w[c|0]|w[c+1|0]<<8)<<5;zz(a+180|0,b+48|0,0);zz(a+228|0,b+88|0,2);zz(a+276|0,b+68|0,1);a=a+324|0;if(!(w[a|0]|w[a+1|0]<<8)){GB(e)}gb=d+32|0;return}a=P()|0;O()|0;vb(d+16|0);S(a|0);L()}function U2(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;f=gb-16|0;gb=f;d=Ab(a);e=Xp(a);g=kr(b,c);a:{if(!g){break a}if(hD(b,Jb(a),Jb(a)+(Ab(a)<<2)|0)){d=gb-16|0;gb=d;zH(f,b,c);gb=d+16|0;b=f;c=Jb(b);d=Ab(b);v[22656]=0;W(2494,a|0,c|0,d|0)|0;a=v[22656];v[22656]=0;if((a|0)!=1){Hc(b);break a}a=P()|0;O()|0;Hc(b);S(a|0);L()}if(e-d>>>0<g>>>0){HG(a,e,(d+g|0)-e|0,d,d)}e=Jb(a)+(d<<2)|0;if((b|0)!=(c|0)){while(1){Ge(e,b);e=e+4|0;b=b+4|0;if((c|0)!=(b|0)){continue}break}}v[f>>2]=0;Ge(e,f);jh(a,d+g|0)}gb=f+16|0}function qoa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=Kg(a);if(d>>>0<b>>>0){e=gb-32|0;gb=e;a:{b:{d=b-d|0;c:{if(d>>>0<=(v[wb(a)>>2]-v[a+4>>2]|0)/6>>>0){XC(a,d,c);break c}b=wb(a);b=KW(e+8|0,IC(a,Kg(a)+d|0),Kg(a),b);v[22656]=0;U(643,b|0,d|0,c|0);c=v[22656];v[22656]=0;if((c|0)==1){break b}VC(a);c=b+4|0;IW(wb(a),v[a>>2],v[a+4>>2],c);xc(a,c);xc(a+4|0,b+8|0);xc(wb(a),dc(b));v[b>>2]=v[b+4>>2];KC(a,Kg(a));uv(b)}gb=e+32|0;break a}a=P()|0;O()|0;uv(b);S(a|0);L()}return}if(b>>>0<d>>>0){WC(a,v[a>>2]+B(b,6)|0)}}function Vga(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=gb-32|0;gb=c;e=gb-16|0;gb=e;d=c+24|0;bc(d,b,16);gb=e+16|0;e=yb(d);d=v[c+28>>2];f=v[c+24>>2];v[c+8>>2]=f;v[c+12>>2]=d;v[c>>2]=f;v[c+4>>2]=d;d=c+16|0;cc(d,a,c);d=yb(d);if((d|0)==(e|0)){Rb(a,yb(c+24|0))}gb=c+32|0;a=(d|0)==(e|0);if(!a){c=gb-16|0;gb=c;t[b|0]=0;t[b+1|0]=0;t[b+2|0]=0;t[b+3|0]=0;t[b+4|0]=0;t[b+5|0]=0;t[b+6|0]=0;t[b+7|0]=0;t[b+8|0]=0;t[b+9|0]=0;t[b+10|0]=0;t[b+11|0]=0;t[b+12|0]=0;t[b+13|0]=0;t[b+14|0]=0;t[b+15|0]=0;gb=c+16|0}return a|0}function m4(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0;e=gb-16|0;gb=e;a:{b:{if((a|0)!=(b|0)){c:{d:{f=w[a|0];if((f|0)!=45){break d}a=a+1|0;if((b|0)!=(a|0)){break d}break c}h=v[115137];v[115137]=0;a=Hx(a,e+12|0,d,xe());d=jb;e:{g=v[115137];if(g){if(v[e+12>>2]!=(b|0)){break c}if((g|0)==68){break e}break b}v[115137]=h;if(v[e+12>>2]==(b|0)){break b}break c}v[c>>2]=4;a=-1;b=-1;break a}}v[c>>2]=4;a=0;b=0;break a}b=a;c=(f|0)==45;a=c?0-a|0:a;b=c?0-(d+((b|0)!=0)|0)|0:d}gb=e+16|0;jb=b;return a|0}function Nga(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;e=gb-16|0;gb=e;f=Kb(a);a:{b:{c:{if(Ec(b)){a=0;while(1){d:{if(!a){break d}v[22656]=0;Q(1168,f|0,c|0)|0;d=v[22656];v[22656]=0;if((d|0)!=1){break d}a=P()|0;O()|0;break a}d=Ad(b,a);v[22656]=0;R(1169,e|0,d|0);d=v[22656];v[22656]=0;if((d|0)==1){break c}v[22656]=0;Q(1168,f|0,e|0)|0;d=v[22656];v[22656]=0;if((d|0)==1){break b}vb(e);a=a+1|0;if(Ec(b)>>>0>a>>>0){continue}break}}gb=e+16|0;return}a=P()|0;O()|0;break a}a=P()|0;O()|0;vb(e)}vb(f);S(a|0);L()}function x3(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0;a=gb-208|0;gb=a;u[a+204>>1]=w[81067]|w[81068]<<8;v[a+200>>2]=w[81063]|w[81064]<<8|(w[81065]<<16|w[81066]<<24);f=xe();v[a>>2]=e;g=a+176|0;i=Ff(g,20,f,a+200|0,a);e=i+g|0;g=Tg(g,e,c);f=a+8|0;Fc(f,c);v[22656]=0;f=T(2452,f|0)|0;h=v[22656];v[22656]=0;if((h|0)!=1){Wb(a+8|0);h=f;f=a+16|0;vH(h,a+176|0,e,f);h=b;b=f+(i<<2)|0;b=Un(h,f,(e|0)==(g|0)?b:((g-a<<2)+a|0)-688|0,b,c,d);gb=a+208|0;return b|0}b=P()|0;O()|0;Wb(a+8|0);S(b|0);L()}function sP(a,b,c,d){var e=0,f=0;e=gb-16|0;gb=e;a:{b:{c:{if(!d){break c}d=c>>31;d=d+c^d;if(d>>>0<224){break c}f=e+8|0;Db(f,a+1074312|0,3);if(Cb(f)){break c}if(!(t[(B(b,872)+a|0)+1075843|0]&1)){break a}c=B((c>>31)+((c|0)>0)|0,d&15);c=d>>>0>239?c<<2:c;break b}if(t[(B(b,872)+a|0)+1075843|0]&1){d=e+8|0;Db(d,a+1074312|0,3);if(!Cb(d)){break a}}c=c<<2}if(!c){break a}d=pu(a,b);if(!d){break a}f=d;a=v[(B(b,872)+a|0)+1075648>>2];if(a){a=w[a+33|0]}else{a=13}kb[v[v[d>>2]+84>>2]](f,c,a<<24>>24,b)}gb=e+16|0}function SD(a,b,c){var d=0,e=0,f=0;d=gb+-64|0;gb=d;e=d+40|0;Re(e,a,c);a=v[e>>2];v[22656]=0;e=Sd(e);f=v[22656];v[22656]=0;a:{b:{c:{if((f|0)==1){break c}e=zb(e);v[22656]=0;Xe(d+8|0,3,e,a);e=v[22656];v[22656]=0;if((e|0)==1){break c}v[22656]=0;R(324,d+24|0,d+8|0);e=v[22656];v[22656]=0;if((e|0)==1){break c}v[22656]=0;Q(301,b|0,d+24|0)|0;b=v[22656];v[22656]=0;if((b|0)==1){break b}vb(d+24|0);zc(d+40|0);gb=d- -64|0;return!c|(a|0)!=0}c=P()|0;O()|0;break a}c=P()|0;O()|0;vb(d+24|0)}zc(d+40|0);S(c|0);L()}function Kf(a,b,c,d,e,f){var g=0,h=0,i=0,j=0;a:{if(f&64){d=b;e=f+-64|0;b=e&31;if((e&63)>>>0>=32){e=d<<b;d=0}else{e=(1<<b)-1&d>>>32-b|c<<b;d=d<<b}b=0;c=0;break a}if(!f){break a}g=d;i=f;d=f&31;if((f&63)>>>0>=32){h=g<<d;j=0}else{h=(1<<d)-1&g>>>32-d|e<<d;j=g<<d}d=c;g=b;f=64-f|0;e=f&31;if((f&63)>>>0>=32){f=0;d=d>>>e|0}else{f=d>>>e|0;d=((1<<e)-1&d)<<32-e|g>>>e}d=j|d;e=f|h;f=b;b=i&31;if((i&63)>>>0>=32){h=f<<b;b=0}else{h=(1<<b)-1&f>>>32-b|c<<b;b=f<<b}c=h}v[a>>2]=b;v[a+4>>2]=c;v[a+8>>2]=d;v[a+12>>2]=e}function Zz(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;e=gb-32|0;gb=e;v[e+24>>2]=b;m=e,n=zd(a),v[m+16>>2]=n;j=ck(e+24|0,e+16|0);h=j;i=gb-16|0;gb=i;a:{b=a;g=Ab(b);if(g>>>0>=h>>>0){if(c){f=Kc(b);b:{if(f-g>>>0>=c>>>0){f=Jb(b);k=g-h|0;if(!k){break b}l=f+h|0;fm(l+c|0,l,k);break b}Ym(b,f,(c+g|0)-f|0,g,h,0,c);f=v[b>>2]}Ir(f+h|0,c,d);d=b;b=c+g|0;jh(d,b);t[i+15|0]=0;Bd(b+f|0,i+15|0)}gb=i+16|0;break a}Qn();L()}m=e,n=zd(a),v[m+8>>2]=n;a=we(e+8|0,j);gb=e+32|0;return a|0}function Yja(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;if(y[a+4>>2]<y[wb(a)>>2]){d=gb-16|0;gb=d;c=Fg(d,a,1);wb(a);YS(v[c+4>>2],b);v[c+4>>2]=v[c+4>>2]+4;$b(c);gb=d+16|0;return}f=gb-32|0;gb=f;e=wb(a);d=fh(a,Nb(a)+1|0);i=Nb(a);g=gb-16|0;gb=g;v[g+12>>2]=0;c=f+8|0;kf(c+12|0,e);if(d){h=RW(d)}v[c>>2]=h;e=(i<<2)+h|0;v[c+8>>2]=e;v[c+4>>2]=e;j=dc(c),k=(d<<2)+h|0,v[j>>2]=k;gb=g+16|0;YS(v[c+8>>2],b);v[c+8>>2]=v[c+8>>2]+4;WS(a,c);a=c;VS(c);b=v[c>>2];if(b){NC(v[a+16>>2],b,Ck(a))}gb=f+32|0}function L$(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;e=gb-16|0;gb=e;f=Kb(a);a:{b:{c:{if(Ec(b)){a=0;while(1){d:{if(!a){break d}v[22656]=0;Q(113,f|0,c|0)|0;d=v[22656];v[22656]=0;if((d|0)!=1){break d}a=P()|0;O()|0;break a}d=Ad(b,a);v[22656]=0;R(175,e|0,d|0);d=v[22656];v[22656]=0;if((d|0)==1){break c}v[22656]=0;Q(113,f|0,e|0)|0;d=v[22656];v[22656]=0;if((d|0)==1){break b}vb(e);a=a+1|0;if(Ec(b)>>>0>a>>>0){continue}break}}gb=e+16|0;return}a=P()|0;O()|0;break a}a=P()|0;O()|0;vb(e)}vb(f);S(a|0);L()}function D3(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0;a=gb-32|0;gb=a;v[a+24>>2]=37;v[a+28>>2]=0;h=a+24|0;il(h|1,7874,1,v[c+4>>2]);i=v[c+4>>2];g=a-32|0;gb=g;j=xe();v[a>>2]=e;v[a+4>>2]=f;e=i>>>9&1;f=Ff(g,e+23|0,j,h,a)+g|0;h=Tg(g,f,c);e=g-((e<<3)+187&240)|0;gb=e;i=a+8|0;Fc(i,c);v[22656]=0;ja(2473,g|0,h|0,f|0,e|0,a+20|0,a+16|0,i|0);f=v[22656];v[22656]=0;if((f|0)!=1){Wb(a+8|0);b=Un(b,e,v[a+20>>2],v[a+16>>2],c,d);gb=a+32|0;return b|0}b=P()|0;O()|0;Wb(a+8|0);S(b|0);L()}function B3(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0;a=gb-32|0;gb=a;v[a+24>>2]=37;v[a+28>>2]=0;h=a+24|0;il(h|1,7874,0,v[c+4>>2]);i=v[c+4>>2];g=a-32|0;gb=g;j=xe();v[a>>2]=e;v[a+4>>2]=f;e=i>>>9&1;f=Ff(g,e+23|0,j,h,a)+g|0;h=Tg(g,f,c);e=g-((e<<3)+187&240)|0;gb=e;i=a+8|0;Fc(i,c);v[22656]=0;ja(2473,g|0,h|0,f|0,e|0,a+20|0,a+16|0,i|0);f=v[22656];v[22656]=0;if((f|0)!=1){Wb(a+8|0);b=Un(b,e,v[a+20>>2],v[a+16>>2],c,d);gb=a+32|0;return b|0}b=P()|0;O()|0;Wb(a+8|0);S(b|0);L()}function hy(a,b){var c=0,d=0,e=0,f=0,g=0,h=0;e=gb-16|0;gb=e;f=(p(a),j(2));c=f&2147483647;a:{if(c>>>0<=1305022426){g=+a;d=g*.6366197723675814+6755399441055744+-6755399441055744;A[b>>3]=g+d*-1.5707963109016418+d*-1.5893254773528196e-8;if(D(d)<2147483648){c=~~d;break a}c=-2147483648;break a}if(c>>>0>=2139095040){A[b>>3]=C(a-a);c=0;break a}h=c;c=(c>>>23|0)-150|0;A[e+8>>3]=(l(2,h-(c<<23)|0),q());c=_I(e+8|0,e,c,1,0);d=A[e>>3];if((f|0)<0){A[b>>3]=-d;c=0-c|0;break a}A[b>>3]=d}gb=e+16|0;return c}function zja(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0;b=gb-16|0;gb=b;h=v[a+24>>2];i=v[a+20>>2];j=v[a+16>>2];f=v[a+4>>2];e=f;g=v[a>>2];v[b+8>>2]=g;v[b+12>>2]=e;f=v[a+12>>2];v[b>>2]=v[a+8>>2];v[b+4>>2]=f;if(d){while(1){f=e+j|0;e=t[f|0];e=((B(t[f+1|0]-e|0,g>>>10&4194048)|0)/16384|0)+(e<<8)|0;v[c>>2]=v[c>>2]+B(e,i);v[c+4>>2]=v[c+4>>2]+B(e,h);Ub(b+8|0,b);d=d-1|0;if(d){c=c+8|0;g=v[b+8>>2];e=v[b+12>>2];continue}break}g=v[b+8>>2];e=v[b+12>>2]}v[a>>2]=g;v[a+4>>2]=e;gb=b+16|0}function XU(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=gb-32|0;gb=c;a:{if(!w[b+8|0]){while(1){if(!w[b+d|0]){aa(14540,6236,413,10498);L()}d=d+1|0;if((d|0)!=8){continue}break}v[c+24>>2]=0;v[c+28>>2]=0;d=wd(c+8|0,c+24|0,8);e=v[d+4>>2];v[c>>2]=v[d>>2];v[c+4>>2]=e;e=c+16|0;cc(e,a,c);d=0;if(!((yb(e)|0)!=8|(v[c+24>>2]!=(w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24))|v[c+28>>2]!=(w[b+4|0]|w[b+5|0]<<8|(w[b+6|0]<<16|w[b+7|0]<<24))))){Rb(a,8);d=1}gb=c+32|0;break a}aa(14519,6236,411,10498);L()}return d|0}function Naa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;v[22656]=0;_(1934,a|0);d=v[22656];v[22656]=0;a:{if((d|0)==1){break a}v[22656]=0;_(1945,c|0);d=v[22656];v[22656]=0;if((d|0)==1){break a}d=v[a+24>>2];v[22656]=0;b=Q(1946,d|0,b|0)|0;d=v[22656];v[22656]=0;if((d|0)==1){break a}v[c>>2]=b;return 1}b=V(0)|0;O()|0;Z(b|0)|0;v[22656]=0;Y(1911,7623,a|0,0,0);a=v[22656];v[22656]=0;if((a|0)!=1){$();return 0}a=P()|0;O()|0;v[22656]=0;X(20);b=v[22656];v[22656]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}function yja(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0;b=gb-16|0;gb=b;h=v[a+24>>2];i=v[a+20>>2];j=v[a+16>>2];f=v[a+4>>2];e=f;g=v[a>>2];v[b+8>>2]=g;v[b+12>>2]=e;f=v[a+12>>2];v[b>>2]=v[a+8>>2];v[b+4>>2]=f;if(d){while(1){f=(e<<1)+j|0;e=u[f>>1];e=e+((B(u[f+2>>1]-e|0,g>>>18|0)|0)/16384|0)|0;v[c>>2]=v[c>>2]+B(e,i);v[c+4>>2]=v[c+4>>2]+B(e,h);Ub(b+8|0,b);d=d-1|0;if(d){c=c+8|0;g=v[b+8>>2];e=v[b+12>>2];continue}break}g=v[b+8>>2];e=v[b+12>>2]}v[a>>2]=g;v[a+4>>2]=e;gb=b+16|0}function kp(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0;f=gb-32|0;gb=f;v[f+28>>2]=c;g=Pb(b,c);a:{if(!g){break a}qc(f+28|0,65535);Af(a,x[f+28>>1]);i=f,j=Vb(a),v[i+16>>2]=j;i=f,j=Zb(a),v[i+8>>2]=j;if(!Gb(f+16|0,f+8|0)){break a}while(1){a=v[f+16>>2];c=f+27|0;if(!Ng(b,c)){h=gb-16|0;gb=h;Hf(c);gb=h+16|0}c=w[f+27|0];u[a>>1]=c;b:{if((c|0)==(d|0)){c=65535}else{if((c|0)!=(e|0)){break b}c=65534}u[a>>1]=c}a=f+16|0;of(a);if(Gb(a,f+8|0)){continue}break}}gb=f+32|0;return g|0}function Un(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0;i=gb-16|0;gb=i;a:{b:{if(!a){break b}h=v[e+12>>2];g=c-b|0;if((g|0)>0){g=g>>2;if((un(a,b,g)|0)!=(g|0)){break b}}b=d-b>>2;b=(b|0)<(h|0)?h-b|0:0;if((b|0)>0){f=tH(i,b,f);h=Jb(f);v[22656]=0;h=W(2475,a|0,h|0,b|0)|0;g=v[22656];v[22656]=0;if((g|0)==1){break a}Hc(f);if((b|0)!=(h|0)){break b}}b=d-c|0;if((b|0)>0){b=b>>2;if((un(a,c,b)|0)!=(b|0)){break b}}XB(e);j=a}gb=i+16|0;return j|0}a=P()|0;O()|0;Hc(f);S(a|0);L()}function F4(a){a=a|0;var b=0,c=0,d=0,e=0;b=gb-32|0;gb=b;c=Tb(b,13845);v[22656]=0;U(138,b+16|0,a|0,c|0);a=v[22656];v[22656]=0;a:{b:{c:{if((a|0)!=1){vb(c);if(Ec(b+16|0)){break c}a=0;break a}d=P()|0;O()|0;vb(c);break b}a=0;while(1){d:{c=Ad(b+16|0,d);v[22656]=0;c=T(139,c|0)|0;e=v[22656];v[22656]=0;if((e|0)==1){break d}a=(c&255)<<24-(d<<3)|a;c=Ec(b+16|0);if(d>>>0>2){break a}d=d+1|0;if(c>>>0>d>>>0){continue}break a}break}d=P()|0;O()|0;sm(b+16|0)}S(d|0);L()}sm(b+16|0);gb=b+32|0;return a|0}function r4(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0;e=gb-16|0;gb=e;a:{b:{c:{d:{if((a|0)!=(b|0)){e:{f:{f=w[a|0];if((f|0)!=45){break f}a=a+1|0;if((b|0)!=(a|0)){break f}break e}h=v[115137];v[115137]=0;a=Hx(a,e+12|0,d,xe());d=jb;g=v[115137];g:{if(g){if(v[e+12>>2]!=(b|0)){break g}if((g|0)==68){break c}break d}v[115137]=h;if(v[e+12>>2]==(b|0)){break d}}}}v[c>>2]=4;a=0;break a}if(!d&a>>>0<=65535){break b}}v[c>>2]=4;a=65535;break a}a=(f|0)==45?0-a|0:a}gb=e+16|0;return a&65535}function I3(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0;a=gb-96|0;gb=a;u[a+92>>1]=w[81067]|w[81068]<<8;v[a+88>>2]=w[81063]|w[81064]<<8|(w[81065]<<16|w[81066]<<24);f=xe();v[a>>2]=e;g=a- -64|0;i=Ff(g,20,f,a+88|0,a);e=i+g|0;g=Tg(g,e,c);f=a+8|0;Fc(f,c);v[22656]=0;f=T(21,f|0)|0;h=v[22656];v[22656]=0;if((h|0)!=1){Wb(a+8|0);h=f;f=a+16|0;wH(h,a- -64|0,e,f);h=b;b=f+i|0;b=vn(h,f,(e|0)==(g|0)?b:((g-a|0)+a|0)-48|0,b,c,d);gb=a+96|0;return b|0}b=P()|0;O()|0;Wb(a+8|0);S(b|0);L()}function zK(a){var b=0,c=0,d=0,e=0,f=0;if(v[a+16>>2]){while(1){c=cA(v[a>>2]);d=jb;e=v[a+28>>2];if((d|0)==(e|0)&y[a+24>>2]<=c>>>0|d>>>0>e>>>0){continue}d=b;b=v[a+8>>2];b=(c&v[a+40>>2])+(b>>>0<32?d<<b:0)|0;c=v[a+16>>2];f=f+1|0;if(c>>>0>f>>>0){continue}break}}if(y[a+12>>2]>c>>>0){while(1){d=cA(v[a>>2]);f=jb;e=v[a+36>>2];if((f|0)==(e|0)&y[a+32>>2]<=d>>>0|f>>>0>e>>>0){continue}e=b;b=v[a+8>>2];b=(d&v[a+48>>2])+(b>>>0<31?e<<b+1:0)|0;c=c+1|0;if(c>>>0<y[a+12>>2]){continue}break}}return b}function v_(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0;e=gb-48|0;gb=e;g=-1;c=gb-32|0;gb=c;f=c+24|0;h=e+8|0;ds(f,h);f=yb(f);d=v[c+28>>2];i=v[c+24>>2];v[c+8>>2]=i;v[c+12>>2]=d;v[c>>2]=i;v[c+4>>2]=d;d=c+16|0;hd(d,a,c);d=yb(d);if((d|0)==(f|0)){bd(a,yb(c+24|0))}gb=c+32|0;a=(d|0)==(f|0);if(!a){Gw(h)}a:{if(!a){break a}g=0;if(!tF(e+8|0)){break a}if(b){c=v[b>>2];a=e+12|0;if(!v[b+4>>2]&c>>>0<Xb(w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24))-8>>>0){break a}}g=1}gb=e+48|0;return g|0}function RD(a,b,c){var d=0,e=0;d=gb+-64|0;gb=d;e=d+40|0;Re(e,a,c);a=v[e>>2];v[22656]=0;c=Sd(e);e=v[22656];v[22656]=0;a:{b:{c:{if((e|0)==1){break c}c=zb(c);v[22656]=0;Xe(d+8|0,3,c,a);a=v[22656];v[22656]=0;if((a|0)==1){break c}v[22656]=0;R(324,d+24|0,d+8|0);a=v[22656];v[22656]=0;if((a|0)==1){break c}v[22656]=0;Q(399,b|0,d+24|0)|0;a=v[22656];v[22656]=0;if((a|0)==1){break b}vb(d+24|0);zc(d+40|0);gb=d- -64|0;return}c=P()|0;O()|0;break a}c=P()|0;O()|0;vb(d+24|0)}zc(d+40|0);S(c|0);L()}function Mja(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0;b=gb-16|0;gb=b;g=v[a+24>>2];h=v[a+20>>2];i=v[a+16>>2];e=v[a+4>>2];f=v[a>>2];v[b+8>>2]=f;v[b+12>>2]=e;j=v[a+12>>2];v[b>>2]=v[a+8>>2];v[b+4>>2]=j;if(d){while(1){e=((((e&2147483647)<<1|f>>>31)&2147483646)<<1)+i|0;f=u[e+2>>1];v[c>>2]=v[c>>2]+B(u[e>>1],h);v[c+4>>2]=v[c+4>>2]+B(f,g);Ub(b+8|0,b);d=d-1|0;if(d){c=c+8|0;f=v[b+8>>2];e=v[b+12>>2];continue}break}f=v[b+8>>2];e=v[b+12>>2]}v[a>>2]=f;v[a+4>>2]=e;gb=b+16|0}function Nja(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0;b=gb-16|0;gb=b;g=v[a+24>>2];h=v[a+20>>2];i=v[a+16>>2];e=v[a+4>>2];f=v[a>>2];v[b+8>>2]=f;v[b+12>>2]=e;j=v[a+12>>2];v[b>>2]=v[a+8>>2];v[b+4>>2]=j;if(d){g=g<<8;h=h<<8;while(1){e=(((e&2147483647)<<1|f>>>31)&-2)+i|0;f=t[e+1|0];v[c>>2]=v[c>>2]+B(h,t[e|0]);v[c+4>>2]=v[c+4>>2]+B(f,g);Ub(b+8|0,b);d=d-1|0;if(d){c=c+8|0;f=v[b+8>>2];e=v[b+12>>2];continue}break}f=v[b+8>>2];e=v[b+12>>2]}v[a>>2]=f;v[a+4>>2]=e;gb=b+16|0}function c$(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;d=gb-16|0;gb=d;e=v[b+4>>2];b=v[b>>2];v[d>>2]=b;v[d+4>>2]=e;v[d+8>>2]=b;v[d+12>>2]=e;g=gb-16|0;gb=g;h=g+8|0;f=h;i=gb-16|0;gb=i;e=gb-16|0;gb=e;c=gb-16|0;gb=c;b=e;v[b+4>>2]=1;j=b,k=Mc(24,4),v[j+8>>2]=k;gb=c+16|0;c=v[b+8>>2];v[22656]=0;Q(213,c|0,d|0)|0;c=v[22656];v[22656]=0;a:{if((c|0)!=1){c=f;f=Kp(b);Rw(c,dc(f),f);cG(b);gb=e+16|0;break a}a=P()|0;O()|0;cG(b);S(a|0);L()}gb=i+16|0;Xf(a,h);Kd(h);gb=g+16|0;gb=d+16|0}function YE(a,b){a=a|0;b=b|0;var c=0,d=0;Qb(b,0,44);if(w[a+2|0]|w[a+3|0]<<8?1:w[a|0]|w[a+1|0]<<8){v[b+20>>2]=((w[a|0]|w[a+1|0]<<8)>>>9|0)+80;c=b,d=Lb((w[a|0]|w[a+1|0]<<8)>>>5&15,1,12)-1|0,v[c+16>>2]=d;c=b,d=Lb((w[a|0]|w[a+1|0]<<8)&31,1,31),v[c+12>>2]=d;c=b,d=Lb((w[a+2|0]|w[a+3|0]<<8)>>>11|0,0,23),v[c+8>>2]=d;c=b,d=Lb((w[a+2|0]|w[a+3|0]<<8)>>>5&63,0,59),v[c+4>>2]=d;c=b,d=Lb((w[a+2|0]|w[a+3|0]<<8)<<1&62,0,59),v[c>>2]=d}v[b+44>>2]=w[a+4|0]|w[a+5|0]<<8|(w[a+6|0]<<16|w[a+7|0]<<24)}function gea(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;f=gb-32|0;gb=f;g=fg(a,c);d=f+8|0;se(d,v[a+28>>2]);e=v[d+12>>2];v[f+24>>2]=v[d+8>>2];v[f+28>>2]=e;a:{b:{if(!g){d=-1;if(!nd(a,5)){break b}break a}d=v[g+8>>2]}h=v[a+28>>2];c:{if(!((d|0)!=4&(d|0)!=-1)){d=gb-16|0;gb=d;v[d+8>>2]=0;mq(h,d+8|0);z[b>>2]=z[d+8>>2];gb=d+16|0;break c}e=gb-32|0;gb=e;v[e+28>>2]=0;v[e+24>>2]=d;v[e+20>>2]=4;eo(e+8|0,h,e+28|0,v[Fb(e+24|0,e+20|0)>>2]);v[b>>2]=0;gb=e+32|0}}Zf(a,g,c,f+24|0);gb=f+32|0}function a3(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;f=gb-32|0;gb=f;d=Ab(a);e=Kc(a);g=Zh(b,c);a:{if(!g){break a}if(hD(b,Jb(a),Jb(a)+Ab(a)|0)){b=Pj(f+16|0,b,c);c=Jb(b);d=Ab(b);v[22656]=0;W(2487,a|0,c|0,d|0)|0;a=v[22656];v[22656]=0;if((a|0)!=1){vb(b);break a}a=P()|0;O()|0;vb(b);S(a|0);L()}if(e-d>>>0<g>>>0){Ym(a,e,(d+g|0)-e|0,d,d,0,0)}e=Jb(a)+d|0;if((b|0)!=(c|0)){while(1){Bd(e,b);e=e+1|0;b=b+1|0;if((c|0)!=(b|0)){continue}break}}t[f+15|0]=0;Bd(e,f+15|0);jh(a,d+g|0)}gb=f+32|0}function _P(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;e=gb-16|0;gb=e;v[e+12>>2]=c>>>3;v[e+8>>2]=v[a>>2];h=v[Fb(e+12|0,e+8|0)>>2];b=zb(b);if(h){a=v[a+20>>2];c=h;while(1){f=zb(w[b+7|0]);d=zb(w[b+6|0]);g=d>>>24|0;i=f|d<<8;f=zb(w[b+5|0]);d=f>>>16|0;f=i|f<<16;i=d|g;d=zb(w[b+4|0]);g=d>>>8|0;d=d<<24|f;g=zb(w[b+3|0])|(g|i);j=a,k=Jc(d,zb(w[b+2|0])<<8|g|zb(w[b+1|0])<<16|zb(w[b|0])<<24,48),u[j>>1]=k;a=a+2|0;b=b+8|0;c=c-1|0;if(c){continue}break}}gb=e+16|0;return h<<3}function S6(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=gb-48|0;gb=e;v[e+40>>2]=c;c=v[b+12>>2];v[e+32>>2]=v[b+8>>2];v[e+36>>2]=c;c=v[b+4>>2];v[e+24>>2]=v[b>>2];v[e+28>>2]=c;b=v[pi(e+16|0,e+40|0)>>2];c=v[e+36>>2];v[e+8>>2]=v[e+32>>2];v[e+12>>2]=c;v[22656]=0;c=v[e+28>>2];v[e>>2]=v[e+24>>2];v[e+4>>2]=c;da(1932,a+8|0,e|0,b|0,d|0)|0;b=v[22656];v[22656]=0;if((b|0)!=1){RJ(a);b=QJ(a+88|0);v[a>>2]=59720;v[b>>2]=59808;eg(e+40|0);gb=e+48|0;return a|0}a=P()|0;O()|0;eg(e+40|0);S(a|0);L()}function $P(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;e=gb-16|0;gb=e;v[e+12>>2]=c>>>3;v[e+8>>2]=v[a>>2];h=v[Fb(e+12|0,e+8|0)>>2];b=zb(b);if(h){a=v[a+20>>2];c=h;while(1){f=zb(w[b|0]);d=zb(w[b+1|0]);g=d>>>24|0;i=f|d<<8;f=zb(w[b+2|0]);d=f>>>16|0;f=i|f<<16;i=d|g;d=zb(w[b+3|0]);g=d>>>8|0;d=d<<24|f;g=zb(w[b+4|0])|(g|i);j=a,k=Jc(d,zb(w[b+5|0])<<8|g|zb(w[b+6|0])<<16|zb(w[b+7|0])<<24,48),u[j>>1]=k;a=a+2|0;b=b+8|0;c=c-1|0;if(c){continue}break}}gb=e+16|0;return h<<3}function P3(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0;a=gb-32|0;gb=a;v[a+24>>2]=37;v[a+28>>2]=0;h=a+24|0;il(h|1,7874,1,v[c+4>>2]);i=v[c+4>>2];g=a-32|0;gb=g;j=xe();v[a>>2]=e;v[a+4>>2]=f;f=Ff(g,(i>>>9&1)+23|0,j,h,a)+g|0;h=Tg(g,f,c);e=g-48|0;gb=e;i=a+8|0;Fc(i,c);v[22656]=0;ja(2466,g|0,h|0,f|0,e|0,a+20|0,a+16|0,i|0);f=v[22656];v[22656]=0;if((f|0)!=1){Wb(a+8|0);b=vn(b,e,v[a+20>>2],v[a+16>>2],c,d);gb=a+32|0;return b|0}b=P()|0;O()|0;Wb(a+8|0);S(b|0);L()}function N3(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0;a=gb-32|0;gb=a;v[a+24>>2]=37;v[a+28>>2]=0;h=a+24|0;il(h|1,7874,0,v[c+4>>2]);i=v[c+4>>2];g=a-32|0;gb=g;j=xe();v[a>>2]=e;v[a+4>>2]=f;f=Ff(g,(i>>>9&1)+23|0,j,h,a)+g|0;h=Tg(g,f,c);e=g-48|0;gb=e;i=a+8|0;Fc(i,c);v[22656]=0;ja(2466,g|0,h|0,f|0,e|0,a+20|0,a+16|0,i|0);f=v[22656];v[22656]=0;if((f|0)!=1){Wb(a+8|0);b=vn(b,e,v[a+20>>2],v[a+16>>2],c,d);gb=a+32|0;return b|0}b=P()|0;O()|0;Wb(a+8|0);S(b|0);L()}function FQ(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0;d=gb-16|0;gb=d;v[d+12>>2]=c;v[d+8>>2]=v[a>>2];c=d+8|0;g=v[Fb(c,d+12|0)>>2];v[d+8>>2]=v[a>>2];v[d+4>>2]=v[d+12>>2]-g;h=v[Fb(c,d+4|0)>>2];c=zb(b);if(g){e=v[a+20>>2];f=g;while(1){i=e,j=zb(w[c|0])^128,t[i|0]=j;e=e+2|0;c=c+1|0;f=f-1|0;if(f){continue}break}}b=zb(b);if(h){c=b+v[a>>2]|0;e=v[a+20>>2]+1|0;f=h;while(1){i=e,j=zb(w[c|0])^128,t[i|0]=j;e=e+2|0;c=c+1|0;f=f-1|0;if(f){continue}break}}gb=d+16|0;return g+h|0}function EQ(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0;e=gb-16|0;gb=e;v[e+12>>2]=c;v[e+8>>2]=v[a>>2];c=e+8|0;h=v[Fb(c,e+12|0)>>2];v[e+8>>2]=v[a>>2];v[e+4>>2]=v[e+12>>2]-h;i=v[Fb(c,e+4|0)>>2];c=zb(b);if(h){f=v[a+20>>2];g=h;j=d;while(1){j=zb(w[c|0])+j|0;t[f|0]=j;f=f+2|0;c=c+1|0;g=g-1|0;if(g){continue}break}}b=zb(b);if(i){c=b+v[a>>2]|0;f=v[a+20>>2]+1|0;g=i;while(1){d=zb(w[c|0])+d|0;t[f|0]=d;f=f+2|0;c=c+1|0;g=g-1|0;if(g){continue}break}}gb=e+16|0;return h+i|0}function zO(a){var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;g=v[a+104>>2];e=(g<<3)+a|0;c=((g+7>>>0)%12<<3)+a|0;f=v[c>>2];c=v[c+4>>2];h=v[a+96>>2];i=v[a+100>>2];a:{if(!(h|i)){b=v[e+4>>2];d=v[e>>2];j=(b|0)==(c|0)&d>>>0>f>>>0|c>>>0<b>>>0;break a}b=v[e+4>>2];d=v[e>>2];j=!(c|f)|((b|0)==(c|0)&d>>>0>=f>>>0|c>>>0<b>>>0)}b=b+i|0;d=h+d|0;b=d>>>0<h>>>0?b+1|0:b;v[e>>2]=f-d;v[e+4>>2]=c-(b+(f>>>0<d>>>0)|0)&65535;v[a+104>>2]=(g+1>>>0)%12;v[a+96>>2]=j;v[a+100>>2]=0;jb=v[e+4>>2];return v[e>>2]}function uZ(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0;f=gb-32|0;gb=f;v[f+28>>2]=c;g=Pb(b,c<<1);a:{if(!g){break a}qc(f+28|0,65535);Af(a,x[f+28>>1]);h=f,i=Vb(a),v[h+16>>2]=i;h=f,i=Zb(a),v[h+8>>2]=i;if(!Gb(f+16|0,f+8|0)){break a}while(1){a=v[f+16>>2];c=f+24|0;if(!Ep(b,c)){PD(c)}c=w[f+24|0]|w[f+25|0]<<8;u[a>>1]=c;b:{if((c|0)==(d|0)){c=65535}else{if((c|0)!=(e|0)){break b}c=65534}u[a>>1]=c}a=f+16|0;of(a);if(Gb(a,f+8|0)){continue}break}}gb=f+32|0;return g|0}function s1(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0;if(!(!e|(c|0)==(d|0))){while(1){a:{g=1;f=gb-16|0;gb=f;v[f+12>>2]=v[a+8>>2];h=vi(f+8|0,f+12|0);v[22656]=0;i=EH(c,d-c|0,b);l=v[22656];v[22656]=0;b:{if((l|0)!=1){hf(h);gb=f+16|0;break b}a=P()|0;O()|0;hf(h);S(a|0);L()}c:{switch(i+2|0){default:g=i;break;case 0:case 1:break a;case 2:break c}}j=g+j|0;k=k+1|0;if(k>>>0>=e>>>0){break a}c=c+g|0;if((d|0)!=(c|0)){continue}}break}return j|0}return 0}function jG(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;f=gb-32|0;gb=f;v[f+16>>2]=c;v[f+24>>2]=b;k=f,l=zd(a),v[k+8>>2]=l;b=f+24|0;h=f+8|0;i=ck(b,h);e=i;b=ck(f+16|0,b);a:{if(Ab(a)>>>0>=e>>>0){if((b|0)==-1){AE(a,e);break a}d=gb-16|0;gb=d;v[d+12>>2]=b;if(b){c=Ab(a);j=Jb(a);g=c-e|0;v[d+8>>2]=g;b=v[Fb(d+12|0,d+8|0)>>2];v[d+12>>2]=b;g=g-b|0;if(g){e=e+j|0;fm(e,b+e|0,g);b=v[d+12>>2]}e=a;a=c-b|0;jh(e,a);t[d+7|0]=0;Bd(a+j|0,d+7|0)}gb=d+16|0;break a}Qn();L()}we(h,i);gb=f+32|0}function it(a,b,c){var d=0,e=0;d=(c|0)!=0;a:{b:{c:{if(!(a&3)|!c){break c}e=b&255;while(1){if((e|0)==w[a|0]){break b}c=c-1|0;d=(c|0)!=0;a=a+1|0;if(!(a&3)){break c}if(c){continue}break}}if(!d){break a}d:{if(w[a|0]==(b&255)|c>>>0<4){break d}d=B(b&255,16843009);while(1){e=d^v[a>>2];if((e^-1)&e-16843009&-2139062144){break d}a=a+4|0;c=c-4|0;if(c>>>0>3){continue}break}}if(!c){break a}}b=b&255;while(1){if((b|0)==w[a|0]){return a}a=a+1|0;c=c-1|0;if(c){continue}break}}return 0}function Y6(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0;f=gb-32|0;gb=f;zy(b,c,yb(d));e=v[b+16>>2];a:{if(e>>>0<=c>>>0){ok(a,d,0);break a}v[f+28>>2]=e-c;i=f,j=yb(d),v[i+24>>2]=j;g=v[Fb(f+28|0,f+24|0)>>2];SB(f+16|0,d,0,g);e=v[f+20>>2];v[f+8>>2]=v[f+16>>2];v[f+12>>2]=e;e=gb-32|0;gb=e;b=b+4|0;i=e,j=Vb(b),v[i+24>>2]=j;h=we(e+24|0,c);i=e,j=Vb(b),v[i+8>>2]=j;i=e,j=we(e+8|0,c),v[i+16>>2]=j;b=f+8|0;Vi(h,we(e+16|0,yb(b)),v[b>>2]);gb=e+32|0;SB(a,d,0,g)}gb=f+32|0}function Rfa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;c=gb-32|0;gb=c;a:{if((b-1&65535)>>>0>3998){break a}f=1;e=(B(b,104)+a|0)+484380|0;if(!Jd(e)){break a}g=a+1298224|0;d=a+1074992|0;while(1){if(v[d+104>>2]==(e|0)){v[d+76>>2]=0;v[d>>2]=0;v[d+4>>2]=0;v[d+16>>2]=0}d=d+872|0;if((g|0)!=(d|0)){continue}break}Pl(e);v[e>>2]=0;a=(B(b,104)+a|0)+484414|0;u[a>>1]=x[a>>1]&65470;v[c+24>>2]=0;v[c+8>>2]=0;v[c+16>>2]=0;v[c+20>>2]=0;v[c>>2]=0;v[c+4>>2]=0;So(e,0,c)}gb=c+32|0;return f|0}function Efa(a,b){a=a|0;b=b|0;var c=0;b=38480;a=dd(a);a:{while(1){b:{if(!cd(a)){if(!wj(v[b+8>>2],v[wo(a)>>2])){break b}}v[22656]=0;R(1413,a|0,b+8|0);c=v[22656];v[22656]=0;if((c|0)!=1){break b}break a}b=b+12|0;if((b|0)!=39044){continue}break}b=39056;while(1){c:{if(!cd(a)){if(!wj(v[b+8>>2],v[wo(a)>>2])){break c}}v[22656]=0;R(1413,a|0,b+8|0);c=v[22656];v[22656]=0;if((c|0)!=1){break c}break a}b=b+12|0;if((b|0)!=39104){continue}break}return}b=P()|0;O()|0;Nc(a);S(b|0);L()}function vn(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0;i=gb-16|0;gb=i;a:{b:{if(!a){break b}g=v[e+12>>2];h=c-b|0;if((h|0)>0){if((un(a,b,h)|0)!=(h|0)){break b}}b=d-b|0;b=(b|0)<(g|0)?g-b|0:0;if((b|0)>0){f=He(i,b,f);g=Jb(f);v[22656]=0;g=W(28,a|0,g|0,b|0)|0;h=v[22656];v[22656]=0;if((h|0)==1){break a}vb(f);if((b|0)!=(g|0)){break b}}b=d-c|0;if((b|0)>0){if((un(a,c,b)|0)!=(b|0)){break b}}XB(e);j=a}gb=i+16|0;return j|0}a=P()|0;O()|0;vb(f);S(a|0);L()}function Ri(a){a=a|0;var b=0,c=0,d=0,e=0,f=0;b=gb-48|0;gb=b;if(!cd(a)){pS(b+32|0,Zb(a));pS(b+24|0,Vb(a));c=v[b+36>>2];v[b+16>>2]=v[b+32>>2];v[b+20>>2]=c;c=v[b+28>>2];v[b+8>>2]=v[b+24>>2];v[b+12>>2]=c;c=b+16|0;e=b+8|0;a:{if(!qS(c,e)){break a}while(1){d=gb-16|0;gb=d;v[d+8>>2]=v[c+4>>2];f=hS(d+8|0);gb=d+16|0;if(x[v[f>>2]>>1]!=65535){break a}hS(c+4|0);if(qS(c,e)){continue}break}}d=v[c+4>>2];v[b+40>>2]=v[c>>2];v[b+44>>2]=d;c=AD(Vb(a),v[b+44>>2])}gb=b+48|0;return c&65535}function IG(a,b,c,d,e,f,g,h){var i=0,j=0,k=0,l=0;i=gb-16|0;gb=i;if((b^-1)+1073741807>>>0>=c>>>0){j=Jb(a);l=a;a:{if(b>>>0<536870887){v[i+8>>2]=b<<1;v[i+12>>2]=b+c;c=om(v[Lc(i+12|0,i+8|0)>>2]);break a}c=1073741806}k=c+1|0;c=Si(l,k);if(e){yi(c,j,e)}if(g){yi(c+(e<<2)|0,h,g)}d=d-(e+f|0)|0;if(d){h=e<<2;yi((h+c|0)+(g<<2)|0,(h+j|0)+(f<<2)|0,d)}b=b+1|0;if((b|0)!=2){ai(a,j,b)}ef(a,c);rg(a,k);b=a;a=d+(e+g|0)|0;de(b,a);v[i+4>>2]=0;Ge(c+(a<<2)|0,i+4|0);gb=i+16|0;return}vg();L()}function GQ(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0;d=gb-16|0;gb=d;v[d+12>>2]=c;v[d+8>>2]=v[a>>2];c=d+8|0;g=v[Fb(c,d+12|0)>>2];v[d+8>>2]=v[a>>2];v[d+4>>2]=v[d+12>>2]-g;h=v[Fb(c,d+4|0)>>2];c=zb(b);if(g){e=v[a+20>>2];f=g;while(1){i=e,j=Wh(w[c|0]),t[i|0]=j;e=e+2|0;c=c+1|0;f=f-1|0;if(f){continue}break}}b=zb(b);if(h){c=b+v[a>>2]|0;e=v[a+20>>2]+1|0;f=h;while(1){i=e,j=Wh(w[c|0]),t[i|0]=j;e=e+2|0;c=c+1|0;f=f-1|0;if(f){continue}break}}gb=d+16|0;return g+h|0}function Iaa(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0;v[22656]=0;_(1934,a|0);h=v[22656];v[22656]=0;a:{b:{if((h|0)!=1){h=v[a+24>>2];v[22656]=0;b=sa(1951,h|0,b|0,c|0,d|0,e|0,f|0,g|0)|0;c=v[22656];v[22656]=0;if((c|0)!=1){break b}}b=V(0)|0;O()|0;Z(b|0)|0;v[22656]=0;Y(1911,10292,a|0,0,0);a=v[22656];v[22656]=0;if((a|0)==1){break a}$();b=0}return b|0}a=P()|0;O()|0;v[22656]=0;X(20);b=v[22656];v[22656]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}function HV(a,b,c,d){var e=0,f=0;f=gb-16|0;gb=f;e=x[c>>1];while(1){a:{e=e<<1;u[c>>1]=e;t[b|0]=(e&65534)>>>0>255;e=w[c|0];u[c>>1]=e;if(!e){if(!lf(a,f+15|0)){break a}e=w[f+15|0];u[c>>1]=e<<1|1;t[b|0]=e>>>7;u[c>>1]=w[c|0]}t[d|0]=w[b|0]+(w[d|0]<<1);e=x[c>>1]<<1;u[c>>1]=e;t[b|0]=(e&65534)>>>0>255;e=w[c|0];u[c>>1]=e;if(!e){if(!lf(a,f+14|0)){break a}e=w[f+14|0];u[c>>1]=e<<1|1;t[b|0]=e>>>7;e=w[c|0];u[c>>1]=e;if(w[b|0]){continue}break a}if(w[b|0]){continue}}break}gb=f+16|0}function Faa(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0;v[22656]=0;_(1934,a|0);h=v[22656];v[22656]=0;a:{b:{if((h|0)!=1){h=v[a+24>>2];v[22656]=0;b=sa(1954,h|0,b|0,c|0,d|0,e|0,f|0,g|0)|0;c=v[22656];v[22656]=0;if((c|0)!=1){break b}}b=V(0)|0;O()|0;Z(b|0)|0;v[22656]=0;Y(1911,10224,a|0,0,0);a=v[22656];v[22656]=0;if((a|0)==1){break a}$();b=0}return b|0}a=P()|0;O()|0;v[22656]=0;X(20);b=v[22656];v[22656]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}function xH(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0;e=gb-16|0;gb=e;a:{b:{c:{d:{if((a|0)!=(b|0)){e:{f:{f=w[a|0];if((f|0)!=45){break f}a=a+1|0;if((b|0)!=(a|0)){break f}break e}h=v[115137];v[115137]=0;a=Hx(a,e+12|0,d,xe());d=jb;g=v[115137];g:{if(g){if(v[e+12>>2]!=(b|0)){break g}if((g|0)==68){break c}break d}v[115137]=h;if(v[e+12>>2]==(b|0)){break d}}}}v[c>>2]=4;a=0;break a}if(!d){break b}}v[c>>2]=4;a=-1;break a}a=(f|0)==45?0-a|0:a}gb=e+16|0;return a|0}function qf(a,b,c,d,e,f,g,h,i){var j=0,k=0,l=0,m=0;h=kqa(b,c,h,i);i=jb;j=h;h=kqa(d,e,f,g);e=j+h|0;d=jb+i|0;i=e;h=e>>>0<h>>>0?d+1|0:d;j=g;e=0;g=e;k=i;l=c;d=0;i=kqa(j,e,c,d);e=k+i|0;c=jb+h|0;k=e;e=e>>>0<i>>>0?c+1|0:c;h=f;c=0;i=b;f=kqa(h,c,i,0);b=jb;d=kqa(h,c,l,d);b=b+d|0;c=jb;c=b>>>0<d>>>0?c+1|0:c;h=c;c=c+k|0;d=c>>>0<h>>>0?e+1|0:e;h=c;c=d;d=kqa(i,m,j,g)+b|0;e=jb;e=b>>>0>d>>>0?e+1|0:e;b=h;h=e;e=b+e|0;v[a+8>>2]=e;v[a+12>>2]=e>>>0<h>>>0?c+1|0:c;v[a>>2]=f;v[a+4>>2]=d}function Xka(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=vh(a);a:{if(b){v[22656]=0;R(898,a|0,b|0);d=v[22656];v[22656]=0;if((d|0)==1){break a}d=gb-16|0;gb=d;c=d;v[c>>2]=a;e=v[a+4>>2];v[c+4>>2]=e;v[c+8>>2]=e+B(b,9);e=c;b=v[c+4>>2];c=v[c+8>>2];if((b|0)!=(c|0)){while(1){t[b|0]=0;t[b+1|0]=0;t[b+2|0]=0;t[b+3|0]=0;t[b+4|0]=0;t[b+5|0]=0;t[b+6|0]=0;t[b+7|0]=0;t[b+8|0]=0;b=b+9|0;v[e+4>>2]=b;if((b|0)!=(c|0)){continue}break}}$b(e);gb=d+16|0}return a|0}a=P()|0;O()|0;VB(c);S(a|0);L()}function ql(a,b,c){a=a|0;b=b|0;c=c|0;a:{if(a){if(b>>>0<=127){break a}b:{if(!v[v[115196]>>2]){if((b&-128)==57216){break a}break b}if(b>>>0<=2047){t[a+1|0]=b&63|128;t[a|0]=b>>>6|192;return 2}if(!((b&-8192)!=57344&b>>>0>=55296)){t[a+2|0]=b&63|128;t[a|0]=b>>>12|224;t[a+1|0]=b>>>6&63|128;return 3}if(b-65536>>>0<=1048575){t[a+3|0]=b&63|128;t[a|0]=b>>>18|240;t[a+2|0]=b>>>6&63|128;t[a+1|0]=b>>>12&63|128;return 4}}v[115137]=25;a=-1}else{a=1}return a|0}t[a|0]=b;return 1}function nc(a,b){var c=0,d=0,e=0;a:{b:{c=v[a+1396>>2];if((c|0)>=0){if((b|0)>(c|0)){if((b|0)>24){return nc(a,24)+(nc(a,b-24|0)<<24)|0}if(!c){v[a+1392>>2]=0}while(1){d=rt(a);if((d|0)==-1){break b}e=v[a+1396>>2];c=e+8|0;v[a+1396>>2]=c;v[a+1392>>2]=v[a+1392>>2]+(d<<e);if((b|0)>(c|0)){continue}break}}if((b|0)>(c|0)){break a}v[a+1396>>2]=c-b;c=a;a=v[a+1392>>2];v[c+1392>>2]=a>>>b;a=a&(-1<<b^-1)}else{a=0}return a}v[a+1396>>2]=-1;return 0}aa(7347,10534,1632,3887);L()}function aha(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0;d=gb-32|0;gb=d;f=v[c+12>>2];a:{if(!f){break a}g=t[c+16|0];e=Ab(b);if(!e){break a}h=e-1|0;c=0;while(1){b:{if(!c|(c>>>0)%(f>>>0)){break b}if((c|0)==(h|0)){if(w[pc(b,0)|0]==(hg(43)&255)){break b}if(w[pc(b,0)|0]==(hg(45)&255)){break b}}i=d,j=zd(b),v[i+8>>2]=j;i=d,j=we(d+8|0,e-c|0),v[i+16>>2]=j;Fd(d+24|0,d+16|0);Zz(b,v[d+24>>2],1,hg(g))}c=c+1|0;if((e|0)!=(c|0)){continue}break}}Dc(a,b);gb=d+32|0}function E9(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=+d;e=+e;var f=0,g=0;v[22656]=0;_(2007,a|0);f=v[22656];v[22656]=0;a:{b:{if((f|0)!=1){f=v[a+28>>2];g=v[v[f>>2]+72>>2];v[22656]=0;b=Ua(g|0,f|0,b|0,c|0,+d,+e)|0;c=v[22656];v[22656]=0;if((c|0)!=1){break b}}b=V(0)|0;O()|0;Z(b|0)|0;v[22656]=0;Y(1911,8588,a|0,0,0);a=v[22656];v[22656]=0;if((a|0)==1){break a}$();b=-1}return b|0}a=P()|0;O()|0;v[22656]=0;X(20);b=v[22656];v[22656]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}function VN(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;e=gb-32|0;gb=e;v[e+24>>2]=b;m=e,n=zd(a),v[m+16>>2]=n;j=ck(e+24|0,e+16|0);h=j;i=gb-16|0;gb=i;a:{b=a;g=Ab(b);if(g>>>0>=h>>>0){if(c){f=Kc(b);b:{if(f-g>>>0>=c>>>0){f=Jb(b);k=g-h|0;if(!k){break b}l=f+h|0;fm(l+c|0,l,k);break b}Ym(b,f,(c+g|0)-f|0,g,h,0,c);f=v[b>>2]}Ir(f+h|0,c,d);d=b;b=c+g|0;jh(d,b);t[i+15|0]=0;Bd(b+f|0,i+15|0)}gb=i+16|0;break a}Qn();L()}m=e,n=zd(a),v[m+8>>2]=n;we(e+8|0,j);gb=e+32|0}function xU(a){var b=0,c=0,d=0;a:{if((w[a+44|0]|w[a+45|0]<<8|(w[a+46|0]<<16|w[a+47|0]<<24))!=1179472976|w[a+28|0]!=26|w[a+30|0]>2){break a}b=a+40|0;if(w[b|0]|w[b+1|0]<<8){break a}b=a+38|0;c=w[b+1|0]<<8;if(!(w[b|0]|c)|(c|w[b|0])>>>0>32){break a}b=a+32|0;c=w[b+1|0]<<8;if(!(w[b|0]|c)|(c|w[b|0])>>>0>256){break a}b=a+34|0;c=w[b+1|0]<<8;if(!(w[b|0]|c)|(c|w[b|0])>>>0>255){break a}a=a+36|0;if(!(w[a|0]|w[a+1|0]<<8)){break a}d=(w[a|0]|w[a+1|0]<<8)>>>0<129}return d}function Oga(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0;d=gb-32|0;gb=d;f=v[c+12>>2];a:{if(!f){break a}g=t[c+16|0];e=Ab(b);if(!e){break a}h=e-1|0;c=0;while(1){b:{if(!c|(c>>>0)%(f>>>0)){break b}if((c|0)==(h|0)){if(w[Jb(b)|0]==(hg(43)&255)){break b}if(w[Jb(b)|0]==(hg(45)&255)){break b}}i=d,j=zd(b),v[i+8>>2]=j;i=d,j=we(d+8|0,e-c|0),v[i+16>>2]=j;Fd(d+24|0,d+16|0);VN(b,v[d+24>>2],1,hg(g))}c=c+1|0;if((e|0)!=(c|0)){continue}break}}Dc(a,b);gb=d+32|0}function Bna(a,b){a=a|0;b=b|0;var c=0,d=0;c=Je(a);if(c>>>0<b>>>0){d=gb-32|0;gb=d;a:{b:{c=b-c|0;c:{if(c>>>0<=(v[wb(a)>>2]-v[a+4>>2]|0)/20>>>0){xE(a,c);break c}b=wb(a);b=iD(d+8|0,jD(a,Je(a)+c|0),Je(a),b);v[22656]=0;R(683,b|0,c|0);c=v[22656];v[22656]=0;if((c|0)==1){break b}v[22656]=0;Ev(a,b);a=v[22656];v[22656]=0;if((a|0)==1){break b}jp(b)}gb=d+32|0;break a}a=P()|0;O()|0;jp(b);S(a|0);L()}return}if(b>>>0<c>>>0){b=v[a>>2]+B(b,20)|0;Je(a);hE(a,b);em(a);Je(a)}}function e7(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0;e=gb-48|0;gb=e;a:{if(w[b+8|0]){b=b+12|0;i=e,j=oc(b)-c|0,v[i+40>>2]=j;i=e,j=yb(d),v[i+32>>2]=j;f=e+40|0;h=e+32|0;g=v[Fb(f,h)>>2];i=e,j=Vb(b),v[i+40>>2]=j;f=we(f,c);i=e,j=Vb(b),v[i+24>>2]=j;i=e,j=we(e+24|0,c),v[i+32>>2]=j;Vi(f,we(h,g),v[d>>2]);ok(a,d,g);break a}g=v[d+4>>2];d=v[d>>2];v[e+16>>2]=d;v[e+20>>2]=g;f=v[v[b>>2]+40>>2];v[e+8>>2]=d;v[e+12>>2]=g;kb[f|0](a,b,c,e+8|0)}gb=e+48|0}function nY(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0;a:{b=v[a+1064>>2];if((b|0)>255){break a}while(1){f=(B(b,6)+a|0)+1072|0,g=cl(a,7),t[f|0]=g;d=cl(a,1);e=cl(a,1);c=v[a+1060>>2];if((c|0)>255){break a}b=v[a+1064>>2]+1|0;v[a+1060>>2]=b;v[a+1064>>2]=b;b:{if(d){u[(B(c,6)+a|0)+1068>>1]=b;nY(a);b=v[a+1064>>2];break b}u[(B(c,6)+a|0)+1068>>1]=65535}v[a+1060>>2]=b;if(e){u[(B(c,6)+a|0)+1070>>1]=b;if((b|0)<=255){continue}break a}break}u[(B(c,6)+a|0)+1070>>1]=65535}}function mca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;b=Fi(a,b,c,d);v[a>>2]=51840;d=mc(a+4208|0);v[a+4240>>2]=0;v[a+4244>>2]=0;c=wf(c);v[a+4260>>2]=0;v[a+4256>>2]=c;v[a+4236>>2]=0;c=a+4228|0;v[c>>2]=1048576e3;v[c+4>>2]=1048576e3;v[a+4220>>2]=1056964608;v[a+4224>>2]=1056964608;v[22656]=0;W(1532,a+44|0,2,2)|0;c=v[22656];v[22656]=0;a:{if((c|0)==1){break a}v[22656]=0;Th(b);c=v[22656];v[22656]=0;if((c|0)==1){break a}return a|0}a=P()|0;O()|0;Nc(d);Lf(b);S(a|0);L()}function _B(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=gb-48|0;gb=d;e=mc(a);f=d,g=Vb(b),v[f+40>>2]=g;f=d,g=Zb(b),v[f+32>>2]=g;a:{if(Gb(d+40|0,d+32|0)){while(1){a=d+8|0;b=v[d+40>>2];Zi(a,b);if((w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24))==(c|0)){a=d+8|0;rn(a,b);v[22656]=0;R(536,e|0,a|0);a=v[22656];v[22656]=0;if((a|0)==1){break a}xb(d+8|0)}a=d+40|0;pn(a);if(Gb(a,d+32|0)){continue}break}}gb=d+48|0;return}a=P()|0;O()|0;xb(d+8|0);jd(e);S(a|0);L()}function H9(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;v[22656]=0;_(2007,a|0);e=v[22656];v[22656]=0;a:{b:{if((e|0)!=1){e=v[a+28>>2];f=v[v[e>>2]+12>>2];v[22656]=0;b=da(f|0,e|0,b|0,c|0,d|0)|0;c=v[22656];v[22656]=0;if((c|0)!=1){break b}}b=V(0)|0;O()|0;Z(b|0)|0;v[22656]=0;Y(1911,8733,a|0,0,0);a=v[22656];v[22656]=0;if((a|0)==1){break a}$();b=-1}return b|0}a=P()|0;O()|0;v[22656]=0;X(20);b=v[22656];v[22656]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}function G9(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;v[22656]=0;_(2007,a|0);e=v[22656];v[22656]=0;a:{b:{if((e|0)!=1){e=v[a+28>>2];f=v[v[e>>2]+8>>2];v[22656]=0;b=da(f|0,e|0,b|0,c|0,d|0)|0;c=v[22656];v[22656]=0;if((c|0)!=1){break b}}b=V(0)|0;O()|0;Z(b|0)|0;v[22656]=0;Y(1911,8769,a|0,0,0);a=v[22656];v[22656]=0;if((a|0)==1){break a}$();b=-1}return b|0}a=P()|0;O()|0;v[22656]=0;X(20);b=v[22656];v[22656]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}function kG(a){var b=0,c=0;a:{if((w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24))!=1129474426|(w[a+4|0]|w[a+5|0]<<8|(w[a+6|0]<<16|w[a+7|0]<<24))!=1634291279){break a}b=a+8|0;if((w[b|0]|w[b+1|0]<<8)!=14){break a}b=a+12|0;if(!(w[b|0]|w[b+1|0]<<8)){break a}b=a+14|0;if(!(w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24))|(w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24))<0){break a}a=a+18|0;c=(w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24))>>>0>23}return c}function hL(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;b=gb-48|0;gb=b;v[b+40>>2]=e;v[b+44>>2]=f;c=wd(b+32|0,c,d);d=v[c+4>>2];v[b+8>>2]=v[c>>2];v[b+12>>2]=d;a:{a=lA(a,b+8|0,b+40|0);if(a+1>>>0>=3){a=ba(8)|0;v[22656]=0;b=Q(70,b+16|0,5190)|0;c=v[22656];v[22656]=0;b:{if((c|0)!=1){rc(a,b);v[22656]=0;U(186,a|0,54952,1936);a=v[22656];v[22656]=0;if((a|0)!=1){break a}d=P()|0;O()|0;vb(b);break b}d=P()|0;O()|0;ca(a|0)}S(d|0);L()}gb=b+48|0;return a|0}L()}function C9(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;v[22656]=0;_(2007,a|0);d=v[22656];v[22656]=0;e=1;a:{b:{if((d|0)!=1){d=v[a+28>>2];f=v[v[d>>2]+64>>2];v[22656]=0;U(f|0,d|0,b|0,(c|0)!=0|0);b=v[22656];v[22656]=0;if((b|0)!=1){break b}}b=V(0)|0;O()|0;Z(b|0)|0;v[22656]=0;Y(1911,3717,a|0,0,0);a=v[22656];v[22656]=0;if((a|0)==1){break a}$();e=0}return e|0}a=P()|0;O()|0;v[22656]=0;X(20);b=v[22656];v[22656]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}function A9(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;v[22656]=0;_(2007,a|0);d=v[22656];v[22656]=0;e=1;a:{b:{if((d|0)!=1){d=v[a+28>>2];f=v[v[d>>2]+56>>2];v[22656]=0;U(f|0,d|0,b|0,(c|0)!=0|0);b=v[22656];v[22656]=0;if((b|0)!=1){break b}}b=V(0)|0;O()|0;Z(b|0)|0;v[22656]=0;Y(1911,3771,a|0,0,0);a=v[22656];v[22656]=0;if((a|0)==1){break a}$();e=0}return e|0}a=P()|0;O()|0;v[22656]=0;X(20);b=v[22656];v[22656]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}function nP(a,b,c){var d=0,e=0;d=gb-16|0;gb=d;a:{if(v[a+480180>>2]==4){e=w[b+813|0];if(c){t[b+813|0]=e&240|c&15;break a}c=e&15;break a}if(v[a+480180>>2]!=1048576){break a}if(c){t[b+813|0]=c;break a}c=w[b+813|0]}b:{if(!(t[b+851|0]&1)|!v[b+700>>2]){break b}c=c&255;if(!c){break b}sk(a,b,b+700|0,0-(c<<2)|0,0);if(v[b+700>>2]<65536){break b}c=d+8|0;Db(c,a+1074312|0,7);if(Cb(c)|(v[a+480180>>2]!=4?w[a+480208|0]&16:0)){break b}v[b+700>>2]=65535}gb=d+16|0}function IN(a,b){var c=0,d=0,e=0,f=0,g=0,h=0;c=a;d=b;if((c|0)!=(d|0)){e=gb-16|0;gb=e;g=v[d+4>>2];d=v[d>>2];f=(g-d|0)/6|0;a:{if(f>>>0<=Yj(c)>>>0){if(Kg(c)>>>0<f>>>0){v[e+12>>2]=d;h=Kg(c);v[e+12>>2]=v[e+12>>2]+B(h,6);h=d;d=v[e+12>>2];sz(h,d,v[c>>2]);qz(c,d,g,f-Kg(c)|0);break a}WC(c,sz(d,g,v[c>>2]));break a}DN(c);iX(c,IC(c,f));qz(c,d,g,f)}gb=e+16|0}v[a+12>>2]=v[b+12>>2];v[a+16>>2]=v[b+16>>2];v[a+20>>2]=v[b+20>>2];HN(a+24|0,b+24|0);ik(a+36|0,b+36|0)}function wX(a){var b=0,c=0,d=0;a:{if((w[a+60|0]|w[a+61|0]<<8|(w[a+62|0]<<16|w[a+63|0]<<24))!=808537417){break a}b=a+32|0;if((w[b|0]|w[b+1|0]<<8)>>>0>256){break a}b=a+36|0;if(w[a+49|0]<32|(w[b|0]|w[b+1|0]<<8)>>>0>255|w[a+50|0]>64){break a}b=a+51|0;if(w[b|0]<4|t[b|0]<0){break a}d=a+576|0;a=a- -64|0;b=0;while(1){c=0;b:{switch(w[a+15|0]){case 0:case 1:b=1;break;case 2:break b;default:break a}}c=b;a=a+16|0;if((d|0)!=(a|0)){continue}break}}return c&1}function Bv(a,b){a=a|0;b=b|0;var c=0,d=0;d=w[a+3|0];a:{if(d>>>0>17){break a}d=1<<d;b:{if(!(d&63503)){if(d&198144){break b}break a}if(!w[a|0]){break a}}c:{d:{e:{switch(w[a+3|0]){case 16:case 17:c=8;break d;case 0:case 1:case 2:case 3:case 11:case 12:case 13:case 14:case 15:c=w[a|0];if(!(c&7)){break d}case 10:c=b+1>>>1|0;b=(w[a+3|0]==10)<<4;break c;case 9:break e;default:break d}}c=16}c=B(c>>>3|0,b);b=(w[a+3|0]==10)<<4}c=b+B(hp(a),c)|0}return c|0}function B$(a,b,c,d,e,f,g,h,i,j,k,l){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;l=l|0;var m=0;v[22656]=0;m=a;a=0;a=wG(1925,m|a,b,c,d,a|e,f);b=v[22656];v[22656]=0;a:{b:{if((b|0)==1){a=V(0)|0;O()|0;Z(a|0)|0;v[22656]=0;ja(1922,5974,g|0,h|0,i|0,j|0,k|0,l|0);a=v[22656];v[22656]=0;if((a|0)==1){break b}$();a=-255}break a}a=P()|0;O()|0;v[22656]=0;X(20);b=v[22656];v[22656]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}return a|0}function yoa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;a:{e=gb-48|0;gb=e;Rn(e+24|0,c);v[22656]=0;R(144,e+36|0,d|0);c=v[22656];v[22656]=0;b:{c:{if((c|0)!=1){v[22656]=0;qi(e+16|0,e+24|0);c=v[22656];v[22656]=0;if((c|0)==1){break c}v[22656]=0;c=v[e+20>>2];v[e+8>>2]=v[e+16>>2];v[e+12>>2]=c;U(146,a|0,b|0,e+8|0);a=v[22656];v[22656]=0;if((a|0)==1){break c}Cf(e+24|0);gb=e+48|0;break a}a=P()|0;O()|0;vb(e+24|0);break b}a=P()|0;O()|0;Cf(e+24|0)}S(a|0);L()}}function woa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;a:{e=gb-48|0;gb=e;gD(e+24|0,c);v[22656]=0;R(637,e+36|0,d|0);c=v[22656];v[22656]=0;b:{c:{if((c|0)!=1){v[22656]=0;qi(e+16|0,e+24|0);c=v[22656];v[22656]=0;if((c|0)==1){break c}v[22656]=0;c=v[e+20>>2];v[e+8>>2]=v[e+16>>2];v[e+12>>2]=c;U(146,a|0,b|0,e+8|0);a=v[22656];v[22656]=0;if((a|0)==1){break c}Cf(e+24|0);gb=e+48|0;break a}a=P()|0;O()|0;vb(e+24|0);break b}a=P()|0;O()|0;Cf(e+24|0)}S(a|0);L()}}function _oa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;a:{e=gb-48|0;gb=e;gD(e+24|0,c);v[22656]=0;R(539,e+36|0,d|0);c=v[22656];v[22656]=0;b:{c:{if((c|0)!=1){v[22656]=0;qi(e+16|0,e+24|0);c=v[22656];v[22656]=0;if((c|0)==1){break c}v[22656]=0;c=v[e+20>>2];v[e+8>>2]=v[e+16>>2];v[e+12>>2]=c;U(146,a|0,b|0,e+8|0);a=v[22656];v[22656]=0;if((a|0)==1){break c}Cf(e+24|0);gb=e+48|0;break a}a=P()|0;O()|0;vb(e+24|0);break b}a=P()|0;O()|0;Cf(e+24|0)}S(a|0);L()}}function Ypa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;a:{e=gb-48|0;gb=e;Rn(e+24|0,c);v[22656]=0;R(160,e+36|0,d|0);c=v[22656];v[22656]=0;b:{c:{if((c|0)!=1){v[22656]=0;qi(e+16|0,e+24|0);c=v[22656];v[22656]=0;if((c|0)==1){break c}v[22656]=0;c=v[e+20>>2];v[e+8>>2]=v[e+16>>2];v[e+12>>2]=c;U(146,a|0,b|0,e+8|0);a=v[22656];v[22656]=0;if((a|0)==1){break c}Cf(e+24|0);gb=e+48|0;break a}a=P()|0;O()|0;vb(e+24|0);break b}a=P()|0;O()|0;Cf(e+24|0)}S(a|0);L()}}function Vma(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;a:{e=gb-48|0;gb=e;Kh(e+24|0,c);v[22656]=0;R(777,e+36|0,d|0);c=v[22656];v[22656]=0;b:{c:{if((c|0)!=1){v[22656]=0;qi(e+16|0,e+24|0);c=v[22656];v[22656]=0;if((c|0)==1){break c}v[22656]=0;c=v[e+20>>2];v[e+8>>2]=v[e+16>>2];v[e+12>>2]=c;U(453,a|0,b|0,e+8|0);a=v[22656];v[22656]=0;if((a|0)==1){break c}Cf(e+24|0);gb=e+48|0;break a}a=P()|0;O()|0;vb(e+24|0);break b}a=P()|0;O()|0;Cf(e+24|0)}S(a|0);L()}}function sB(a,b,c,d,e){var f=0,g=0,h=0,i=0,j=0,k=0;i=-1;f=d&2147483647;k=f;g=(f|0)==2147418112;h=c;a:{if(g&!c?a|b:g&(c|0)!=0|f>>>0>2147418112){break a}f=e&2147483647;g=f;j=(f|0)==2147418112;if(j?0:j&0|f>>>0>2147418112){break a}if(!(a|h|(g|k|b))){return 0}h=d&e;if((h|0)>0|(h|0)>=0){if(!c&(d|0)==(e|0)?0:(d|0)<(e|0)){break a}return(a|c)!=0|(d^e|b)!=0}if(!c&(d|0)==(e|0)?a|b:(c|0)!=0&(d|0)>=(e|0)|(d|0)>(e|0)){break a}i=(a|c)!=0|(d^e|b)!=0}return i}function dw(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;a:{e=gb-48|0;gb=e;OD(e+24|0,c);v[22656]=0;R(144,e+36|0,d|0);c=v[22656];v[22656]=0;b:{c:{if((c|0)!=1){v[22656]=0;qi(e+16|0,e+24|0);c=v[22656];v[22656]=0;if((c|0)==1){break c}v[22656]=0;c=v[e+20>>2];v[e+8>>2]=v[e+16>>2];v[e+12>>2]=c;U(146,a|0,b|0,e+8|0);a=v[22656];v[22656]=0;if((a|0)==1){break c}Cf(e+24|0);gb=e+48|0;break a}a=P()|0;O()|0;vb(e+24|0);break b}a=P()|0;O()|0;Cf(e+24|0)}S(a|0);L()}}function O4(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;a:{e=gb-48|0;gb=e;Kh(e+24|0,c);v[22656]=0;R(144,e+36|0,d|0);c=v[22656];v[22656]=0;b:{c:{if((c|0)!=1){v[22656]=0;qi(e+16|0,e+24|0);c=v[22656];v[22656]=0;if((c|0)==1){break c}v[22656]=0;c=v[e+20>>2];v[e+8>>2]=v[e+16>>2];v[e+12>>2]=c;U(146,a|0,b|0,e+8|0);a=v[22656];v[22656]=0;if((a|0)==1){break c}Cf(e+24|0);gb=e+48|0;break a}a=P()|0;O()|0;vb(e+24|0);break b}a=P()|0;O()|0;Cf(e+24|0)}S(a|0);L()}}function CZ(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;a:{e=gb-48|0;gb=e;kw(e+24|0,c);v[22656]=0;R(365,e+36|0,d|0);c=v[22656];v[22656]=0;b:{c:{if((c|0)!=1){v[22656]=0;qi(e+16|0,e+24|0);c=v[22656];v[22656]=0;if((c|0)==1){break c}v[22656]=0;c=v[e+20>>2];v[e+8>>2]=v[e+16>>2];v[e+12>>2]=c;U(146,a|0,b|0,e+8|0);a=v[22656];v[22656]=0;if((a|0)==1){break c}Cf(e+24|0);gb=e+48|0;break a}a=P()|0;O()|0;vb(e+24|0);break b}a=P()|0;O()|0;Cf(e+24|0)}S(a|0);L()}}function qN(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=Nb(a);if(c>>>0<=127){e=gb-32|0;gb=e;a:{b:{d=128-c|0;c:{if(d>>>0<=v[wb(a)>>2]-v[a+4>>2]>>2>>>0){jz(a,d,b);break c}c=wb(a);c=fn(e+8|0,fh(a,Nb(a)+d|0),Nb(a),c);v[22656]=0;U(1500,c|0,d|0,b|0);b=v[22656];v[22656]=0;if((b|0)==1){break b}v[22656]=0;R(1501,a|0,c|0);a=v[22656];v[22656]=0;if((a|0)==1){break b}eh(c)}gb=e+32|0;break a}a=P()|0;O()|0;eh(c);S(a|0);L()}return}if((c|0)!=128){hj(a,v[a>>2]+512|0)}}function uP(a,b,c){var d=0,e=0;d=gb-16|0;gb=d;a:{if(v[a+480180>>2]==4){e=w[b+814|0];if(c){t[b+814|0]=e&240|c&15;break a}c=e&15;break a}if(v[a+480180>>2]!=1048576){break a}if(c){t[b+813|0]=c;break a}c=w[b+813|0]}b:{if(!(t[b+851|0]&1)|!v[b+700>>2]){break b}c=c&255;if(!c){break b}sk(a,b,b+700|0,0-c|0,0);if(v[b+700>>2]<65536){break b}c=d+8|0;Db(c,a+1074312|0,7);if(Cb(c)|(v[a+480180>>2]!=4?w[a+480208|0]&16:0)){break b}v[b+700>>2]=65535}gb=d+16|0}function OS(a,b){var c=0,d=0,e=0,f=0;c=gb-16|0;gb=c;v[c+12>>2]=v[a+4>>2];v[c+8>>2]=v[b+4>>2];a:{b:{if(!v[Fb(c+12|0,c+8|0)>>2]){break b}while(1){e=Zq(t[lc(a,d)|0]);f=Zq(t[lc(b,d)|0]);if((e|0)!=(f|0)){d=(e&255)>>>0<(f&255)>>>0?-1:1;break a}if(e){v[c+12>>2]=v[a+4>>2];v[c+8>>2]=v[b+4>>2];d=d+1|0;if(d>>>0>=y[Fb(c+12|0,c+8|0)>>2]){break b}continue}break}d=0;break a}d=0;if(v[a+4>>2]==v[b+4>>2]){break a}d=y[a+4>>2]<y[b+4>>2]?-1:1}gb=c+16|0;return d}function voa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=oc(a);if(d>>>0<b>>>0){e=gb-32|0;gb=e;a:{b:{d=b-d|0;c:{if(d>>>0<=v[wb(a)>>2]-v[a+4>>2]>>>0){En(a,d,c);break c}b=wb(a);b=Zg(e+8|0,qh(a,oc(a)+d|0),oc(a),b);v[22656]=0;U(638,b|0,d|0,c|0);c=v[22656];v[22656]=0;if((c|0)==1){break b}v[22656]=0;R(296,a|0,b|0);a=v[22656];v[22656]=0;if((a|0)==1){break b}be(b)}gb=e+32|0;break a}a=P()|0;O()|0;be(b);S(a|0);L()}return}if(b>>>0<d>>>0){Em(a,v[a>>2]+b|0)}}function afa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;a:{d=gb-32|0;gb=d;e=hh(a);b:{c:{d:{e:{while(1){v[22656]=0;a=Q(191,b|0,8)|0;f=v[22656];v[22656]=0;if((f|0)==1){break c}if(!a){break d}v[22656]=0;U(1467,d|0,b|0,c|0);a=v[22656];v[22656]=0;if((a|0)!=1){v[22656]=0;R(1468,e|0,d|0);a=v[22656];v[22656]=0;if((a|0)==1){break e}ed(d);continue}break}a=P()|0;O()|0;break b}a=P()|0;O()|0;ed(d);break b}gb=d+32|0;break a}a=P()|0;O()|0}ke(e);S(a|0);L()}}function Tga(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;a:{d=gb-32|0;gb=d;e=Io(a);b:{c:{d:{e:{while(1){v[22656]=0;a=Q(191,b|0,8)|0;f=v[22656];v[22656]=0;if((f|0)==1){break c}if(!a){break d}v[22656]=0;U(1159,d|0,b|0,c|0);a=v[22656];v[22656]=0;if((a|0)!=1){v[22656]=0;R(1160,e|0,d|0);a=v[22656];v[22656]=0;if((a|0)==1){break e}ed(d);continue}break}a=P()|0;O()|0;break b}a=P()|0;O()|0;ed(d);break b}gb=d+32|0;break a}a=P()|0;O()|0}zB(e);S(a|0);L()}}function Lna(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=gb-16|0;gb=d;c=-1;a:{if(!ek(a,d+8|0)){break a}c=d+8|0;b:{if((w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24))!=(An(6109)|0)){break b}c=c+4|0;if((w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24))>>>0<256){break b}e=(w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24))>>>0<260}c=0;if(!e){break a}c=a;a=d+12|0;c=Oe(c,b,(w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24))>>>0<259?80:76,0)}gb=d+16|0;return c|0}function Jaa(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0;v[22656]=0;_(1934,a|0);f=v[22656];v[22656]=0;a:{b:{if((f|0)!=1){f=v[a+24>>2];v[22656]=0;b=fa(1950,f|0,b|0,c|0,d|0,e|0)|0;c=v[22656];v[22656]=0;if((c|0)!=1){break b}}b=V(0)|0;O()|0;Z(b|0)|0;v[22656]=0;Y(1911,6840,a|0,0,0);a=v[22656];v[22656]=0;if((a|0)==1){break a}$();b=0}return b|0}a=P()|0;O()|0;v[22656]=0;X(20);b=v[22656];v[22656]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}function Gaa(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0;v[22656]=0;_(1934,a|0);f=v[22656];v[22656]=0;a:{b:{if((f|0)!=1){f=v[a+24>>2];v[22656]=0;b=fa(1953,f|0,b|0,c|0,d|0,e|0)|0;c=v[22656];v[22656]=0;if((c|0)!=1){break b}}b=V(0)|0;O()|0;Z(b|0)|0;v[22656]=0;Y(1911,6768,a|0,0,0);a=v[22656];v[22656]=0;if((a|0)==1){break a}$();b=0}return b|0}a=P()|0;O()|0;v[22656]=0;X(20);b=v[22656];v[22656]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}function y9(a,b,c){a=a|0;b=b|0;c=+c;var d=0,e=0,f=0;v[22656]=0;_(2007,a|0);d=v[22656];v[22656]=0;e=1;a:{b:{if((d|0)!=1){d=v[a+28>>2];f=v[v[d>>2]+48>>2];v[22656]=0;Wa(f|0,d|0,b|0,+c);b=v[22656];v[22656]=0;if((b|0)!=1){break b}}b=V(0)|0;O()|0;Z(b|0)|0;v[22656]=0;Y(1911,8932,a|0,0,0);a=v[22656];v[22656]=0;if((a|0)==1){break a}$();e=0}return e|0}a=P()|0;O()|0;v[22656]=0;X(20);b=v[22656];v[22656]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}function jf(a,b,c,d){var e=0,f=0;a:{if(!Ab(a)|(c-b|0)<5){break a}e=b;f=c;b:{if((e|0)==(f|0)){break b}f=f-4|0;if(f>>>0<=e>>>0){break b}while(1){xc(e,f);e=e+4|0;f=f-4|0;if(e>>>0<f>>>0){continue}break}}e=Jb(a);f=Ab(a);a=c-4|0;c:{if(a>>>0>b>>>0){c=e+f|0;while(1){f=w[e|0];if((f-1&255)>>>0<=125&(f|0)!=v[b>>2]){break c}e=((c-e|0)>1)+e|0;b=b+4|0;if(a>>>0>b>>>0){continue}break}}b=w[e|0];if((b-1&255)>>>0>125|b>>>0>v[a>>2]-1>>>0){break a}}v[d>>2]=4}}function Goa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;d=gb-32|0;gb=d;v[d+28>>2]=c;c=Pb(b,c<<2);a:{if(!c){break a}qc(d+28|0,65535);Af(a,x[d+28>>1]);g=d,h=Vb(a),v[g+16>>2]=h;g=d,h=Zb(a),v[g+8>>2]=h;if(!Gb(d+16|0,d+8|0)){break a}while(1){a=v[d+16>>2];e=d+24|0;if(!js(b,e)){f=gb-16|0;gb=f;ak(e);gb=f+16|0}e=w[d+24|0]|w[d+25|0]<<8;u[a>>1]=e;if((e|0)==65535){u[a>>1]=65535}a=d+16|0;of(a);if(Gb(a,d+8|0)){continue}break}}gb=d+32|0;return c|0}function Mha(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;a:{d=gb-48|0;gb=d;LC(d+24|0,c);v[22656]=0;R(637,d+36|0,49084);c=v[22656];v[22656]=0;b:{c:{if((c|0)!=1){v[22656]=0;qi(d+16|0,d+24|0);c=v[22656];v[22656]=0;if((c|0)==1){break c}v[22656]=0;c=v[d+20>>2];v[d+8>>2]=v[d+16>>2];v[d+12>>2]=c;U(146,a|0,b|0,d+8|0);a=v[22656];v[22656]=0;if((a|0)==1){break c}Cf(d+24|0);gb=d+48|0;break a}a=P()|0;O()|0;vb(d+24|0);break b}a=P()|0;O()|0;Cf(d+24|0)}S(a|0);L()}}function Oe(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0;e=gb-16|0;gb=e;g=yo(a);f=e;i=e;a:{if(b){j=v[b+4>>2];h=v[b>>2];break a}h=yo(a)}v[i+8>>2]=h;v[f+12>>2]=j;f=v[a+12>>2];a=1;b:{if(!b){break b}a=c+f|0;d=c>>>0>a>>>0?d+1|0:d;b=a;v[e>>2]=2048;v[e+4>>2]=0;a=Uk(e+8|0,e);c=v[a>>2];a=v[a+4>>2];c:{if(!a&c>>>0>g>>>0|a){a=-1;if(!d&b>>>0<=g>>>0){break c}break b}a=0;c=v[e+12>>2];if((c|0)==(d|0)&b>>>0>y[e+8>>2]|c>>>0<d>>>0){break b}}a=1}gb=e+16|0;return a}function v7(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;d=gb-16|0;gb=d;c=Xh(C(z[a+24>>2]*C(65536)));if(!((c|0)==65536|!v[b+8>>2])){g=c;h=c>>31;while(1){e=0;if(v[b+4>>2]){while(1){c=v[Xg(b,e,f)>>2];c=Ac(lqa(kqa(c,c>>31,g,h),jb,65536,0),jb);i=Xg(b,e,f),j=c,v[i>>2]=j;e=e+1|0;if(e>>>0<y[b+4>>2]){continue}break}}f=f+1|0;if(f>>>0<y[b+8>>2]){continue}break}}v[d+8>>2]=v[b+8>>2];g=v[b+4>>2];v[d>>2]=v[b>>2];v[d+4>>2]=g;fK(a,d);gb=d+16|0}function Oda(a,b){a=a|0;b=b|0;var c=0,d=0;c=Nb(a);if(c>>>0<b>>>0){d=gb-32|0;gb=d;a:{b:{c=b-c|0;c:{if(c>>>0<=v[wb(a)>>2]-v[a+4>>2]>>2>>>0){hN(a,c);break c}b=wb(a);b=fn(d+8|0,fh(a,Nb(a)+c|0),Nb(a),b);v[22656]=0;R(1542,b|0,c|0);c=v[22656];v[22656]=0;if((c|0)==1){break b}v[22656]=0;R(1539,a|0,b|0);a=v[22656];v[22656]=0;if((a|0)==1){break b}eh(b)}gb=d+32|0;break a}a=P()|0;O()|0;eh(b);S(a|0);L()}return}if(b>>>0<c>>>0){hj(a,v[a>>2]+(b<<2)|0)}}function E7(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;d=gb-16|0;gb=d;c=Xh(C(z[a+24>>2]*C(65536)));if(!((c|0)==65536|!v[b+8>>2])){g=c;h=c>>31;while(1){e=0;if(v[b+4>>2]){while(1){c=v[Xg(b,e,f)>>2];c=Ac(lqa(kqa(c,c>>31,g,h),jb,65536,0),jb);i=Xg(b,e,f),j=c,v[i>>2]=j;e=e+1|0;if(e>>>0<y[b+4>>2]){continue}break}}f=f+1|0;if(f>>>0<y[b+8>>2]){continue}break}}v[d+8>>2]=v[b+8>>2];g=v[b+4>>2];v[d>>2]=v[b>>2];v[d+4>>2]=g;mK(a,d);gb=d+16|0}function ie(a){var b=0,c=0,d=0;d=Wp(Nf(a)+1|0,1);if(d){a:{c=d;b:{if((c^a)&3){break b}if(a&3){while(1){b=w[a|0];t[c|0]=b;if(!b){break a}c=c+1|0;a=a+1|0;if(a&3){continue}break}}b=v[a>>2];if((b^-1)&b-16843009&-2139062144){break b}while(1){v[c>>2]=b;b=v[a+4>>2];c=c+4|0;a=a+4|0;if(!(b-16843009&(b^-1)&-2139062144)){continue}break}}b=w[a|0];t[c|0]=b;if(!b){break a}while(1){b=w[a+1|0];t[c+1|0]=b;c=c+1|0;a=a+1|0;if(b){continue}break}}}return d}function V5(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=gb-32|0;gb=d;v[d+16>>2]=b;e=v[a+48>>2];v[d+20>>2]=c-((e|0)!=0);f=v[a+44>>2];v[d+28>>2]=e;v[d+24>>2]=f;e=-1;a:{b:{if(!ht(eb(v[a+60>>2],d+16|0,2,d+12|0)|0)){e=v[d+12>>2];if((e|0)>0){break b}}v[a>>2]=v[a>>2]|e&48^16;break a}g=v[d+20>>2];if(g>>>0>=e>>>0){break a}f=v[a+44>>2];v[a+4>>2]=f;v[a+8>>2]=f+(e-g|0);if(v[a+48>>2]){v[a+4>>2]=f+1;t[(b+c|0)-1|0]=w[f|0]}e=c}gb=d+32|0;return e|0}function Tr(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=gb-32|0;gb=c;a:{if(!w[b+7|0]){while(1){if(!w[b+d|0]){aa(14540,6236,413,10498);L()}d=d+1|0;if((d|0)!=7){continue}break}d=0;t[c+27|0]=0;t[c+28|0]=0;t[c+29|0]=0;t[c+30|0]=0;v[c+24>>2]=0;e=wd(c+8|0,c+24|0,7);f=v[e+4>>2];v[c>>2]=v[e>>2];v[c+4>>2]=f;e=c+16|0;cc(e,a,c);b:{if((yb(e)|0)!=7){break b}if(sd(c+24|0,b,7)){break b}Rb(a,7);d=1}gb=c+32|0;break a}aa(14519,6236,411,10498);L()}return d|0}function T5(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0;e=gb-16|0;gb=e;a:{if((c|0)<=0){break a}while(1){d=v[a+16>>2];g=v[a+12>>2];b:{if(d>>>0>g>>>0){v[e+12>>2]=2147483647;v[e+8>>2]=d-g;v[e+4>>2]=c-f;d=v[pd(e+12|0,pd(e+8|0,e+4|0))>>2];Qg(b,v[a+12>>2],d);v[a+12>>2]=v[a+12>>2]+d;break b}d=kb[v[v[a>>2]+40>>2]](a)|0;if((d|0)==-1){break a}h=b,i=Wh(d),t[h|0]=i;d=1}b=b+d|0;f=d+f|0;if((f|0)<(c|0)){continue}break}}gb=e+16|0;return f|0}function P5(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;e=gb-16|0;gb=e;a:{if((c|0)<=0){break a}while(1){d=v[a+12>>2];f=v[a+16>>2];b:{if(d>>>0<f>>>0){v[e+12>>2]=2147483647;v[e+8>>2]=f-d>>2;v[e+4>>2]=c-g;d=v[pd(e+12|0,pd(e+8|0,e+4|0))>>2];yi(b,v[a+12>>2],d);f=d<<2;v[a+12>>2]=f+v[a+12>>2];b=b+f|0;break b}d=kb[v[v[a>>2]+40>>2]](a)|0;if((d|0)==-1){break a}v[b>>2]=d;d=1;b=b+4|0}g=d+g|0;if((g|0)<(c|0)){continue}break}}gb=e+16|0;return g|0}function BE(a,b){a=a|0;b=b|0;var c=0,d=0;c=tc(a);if(c>>>0<b>>>0){d=gb-32|0;gb=d;a:{b:{c=b-c|0;c:{if(c>>>0<=v[wb(a)>>2]-v[a+4>>2]>>1>>>0){oE(a,c);break c}b=wb(a);b=Gn(d+8|0,Vk(a,tc(a)+c|0),tc(a),b);v[22656]=0;R(338,b|0,c|0);c=v[22656];v[22656]=0;if((c|0)==1){break b}v[22656]=0;R(313,a|0,b|0);a=v[22656];v[22656]=0;if((a|0)==1){break b}Hh(b)}gb=d+32|0;break a}a=P()|0;O()|0;Hh(b);S(a|0);L()}return}if(b>>>0<c>>>0){yn(a,v[a>>2]+(b<<1)|0)}}function x8(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0;h=gb-16|0;gb=h;a:{b:{c:{if(g?!f|(!d|!e):1){a=ba(8)|0;v[22656]=0;b=Q(70,h|0,5333)|0;c=v[22656];v[22656]=0;if((c|0)==1){break c}rc(a,b);v[22656]=0;U(186,a|0,54952,1936);a=v[22656];v[22656]=0;if((a|0)!=1){break a}e=P()|0;O()|0;vb(b);break b}Cj(a,b,4);c=Ny(a,c,d,e,f,g);A[a+16>>3]=A[a+16>>3]+ +(c>>>0)/+(b|0);gb=h+16|0;return c|0}e=P()|0;O()|0;ca(a|0)}S(e|0)}L()}function A8(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0;h=gb-16|0;gb=h;a:{b:{c:{if(g?!f|(!d|!e):1){a=ba(8)|0;v[22656]=0;b=Q(70,h|0,5333)|0;c=v[22656];v[22656]=0;if((c|0)==1){break c}rc(a,b);v[22656]=0;U(186,a|0,54952,1936);a=v[22656];v[22656]=0;if((a|0)!=1){break a}e=P()|0;O()|0;vb(b);break b}Cj(a,b,4);c=Oy(a,c,d,e,f,g);A[a+16>>3]=A[a+16>>3]+ +(c>>>0)/+(b|0);gb=h+16|0;return c|0}e=P()|0;O()|0;ca(a|0)}S(e|0)}L()}function dpa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=gb-32|0;gb=c;e=c+24|0;bc(e,b,15);e=yb(e);d=v[c+28>>2];f=v[c+24>>2];v[c+8>>2]=f;v[c+12>>2]=d;v[c>>2]=f;v[c+4>>2]=d;d=c+16|0;cc(d,a,c);d=yb(d);if((d|0)==(e|0)){Rb(a,yb(c+24|0))}gb=c+32|0;if((d|0)!=(e|0)){t[b|0]=0;t[b+1|0]=0;t[b+2|0]=0;t[b+3|0]=0;t[b+4|0]=0;t[b+5|0]=0;t[b+6|0]=0;t[b+7|0]=0;t[b+7|0]=0;t[b+8|0]=0;t[b+9|0]=0;t[b+10|0]=0;t[b+11|0]=0;t[b+12|0]=0;t[b+13|0]=0;t[b+14|0]=0}}function q9(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;v[22656]=0;_(2007,a|0);c=v[22656];v[22656]=0;d=1;a:{b:{if((c|0)!=1){c=v[a+28>>2];e=v[v[c>>2]+16>>2];v[22656]=0;R(e|0,c|0,b|0);b=v[22656];v[22656]=0;if((b|0)!=1){break b}}b=V(0)|0;O()|0;Z(b|0)|0;v[22656]=0;Y(1911,10094,a|0,0,0);a=v[22656];v[22656]=0;if((a|0)==1){break a}$();d=0}return d|0}a=P()|0;O()|0;v[22656]=0;X(20);b=v[22656];v[22656]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}function YM(a){var b=0,c=0,d=0,e=0;c=gb-32|0;gb=c;a:{b:{if(Dl(a)>>>0<=Vf(a)>>>0){break b}b=wb(a);d=Vf(a);e=Vf(a);v[22656]=0;b=da(1536,c+8|0,d|0,e|0,b|0)|0;d=v[22656];v[22656]=0;c:{d:{if((d|0)!=1){v[22656]=0;R(1537,a|0,b|0);a=v[22656];v[22656]=0;if((a|0)==1){break d}St(b);break b}a=V(0)|0;O()|0;break c}a=V(0)|0;O()|0;St(b)}Z(a|0)|0;v[22656]=0;X(20);a=v[22656];v[22656]=0;if((a|0)==1){break a}}gb=c+32|0;return}V(0)|0;O()|0;Bb();L()}function XM(a){var b=0,c=0,d=0,e=0;c=gb-32|0;gb=c;a:{b:{if(pe(a)>>>0<=Nb(a)>>>0){break b}b=wb(a);d=Nb(a);e=Nb(a);v[22656]=0;b=da(1538,c+8|0,d|0,e|0,b|0)|0;d=v[22656];v[22656]=0;c:{d:{if((d|0)!=1){v[22656]=0;R(1539,a|0,b|0);a=v[22656];v[22656]=0;if((a|0)==1){break d}eh(b);break b}a=V(0)|0;O()|0;break c}a=V(0)|0;O()|0;eh(b)}Z(a|0)|0;v[22656]=0;X(20);a=v[22656];v[22656]=0;if((a|0)==1){break a}}gb=c+32|0;return}V(0)|0;O()|0;Bb();L()}function Dna(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=gb-32|0;gb=c;e=c+24|0;bc(e,b,14);e=yb(e);d=v[c+28>>2];f=v[c+24>>2];v[c+8>>2]=f;v[c+12>>2]=d;v[c>>2]=f;v[c+4>>2]=d;d=c+16|0;cc(d,a,c);d=yb(d);if((d|0)==(e|0)){Rb(a,yb(c+24|0))}gb=c+32|0;if((d|0)!=(e|0)){t[b|0]=0;t[b+1|0]=0;t[b+2|0]=0;t[b+3|0]=0;t[b+4|0]=0;t[b+5|0]=0;t[b+6|0]=0;t[b+7|0]=0;t[b+6|0]=0;t[b+7|0]=0;t[b+8|0]=0;t[b+9|0]=0;t[b+10|0]=0;t[b+11|0]=0;t[b+12|0]=0;t[b+13|0]=0}}function Daa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;v[22656]=0;_(1934,a|0);e=v[22656];v[22656]=0;a:{b:{if((e|0)!=1){e=v[a+24>>2];v[22656]=0;b=da(1956,e|0,b|0,c|0,d|0)|0;c=v[22656];v[22656]=0;if((c|0)!=1){break b}}b=V(0)|0;O()|0;Z(b|0)|0;v[22656]=0;Y(1911,10255,a|0,0,0);a=v[22656];v[22656]=0;if((a|0)==1){break a}$();b=0}return b|0}a=P()|0;O()|0;v[22656]=0;X(20);b=v[22656];v[22656]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}function Baa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;v[22656]=0;_(1934,a|0);e=v[22656];v[22656]=0;a:{b:{if((e|0)!=1){e=v[a+24>>2];v[22656]=0;b=da(1958,e|0,b|0,c|0,d|0)|0;c=v[22656];v[22656]=0;if((c|0)!=1){break b}}b=V(0)|0;O()|0;Z(b|0)|0;v[22656]=0;Y(1911,10181,a|0,0,0);a=v[22656];v[22656]=0;if((a|0)==1){break a}$();b=0}return b|0}a=P()|0;O()|0;v[22656]=0;X(20);b=v[22656];v[22656]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}function r9(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;v[22656]=0;_(2007,a|0);c=v[22656];v[22656]=0;d=1;a:{b:{if((c|0)!=1){c=v[a+28>>2];e=v[v[c>>2]+20>>2];v[22656]=0;R(e|0,c|0,b|0);b=v[22656];v[22656]=0;if((b|0)!=1){break b}}b=V(0)|0;O()|0;Z(b|0)|0;v[22656]=0;Y(1911,6469,a|0,0,0);a=v[22656];v[22656]=0;if((a|0)==1){break a}$();d=0}return d|0}a=P()|0;O()|0;v[22656]=0;X(20);b=v[22656];v[22656]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}function SY(){var a=0,b=0;a=gb-16|0;gb=a;a:{if(db(a+12|0,a+8|0)|0){break a}b=Cd((v[a+12>>2]<<2)+4|0);v[115994]=b;if(!b){break a}b=Cd(v[a+8>>2]);if(b){v[v[115994]+(v[a+12>>2]<<2)>>2]=0;if(!(cb(v[115994],b|0)|0)){break a}}v[115994]=0}gb=a+16|0;b:{if(t[463968]&1){break b}if(!Qd(463968)){break b}v[22656]=0;X(2394);a=v[22656];v[22656]=0;if((a|0)!=1){Pd(463968);break b}a=P()|0;O()|0;$e(463968);S(a|0);L()}v[115196]=460592;v[115163]=42}function Kaa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;v[22656]=0;_(1934,a|0);e=v[22656];v[22656]=0;a:{b:{if((e|0)!=1){e=v[a+24>>2];v[22656]=0;b=da(1949,e|0,b|0,c|0,d|0)|0;c=v[22656];v[22656]=0;if((c|0)!=1){break b}}b=V(0)|0;O()|0;Z(b|0)|0;v[22656]=0;Y(1911,6608,a|0,0,0);a=v[22656];v[22656]=0;if((a|0)==1){break a}$();b=0}return b|0}a=P()|0;O()|0;v[22656]=0;X(20);b=v[22656];v[22656]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}function Haa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;v[22656]=0;_(1934,a|0);e=v[22656];v[22656]=0;a:{b:{if((e|0)!=1){e=v[a+24>>2];v[22656]=0;b=da(1952,e|0,b|0,c|0,d|0)|0;c=v[22656];v[22656]=0;if((c|0)!=1){break b}}b=V(0)|0;O()|0;Z(b|0)|0;v[22656]=0;Y(1911,6577,a|0,0,0);a=v[22656];v[22656]=0;if((a|0)==1){break a}$();b=0}return b|0}a=P()|0;O()|0;v[22656]=0;X(20);b=v[22656];v[22656]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}function F9(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;v[22656]=0;_(2007,a|0);c=v[22656];v[22656]=0;d=1;a:{b:{if((c|0)!=1){c=v[a+28>>2];e=v[v[c>>2]+76>>2];v[22656]=0;R(e|0,c|0,b|0);b=v[22656];v[22656]=0;if((b|0)!=1){break b}}b=V(0)|0;O()|0;Z(b|0)|0;v[22656]=0;Y(1911,8598,a|0,0,0);a=v[22656];v[22656]=0;if((a|0)==1){break a}$();d=0}return d|0}a=P()|0;O()|0;v[22656]=0;X(20);b=v[22656];v[22656]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}function Eaa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;v[22656]=0;_(1934,a|0);e=v[22656];v[22656]=0;a:{b:{if((e|0)!=1){e=v[a+24>>2];v[22656]=0;b=da(1955,e|0,b|0,c|0,d|0)|0;c=v[22656];v[22656]=0;if((c|0)!=1){break b}}b=V(0)|0;O()|0;Z(b|0)|0;v[22656]=0;Y(1911,6801,a|0,0,0);a=v[22656];v[22656]=0;if((a|0)==1){break a}$();b=0}return b|0}a=P()|0;O()|0;v[22656]=0;X(20);b=v[22656];v[22656]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}function EZ(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;g=gb-16|0;gb=g;d=-1;a:{if(!Wf(a,7)){break a}d=0;if(!gE(a,9028)){break a}c=gb-32|0;gb=c;d=g;e=c+24|0;XD(e,g);h=yb(e);e=v[c+28>>2];f=v[c+24>>2];v[c+8>>2]=f;v[c+12>>2]=e;v[c>>2]=f;v[c+4>>2]=e;f=c+16|0;e=a;hd(f,e,c);f=yb(f);if((f|0)==(h|0)){bd(e,yb(c+24|0))}gb=c+32|0;e=(f|0)==(h|0);if(!e){WD(d)}d=-1;if(!e){break a}d=0;if(!fE(g)){break a}d=Oe(a,b,eE(g),jb)}gb=g+16|0;return d|0}function Caa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;v[22656]=0;_(1934,a|0);e=v[22656];v[22656]=0;a:{b:{if((e|0)!=1){e=v[a+24>>2];v[22656]=0;b=da(1957,e|0,b|0,c|0,d|0)|0;c=v[22656];v[22656]=0;if((c|0)!=1){break b}}b=V(0)|0;O()|0;Z(b|0)|0;v[22656]=0;Y(1911,6723,a|0,0,0);a=v[22656];v[22656]=0;if((a|0)==1){break a}$();b=0}return b|0}a=P()|0;O()|0;v[22656]=0;X(20);b=v[22656];v[22656]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}function w9(a,b){a=a|0;b=+b;var c=0,d=0,e=0;v[22656]=0;_(2007,a|0);c=v[22656];v[22656]=0;d=1;a:{b:{if((c|0)!=1){c=v[a+28>>2];e=v[v[c>>2]+40>>2];v[22656]=0;ta(e|0,c|0,+b);c=v[22656];v[22656]=0;if((c|0)!=1){break b}}d=V(0)|0;O()|0;Z(d|0)|0;v[22656]=0;Y(1911,8970,a|0,0,0);a=v[22656];v[22656]=0;if((a|0)==1){break a}$();d=0}return d|0}a=P()|0;O()|0;v[22656]=0;X(20);d=v[22656];v[22656]=0;if((d|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}function vba(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0;t[a+4202|0]=1;b=Lj(C(C(wf(v[a+16>>2])>>>0)*C(.04500000178813934)));c=Lj(C(C(b>>>0)*C(1.1892070770263672)));d=Lj(C(C(c>>>0)*C(1.1892070770263672)));g=Lj(C(C(d>>>0)*C(1.1892070770263672)));e=Lj(C(C(b+d>>>0)*C(.11546666920185089)));f=Lj(C(C(c+g>>>0)*C(.11546666920185089)));v[a+4292>>2]=f;v[a+4288>>2]=e;v[a+4276>>2]=d-e;v[a+4272>>2]=b-e;v[a+4284>>2]=g-f;v[a+4280>>2]=c-f;YL(a);WL(a)}function u9(a,b){a=a|0;b=+b;var c=0,d=0,e=0;v[22656]=0;_(2007,a|0);c=v[22656];v[22656]=0;d=1;a:{b:{if((c|0)!=1){c=v[a+28>>2];e=v[v[c>>2]+32>>2];v[22656]=0;ta(e|0,c|0,+b);c=v[22656];v[22656]=0;if((c|0)!=1){break b}}d=V(0)|0;O()|0;Z(d|0)|0;v[22656]=0;Y(1911,4841,a|0,0,0);a=v[22656];v[22656]=0;if((a|0)==1){break a}$();d=0}return d|0}a=P()|0;O()|0;v[22656]=0;X(20);d=v[22656];v[22656]=0;if((d|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}function s9(a,b){a=a|0;b=+b;var c=0,d=0,e=0;v[22656]=0;_(2007,a|0);c=v[22656];v[22656]=0;d=1;a:{b:{if((c|0)!=1){c=v[a+28>>2];e=v[v[c>>2]+24>>2];v[22656]=0;ta(e|0,c|0,+b);c=v[22656];v[22656]=0;if((c|0)!=1){break b}}d=V(0)|0;O()|0;Z(d|0)|0;v[22656]=0;Y(1911,4789,a|0,0,0);a=v[22656];v[22656]=0;if((a|0)==1){break a}$();d=0}return d|0}a=P()|0;O()|0;v[22656]=0;X(20);d=v[22656];v[22656]=0;if((d|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}function PS(a,b){var c=0,d=0,e=0,f=0;c=gb-16|0;gb=c;a=Kb(a);d=Ab(b);v[22656]=0;R(60,a|0,d|0);d=v[22656];v[22656]=0;if((d|0)!=1){a:{e=c,f=zd(b),v[e+8>>2]=f;e=c,f=gf(b),v[e>>2]=f;if(Gb(c+8|0,c)){while(1){b=w[v[c+8>>2]];b:{if((b|0)==13){v[22656]=0;R(61,a|0,10);break b}v[22656]=0;R(61,a|0,b<<24>>24)}b=v[22656];v[22656]=0;if((b|0)==1){break a}b=c+8|0;Pe(b);if(Gb(b,c)){continue}break}}gb=c+16|0;return}}b=P()|0;O()|0;vb(a);S(b|0);L()}function Ina(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;a:{c=gb-32|0;gb=c;d=hh(a);b:{c:{d:{e:{while(1){v[22656]=0;a=Q(191,b|0,6)|0;e=v[22656];v[22656]=0;if((e|0)==1){break c}if(!a){break d}v[22656]=0;R(681,c|0,b|0);a=v[22656];v[22656]=0;if((a|0)!=1){v[22656]=0;R(682,d|0,c|0);a=v[22656];v[22656]=0;if((a|0)==1){break e}ed(c);continue}break}a=P()|0;O()|0;break b}a=P()|0;O()|0;ed(c);break b}gb=c+32|0;break a}a=P()|0;O()|0}ke(d);S(a|0);L()}}
function Hna(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0;e=gb-16|0;gb=e;f=Vb(b);g=Zb(b);d=gb-32|0;gb=d;v[d+16>>2]=g;v[d+24>>2]=f;v[d+8>>2]=c;if(Gb(d+24|0,d+16|0)){while(1){c=gb-16|0;gb=c;f=c+8|0;mW(f,v[d+24>>2]);gb=c+16|0;if(v[d+8>>2]!=(w[f|0]|w[f+1|0]<<8)){c=d+24|0;pn(c);if(Gb(c,d+16|0)){continue}}break}f=v[d+24>>2]}gb=d+32|0;v[e+8>>2]=f;h=e,i=Zb(b),v[h>>2]=i;a:{if(Sj(e+8|0,e)){Jh(a);break a}rn(a,v[e+8>>2])}gb=e+16|0}function Ela(a){a=a|0;var b=0,c=0,d=0,e=0;b=gb-16|0;gb=b;t[b+15|0]=128;d=Pv(a,127,b+15|0);v[22656]=0;t[b+14|0]=64;e=W(780,a+12|0,127,b+14|0)|0;c=v[22656];v[22656]=0;a:{b:{if((c|0)!=1){v[22656]=0;t[b+13|0]=0;W(862,a+24|0,127,b+13|0)|0;c=v[22656];v[22656]=0;if((c|0)==1){break b}v[a+36>>2]=-1;v[a+40>>2]=108855296;v[a+44>>2]=0;v[a+48>>2]=0;u[a+52>>1]=0;gb=b+16|0;return a|0}a=P()|0;O()|0;break a}a=P()|0;O()|0;gc(e)}gc(d);S(a|0);L()}function z9(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;v[22656]=0;_(2007,a|0);c=v[22656];v[22656]=0;a:{b:{if((c|0)!=1){c=v[a+28>>2];e=v[v[c>>2]+52>>2];v[22656]=0;d=+Va(e|0,c|0,b|0);b=v[22656];v[22656]=0;if((b|0)!=1){break b}}b=V(0)|0;O()|0;Z(b|0)|0;v[22656]=0;Y(1911,8951,a|0,0,0);a=v[22656];v[22656]=0;if((a|0)==1){break a}$();d=0}return+d}a=P()|0;O()|0;v[22656]=0;X(20);b=v[22656];v[22656]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}function iga(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=gb-16|0;gb=d;Fc(a,b);v[22656]=0;U(97,d+8|0,b|0,c|0);e=v[22656];v[22656]=0;a:{if((e|0)==1){break a}Wb(d+8|0);v[22656]=0;e=v[b+24>>2];f=v[22656];v[22656]=0;if((f|0)==1){break a}if(e){v[22656]=0;b=v[b+24>>2];e=v[22656];v[22656]=0;if((e|0)==1){break a}v[22656]=0;U(98,d|0,b|0,c|0);b=v[22656];v[22656]=0;if((b|0)==1){break a}Wb(d)}gb=d+16|0;return}b=P()|0;O()|0;Wb(a);S(b|0);L()}function hpa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;a:{c=gb-32|0;gb=c;d=hh(a);b:{c:{d:{e:{while(1){v[22656]=0;a=Q(191,b|0,8)|0;e=v[22656];v[22656]=0;if((e|0)==1){break c}if(!a){break d}v[22656]=0;R(537,c|0,b|0);a=v[22656];v[22656]=0;if((a|0)!=1){v[22656]=0;R(538,d|0,c|0);a=v[22656];v[22656]=0;if((a|0)==1){break e}ed(c);continue}break}a=P()|0;O()|0;break b}a=P()|0;O()|0;ed(c);break b}gb=c+32|0;break a}a=P()|0;O()|0}ke(d);S(a|0);L()}}function gr(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;d=(w[ic(a,0)|0]&15)<<8|w[ic(a,1)|0];a:{if(!d|(d|0)==4095){break a}e=108;while(1){f=x[(c<<1)+39120>>1];if(f>>>0<=d>>>0){if(!(!c|(d|0)==(f|0)|(x[(c<<1)+39118>>1]-d|0)>=(d-f|0))){e=c+24|0;break a}e=c+25|0;break a}c=c+1|0;if(c>>>0<84){continue}break}}t[b|0]=e;c=w[ic(a,2)|0];g=b,h=w[ic(a,0)|0]&16|c>>>4,t[g+1|0]=h;g=b,h=w[ic(a,2)|0]&15,t[g+3|0]=h;g=b,h=w[ic(a,3)|0],t[g+5|0]=h}function Yla(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;a:{c=gb-32|0;gb=c;d=hh(a);b:{c:{d:{e:{while(1){v[22656]=0;a=Q(191,b|0,8)|0;e=v[22656];v[22656]=0;if((e|0)==1){break c}if(!a){break d}v[22656]=0;R(823,c|0,b|0);a=v[22656];v[22656]=0;if((a|0)!=1){v[22656]=0;R(824,d|0,c|0);a=v[22656];v[22656]=0;if((a|0)==1){break e}ed(c);continue}break}a=P()|0;O()|0;break b}a=P()|0;O()|0;ed(c);break b}gb=c+32|0;break a}a=P()|0;O()|0}ke(d);S(a|0);L()}}function W1(a,b){a=a|0;b=b|0;var c=0;a=Kb(a);a:{if(w[b+16|0]){v[22656]=0;Q(154,a|0,2041)|0;c=v[22656];v[22656]=0;if((c|0)==1){break a}}if(w[b+17|0]){v[22656]=0;Q(154,a|0,9784)|0;c=v[22656];v[22656]=0;if((c|0)==1){break a}}if(gd(a)){v[22656]=0;Q(154,a|0,7337)|0;c=v[22656];v[22656]=0;if((c|0)==1){break a}}if(w[b+18|0]){v[22656]=0;Q(154,a|0,8320)|0;b=v[22656];v[22656]=0;if((b|0)==1){break a}}return}b=P()|0;O()|0;vb(a);S(b|0);L()}function Gla(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;a:{c=gb-32|0;gb=c;d=hh(a);b:{c:{d:{e:{while(1){v[22656]=0;a=Q(191,b|0,8)|0;e=v[22656];v[22656]=0;if((e|0)==1){break c}if(!a){break d}v[22656]=0;R(863,c|0,b|0);a=v[22656];v[22656]=0;if((a|0)!=1){v[22656]=0;R(864,d|0,c|0);a=v[22656];v[22656]=0;if((a|0)==1){break e}ed(c);continue}break}a=P()|0;O()|0;break b}a=P()|0;O()|0;ed(c);break b}gb=c+32|0;break a}a=P()|0;O()|0}ke(d);S(a|0);L()}}function wp(a,b,c,d,e,f,g,h){var i=0,j=0,k=0,l=0;i=gb-16|0;gb=i;if((b^-1)-17>>>0>=c>>>0){j=Jb(a);l=a;a:{if(b>>>0<2147483623){v[i+8>>2]=b<<1;v[i+12>>2]=b+c;c=Xk(v[Lc(i+12|0,i+8|0)>>2]);break a}c=-18}k=c+1|0;c=oi(l,k);if(e){Qg(c,j,e)}if(g){Qg(c+e|0,h,g)}d=d-(e+f|0)|0;if(d){Qg((c+e|0)+g|0,(e+j|0)+f|0,d)}b=b+1|0;if((b|0)!=11){al(a,j,b)}ef(a,c);rg(a,k);b=a;a=d+(e+g|0)|0;de(b,a);t[i+7|0]=0;Bd(a+c|0,i+7|0);gb=i+16|0;return}vg();L()}function aZ(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;a:{c=gb-32|0;gb=c;d=hh(a);b:{c:{d:{e:{while(1){v[22656]=0;a=Q(191,b|0,8)|0;e=v[22656];v[22656]=0;if((e|0)==1){break c}if(!a){break d}v[22656]=0;R(448,c|0,b|0);a=v[22656];v[22656]=0;if((a|0)!=1){v[22656]=0;R(449,d|0,c|0);a=v[22656];v[22656]=0;if((a|0)==1){break e}ed(c);continue}break}a=P()|0;O()|0;break b}a=P()|0;O()|0;ed(c);break b}gb=c+32|0;break a}a=P()|0;O()|0}ke(d);S(a|0);L()}}function Ty(a,b){a=a|0;b=b|0;var c=0,d=0;c=oc(a);if(c>>>0<b>>>0){d=gb-32|0;gb=d;a:{b:{c=b-c|0;c:{if(c>>>0<=v[wb(a)>>2]-v[a+4>>2]>>>0){gq(a,c);break c}b=wb(a);b=Zg(d+8|0,qh(a,oc(a)+c|0),oc(a),b);v[22656]=0;R(123,b|0,c|0);c=v[22656];v[22656]=0;if((c|0)==1){break b}v[22656]=0;R(120,a|0,b|0);a=v[22656];v[22656]=0;if((a|0)==1){break b}be(b)}gb=d+32|0;break a}a=P()|0;O()|0;be(b);S(a|0);L()}return}if(b>>>0<c>>>0){Em(a,v[a>>2]+b|0)}}function Ok(a,b){a=a|0;b=b|0;var c=0,d=0;c=oc(a);if(c>>>0<b>>>0){d=gb-32|0;gb=d;a:{b:{c=b-c|0;c:{if(c>>>0<=v[wb(a)>>2]-v[a+4>>2]>>>0){gq(a,c);break c}b=wb(a);b=Zg(d+8|0,qh(a,oc(a)+c|0),oc(a),b);v[22656]=0;R(395,b|0,c|0);c=v[22656];v[22656]=0;if((c|0)==1){break b}v[22656]=0;R(396,a|0,b|0);a=v[22656];v[22656]=0;if((a|0)==1){break b}be(b)}gb=d+32|0;break a}a=P()|0;O()|0;be(b);S(a|0);L()}return}if(b>>>0<c>>>0){Em(a,v[a>>2]+b|0)}}function D9(a,b){a=a|0;b=b|0;var c=0,d=0;v[22656]=0;_(2007,a|0);c=v[22656];v[22656]=0;a:{b:{if((c|0)!=1){c=v[a+28>>2];d=v[v[c>>2]+68>>2];v[22656]=0;b=Q(d|0,c|0,b|0)|0;c=v[22656];v[22656]=0;if((c|0)!=1){break b}}b=V(0)|0;O()|0;Z(b|0)|0;v[22656]=0;Y(1911,3744,a|0,0,0);a=v[22656];v[22656]=0;if((a|0)==1){break a}$();b=-1}return b|0}a=P()|0;O()|0;v[22656]=0;X(20);b=v[22656];v[22656]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}function B9(a,b){a=a|0;b=b|0;var c=0,d=0;v[22656]=0;_(2007,a|0);c=v[22656];v[22656]=0;a:{b:{if((c|0)!=1){c=v[a+28>>2];d=v[v[c>>2]+60>>2];v[22656]=0;b=Q(d|0,c|0,b|0)|0;c=v[22656];v[22656]=0;if((c|0)!=1){break b}}b=V(0)|0;O()|0;Z(b|0)|0;v[22656]=0;Y(1911,3795,a|0,0,0);a=v[22656];v[22656]=0;if((a|0)==1){break a}$();b=-1}return b|0}a=P()|0;O()|0;v[22656]=0;X(20);b=v[22656];v[22656]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}function R5(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0;e=gb-16|0;gb=e;a:{if((c|0)<=0){break a}while(1){d=v[a+28>>2];g=v[a+24>>2];b:{if(d>>>0<=g>>>0){if(((i=a,j=Mg(t[b|0]),h=v[v[a>>2]+52>>2],kb[h](i|0,j|0)|0)|0)==-1){break a}f=f+1|0;b=b+1|0;break b}v[e+12>>2]=d-g;v[e+8>>2]=c-f;d=v[pd(e+12|0,e+8|0)>>2];Qg(v[a+24>>2],b,d);v[a+24>>2]=d+v[a+24>>2];f=d+f|0;b=b+d|0}if((c|0)>(f|0)){continue}break}}gb=e+16|0;return f|0}function El(a,b){var c=0,d=0;c=Nb(a);if(c>>>0<b>>>0){d=gb-32|0;gb=d;a:{b:{c=b-c|0;c:{if(c>>>0<=v[wb(a)>>2]-v[a+4>>2]>>2>>>0){hN(a,c);break c}b=wb(a);b=fn(d+8|0,fh(a,Nb(a)+c|0),Nb(a),b);v[22656]=0;R(1502,b|0,c|0);c=v[22656];v[22656]=0;if((c|0)==1){break b}v[22656]=0;R(1501,a|0,b|0);a=v[22656];v[22656]=0;if((a|0)==1){break b}eh(b)}gb=d+32|0;break a}a=P()|0;O()|0;eh(b);S(a|0);L()}return}if(b>>>0<c>>>0){hj(a,v[a>>2]+(b<<2)|0)}}function _9(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0;v[22656]=0;_(1934,a|0);f=v[22656];v[22656]=0;a:{b:{if((f|0)!=1){f=v[a+24>>2];v[22656]=0;b=Et(f,b,c,d,e);c=v[22656];v[22656]=0;if((c|0)!=1){break b}}b=V(0)|0;O()|0;Z(b|0)|0;v[22656]=0;Y(1911,9662,a|0,0,0);a=v[22656];v[22656]=0;if((a|0)==1){break a}$();b=0}return b|0}a=P()|0;O()|0;v[22656]=0;X(20);b=v[22656];v[22656]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}function gE(a,b){var c=0,d=0,e=0,f=0;c=gb-32|0;gb=c;a:{if(!w[b+7|0]){while(1){if(!w[b+d|0]){aa(14540,6236,413,10498);L()}d=d+1|0;if((d|0)!=7){continue}break}d=0;t[c+27|0]=0;t[c+28|0]=0;t[c+29|0]=0;t[c+30|0]=0;v[c+24>>2]=0;e=wd(c+8|0,c+24|0,7);f=v[e+4>>2];v[c>>2]=v[e>>2];v[c+4>>2]=f;e=c+16|0;hd(e,a,c);b:{if((yb(e)|0)!=7){break b}if(sd(c+24|0,b,7)){break b}bd(a,7);d=1}gb=c+32|0;break a}aa(14519,6236,411,10498);L()}return d}function KT(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0,j=0;d=gb-16|0;gb=d;f=v[c>>2];v[d+8>>2]=6553600;e=b+4|0;i=d,j=Xb(w[e|0]|w[e+1|0]<<8|(w[e+2|0]<<16|w[e+3|0]<<24)),v[i+4>>2]=j;g=+(f>>>0)/6553600;f=d+8|0;e=d+4|0;h=hr(g*+y[Fb(f,e)>>2]);v[d+12>>2]=h;v[d+4>>2]=6553600;b=b+8|0;i=d,j=Xb(w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24)),v[i>>2]=j;i=d,j=hr(g*+y[Fb(e,d)>>2]),v[i+8>>2]=j;v[d+4>>2]=v[c>>2]-h;Su(a,d+12|0,Fb(e,f));gb=d+16|0}function Bca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;b=Fi(a,b,c,d);v[a>>2]=51228;c=mc(a+4256|0);d=a+4224|0;v[d>>2]=1017370378;v[d+4>>2]=1065353216;d=a+4216|0;v[d>>2]=1028670828;v[d+4>>2]=1059760811;v[a+4208>>2]=1056964608;v[a+4212>>2]=1017370378;v[22656]=0;W(1532,a+44|0,2,2)|0;d=v[22656];v[22656]=0;a:{if((d|0)==1){break a}v[22656]=0;Th(b);d=v[22656];v[22656]=0;if((d|0)==1){break a}return a|0}a=P()|0;O()|0;Nc(c);Lf(b);S(a|0);L()}function pfa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=gb-32|0;gb=c;e=c+24|0;OW(e,b);e=yb(e);d=v[c+28>>2];f=v[c+24>>2];v[c+8>>2]=f;v[c+12>>2]=d;v[c>>2]=f;v[c+4>>2]=d;d=c+16|0;cc(d,a,c);d=yb(d);if((d|0)==(e|0)){Rb(a,yb(c+24|0))}gb=c+32|0;a=(d|0)==(e|0);if(!a){c=gb-16|0;gb=c;t[b+8|0]=0;t[b+9|0]=0;t[b+10|0]=0;t[b+11|0]=0;t[b|0]=0;t[b+1|0]=0;t[b+2|0]=0;t[b+3|0]=0;t[b+4|0]=0;t[b+5|0]=0;t[b+6|0]=0;t[b+7|0]=0;gb=c+16|0}return a|0}function bQ(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;d=gb-16|0;gb=d;v[d+12>>2]=c>>>3;v[d+8>>2]=v[a>>2];e=v[Fb(d+12|0,d+8|0)>>2];b=zb(b);if(e){a=v[a+20>>2];c=e;while(1){f=zb(w[b|0]);g=a,h=id(f|zb(w[b+1|0])<<8|zb(w[b+2|0])<<16|zb(w[b+3|0])<<24,16),u[g>>1]=h;f=zb(w[b+4|0]);g=a,h=id(f|zb(w[b+5|0])<<8|zb(w[b+6|0])<<16|zb(w[b+7|0])<<24,16),u[g+2>>1]=h;a=a+4|0;b=b+8|0;c=c-1|0;if(c){continue}break}}gb=d+16|0;return e<<3}function aQ(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;d=gb-16|0;gb=d;v[d+12>>2]=c>>>3;v[d+8>>2]=v[a>>2];e=v[Fb(d+12|0,d+8|0)>>2];b=zb(b);if(e){a=v[a+20>>2];c=e;while(1){f=zb(w[b+3|0]);g=a,h=id(f|zb(w[b+2|0])<<8|zb(w[b+1|0])<<16|zb(w[b|0])<<24,16),u[g>>1]=h;f=zb(w[b+7|0]);g=a,h=id(f|zb(w[b+6|0])<<8|zb(w[b+5|0])<<16|zb(w[b+4|0])<<24,16),u[g+2>>1]=h;a=a+4|0;b=b+8|0;c=c-1|0;if(c){continue}break}}gb=d+16|0;return e<<3}function Iz(a,b,c,d){var e=0,f=0,g=0;f=gb-48|0;gb=f;a:{if(!c){c=Tc(a,b);a=v[d+12>>2];v[c+8>>2]=v[d+8>>2];v[c+12>>2]=a;a=v[d+4>>2];v[c>>2]=v[d>>2];v[c+4>>2]=a;break a}e=v[d+12>>2];v[f+24>>2]=v[d+8>>2];v[f+28>>2]=e;g=v[d+4>>2];e=f;v[e+16>>2]=v[d>>2];v[e+20>>2]=g;g=c>>>1|0;Iz(a,b,g,e+16|0);Li(e+32|0,d,Tc(a,c));d=v[e+44>>2];v[e+8>>2]=v[e+40>>2];v[e+12>>2]=d;d=v[e+36>>2];v[e>>2]=v[e+32>>2];v[e+4>>2]=d;Iz(a,b|c,g,e)}gb=f+48|0}function Nr(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0;f=gb-16|0;gb=f;e=Vb(b);g=Zb(b);d=gb-32|0;gb=d;v[d+16>>2]=g;v[d+24>>2]=e;v[d+8>>2]=c;if(Gb(d+24|0,d+16|0)){while(1){c=gb-16|0;gb=c;e=c+8|0;Zi(e,v[d+24>>2]);e=FY(e);gb=c+16|0;if(v[d+8>>2]!=(e|0)){c=d+24|0;pn(c);if(Gb(c,d+16|0)){continue}}break}e=v[d+24>>2]}gb=d+32|0;v[f+8>>2]=e;h=f,i=Zb(b),v[h>>2]=i;a:{if(Sj(f+8|0,f)){Jh(a);break a}rn(a,v[f+8>>2])}gb=f+16|0}function NN(a){var b=0,c=0,d=0,e=0;a:{if((w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24))!=1163089229){break a}b=a+4|0;c=w[b+1|0]<<8;d=w[b+2|0]<<16|w[b+3|0]<<24;if((w[b|0]|c|d)!=-1346458146&(d|(c|w[b|0]))!=-1095062050){break a}b=a+16|0;if(!(w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24))){break a}a=a+8|0;e=((w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24))+24|0)==(w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24))}return e}function Laa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;v[22656]=0;_(1934,a|0);d=v[22656];v[22656]=0;e=1;a:{b:{if((d|0)!=1){d=v[a+24>>2];v[22656]=0;U(1948,d|0,b|0,c|0);b=v[22656];v[22656]=0;if((b|0)!=1){break b}}b=V(0)|0;O()|0;Z(b|0)|0;v[22656]=0;Y(1911,7591,a|0,0,0);a=v[22656];v[22656]=0;if((a|0)==1){break a}$();e=0}return e|0}a=P()|0;O()|0;v[22656]=0;X(20);b=v[22656];v[22656]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}function r5(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=a+32|0;ik(c,b);v[a+44>>2]=0;b=v[a+48>>2];if(b&8){d=a,e=Jb(c)+Ab(c)|0,v[d+44>>2]=e;$n(a,Jb(c),Jb(c),v[a+44>>2]);b=v[a+48>>2]}a:{if(!(b&16)){break a}b=Ab(c);d=a,e=b+Jb(c)|0,v[d+44>>2]=e;xu(c,Kc(c));Ux(a,Jb(c),Jb(c)+Ab(c)|0);if(!(w[a+48|0]&3)){break a}b:{if((b|0)<0){c=b-2147483647|0;while(1){b=c;$s(a,2147483647);c=1;if((b|0)<0){continue}break}break b}if(!b){break a}}$s(a,b)}}function dJ(a){var b=0,c=C(0),d=C(0),e=C(0),f=C(0),g=C(0),h=C(0),i=0,j=0,k=0,l=C(0),m=C(0),n=C(0),o=C(0),p=0;c=z[a>>2];i=a-16|0;d=z[i>>2];e=C(c+d);b=a-8|0;f=z[b>>2];j=a-24|0;g=z[j>>2];h=C(f+g);z[a>>2]=e+h;z[b>>2]=e-h;b=a-12|0;h=z[b>>2];k=a-28|0;l=z[k>>2];e=C(h+l);p=b;b=a-4|0;m=z[b>>2];a=a-20|0;n=z[a>>2];o=C(m+n);z[p>>2]=o-e;f=C(f-g);g=C(m-n);z[k>>2]=f+g;c=C(c-d);d=C(h-l);z[i>>2]=c+d;z[j>>2]=c-d;z[b>>2]=e+o;z[a>>2]=g-f}function YO(a,b){var c=0,d=0,e=0,f=0,g=0;c=v[a>>2];v[a>>2]=b;if(c){a=gb-16|0;gb=a;f=a,g=Vb(c),v[f+8>>2]=g;f=a,g=Zb(c),v[f>>2]=g;if(Gb(a+8|0,a)){while(1){e=v[a+8>>2];a:{while(1){b=v[e>>2];d=v[b>>2];if(!d){break a}b=v[v[d>>2]+8>>2];v[22656]=0;_(b|0,d|0);b=v[22656];v[22656]=0;if((b|0)!=1){continue}break}V(0)|0;O()|0;Hl(c);Bb();L()}Hb(b+20|0);Hb(b+8|0);Yb(b);b=a+8|0;Qe(b);if(Gb(b,a)){continue}break}}Hl(c);gb=a+16|0;Yb(c)}}function Tha(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;e=gb-16|0;gb=e;u[e+12>>1]=c;u[e+14>>1]=b;zg(e+14|0,x[v[v[a+24>>2]+8>>2]+12>>1]);c=e+12|0;b=gb-16|0;gb=b;d=x[e+14>>1];v[b+12>>2]=d;a:{if(Pg(a)>>>0>=d>>>0){g=b,h=tc(a),v[g+8>>2]=h;pv(v[a>>2],v[Fb(b+12|0,b+8|0)>>2],c);f=v[b+8>>2];d=v[b+12>>2];if(f>>>0<d>>>0){up(a,d-f|0,c);break a}yn(a,v[a>>2]+(d<<1)|0);break a}rS(a);aC(a,Vk(a,d));up(a,d,c)}gb=b+16|0;gb=e+16|0}function Oaa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;v[22656]=0;_(1934,a|0);d=v[22656];v[22656]=0;a:{b:{if((d|0)!=1){d=v[a+24>>2];v[22656]=0;e=+oa(1944,d|0,b|0,c|0);b=v[22656];v[22656]=0;if((b|0)!=1){break b}}b=V(0)|0;O()|0;Z(b|0)|0;v[22656]=0;Y(1911,2442,a|0,0,0);a=v[22656];v[22656]=0;if((a|0)==1){break a}$();e=0}return+e}a=P()|0;O()|0;v[22656]=0;X(20);b=v[22656];v[22656]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}function ud(a,b){a=a|0;b=b|0;var c=0,d=0;d=gb-16|0;gb=d;Pl(a);v[a+16>>2]=0;v[a+8>>2]=0;v[a+12>>2]=0;v[a>>2]=0;v[a+4>>2]=0;u[a+32>>1]=64;v[a+24>>2]=8363;v[a+28>>2]=16777344;v[a+36>>2]=0;t[a+39|0]=0;t[a+40|0]=0;t[a+41|0]=0;t[a+42|0]=0;c=x[a+34>>1]&-25151;u[a+34>>1]=(b|0)==4?c|32:c;b=Tb(d,18726);v[22656]=0;Q(303,a+43|0,b|0)|0;c=v[22656];v[22656]=0;if((c|0)!=1){vb(b);Lu(a);gb=d+16|0;return}a=P()|0;O()|0;vb(b);S(a|0);L()}function Xha(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;e=gb-32|0;gb=e;v[e+24>>2]=b;d=gb-16|0;gb=d;v[d>>2]=c;v[d+8>>2]=b;b=rv(d,d+8|0);gb=d+16|0;a:{b=Tk(e+8|0,a+8|0,b);if(v[b>>2]!=v[b+4>>2]){while(1){c=v[a+16>>2];d=v[b>>2];f=v[e+24>>2];v[22656]=0;hn(c,d,f);c=v[22656];v[22656]=0;if((c|0)==1){break a}v[b>>2]=v[b>>2]+4;Qe(e+24|0);if(v[b>>2]!=v[b+4>>2]){continue}break}}_c(b);gb=e+32|0;return}a=P()|0;O()|0;_c(b);S(a|0);L()}function zy(a,b,c){var d=0,e=0,f=0,g=0;d=gb-32|0;gb=d;a:{if(w[a+20|0]){break a}e=b;b=-1-b|0;b=e+(b>>>0<c>>>0?b:c)|0;c=v[a+16>>2];if(b>>>0<=c>>>0){break a}b=yy(b,4096);SJ(a,b-c|0);b=wd(d+16|0,lc(a+4|0,v[a+16>>2]),b-v[a+16>>2]|0);c=v[v[a>>2]+44>>2];e=v[b+4>>2];v[d+8>>2]=v[b>>2];v[d+12>>2]=e;b=d+24|0;kb[c|0](b,a,d+8|0);f=a,g=yb(b)+v[a+16>>2]|0,v[f+16>>2]=g;if(!(kb[v[v[a>>2]+40>>2]](a)|0)){break a}t[a+20|0]=1}gb=d+32|0}function ZC(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;f=c;c=0;a:{if(!b){break a}if(!Pb(a,b)){break a}if(b>>>0<=3){c=gb-16|0;gb=c;if(Pb(a,b)){while(1){t[c+11|0]=0;b:{if(b>>>0>d>>>0){Ng(a,c+11|0);e=t[c+11|0];g=e>>>31|0;break b}e=0-g|0}t[(c+12|0)+d|0]=e;d=d+1|0;if((d|0)!=4){continue}break}v[c+4>>2]=v[c+12>>2];a=c+4|0;d=w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24)}gb=c+16|0;c=d;break a}c=sg(a);Rb(a,b-4|0)}t[f|0]=c}function Oja(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0;b=gb-16|0;gb=b;g=v[a+24>>2];h=v[a+20>>2];i=v[a+16>>2];e=v[a+4>>2];f=v[a>>2];v[b+8>>2]=f;v[b+12>>2]=e;j=v[a+12>>2];v[b>>2]=v[a+8>>2];v[b+4>>2]=j;if(d){while(1){e=u[(e<<1)+i>>1];v[c>>2]=v[c>>2]+B(e,h);v[c+4>>2]=v[c+4>>2]+B(e,g);Ub(b+8|0,b);d=d-1|0;if(d){c=c+8|0;e=v[b+12>>2];continue}break}f=v[b+8>>2];e=v[b+12>>2]}v[a>>2]=f;v[a+4>>2]=e;gb=b+16|0}function A$(a,b,c,d,e,f,g,h,i,j){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;v[22656]=0;a=La(1926,a|0,b|0,c|0,d|0)|0;b=v[22656];v[22656]=0;a:{b:{if((b|0)==1){a=V(0)|0;O()|0;Z(a|0)|0;v[22656]=0;ja(1922,8355,e|0,f|0,g|0,h|0,i|0,j|0);a=v[22656];v[22656]=0;if((a|0)==1){break b}$();a=-255}break a}a=P()|0;O()|0;v[22656]=0;X(20);b=v[22656];v[22656]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}return a|0}function x9(a){a=a|0;var b=0,c=0,d=0;v[22656]=0;_(2007,a|0);b=v[22656];v[22656]=0;a:{b:{if((b|0)!=1){b=v[a+28>>2];d=v[v[b>>2]+44>>2];v[22656]=0;c=+pa(d|0,b|0);b=v[22656];v[22656]=0;if((b|0)!=1){break b}}b=V(0)|0;O()|0;Z(b|0)|0;v[22656]=0;Y(1911,8988,a|0,0,0);a=v[22656];v[22656]=0;if((a|0)==1){break a}$();c=0}return+c}a=P()|0;O()|0;v[22656]=0;X(20);b=v[22656];v[22656]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}function v9(a){a=a|0;var b=0,c=0,d=0;v[22656]=0;_(2007,a|0);b=v[22656];v[22656]=0;a:{b:{if((b|0)!=1){b=v[a+28>>2];d=v[v[b>>2]+36>>2];v[22656]=0;c=+pa(d|0,b|0);b=v[22656];v[22656]=0;if((b|0)!=1){break b}}b=V(0)|0;O()|0;Z(b|0)|0;v[22656]=0;Y(1911,4858,a|0,0,0);a=v[22656];v[22656]=0;if((a|0)==1){break a}$();c=0}return+c}a=P()|0;O()|0;v[22656]=0;X(20);b=v[22656];v[22656]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}function t9(a){a=a|0;var b=0,c=0,d=0;v[22656]=0;_(2007,a|0);b=v[22656];v[22656]=0;a:{b:{if((b|0)!=1){b=v[a+28>>2];d=v[v[b>>2]+28>>2];v[22656]=0;c=+pa(d|0,b|0);b=v[22656];v[22656]=0;if((b|0)!=1){break b}}b=V(0)|0;O()|0;Z(b|0)|0;v[22656]=0;Y(1911,4806,a|0,0,0);a=v[22656];v[22656]=0;if((a|0)==1){break a}$();c=0}return+c}a=P()|0;O()|0;v[22656]=0;X(20);b=v[22656];v[22656]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}function Gh(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=gb-32|0;gb=c;a:{if(!w[b+4|0]){while(1){if(!w[b+d|0]){aa(14540,6236,413,10498);L()}d=d+1|0;if((d|0)!=4){continue}break}d=0;v[c+28>>2]=0;e=wd(c+8|0,c+28|0,4);f=v[e+4>>2];v[c>>2]=v[e>>2];v[c+4>>2]=f;e=c+16|0;cc(e,a,c);if(!((yb(e)|0)!=4|v[c+28>>2]!=(w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24)))){Rb(a,4);d=1}gb=c+32|0;break a}aa(14519,6236,411,10498);L()}return d|0}function mna(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;c=v[b>>2];f=lD(b);d=gb-16|0;gb=d;e=kr(c,f);a:{if(e>>>0<=pe(a)>>>0){if(Nb(a)>>>0<e>>>0){v[d+12>>2]=c;XV(d+12|0,Nb(a));b=v[d+12>>2];Rg(c,b,v[a>>2]);WV(a,b,f,e-Nb(a)|0);break a}hj(a,Rg(c,f,v[a>>2]));break a}VV(a);b=a;g=fh(a,e);if(g>>>0>oC(a)>>>0){Sc();L()}h=XE(wb(b),g);v[b>>2]=h;v[b+4>>2]=h;i=wb(b),j=(g<<2)+h|0,v[i>>2]=j;dn(b,0);WV(a,c,f,e)}gb=d+16|0}function bpa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=gb-48|0;gb=d;a=mc(a);f=d,g=Vb(b),v[f+40>>2]=g;f=d,g=Zb(b),v[f+32>>2]=g;a:{if(Gb(d+40|0,d+32|0)){while(1){b=d+8|0;e=v[d+40>>2];Zi(b,e);if((FY(b)|0)==(c|0)){b=d+8|0;rn(b,e);v[22656]=0;R(536,a|0,b|0);b=v[22656];v[22656]=0;if((b|0)==1){break a}xb(d+8|0)}b=d+40|0;pn(b);if(Gb(b,d+32|0)){continue}break}}gb=d+48|0;return}b=P()|0;O()|0;xb(d+8|0);jd(a);S(b|0);L()}function ala(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;a:{d=gb-32|0;gb=d;e=gb-16|0;gb=e;f=e,g=Ib(w[c|0]|w[c+1|0]<<8),u[f+14>>1]=g;c=d+16|0;kR(c,e+14|0);gb=e+16|0;v[22656]=0;mj(d+8|0,c);c=v[22656];v[22656]=0;b:{if((c|0)==1){break b}v[22656]=0;c=v[d+12>>2];v[d>>2]=v[d+8>>2];v[d+4>>2]=c;U(146,a|0,b|0,d|0);a=v[22656];v[22656]=0;if((a|0)==1){break b}Hb(d+16|0);gb=d+32|0;break a}a=P()|0;O()|0;Hb(d+16|0);S(a|0);L()}}function Pja(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0;b=gb-16|0;gb=b;g=v[a+24>>2];h=v[a+20>>2];i=v[a+16>>2];e=v[a+4>>2];f=v[a>>2];v[b+8>>2]=f;v[b+12>>2]=e;j=v[a+12>>2];v[b>>2]=v[a+8>>2];v[b+4>>2]=j;if(d){while(1){e=t[e+i|0]<<8;v[c>>2]=v[c>>2]+B(e,h);v[c+4>>2]=v[c+4>>2]+B(e,g);Ub(b+8|0,b);d=d-1|0;if(d){c=c+8|0;e=v[b+12>>2];continue}break}f=v[b+8>>2];e=v[b+12>>2]}v[a>>2]=f;v[a+4>>2]=e;gb=b+16|0}function pj(a,b,c,d,e){var f=0,g=0,h=0;g=gb-16|0;gb=g;v[g+8>>2]=b;b=0;f=6;a:{b:{if(mk(a,g+8|0)){break b}f=4;h=pl(a);if(!nh(d,2048,h)){break b}b=Tn(d,h);ol(a);b=b-48|0;c:{if(!nk(a,g+8|0)|(e|0)<2){break c}while(1){f=pl(a);if(!nh(d,2048,f)){break a}f=Tn(d,f);ol(a);b=(f+B(b,10)|0)-48|0;if(!nk(a,g+8|0)){break c}f=(e|0)>2;e=e-1|0;if(f){continue}break}}f=2;if(!mk(a,g+8|0)){break a}}v[c>>2]=v[c>>2]|f}gb=g+16|0;return b}function oj(a,b,c,d,e){var f=0,g=0,h=0;g=gb-16|0;gb=g;v[g+8>>2]=b;b=0;f=6;a:{b:{if(jl(a,g+8|0)){break b}f=4;h=xm(a);if(!kl(d,2048,h)){break b}b=Sn(d,h);wm(a);b=b-48|0;c:{if(!ym(a,g+8|0)|(e|0)<2){break c}while(1){f=xm(a);if(!kl(d,2048,f)){break a}f=Sn(d,f);wm(a);b=(f+B(b,10)|0)-48|0;if(!ym(a,g+8|0)){break c}f=(e|0)>2;e=e-1|0;if(f){continue}break}}f=2;if(!jl(a,g+8|0)){break a}}v[c>>2]=v[c>>2]|f}gb=g+16|0;return b}function y8(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0;f=gb-16|0;gb=f;a:{b:{c:{if(!(e?d:0)){a=ba(8)|0;v[22656]=0;b=Q(70,f|0,5333)|0;c=v[22656];v[22656]=0;if((c|0)==1){break c}rc(a,b);v[22656]=0;U(186,a|0,54952,1936);a=v[22656];v[22656]=0;if((a|0)!=1){break a}e=P()|0;O()|0;vb(b);break b}Cj(a,b,2);c=Ny(a,c,d,e,0,0);A[a+16>>3]=A[a+16>>3]+ +(c>>>0)/+(b|0);gb=f+16|0;return c|0}e=P()|0;O()|0;ca(a|0)}S(e|0)}L()}function jy(a){var b=0,c=0,d=0;a:{b:{if(!v[a+1384>>2]){b=v[a+1380>>2];if((b|0)==-1){v[a+1388>>2]=v[a+1116>>2]-1;if(!qt(a)){v[a+1384>>2]=1;return 0}if(!(t[a+1375|0]&1)){break b}b=v[a+1380>>2]}d=b+1|0;v[a+1380>>2]=d;c=w[(a+b|0)+1120|0];if((c|0)!=255){v[a+1388>>2]=b;v[a+1384>>2]=1}if(v[a+1116>>2]<=(d|0)){v[a+1380>>2]=-1}if(w[a+1376|0]){break a}t[a+1376|0]=c}return c}ec(a,32);return 0}aa(12858,10534,1564,3128);L()}function dga(a){a=a|0;var b=0,c=0,d=0,e=0,f=0;d=gb-880|0;gb=d;b=Qb(a,0,76);v[b+84>>2]=0;v[b+88>>2]=0;v[b+80>>2]=256;u[b+76>>1]=65535;v[b+92>>2]=0;v[b+96>>2]=0;t[b+100|0]=1;e=b+223848|0;c=b+616|0;a=c;while(1){a=OB(a)+872|0;if((e|0)!=(a|0)){continue}break}a=d+8|0;Qb(a,0,872);e=OB(a);a=c;c=((a+223232|0)-a|0)/872|0;if((c|0)>0){while(1){qu(a,e);a=a+872|0;f=c>>>0>1;c=c-1|0;if(f){continue}break}}gb=d+880|0;return b|0}function B8(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0;f=gb-16|0;gb=f;a:{b:{c:{if(!(e?d:0)){a=ba(8)|0;v[22656]=0;b=Q(70,f|0,5333)|0;c=v[22656];v[22656]=0;if((c|0)==1){break c}rc(a,b);v[22656]=0;U(186,a|0,54952,1936);a=v[22656];v[22656]=0;if((a|0)!=1){break a}e=P()|0;O()|0;vb(b);break b}Cj(a,b,2);c=Oy(a,c,d,e,0,0);A[a+16>>3]=A[a+16>>3]+ +(c>>>0)/+(b|0);gb=f+16|0;return c|0}e=P()|0;O()|0;ca(a|0)}S(e|0)}L()}function Wz(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=gb-16|0;gb=e;t[e+15|0]=!d|y[c+20>>2]<2?0:v[b+480180>>2]==1;d=!v[c+52>>2]|d;t[e+14|0]=d;if(!(!x[b+480188>>1]|((d|0)!=1|v[b+480180>>2]!=2))){d=0;while(1){v[(B(d,872)+c|0)+1380>>2]=0;d=d+1|0;if(d>>>0<x[b+480188>>1]){continue}break}}v[c+24>>2]=0;v[c+16>>2]=0;v[c+20>>2]=0;v[c+48>>2]=v[c+52>>2];u[c+72>>1]=x[c+74>>1];t[a|0]=w[e+15|0];t[a+1|0]=w[e+14|0];gb=e+16|0}function Qu(a,b){var c=0,d=0;d=gb-32|0;gb=d;c=d+16|0;pT(c,a,a+1|0,a+2|0,a+3|0);pT(d,b,b+1|0,b+2|0,b+3|0);gb=d+32|0;a=d;b=1;a:{if(w[v[c>>2]]<w[v[a>>2]]){break a}b=0;if(w[v[a>>2]]<w[v[c>>2]]){break a}b=1;b:{if(t[v[c+4>>2]]<t[v[a+4>>2]]){break b}b=0;if(t[v[a+4>>2]]<t[v[c+4>>2]]){break b}b=1;c:{if(w[v[c+8>>2]]<w[v[a+8>>2]]){break c}b=0;if(w[v[a+8>>2]]<w[v[c+8>>2]]){break c}b=w[v[c+12>>2]]<w[v[a+12>>2]]}}}return b}function kfa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;a:{d=gb+-64|0;gb=d;Se(b);e=d+40|0;Re(e,a,c);a=v[e>>2];v[22656]=0;c=Sd(e);e=v[22656];v[22656]=0;b:{if((e|0)==1){break b}c=zb(c);v[22656]=0;Xe(d+8|0,1,c,a);a=v[22656];v[22656]=0;if((a|0)==1){break b}v[22656]=0;R(324,d+24|0,d+8|0);a=v[22656];v[22656]=0;if((a|0)==1){break b}a=d+24|0;Eb(b,a);vb(a);zc(d+40|0);gb=d- -64|0;break a}a=P()|0;O()|0;zc(d+40|0);S(a|0);L()}}function k4(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=C(0),g=0,h=C(0);e=gb-16|0;gb=e;a:{b:{c:{if((a|0)!=(b|0)){g=v[115137];v[115137]=0;xe();d=gb-16|0;gb=d;Gx(d,a,e+12|0,0);f=PH(v[d>>2],v[d+4>>2],v[d+8>>2],v[d+12>>2]);gb=d+16|0;a=v[115137];if(!a){break c}if(v[e+12>>2]!=(b|0)){break b}h=f;if((a|0)!=68){break a}break b}v[c>>2]=4;break a}v[115137]=g;if(v[e+12>>2]==(b|0)){break a}}v[c>>2]=4;f=h}gb=e+16|0;return C(f)}function Wca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;c=Fi(a,b,c,d);v[a>>2]=50736;d=mc(a+4208|0);v[a+4220>>2]=0;v[a+4224>>2]=1056964608;b=a+4228|0;t[b+4|0]=0;t[b+5|0]=4;t[b|0]=69;t[b+1|0]=99;t[b+2|0]=104;t[b+3|0]=111;t[b+6|0]=1;v[22656]=0;W(1532,a+44|0,2,2)|0;b=v[22656];v[22656]=0;a:{if((b|0)==1){break a}v[22656]=0;Th(c);b=v[22656];v[22656]=0;if((b|0)==1){break a}Mt(a);return a|0}a=P()|0;O()|0;Nc(d);Lf(c);S(a|0);L()}function oba(a){a=a|0;var b=0,c=0;b=gb-16|0;gb=b;a:{b:{if(!a){break b}a=uc(b+8|0,a);v[22656]=0;c=v[a+4>>2];v[b>>2]=v[a>>2];v[b+4>>2]=c;a=iL(b);c=v[22656];v[22656]=0;if((c|0)!=1){break a}a=V(0)|0;O()|0;Z(a|0)|0;v[22656]=0;Y(1911,9791,0,0,0);a=v[22656];v[22656]=0;if((a|0)!=1){$();break b}a=P()|0;O()|0;v[22656]=0;X(20);b=v[22656];v[22656]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}a=0}gb=b+16|0;return a|0}function W2(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;e=gb-16|0;gb=e;d=v[fc(a)>>2];i=v[b>>2];g=v[a>>2];f=(d|0)==2479;j=f?0:g;d=v[c>>2]-v[a>>2]|0;a:{if(d>>>0<2147483647){d=d<<1;break a}d=-1}h=d?d:4;d=Vp(j,h);if(d){if(!f){ce(a)}v[e+4>>2]=2428;d=ge(e+8|0,d,e+4|0);Ee(a,ce(d));f=v[fc(d)>>2];k=fc(a),l=f,v[k>>2]=l;Ic(d);v[b>>2]=v[a>>2]+(i-g|0);v[c>>2]=v[a>>2]+(h&-4);gb=e+16|0;return}Gs();L()}function Vaa(a,b){a=a|0;b=b|0;var c=0,d=0;v[22656]=0;_(1934,a|0);c=v[22656];v[22656]=0;d=1;a:{b:{if((c|0)!=1){c=v[a+24>>2];v[22656]=0;R(1937,c|0,b|0);b=v[22656];v[22656]=0;if((b|0)!=1){break b}}b=V(0)|0;O()|0;Z(b|0)|0;v[22656]=0;Y(1911,8133,a|0,0,0);a=v[22656];v[22656]=0;if((a|0)==1){break a}$();d=0}return d|0}a=P()|0;O()|0;v[22656]=0;X(20);b=v[22656];v[22656]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}function Fu(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0;d=gb-16|0;gb=d;v[b+40>>2]=0;v[b+44>>2]=0;e=b- -64|0;v[e>>2]=0;v[e+4>>2]=0;v[b+56>>2]=0;v[b+60>>2]=0;v[b+48>>2]=0;v[b+52>>2]=0;while(1){FR(b,A[ye(c,0)>>3]);f=f+1|0;if((f|0)!=1e4){continue}break}g=d,h=Vb(c),v[g+8>>2]=h;g=d,h=Zb(c),v[g>>2]=h;if(Gb(d+8|0,d)){while(1){e=d+8|0;f=v[e>>2];g=f,i=FR(b,A[f>>3]),A[g>>3]=i;Eu(e);if(Gb(e,d)){continue}break}}TB(a,c);gb=d+16|0}function doa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0;e=gb-32|0;gb=e;v[e+24>>2]=d;g=fg(a,c);se(e,v[a+28>>2]);d=v[e+12>>2];v[e+16>>2]=v[e+8>>2];v[e+20>>2]=d;a:{if(!g){if(nd(a,5)){break a}}h=v[a+28>>2];i=v[e+24>>2];f=gb-16|0;gb=f;d=Kb(f);v[22656]=0;da(629,b|0,h|0,d|0,i|0)|0;b=v[22656];v[22656]=0;b:{if((b|0)!=1){vb(d);gb=f+16|0;break b}a=P()|0;O()|0;vb(d);S(a|0);L()}}Zf(a,g,c,e+16|0);gb=e+32|0}function cW(a,b,c,d){var e=0,f=0;f=gb-16|0;gb=f;v[f+12>>2]=a;a:{b:{if(!(!c|b)){e=+(B(a,d)>>>0)*.25*1e4;if(!(e<4294967296&e>=0)){break b}a=~~e>>>0;break a}if(!(!b|!a)){qc(f+12|0,10);a=B(w[v[f+12>>2]+29024|0],1e4);break a}e=+(a>>>0);if(a-1>>>0<=9){e=733.8401379310345/e*1e4;if(!(e<4294967296&e>=0)){break b}a=~~e>>>0;break a}e=e/.264*1e4;if(!(e<4294967296&e>=0)){break b}a=~~e>>>0;break a}a=0}gb=f+16|0;return a}function Pga(a){a=a|0;var b=0;a=Kb(a);v[22656]=0;R(60,a|0,4);b=v[22656];v[22656]=0;a:{b:{if((b|0)==1){break b}v[22656]=0;R(61,a|0,32);b=v[22656];v[22656]=0;if((b|0)==1){break b}v[22656]=0;R(61,a|0,10);b=v[22656];v[22656]=0;if((b|0)==1){break b}v[22656]=0;R(61,a|0,13);b=v[22656];v[22656]=0;if((b|0)==1){break b}v[22656]=0;R(61,a|0,9);b=v[22656];v[22656]=0;if((b|0)!=1){break a}}b=P()|0;O()|0;vb(a);S(b|0);L()}}function Bka(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;c=gb-16|0;gb=c;d=Rc(c+8|0,16,1,1,0);v[c+4>>2]=0;ud(a,0);vc(b);a:{b:{if(Tr(b,11087)){Wc(b,12);if(!Kr(b)){Bp(d,2)}Wc(b,24);break b}if(Gh(b,10969)){vc(b);v[c+4>>2]=4;e=1;break a}Yi(d,8)}e=0}f=a,g=(nf(b)>>>0)/(B(hp(d),w[d|0])>>>3>>>0)|0,v[f>>2]=g;b=Dg(d,a,b);if(!(!e|!b)){d=v[a+20>>2];f=c,g=aj(a),v[f>>2]=g;Qb(d,0,v[Fb(c+4|0,c)>>2])}gb=c+16|0;return(b|0)!=0|0}function nA(a,b){a=a|0;b=b|0;var c=C(0),d=0,e=0,f=0;t[a+1074368|0]=b;fO(a+1074332|0,b);f=a+946300|0;a=a+906300|0;while(1){b=v[a>>2];if(b){c=C(1);d=v[b+20>>2];if(d){c=C(C(w[d+26|0])*C(.10000000149011612))}c=c<C(.10000000149011612)?C(1):c;d=b;if(kb[v[v[b>>2]+136>>2]](b)|0){b=v[b+16>>2];e=b+1074332|0;c=C(C(c/z[e+8>>2])*C(C(y[b+480232>>2])/z[e+20>>2]))}z[d+4196>>2]=c}a=a+160|0;if((f|0)!=(a|0)){continue}break}}function D$(a){a=a|0;var b=0;a=Kb(a);v[22656]=0;R(65,a|0,4);b=v[22656];v[22656]=0;a:{b:{if((b|0)==1){break b}v[22656]=0;R(66,a|0,32);b=v[22656];v[22656]=0;if((b|0)==1){break b}v[22656]=0;R(66,a|0,10);b=v[22656];v[22656]=0;if((b|0)==1){break b}v[22656]=0;R(66,a|0,13);b=v[22656];v[22656]=0;if((b|0)==1){break b}v[22656]=0;R(66,a|0,9);b=v[22656];v[22656]=0;if((b|0)!=1){break a}}b=P()|0;O()|0;vb(a);S(b|0);L()}}function raa(a,b){a=a|0;b=b|0;var c=0,d=C(0);v[22656]=0;_(1934,a|0);c=v[22656];v[22656]=0;a:{b:{if((c|0)!=1){c=v[a+24>>2];v[22656]=0;d=TK(c,b);b=v[22656];v[22656]=0;if((b|0)!=1){break b}}b=V(0)|0;O()|0;Z(b|0)|0;v[22656]=0;Y(1911,6534,a|0,0,0);a=v[22656];v[22656]=0;if((a|0)==1){break a}$();d=C(0)}return C(d)}a=P()|0;O()|0;v[22656]=0;X(20);b=v[22656];v[22656]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}function qaa(a,b){a=a|0;b=b|0;var c=0,d=C(0);v[22656]=0;_(1934,a|0);c=v[22656];v[22656]=0;a:{b:{if((c|0)!=1){c=v[a+24>>2];v[22656]=0;d=SK(c,b);b=v[22656];v[22656]=0;if((b|0)!=1){break b}}b=V(0)|0;O()|0;Z(b|0)|0;v[22656]=0;Y(1911,3286,a|0,0,0);a=v[22656];v[22656]=0;if((a|0)==1){break a}$();d=C(0)}return C(d)}a=P()|0;O()|0;v[22656]=0;X(20);b=v[22656];v[22656]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}function paa(a,b){a=a|0;b=b|0;var c=0,d=C(0);v[22656]=0;_(1934,a|0);c=v[22656];v[22656]=0;a:{b:{if((c|0)!=1){c=v[a+24>>2];v[22656]=0;d=RK(c,b);b=v[22656];v[22656]=0;if((b|0)!=1){break b}}b=V(0)|0;O()|0;Z(b|0)|0;v[22656]=0;Y(1911,3187,a|0,0,0);a=v[22656];v[22656]=0;if((a|0)==1){break a}$();d=C(0)}return C(d)}a=P()|0;O()|0;v[22656]=0;X(20);b=v[22656];v[22656]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}function oaa(a,b){a=a|0;b=b|0;var c=0,d=C(0);v[22656]=0;_(1934,a|0);c=v[22656];v[22656]=0;a:{b:{if((c|0)!=1){c=v[a+24>>2];v[22656]=0;d=QK(c,b);b=v[22656];v[22656]=0;if((b|0)!=1){break b}}b=V(0)|0;O()|0;Z(b|0)|0;v[22656]=0;Y(1911,3329,a|0,0,0);a=v[22656];v[22656]=0;if((a|0)==1){break a}$();d=C(0)}return C(d)}a=P()|0;O()|0;v[22656]=0;X(20);b=v[22656];v[22656]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}function naa(a,b){a=a|0;b=b|0;var c=0,d=C(0);v[22656]=0;_(1934,a|0);c=v[22656];v[22656]=0;a:{b:{if((c|0)!=1){c=v[a+24>>2];v[22656]=0;d=PK(c,b);b=v[22656];v[22656]=0;if((b|0)!=1){break b}}b=V(0)|0;O()|0;Z(b|0)|0;v[22656]=0;Y(1911,3231,a|0,0,0);a=v[22656];v[22656]=0;if((a|0)==1){break a}$();d=C(0)}return C(d)}a=P()|0;O()|0;v[22656]=0;X(20);b=v[22656];v[22656]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}function Xq(a,b,c){var d=0,e=0;a=Kb(a);d=Ab(b);v[22656]=0;R(62,a|0,d|0);d=v[22656];v[22656]=0;if((d|0)!=1){a:{if(Ab(b)){while(1){d=w[pc(b,e)|0];b:{if(d>>>0<256){d=v[(d<<2)+c>>2];v[22656]=0;R(63,a|0,d|0);d=v[22656];v[22656]=0;if((d|0)!=1){break b}break a}v[22656]=0;R(63,a|0,65533);d=v[22656];v[22656]=0;if((d|0)==1){break a}}e=e+1|0;if(Ab(b)>>>0>e>>>0){continue}break}}return}}b=P()|0;O()|0;Hc(a);S(b|0);L()}function sy(a,b,c){var d=0,e=0,f=0;d=gb-32|0;gb=d;e=d+24|0;yc(e,v[v[b>>2]-12>>2]+b|0);v[e+4>>2]=b;b=v[c+4>>2];c=v[c>>2];v[d+8>>2]=c;v[d+12>>2]=b;v[d+16>>2]=c;v[d+20>>2]=b;b=d+8|0;ll(v[d+28>>2],zb(v[b>>2]),yb(b));c=gb-16|0;gb=c;v[c+12>>2]=v[v[d+28>>2]+4>>2];v[22656]=0;v[c+8>>2]=0;e=Gf(c+8|0,c+12|0);f=v[22656];v[22656]=0;a:{if((f|0)!=1){gb=c+16|0;c=v[e>>2];break a}V(0)|0;O()|0;Bb();L()}ok(a,b,c);gb=d+32|0}function cP(a,b){a=a|0;b=b|0;var c=0;_O(a);_O(a+368680|0);if(b){aO(a,1);return a|0}b=a;a:{if(t[459496]&1){break a}if(!Qd(459496)){break a}v[22656]=0;Q(1415,90792,1)|0;c=v[22656];v[22656]=0;if((c|0)!=1){Pd(459496);break a}a=P()|0;O()|0;$e(459496);S(a|0);L()}cu(221904,287440,b+131112|0);cu(287440,352976,b+196648|0);cu(352976,418512,b+262184|0);cu(90816,221904,b+24|0);hc(b+327720|0,418512,40960);return a|0}function TD(a,b,c){var d=0,e=0,f=0;e=gb+-64|0;gb=e;Se(b);d=e+40|0;Re(d,a,c);a=v[d>>2];v[22656]=0;d=Sd(d);f=v[22656];v[22656]=0;a:{if((f|0)==1){break a}d=zb(d);v[22656]=0;Xe(e+8|0,3,d,a);d=v[22656];v[22656]=0;if((d|0)==1){break a}v[22656]=0;R(324,e+24|0,e+8|0);d=v[22656];v[22656]=0;if((d|0)==1){break a}d=b;b=e+24|0;Eb(d,b);vb(b);zc(e+40|0);gb=e- -64|0;return!c|(a|0)!=0}a=P()|0;O()|0;zc(e+40|0);S(a|0);L()}function NY(a,b,c){var d=0,e=0,f=0;e=gb+-64|0;gb=e;Se(b);d=e+40|0;Re(d,a,c);a=v[d>>2];v[22656]=0;d=Sd(d);f=v[22656];v[22656]=0;a:{if((f|0)==1){break a}d=zb(d);v[22656]=0;Xe(e+8|0,2,d,a);d=v[22656];v[22656]=0;if((d|0)==1){break a}v[22656]=0;R(324,e+24|0,e+8|0);d=v[22656];v[22656]=0;if((d|0)==1){break a}d=b;b=e+24|0;Eb(d,b);vb(b);zc(e+40|0);gb=e- -64|0;return!c|(a|0)!=0}a=P()|0;O()|0;zc(e+40|0);S(a|0);L()}function K9(a){a=a|0;var b=0;v[22656]=0;_(2007,a|0);b=v[22656];v[22656]=0;if((b|0)!=1){v[a+24>>2]=0;b=v[a+28>>2];if(b){kb[v[v[b>>2]+4>>2]](b)}v[a+28>>2]=0;b=v[a+20>>2];if(b){Yb(b);v[a+20>>2]=0}Yb(a);return}b=V(0)|0;O()|0;Z(b|0)|0;v[22656]=0;Y(1911,2147,a|0,0,0);a=v[22656];v[22656]=0;if((a|0)!=1){$();return}a=P()|0;O()|0;v[22656]=0;X(20);b=v[22656];v[22656]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}function t4(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;e=gb-16|0;gb=e;a:{b:{if((a|0)!=(b|0)){g=v[115137];v[115137]=0;d=AH(a,e+12|0,d,xe());a=jb;f=v[115137];c:{if(f){if(v[e+12>>2]!=(b|0)){break c}if((f|0)==68){break b}break a}v[115137]=g;if(v[e+12>>2]==(b|0)){break a}}}v[c>>2]=4;d=0;a=0;break a}v[c>>2]=4;if(!!d&(a|0)>=0|(a|0)>0){d=-1;a=2147483647;break a}d=0;a=-2147483648}gb=e+16|0;jb=a;return d|0}function fQ(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;d=gb-16|0;gb=d;v[d+12>>2]=(c>>>0)/6;v[d+8>>2]=v[a>>2];e=v[Fb(d+12|0,d+8|0)>>2];b=zb(b);if(e){a=v[a+20>>2];c=e;while(1){f=zb(w[b|0]);g=a,h=id(zb(w[b+1|0])<<16|f<<8|zb(w[b+2|0])<<24,16),u[g>>1]=h;f=zb(w[b+3|0]);g=a,h=id(zb(w[b+4|0])<<16|f<<8|zb(w[b+5|0])<<24,16),u[g+2>>1]=h;a=a+4|0;b=b+6|0;c=c-1|0;if(c){continue}break}}gb=d+16|0;return B(e,6)|0}function eQ(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;d=gb-16|0;gb=d;v[d+12>>2]=(c>>>0)/6;v[d+8>>2]=v[a>>2];e=v[Fb(d+12|0,d+8|0)>>2];b=zb(b);if(e){a=v[a+20>>2];c=e;while(1){f=zb(w[b+2|0]);g=a,h=id(zb(w[b+1|0])<<16|f<<8|zb(w[b|0])<<24,16),u[g>>1]=h;f=zb(w[b+5|0]);g=a,h=id(zb(w[b+4|0])<<16|f<<8|zb(w[b+3|0])<<24,16),u[g+2>>1]=h;a=a+4|0;b=b+6|0;c=c-1|0;if(c){continue}break}}gb=d+16|0;return B(e,6)|0}function EJ(a,b){a=a|0;b=b|0;var c=0;c=gb-16|0;gb=c;a:{b:{c:{d:{if((b|0)>=0){if((io(a+8|0)|0)>(b|0)){break d}}a=ba(8)|0;v[22656]=0;b=Q(70,c|0,7993)|0;c=v[22656];v[22656]=0;if((c|0)==1){break c}rc(a,b);v[22656]=0;U(186,a|0,54952,1936);a=v[22656];v[22656]=0;if((a|0)!=1){break a}c=P()|0;O()|0;vb(b);break b}gb=c+16|0;return+(+v[(v[a+32>>2]+B(b,872)|0)+1075740>>2]*.015625)}c=P()|0;O()|0;ca(a|0)}S(c|0)}L()}function pU(a,b){var c=0,d=0,e=0,f=0;c=gb-32|0;gb=c;a:{if(!w[b+4|0]){while(1){if(!w[b+d|0]){aa(14540,6236,413,10498);L()}d=d+1|0;if((d|0)!=4){continue}break}d=0;v[c+28>>2]=0;e=wd(c+8|0,c+28|0,4);f=v[e+4>>2];v[c>>2]=v[e>>2];v[c+4>>2]=f;e=c+16|0;hd(e,a,c);if(!((yb(e)|0)!=4|v[c+28>>2]!=(w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24)))){bd(a,4);d=1}gb=c+32|0;break a}aa(14519,6236,411,10498);L()}return d}function i4(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;e=gb-16|0;gb=e;a:{b:{c:{if((a|0)!=(b|0)){g=v[115137];v[115137]=0;xe();d=gb-16|0;gb=d;Gx(d,a,e+12|0,1);f=ey(v[d>>2],v[d+4>>2],v[d+8>>2],v[d+12>>2]);gb=d+16|0;a=v[115137];if(!a){break c}if(v[e+12>>2]!=(b|0)){break b}h=f;if((a|0)!=68){break a}break b}v[c>>2]=4;break a}v[115137]=g;if(v[e+12>>2]==(b|0)){break a}}v[c>>2]=4;f=h}gb=e+16|0;return+f}function eJ(a,b){var c=0,d=0,e=0;if(!w[b+21|0]){ec(a,21);return-1}if(v[a+1396>>2]<=9){sl(a)}c=v[a+1392>>2];e=u[(((c&1023)<<1)+b|0)+36>>1];a:{if((e|0)>=0){d=c;c=w[e+v[b+8>>2]|0];v[a+1392>>2]=d>>>c;c=v[a+1396>>2]-c|0;d=(c|0)<0;v[a+1396>>2]=d?0:c;c=d?-1:e;break a}c=Cm(a,b)}if(!((c|0)>=v[b+2092>>2]?w[b+23|0]:0)){if(!(!(v[a+1384>>2]?w[a+1376|0]:1)|(c|0)>=0)){ec(a,21)}return c}aa(4610,10534,1793,2842);L()}function Taa(a,b){a=a|0;b=b|0;var c=0,d=0;v[22656]=0;_(1934,a|0);c=v[22656];v[22656]=0;d=1;a:{b:{if((c|0)!=1){c=v[a+24>>2];v[22656]=0;cL(c,b);b=v[22656];v[22656]=0;if((b|0)!=1){break b}}b=V(0)|0;O()|0;Z(b|0)|0;v[22656]=0;Y(1911,2876,a|0,0,0);a=v[22656];v[22656]=0;if((a|0)==1){break a}$();d=0}return d|0}a=P()|0;O()|0;v[22656]=0;X(20);b=v[22656];v[22656]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}function Qaa(a,b){a=a|0;b=+b;var c=0;v[22656]=0;_(1934,a|0);c=v[22656];v[22656]=0;a:{b:{if((c|0)!=1){c=v[a+24>>2];v[22656]=0;b=+Ya(1942,c|0,+b);c=v[22656];v[22656]=0;if((c|0)!=1){break b}}c=V(0)|0;O()|0;Z(c|0)|0;v[22656]=0;Y(1911,4650,a|0,0,0);a=v[22656];v[22656]=0;if((a|0)==1){break a}$();b=0}return+b}a=P()|0;O()|0;v[22656]=0;X(20);c=v[22656];v[22656]=0;if((c|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}function N5(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=gb-16|0;gb=d;a:{if((c|0)<=0){break a}while(1){e=v[a+24>>2];g=v[a+28>>2];b:{if(e>>>0>=g>>>0){if((kb[v[v[a>>2]+52>>2]](a,v[b>>2])|0)==-1){break a}f=f+1|0;b=b+4|0;break b}v[d+12>>2]=g-e>>2;v[d+8>>2]=c-f;e=v[pd(d+12|0,d+8|0)>>2];yi(v[a+24>>2],b,e);g=e<<2;v[a+24>>2]=g+v[a+24>>2];f=f+e|0;b=b+g|0}if((c|0)>(f|0)){continue}break}}gb=d+16|0;return f|0}function Me(a){var b=0,c=0,d=0;b=gb-16|0;gb=b;o(+a);d=j(1)|0;j(0)|0;d=d&2147483647;a:{if(d>>>0<=1072243195){c=1;if(d>>>0<1044816030){break a}c=Rp(a,0);break a}c=a-a;if(d>>>0>=2146435072){break a}b:{switch(zG(a,b)&3){case 0:c=Rp(A[b>>3],A[b+8>>3]);break a;case 1:c=-Sp(A[b>>3],A[b+8>>3],1);break a;case 2:c=-Rp(A[b>>3],A[b+8>>3]);break a;default:break b}}c=Sp(A[b>>3],A[b+8>>3],1)}a=c;gb=b+16|0;return a}function QE(a){var b=0,c=0,d=0,e=0,f=0;a:{b:{if((w[a|0]|w[a+1|0]<<8)!=26217){if((w[a|0]|w[a+1|0]<<8)!=20042){break a}if(w[a+110|0]<=64){break b}break a}if(w[a+110|0]>64){break a}}if(t[a+112|0]<0|w[a+111|0]>128){break a}while(1){e=0;d=a+c|0;b=t[d+113|0];f=(b|0)>=0;if(!f&(b&255)>>>0<254){break a}b=w[d+241|0];if(!b&f|b>>>0>15|w[d+369|0]>=64){break a}e=1;c=c+1|0;if((c|0)!=128){continue}break}}return e}function CJ(a,b){a=a|0;b=b|0;var c=0;c=gb-16|0;gb=c;a:{b:{c:{d:{if((b|0)>=0){if((io(a+8|0)|0)>(b|0)){break d}}a=ba(8)|0;v[22656]=0;b=Q(70,c|0,7993)|0;c=v[22656];v[22656]=0;if((c|0)==1){break c}rc(a,b);v[22656]=0;U(186,a|0,54952,1936);a=v[22656];v[22656]=0;if((a|0)!=1){break a}c=P()|0;O()|0;vb(b);break b}gb=c+16|0;return(w[(v[a+32>>2]+B(b,872)|0)+1075081|0]&4)>>>2|0}c=P()|0;O()|0;ca(a|0)}S(c|0)}L()}function z8(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=gb-16|0;gb=e;a:{b:{c:{if(!d){a=ba(8)|0;v[22656]=0;c=Q(70,e|0,5333)|0;b=v[22656];v[22656]=0;if((b|0)==1){break c}rc(a,c);v[22656]=0;U(186,a|0,54952,1936);a=v[22656];v[22656]=0;if((a|0)!=1){break a}b=P()|0;O()|0;vb(c);break b}Cj(a,b,1);c=Ny(a,c,d,0,0,0);A[a+16>>3]=A[a+16>>3]+ +(c>>>0)/+(b|0);gb=e+16|0;return c|0}b=P()|0;O()|0;ca(a|0)}S(b|0)}L()}function Ut(a){var b=0,c=0,d=0;b=w[a+4266|0];z[a+4236>>2]=C(b>>>0)*C(.00390625);v[a+4228>>2]=(B(v[a+4232>>2],w[a+4264|0])+250>>>0)/500;z[a+4240>>2]=C(256-b|0)*C(.00390625);c=w[a+4267|0];b=w[a+4265|0];z[a+4244>>2]=C(B(c,b)|0)*C(152587890625e-16);d=c|-256;z[a+4256>>2]=C(B(d,b|-256)|0)*C(152587890625e-16);z[a+4252>>2]=C(B(b,d)|0)*C(152587890625e-16);z[a+4248>>2]=C(B(256-b|0,c)|0)*C(152587890625e-16)}function C8(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=gb-16|0;gb=e;a:{b:{c:{if(!d){a=ba(8)|0;v[22656]=0;c=Q(70,e|0,5333)|0;b=v[22656];v[22656]=0;if((b|0)==1){break c}rc(a,c);v[22656]=0;U(186,a|0,54952,1936);a=v[22656];v[22656]=0;if((a|0)!=1){break a}b=P()|0;O()|0;vb(c);break b}Cj(a,b,1);c=Oy(a,c,d,0,0,0);A[a+16>>3]=A[a+16>>3]+ +(c>>>0)/+(b|0);gb=e+16|0;return c|0}b=P()|0;O()|0;ca(a|0)}S(b|0)}L()}function qla(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;a:{c=FU(a,b);v[22656]=0;e=Q(872,a+12|0,b+12|0)|0;d=v[22656];v[22656]=0;b:{c:{if((d|0)!=1){v[22656]=0;Q(873,a+24|0,b+24|0)|0;d=v[22656];v[22656]=0;if((d|0)==1){break c}c=v[b+40>>2];v[a+36>>2]=v[b+36>>2];v[a+40>>2]=c;u[a+52>>1]=x[b+52>>1];c=v[b+48>>2];v[a+44>>2]=v[b+44>>2];v[a+48>>2]=c;break a}a=P()|0;O()|0;break b}a=P()|0;O()|0;gc(e)}gc(c);S(a|0);L()}}function maa(a){a=a|0;var b=0,c=0;v[22656]=0;_(1934,a|0);b=v[22656];v[22656]=0;a:{b:{if((b|0)!=1){b=v[a+24>>2];v[22656]=0;b=T(1974,b|0)|0;c=v[22656];v[22656]=0;if((c|0)!=1){break b}}b=V(0)|0;O()|0;Z(b|0)|0;v[22656]=0;Y(1911,4322,a|0,0,0);a=v[22656];v[22656]=0;if((a|0)==1){break a}$();b=0}return b|0}a=P()|0;O()|0;v[22656]=0;X(20);b=v[22656];v[22656]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}function WY(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=gb-32|0;gb=d;v[d+28>>2]=c;a:{if(!Pb(b,c<<1)){break a}qc(d+28|0,65535);Af(a,x[d+28>>1]);e=d,f=Vb(a),v[e+16>>2]=f;e=d,f=Zb(a),v[e+8>>2]=f;if(!Gb(d+16|0,d+8|0)){break a}while(1){a=v[d+16>>2];c=d+24|0;if(!Ep(b,c)){PD(c)}c=Ib(w[d+24|0]|w[d+25|0]<<8);u[a>>1]=c;if((c|0)==65535){u[a>>1]=65535}a=d+16|0;of(a);if(Gb(a,d+8|0)){continue}break}}gb=d+32|0}function Tm(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0;e=gb-16|0;gb=e;f=Vb(b);g=Zb(b);d=gb-32|0;gb=d;v[d+16>>2]=g;v[d+24>>2]=f;v[d+8>>2]=c;a:{if(!Gb(d+24|0,d+16|0)){break a}while(1){if(pD(d+8|0,v[d+24>>2])){break a}c=d+24|0;v[c>>2]=v[c>>2]+28;if(Gb(c,d+16|0)){continue}break}}gb=d+32|0;v[e+8>>2]=v[d+24>>2];h=e,i=Zb(b),v[h>>2]=i;b:{if(Sj(e+8|0,e)){Jh(a);break b}rn(a,v[e+8>>2])}gb=e+16|0}function pga(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;v[a>>2]=b;d=gb-16|0;gb=d;g=d+8|0;e=b+1074376|0;c=hc(sf(223848),e,614);b=0;while(1){f=B(b,872);qu((c+f|0)+616|0,(e+f|0)+616|0);b=b+1|0;if((b|0)!=256){continue}break}b=v[Wi(g,c)>>2];gb=d+16|0;v[a+4>>2]=b;b=Jk(a+8|0);d=dd(a+20|0);v[22656]=0;_(1254,a|0);c=v[22656];v[22656]=0;if((c|0)!=1){return a|0}c=P()|0;O()|0;jP(d);iP(b);hP(a+4|0);S(c|0);L()}function aaa(a,b){a=a|0;b=b|0;var c=0;v[22656]=0;_(1934,a|0);c=v[22656];v[22656]=0;a:{b:{if((c|0)!=1){c=v[a+24>>2];v[22656]=0;b=KK(c,b);c=v[22656];v[22656]=0;if((c|0)!=1){break b}}b=V(0)|0;O()|0;Z(b|0)|0;v[22656]=0;Y(1911,6943,a|0,0,0);a=v[22656];v[22656]=0;if((a|0)==1){break a}$();b=0}return b|0}a=P()|0;O()|0;v[22656]=0;X(20);b=v[22656];v[22656]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}function Raa(a){a=a|0;var b=0,c=0;v[22656]=0;_(1934,a|0);b=v[22656];v[22656]=0;a:{b:{if((b|0)!=1){b=v[a+24>>2];v[22656]=0;c=+pa(1941,b|0);b=v[22656];v[22656]=0;if((b|0)!=1){break b}}b=V(0)|0;O()|0;Z(b|0)|0;v[22656]=0;Y(1911,4722,a|0,0,0);a=v[22656];v[22656]=0;if((a|0)==1){break a}$();c=0}return+c}a=P()|0;O()|0;v[22656]=0;X(20);b=v[22656];v[22656]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}function Os(a){var b=0,c=0;mo(a,1,10906);v[22656]=0;b=ga(147)|0;c=v[22656];v[22656]=0;a:{if((c|0)==1){break a}v[a+12>>2]=b;v[22656]=0;b=ga(148)|0;c=v[22656];v[22656]=0;if((c|0)==1){break a}t[a+16|0]=b;v[22656]=0;b=ga(149)|0;c=v[22656];v[22656]=0;if((c|0)==1){break a}t[a+18|0]=0;t[a+17|0]=b;v[22656]=0;_(150,a+20|0);b=v[22656];v[22656]=0;if((b|0)==1){break a}return}b=P()|0;O()|0;vb(a);S(b|0);L()}function I8(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;b=gb-32|0;gb=b;c=wd(b+24|0,c,d);d=v[c+4>>2];v[b>>2]=v[c>>2];v[b+4>>2]=d;a:{a=lA(a,b,0);if(a+1>>>0>=3){a=ba(8)|0;v[22656]=0;b=Q(70,b+8|0,5190)|0;c=v[22656];v[22656]=0;b:{if((c|0)!=1){rc(a,b);v[22656]=0;U(186,a|0,54952,1936);a=v[22656];v[22656]=0;if((a|0)!=1){break a}d=P()|0;O()|0;vb(b);break b}d=P()|0;O()|0;ca(a|0)}S(d|0);L()}gb=b+32|0;return a|0}L()}function w8(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=gb-16|0;gb=e;a:{b:{c:{if(!d){a=ba(8)|0;v[22656]=0;c=Q(70,e|0,5333)|0;b=v[22656];v[22656]=0;if((b|0)==1){break c}rc(a,c);v[22656]=0;U(186,a|0,54952,1936);a=v[22656];v[22656]=0;if((a|0)!=1){break a}b=P()|0;O()|0;vb(c);break b}Cj(a,b,2);c=kL(a,c,2,d);A[a+16>>3]=A[a+16>>3]+ +(c>>>0)/+(b|0);gb=e+16|0;return c|0}b=P()|0;O()|0;ca(a|0)}S(b|0)}L()}function v8(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=gb-16|0;gb=e;a:{b:{c:{if(!d){a=ba(8)|0;v[22656]=0;c=Q(70,e|0,5333)|0;b=v[22656];v[22656]=0;if((b|0)==1){break c}rc(a,c);v[22656]=0;U(186,a|0,54952,1936);a=v[22656];v[22656]=0;if((a|0)!=1){break a}b=P()|0;O()|0;vb(c);break b}Cj(a,b,4);c=kL(a,c,4,d);A[a+16>>3]=A[a+16>>3]+ +(c>>>0)/+(b|0);gb=e+16|0;return c|0}b=P()|0;O()|0;ca(a|0)}S(b|0)}L()}function u8(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=gb-16|0;gb=e;a:{b:{c:{if(!d){a=ba(8)|0;v[22656]=0;c=Q(70,e|0,5333)|0;b=v[22656];v[22656]=0;if((b|0)==1){break c}rc(a,c);v[22656]=0;U(186,a|0,54952,1936);a=v[22656];v[22656]=0;if((a|0)!=1){break a}b=P()|0;O()|0;vb(c);break b}Cj(a,b,2);c=jL(a,c,2,d);A[a+16>>3]=A[a+16>>3]+ +(c>>>0)/+(b|0);gb=e+16|0;return c|0}b=P()|0;O()|0;ca(a|0)}S(b|0)}L()}function t8(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=gb-16|0;gb=e;a:{b:{c:{if(!d){a=ba(8)|0;v[22656]=0;c=Q(70,e|0,5333)|0;b=v[22656];v[22656]=0;if((b|0)==1){break c}rc(a,c);v[22656]=0;U(186,a|0,54952,1936);a=v[22656];v[22656]=0;if((a|0)!=1){break a}b=P()|0;O()|0;vb(c);break b}Cj(a,b,4);c=jL(a,c,4,d);A[a+16>>3]=A[a+16>>3]+ +(c>>>0)/+(b|0);gb=e+16|0;return c|0}b=P()|0;O()|0;ca(a|0)}S(b|0)}L()}function lda(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0;d=gb-16|0;gb=d;b=d+8|0;LM(b,a,0);if(yb(b)){a=v[a+20>>2];v[a+148>>2]=-1;b=gb-16|0;gb=b;c=v[d+8>>2];f=v[d+12>>2];e=Zh(c,f);a=a+4|0;a:{if(e>>>0<=dg(a)>>>0){if(oc(a)>>>0<e>>>0){v[b+12>>2]=c;xO(b+12|0,oc(a));g=c;c=v[b+12>>2];Rg(g,c,v[a>>2]);rr(a,c,f,e-oc(a)|0);break a}Em(a,Rg(c,f,v[a>>2]));break a}Hv(a);Dn(a,qh(a,e));rr(a,c,f,e)}gb=b+16|0}gb=d+16|0}function hV(a){var b=0,c=0,d=0;a:{if((w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24))!=808604749){break a}b=a+8|0;c=w[b+1|0]<<8;if((w[b|0]|c)>>>0<512|(c|w[b|0])>>>0>767){break a}b=a+112|0;c=w[b+1|0]<<8;if(!(w[b|0]|c)|(c|w[b|0])>>>0>64){break a}b=a+106|0;if((w[b|0]|w[b+1|0]<<8)>>>0>256){break a}b=a+122|0;if((w[b|0]|w[b+1|0]<<8)>>>0>255){break a}a=a+124|0;d=(w[a|0]|w[a+1|0]<<8)>>>0<4e3}return d}function Uaa(a){a=a|0;var b=0,c=0;v[22656]=0;_(1934,a|0);b=v[22656];v[22656]=0;a:{b:{if((b|0)!=1){b=v[a+24>>2];v[22656]=0;b=v[b+8>>2];c=v[22656];v[22656]=0;if((c|0)!=1){break b}}b=V(0)|0;O()|0;Z(b|0)|0;v[22656]=0;Y(1911,8163,a|0,0,0);a=v[22656];v[22656]=0;if((a|0)==1){break a}$();b=-1}return b|0}a=P()|0;O()|0;v[22656]=0;X(20);b=v[22656];v[22656]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}function $9(a,b){a=a|0;b=b|0;var c=0;v[22656]=0;_(1934,a|0);c=v[22656];v[22656]=0;a:{b:{if((c|0)!=1){c=v[a+24>>2];v[22656]=0;b=JK(c,b);c=v[22656];v[22656]=0;if((c|0)!=1){break b}}b=V(0)|0;O()|0;Z(b|0)|0;v[22656]=0;Y(1911,3681,a|0,0,0);a=v[22656];v[22656]=0;if((a|0)==1){break a}$();b=0}return b|0}a=P()|0;O()|0;v[22656]=0;X(20);b=v[22656];v[22656]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}function vR(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=gb-32|0;gb=d;v[a+4>>2]=0;a:{if(b){b:{if(Pu(a)>>>0>=b>>>0){v[a+4>>2]=b;break b}wb(a);e=CB(d+16|0);v[22656]=0;f=Q(951,a|0,b|0)|0;g=v[22656];v[22656]=0;if((g|0)==1){break a}v[22656]=0;R(952,e|0,f|0);f=v[22656];v[22656]=0;if((f|0)==1){break a}v[e+4>>2]=b;BB(a,e);Ye(e)}Ak(d,a);yp(d,b,w[c|0])}gb=d+32|0;return}a=P()|0;O()|0;Ye(e);S(a|0);L()}function w1(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0;f=gb-16|0;gb=f;v[e>>2]=c;c=2;a=sx(f+12|0,0,b,v[a+8>>2]);a:{if(a+1>>>0<2){break a}c=1;b=v[e>>2];g=d-b|0;d=a-1|0;if(g>>>0<d>>>0){break a}c=0;if(!d){break a}d=w[f+12|0];v[e>>2]=b+1;t[b|0]=d;a=a-2|0;if(!a){break a}b=f+12|0;while(1){d=w[b+1|0];g=v[e>>2];v[e>>2]=g+1;t[g|0]=d;b=b+1|0;a=a-1|0;if(a){continue}break}}gb=f+16|0;return c|0}function rna(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;f=gb+-64|0;gb=f;c=gb-32|0;gb=c;d=c+24|0;g=f+8|0;bW(d,g);h=yb(d);d=v[c+28>>2];e=v[c+24>>2];v[c+8>>2]=e;v[c+12>>2]=d;v[c>>2]=e;v[c+4>>2]=d;e=c+16|0;d=a;hd(e,d,c);e=yb(e);if((e|0)==(h|0)){bd(d,yb(c+24|0))}gb=c+32|0;c=(e|0)==(h|0);if(!c){aW(g)}d=-1;a:{if(!c){break a}d=0;if(!jW(f+8|0)){break a}d=Oe(a,b,iW(f+8|0),jb)}gb=f- -64|0;return d|0}function lz(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;f=gb-16|0;gb=f;i=f+8|0;d=gb-16|0;gb=d;c=a;j=b;e=Yd(a);g=fc(a);h=gb-16|0;gb=h;if(e){wb(c);while(1){c=dN(e+16|0,j);g=c?g:e;e=v[(c?4:0)+e>>2];if(e){continue}break}}c=v[yc(h+8|0,g)>>2];gb=h+16|0;v[d+8>>2]=c;k=d,l=Ch(a),v[k>>2]=l;a:{if(Gb(d+8|0,d)){if(!eN(wb(a),b,ue(d+8|0))){break a}}c=Ch(a)}gb=d+16|0;a=v[yc(i,c)>>2];gb=f+16|0;return a}function Paa(a){a=a|0;var b=0,c=0;v[22656]=0;_(1934,a|0);b=v[22656];v[22656]=0;a:{b:{if((b|0)!=1){b=v[a+24>>2];v[22656]=0;c=A[b+16>>3];b=v[22656];v[22656]=0;if((b|0)!=1){break b}}b=V(0)|0;O()|0;Z(b|0)|0;v[22656]=0;Y(1911,4686,a|0,0,0);a=v[22656];v[22656]=0;if((a|0)==1){break a}$();c=0}return+c}a=P()|0;O()|0;v[22656]=0;X(20);b=v[22656];v[22656]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}function ri(a){var b=0,c=0;b=gb-16|0;gb=b;o(+a);c=j(1)|0;j(0)|0;c=c&2147483647;a:{if(c>>>0<=1072243195){if(c>>>0<1045430272){break a}a=Sp(a,0,0);break a}if(c>>>0>=2146435072){a=a-a;break a}b:{switch(zG(a,b)&3){case 0:a=Sp(A[b>>3],A[b+8>>3],1);break a;case 1:a=Rp(A[b>>3],A[b+8>>3]);break a;case 2:a=-Sp(A[b>>3],A[b+8>>3],1);break a;default:break b}}a=-Rp(A[b>>3],A[b+8>>3])}gb=b+16|0;return a}function Xoa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;f=gb-112|0;gb=f;c=gb-32|0;gb=c;d=c+24|0;g=f+8|0;IX(d,g);h=yb(d);d=v[c+28>>2];e=v[c+24>>2];v[c+8>>2]=e;v[c+12>>2]=d;v[c>>2]=e;v[c+4>>2]=d;e=c+16|0;d=a;hd(e,d,c);e=yb(e);if((e|0)==(h|0)){bd(d,yb(c+24|0))}gb=c+32|0;c=(e|0)==(h|0);if(!c){HX(g)}d=-1;a:{if(!c){break a}d=0;if(!LX(f+8|0)){break a}d=Oe(a,b,KX(f+8|0),jb)}gb=f+112|0;return d|0}function y7(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=C(0);c=gb-16|0;gb=c;g=v[a+4>>2];v[c+8>>2]=v[b+8>>2];d=v[b+4>>2];v[c>>2]=v[b>>2];v[c+4>>2]=d;iK(a,c);if(!(!v[b+8>>2]|z[a+24>>2]==C(1))){h=a+12|0;while(1){if(v[b+4>>2]){i=e+g|0;d=0;while(1){j=z[a+24>>2];f=ir(h,d,i);z[f>>2]=j*z[f>>2];d=d+1|0;if(d>>>0<y[b+4>>2]){continue}break}}e=e+1|0;if(e>>>0<y[b+8>>2]){continue}break}}gb=c+16|0}function xaa(a){a=a|0;var b=0,c=0;v[22656]=0;_(1934,a|0);b=v[22656];v[22656]=0;a:{b:{if((b|0)!=1){b=v[a+24>>2];v[22656]=0;b=_K(b);c=v[22656];v[22656]=0;if((c|0)!=1){break b}}b=V(0)|0;O()|0;Z(b|0)|0;v[22656]=0;Y(1911,10112,a|0,0,0);a=v[22656];v[22656]=0;if((a|0)==1){break a}$();b=0}return b|0}a=P()|0;O()|0;v[22656]=0;X(20);b=v[22656];v[22656]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}function b_(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;f=gb-512|0;gb=f;c=gb-32|0;gb=c;d=c+24|0;g=f+8|0;KE(d,g);h=yb(d);d=v[c+28>>2];e=v[c+24>>2];v[c+8>>2]=e;v[c+12>>2]=d;v[c>>2]=e;v[c+4>>2]=d;e=c+16|0;d=a;hd(e,d,c);e=yb(e);if((e|0)==(h|0)){bd(d,yb(c+24|0))}gb=c+32|0;c=(e|0)==(h|0);if(!c){JE(g)}d=-1;a:{if(!c){break a}d=0;if(!QE(f+8|0)){break a}d=Oe(a,b,PE(f+8|0),jb)}gb=f+512|0;return d|0}function Hha(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=ze(a);if(d>>>0<b>>>0){e=gb-32|0;gb=e;a:{b:{d=b-d|0;c:{if(d>>>0<=v[wb(a)>>2]-v[a+4>>2]>>5>>>0){jB(a,d,c);break c}b=wb(a);b=bS(e+8|0,_q(a,ze(a)+d|0),ze(a),b);v[22656]=0;U(1102,b|0,d|0,c|0);c=v[22656];v[22656]=0;if((c|0)==1){break b}aS(a,b);gB(b)}gb=e+32|0;break a}a=P()|0;O()|0;gB(b);S(a|0);L()}return}if(b>>>0<d>>>0){lS(a,v[a>>2]+(b<<5)|0)}}function waa(a){a=a|0;var b=0,c=0;v[22656]=0;_(1934,a|0);b=v[22656];v[22656]=0;a:{b:{if((b|0)!=1){b=v[a+24>>2];v[22656]=0;b=ZK(b);c=v[22656];v[22656]=0;if((c|0)!=1){break b}}b=V(0)|0;O()|0;Z(b|0)|0;v[22656]=0;Y(1911,6487,a|0,0,0);a=v[22656];v[22656]=0;if((a|0)==1){break a}$();b=0}return b|0}a=P()|0;O()|0;v[22656]=0;X(20);b=v[22656];v[22656]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}function vo(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0;f=gb-16|0;gb=f;a:{while(1){g=h&255;if(Zt(b,c,g>>>0>1)){t[f+15|0]=0;t[f+14|0]=0;lB(a,f+15|0,f+14|0);break a}fi(b,d);fi(c,e);h=h+1|0;if(g>>>0<3){continue}break}h=f;g=w[b|0];if(Fj(g)>>>0>Fj(w[d|0])>>>0){fi(b,d);fi(c,e);g=w[b|0]}t[h+11|0]=g;lB(f+12|0,f+11|0,c);t[b|0]=0;t[c|0]=0;b=x[f+12>>1];t[a|0]=b;t[a+1|0]=b>>>8}gb=f+16|0}function vaa(a){a=a|0;var b=0,c=0;v[22656]=0;_(1934,a|0);b=v[22656];v[22656]=0;a:{b:{if((b|0)!=1){b=v[a+24>>2];v[22656]=0;b=YK(b);c=v[22656];v[22656]=0;if((c|0)!=1){break b}}b=V(0)|0;O()|0;Z(b|0)|0;v[22656]=0;Y(1911,5927,a|0,0,0);a=v[22656];v[22656]=0;if((a|0)==1){break a}$();b=0}return b|0}a=P()|0;O()|0;v[22656]=0;X(20);b=v[22656];v[22656]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}function uaa(a){a=a|0;var b=0,c=0;v[22656]=0;_(1934,a|0);b=v[22656];v[22656]=0;a:{b:{if((b|0)!=1){b=v[a+24>>2];v[22656]=0;b=WK(b);c=v[22656];v[22656]=0;if((c|0)!=1){break b}}b=V(0)|0;O()|0;Z(b|0)|0;v[22656]=0;Y(1911,6908,a|0,0,0);a=v[22656];v[22656]=0;if((a|0)==1){break a}$();b=0}return b|0}a=P()|0;O()|0;v[22656]=0;X(20);b=v[22656];v[22656]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}function taa(a){a=a|0;var b=0,c=0;v[22656]=0;_(1934,a|0);b=v[22656];v[22656]=0;a:{b:{if((b|0)!=1){b=v[a+24>>2];v[22656]=0;b=VK(b);c=v[22656];v[22656]=0;if((c|0)!=1){break b}}b=V(0)|0;O()|0;Z(b|0)|0;v[22656]=0;Y(1911,2411,a|0,0,0);a=v[22656];v[22656]=0;if((a|0)==1){break a}$();b=0}return b|0}a=P()|0;O()|0;v[22656]=0;X(20);b=v[22656];v[22656]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}function saa(a){a=a|0;var b=0,c=0;v[22656]=0;_(1934,a|0);b=v[22656];v[22656]=0;a:{b:{if((b|0)!=1){b=v[a+24>>2];v[22656]=0;b=UK(b);c=v[22656];v[22656]=0;if((c|0)!=1){break b}}b=V(0)|0;O()|0;Z(b|0)|0;v[22656]=0;Y(1911,4167,a|0,0,0);a=v[22656];v[22656]=0;if((a|0)==1){break a}$();b=0}return b|0}a=P()|0;O()|0;v[22656]=0;X(20);b=v[22656];v[22656]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}function laa(a){a=a|0;var b=0,c=0;v[22656]=0;_(1934,a|0);b=v[22656];v[22656]=0;a:{b:{if((b|0)!=1){b=v[a+24>>2];v[22656]=0;b=io(b);c=v[22656];v[22656]=0;if((c|0)!=1){break b}}b=V(0)|0;O()|0;Z(b|0)|0;v[22656]=0;Y(1911,4135,a|0,0,0);a=v[22656];v[22656]=0;if((a|0)==1){break a}$();b=0}return b|0}a=P()|0;O()|0;v[22656]=0;X(20);b=v[22656];v[22656]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}function kaa(a){a=a|0;var b=0,c=0;v[22656]=0;_(1934,a|0);b=v[22656];v[22656]=0;a:{b:{if((b|0)!=1){b=v[a+24>>2];v[22656]=0;b=OK(b);c=v[22656];v[22656]=0;if((c|0)!=1){break b}}b=V(0)|0;O()|0;Z(b|0)|0;v[22656]=0;Y(1911,3942,a|0,0,0);a=v[22656];v[22656]=0;if((a|0)==1){break a}$();b=0}return b|0}a=P()|0;O()|0;v[22656]=0;X(20);b=v[22656];v[22656]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}function jaa(a){a=a|0;var b=0,c=0;v[22656]=0;_(1934,a|0);b=v[22656];v[22656]=0;a:{b:{if((b|0)!=1){b=v[a+24>>2];v[22656]=0;b=NK(b);c=v[22656];v[22656]=0;if((c|0)!=1){break b}}b=V(0)|0;O()|0;Z(b|0)|0;v[22656]=0;Y(1911,4010,a|0,0,0);a=v[22656];v[22656]=0;if((a|0)==1){break a}$();b=0}return b|0}a=P()|0;O()|0;v[22656]=0;X(20);b=v[22656];v[22656]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}function iaa(a){a=a|0;var b=0,c=0;v[22656]=0;_(1934,a|0);b=v[22656];v[22656]=0;a:{b:{if((b|0)!=1){b=v[a+24>>2];v[22656]=0;b=wl(b);c=v[22656];v[22656]=0;if((c|0)!=1){break b}}b=V(0)|0;O()|0;Z(b|0)|0;v[22656]=0;Y(1911,3844,a|0,0,0);a=v[22656];v[22656]=0;if((a|0)==1){break a}$();b=0}return b|0}a=P()|0;O()|0;v[22656]=0;X(20);b=v[22656];v[22656]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}function haa(a){a=a|0;var b=0,c=0;v[22656]=0;_(1934,a|0);b=v[22656];v[22656]=0;a:{b:{if((b|0)!=1){b=v[a+24>>2];v[22656]=0;b=hq(b);c=v[22656];v[22656]=0;if((c|0)!=1){break b}}b=V(0)|0;O()|0;Z(b|0)|0;v[22656]=0;Y(1911,4524,a|0,0,0);a=v[22656];v[22656]=0;if((a|0)==1){break a}$();b=0}return b|0}a=P()|0;O()|0;v[22656]=0;X(20);b=v[22656];v[22656]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}function Saa(a){a=a|0;var b=0,c=0;v[22656]=0;_(1934,a|0);b=v[22656];v[22656]=0;a:{b:{if((b|0)!=1){b=v[a+24>>2];v[22656]=0;b=bL(b);c=v[22656];v[22656]=0;if((c|0)!=1){break b}}b=V(0)|0;O()|0;Z(b|0)|0;v[22656]=0;Y(1911,2908,a|0,0,0);a=v[22656];v[22656]=0;if((a|0)==1){break a}$();b=0}return b|0}a=P()|0;O()|0;v[22656]=0;X(20);b=v[22656];v[22656]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}function _Z(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;f=gb-48|0;gb=f;c=gb-32|0;gb=c;d=c+24|0;g=f+8|0;tE(d,g);h=yb(d);d=v[c+28>>2];e=v[c+24>>2];v[c+8>>2]=e;v[c+12>>2]=d;v[c>>2]=e;v[c+4>>2]=d;e=c+16|0;d=a;hd(e,d,c);e=yb(e);if((e|0)==(h|0)){bd(d,yb(c+24|0))}gb=c+32|0;c=(e|0)==(h|0);if(!c){sE(g)}d=-1;a:{if(!c){break a}d=0;if(!GE(f+8|0)){break a}d=Oe(a,b,FE(f+8|0),jb)}gb=f+48|0;return d|0}function yaa(a){a=a|0;var b=0,c=0;v[22656]=0;_(1934,a|0);b=v[22656];v[22656]=0;a:{b:{if((b|0)!=1){b=v[a+24>>2];v[22656]=0;c=$K(b);b=v[22656];v[22656]=0;if((b|0)!=1){break b}}b=V(0)|0;O()|0;Z(b|0)|0;v[22656]=0;Y(1911,7419,a|0,0,0);a=v[22656];v[22656]=0;if((a|0)==1){break a}$();c=0}return+c}a=P()|0;O()|0;v[22656]=0;X(20);b=v[22656];v[22656]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}function xV(a,b){var c=0,d=0,e=0,f=0;c=gb-32|0;gb=c;a:{if(!w[b+5|0]){while(1){if(!w[b+d|0]){aa(14540,6236,413,10498);L()}d=d+1|0;if((d|0)!=5){continue}break}d=0;t[c+28|0]=0;v[c+24>>2]=0;e=wd(c+8|0,c+24|0,5);f=v[e+4>>2];v[c>>2]=v[e>>2];v[c+4>>2]=f;e=c+16|0;cc(e,a,c);b:{if((yb(e)|0)!=5){break b}if(sd(c+24|0,b,5)){break b}Rb(a,5);d=1}gb=c+32|0;break a}aa(14519,6236,411,10498);L()}return d}function eZ(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;f=gb-1968|0;gb=f;c=gb-32|0;gb=c;d=c+24|0;g=f+8|0;KD(d,g);h=yb(d);d=v[c+28>>2];e=v[c+24>>2];v[c+8>>2]=e;v[c+12>>2]=d;v[c>>2]=e;v[c+4>>2]=d;e=c+16|0;d=a;hd(e,d,c);e=yb(e);if((e|0)==(h|0)){bd(d,yb(c+24|0))}gb=c+32|0;c=(e|0)==(h|0);if(!c){JD(g)}d=-1;a:{if(!c){break a}d=0;if(!ND(f+8|0)){break a}d=Oe(a,b,1024,0)}gb=f+1968|0;return d|0}function pV(a){t[a|0]=0;t[a+1|0]=0;t[a+2|0]=0;t[a+3|0]=0;t[a+4|0]=0;t[a+5|0]=0;t[a+6|0]=0;t[a+7|0]=0;t[a+22|0]=0;t[a+23|0]=0;t[a+24|0]=0;t[a+25|0]=0;t[a+26|0]=0;t[a+27|0]=0;t[a+28|0]=0;t[a+29|0]=0;t[a+16|0]=0;t[a+17|0]=0;t[a+18|0]=0;t[a+19|0]=0;t[a+20|0]=0;t[a+21|0]=0;t[a+22|0]=0;t[a+23|0]=0;t[a+8|0]=0;t[a+9|0]=0;t[a+10|0]=0;t[a+11|0]=0;t[a+12|0]=0;t[a+13|0]=0;t[a+14|0]=0;t[a+15|0]=0}function $B(a){t[a|0]=0;t[a+1|0]=0;t[a+2|0]=0;t[a+3|0]=0;t[a+4|0]=0;t[a+5|0]=0;t[a+6|0]=0;t[a+7|0]=0;t[a+24|0]=0;t[a+25|0]=0;t[a+26|0]=0;t[a+27|0]=0;t[a+28|0]=0;t[a+29|0]=0;t[a+30|0]=0;t[a+31|0]=0;t[a+16|0]=0;t[a+17|0]=0;t[a+18|0]=0;t[a+19|0]=0;t[a+20|0]=0;t[a+21|0]=0;t[a+22|0]=0;t[a+23|0]=0;t[a+8|0]=0;t[a+9|0]=0;t[a+10|0]=0;t[a+11|0]=0;t[a+12|0]=0;t[a+13|0]=0;t[a+14|0]=0;t[a+15|0]=0}function X0(){var a=0;a:{if(t[464776]&1){break a}if(!Qd(464776)){break a}a=464608;while(1){a=Kb(a)+12|0;if((a|0)!=464776){continue}break}Pd(464776)}ld(464608,85684);ld(464620,85712);ld(464632,85740);ld(464644,85772);ld(464656,85812);ld(464668,85848);ld(464680,85876);ld(464692,85912);ld(464704,85928);ld(464716,85944);ld(464728,85960);ld(464740,85976);ld(464752,85992);ld(464764,86008)}function Rda(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;b=Fi(a,b,c,d);v[a>>2]=49688;d=mc(a+4208|0);v[a+4228>>2]=0;v[a+4220>>2]=0;v[a+4224>>2]=0;e=a,f=wf(c),v[e+4232>>2]=f;OY(a+4260|0,80,150,80,255);v[22656]=0;W(1532,a+44|0,2,2)|0;c=v[22656];v[22656]=0;a:{if((c|0)==1){break a}v[22656]=0;Th(b);c=v[22656];v[22656]=0;if((c|0)==1){break a}return a|0}a=P()|0;O()|0;Nc(d);Lf(b);S(a|0);L()}function tB(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0;f=gb-32|0;gb=f;v[f+8>>2]=c;g=f,h=nf(b),v[g+28>>2]=h;c=f+8|0;Re(c,b,v[Fb(c,f+28|0)>>2]);v[22656]=0;b=Sd(c);c=v[22656];v[22656]=0;a:{if((c|0)==1){break a}c=v[f+8>>2];v[22656]=0;a=fa(361,a|0,b|0,c|0,d|0,e|0)|0;b=v[22656];v[22656]=0;if((b|0)==1){break a}zc(f+8|0);gb=f+32|0;return a|0}a=P()|0;O()|0;zc(f+8|0);S(a|0);L()}function Mda(a){a=a|0;var b=0,c=0;b=v[a+20>>2];v[b+148>>2]=-1;v[22656]=0;R(440,b+4|0,8);b=v[22656];v[22656]=0;if((b|0)!=1){c=v[v[a+20>>2]+4>>2];b=v[a+4264>>2];a=v[a+4260>>2];t[c|0]=a;t[c+1|0]=a>>>8;t[c+2|0]=a>>>16;t[c+3|0]=a>>>24;t[c+4|0]=b;t[c+5|0]=b>>>8;t[c+6|0]=b>>>16;t[c+7|0]=b>>>24;return}b=V(89116)|0;if((O()|0)==(ea(89116)|0)){Z(b|0)|0;yr(v[a+20>>2]+4|0);$();return}S(b|0);L()}function iG(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0;d=gb-48|0;gb=d;f=v[b>>2];g=v[b+8>>2];e=v[c+4>>2];c=v[c>>2];v[d+16>>2]=c;v[d+20>>2]=e;v[d+24>>2]=c;v[d+28>>2]=e;rh(d+32|0,d+16|0);c=v[v[f>>2]+28>>2];e=v[d+36>>2];v[d+8>>2]=v[d+32>>2];v[d+12>>2]=e;kb[c|0](d+40|0,f,g,d+8|0);c=v[d+44>>2];v[d>>2]=v[d+40>>2];v[d+4>>2]=c;rh(a,d);h=b,i=yb(a)+v[b+8>>2]|0,v[h+8>>2]=i;gb=d+48|0}function Ps(a,b,c){var d=0,e=0;if(c&2048){t[a|0]=43;a=a+1|0}if(c&1024){t[a|0]=35;a=a+1|0}d=c&260;if((d|0)!=260){t[a|0]=46;t[a+1|0]=42;a=a+2|0}e=w[b|0];if(e){while(1){t[a|0]=e;a=a+1|0;e=w[b+1|0];b=b+1|0;if(e){continue}break}}b=c&16384;a:{b:{if((d|0)!=256){if((d|0)!=4){break b}c=b?70:102;break a}c=b?69:101;break a}c=b?65:97;if((d|0)==260){break a}c=b?71:103}t[a|0]=c;return(d|0)!=260}function Dha(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;a:{c=b;wb(b);d=a;f=vh(a);b:{c:{e=tc(b);if(e){v[22656]=0;R(814,d|0,e|0);g=v[22656];v[22656]=0;if((g|0)==1){break c}cS(d,v[c>>2],v[c+4>>2],e)}break b}a=P()|0;O()|0;cs(f);S(a|0);L()}v[22656]=0;Q(4,a+12|0,b+12|0)|0;c=v[22656];v[22656]=0;if((c|0)!=1){v[a+24>>2]=v[b+24>>2];u[a+28>>1]=x[b+28>>1];break a}a=P()|0;O()|0;Ze(d);S(a|0);L()}}function xpa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;f=gb-32|0;gb=f;c=gb-32|0;gb=c;d=c+24|0;g=f+8|0;UD(d,g);h=yb(d);d=v[c+28>>2];e=v[c+24>>2];v[c+8>>2]=e;v[c+12>>2]=d;v[c>>2]=e;v[c+4>>2]=d;e=c+16|0;d=a;hd(e,d,c);e=yb(e);if((e|0)==(h|0)){bd(d,yb(c+24|0))}gb=c+32|0;c=(e|0)==(h|0);if(!c){Zv(g)}d=-1;a:{if(!c){break a}d=0;if(!XX(f+8|0)){break a}d=Oe(a,b,72,0)}gb=f+32|0;return d|0}function EG(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=gb-32|0;gb=d;c=Tb(d,c);v[22656]=0;U(2811,d+16|0,b|0,c|0);e=v[22656];v[22656]=0;a:{b:{if((e|0)!=1){v[22656]=0;Q(2812,a|0,d+16|0)|0;e=v[22656];v[22656]=0;if((e|0)==1){break b}vb(d+16|0);vb(c);v[a>>2]=88764;c=v[b+4>>2];v[a+8>>2]=v[b>>2];v[a+12>>2]=c;gb=d+32|0;return a|0}a=P()|0;O()|0;break a}a=P()|0;O()|0;vb(d+16|0)}vb(c);S(a|0);L()}function tF(a){var b=0,c=0;a:{if((w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24))!=1179340888|(w[a+8|0]|w[a+9|0]<<8|(w[a+10|0]<<16|w[a+11|0]<<24))!=1213419859){break a}b=a+4|0;if(!Xb(w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24))){break a}a=a+12|0;if(!Xb(w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24))){break a}c=Xb(w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24))>>>0>27}return c}function bba(a){a=a|0;var b=0;v[22656]=0;_(1934,a|0);b=v[22656];v[22656]=0;if((b|0)!=1){b=v[a+24>>2];if(b){Yb(Gt(b))}v[a+24>>2]=0;b=v[a+20>>2];if(b){Yb(b);v[a+20>>2]=0}Yb(a);return}b=V(0)|0;O()|0;Z(b|0)|0;v[22656]=0;Y(1911,2174,a|0,0,0);a=v[22656];v[22656]=0;if((a|0)!=1){$();return}a=P()|0;O()|0;v[22656]=0;X(20);b=v[22656];v[22656]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}function yJ(a,b){a=a|0;b=b|0;var c=0;c=gb-16|0;gb=c;a:{b:{c:{if(b>>>0>=256){b=ba(8)|0;v[22656]=0;c=Q(70,c|0,7993)|0;a=v[22656];v[22656]=0;if((a|0)==1){break c}rc(b,c);v[22656]=0;U(186,b|0,54952,1936);a=v[22656];v[22656]=0;if((a|0)!=1){break a}a=P()|0;O()|0;vb(c);break b}a=v[a+32>>2]+B(b,872)|0;v[a+1075008>>2]=0;v[a+1075068>>2]=0;gb=c+16|0;return}a=P()|0;O()|0;ca(b|0)}S(a|0)}L()}function pla(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;g=gb-608|0;gb=g;c=gb-32|0;gb=c;f=g;d=c+24|0;vU(d,g);h=yb(d);d=v[c+28>>2];e=v[c+24>>2];v[c+8>>2]=e;v[c+12>>2]=d;v[c>>2]=e;v[c+4>>2]=d;e=c+16|0;d=a;hd(e,d,c);e=yb(e);if((e|0)==(h|0)){bd(d,yb(c+24|0))}gb=c+32|0;d=(e|0)==(h|0);if(!d){tU(f)}f=-1;a:{if(!d){break a}f=0;if(!xU(g)){break a}f=Oe(a,b,wU(g),jb)}gb=g+608|0;return f|0}function p7(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0;c=gb-16|0;gb=c;g=v[a+4>>2];v[c+8>>2]=v[b+8>>2];d=v[b+4>>2];v[c>>2]=v[b>>2];v[c+4>>2]=d;bK(a,c);if(!(!v[b+8>>2]|z[a+24>>2]==C(1))){h=a+12|0;while(1){if(v[b+4>>2]){i=e+g|0;d=0;while(1){f=Xg(h,d,i);z[f>>2]=z[a+24>>2]*z[f>>2];d=d+1|0;if(d>>>0<y[b+4>>2]){continue}break}}e=e+1|0;if(e>>>0<y[b+8>>2]){continue}break}}gb=c+16|0}function hZ(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=gb-32|0;gb=d;v[a>>2]=0;v[a+4>>2]=0;e=a;if(!Pb(b,c)){c=nf(b)}v[e>>2]=c;c=v[b>>2];a:{if(kb[v[v[c>>2]+16>>2]](c)|0){c=a;a=v[b>>2];f=c,g=(kb[v[v[a>>2]+20>>2]](a)|0)+v[b+8>>2]|0,v[f+4>>2]=g;break a}c=a+8|0;Ok(c,v[a>>2]);if(cd(c)){break a}Vd(d+24|0,c);a=v[d+28>>2];v[d+8>>2]=v[d+24>>2];v[d+12>>2]=a;cc(d+16|0,b,d+8|0)}gb=d+32|0}function SF(a){var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;d=gb-16|0;gb=d;g=gb-16|0;gb=g;e=d+8|0;h=e;f=gb-16|0;gb=f;b=gb-16|0;gb=b;c=f;v[c+4>>2]=1;i=c,j=Mc(16,4),v[i+8>>2]=j;gb=b+16|0;b=v[c+8>>2];v[22656]=0;RF(b);b=v[22656];v[22656]=0;a:{if((b|0)!=1){b=Kp(c);Rw(h,dc(b),b);QF(c);gb=f+16|0;break a}a=P()|0;O()|0;QF(c);S(a|0);L()}gb=g+16|0;Xf(a,e);Kd(e);gb=d+16|0;v[a+8>>2]=0;Ud(a+12|0)}function Qoa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;g=gb-576|0;gb=g;c=gb-32|0;gb=c;f=g;d=c+24|0;tX(d,g);h=yb(d);d=v[c+28>>2];e=v[c+24>>2];v[c+8>>2]=e;v[c+12>>2]=d;v[c>>2]=e;v[c+4>>2]=d;e=c+16|0;d=a;hd(e,d,c);e=yb(e);if((e|0)==(h|0)){bd(d,yb(c+24|0))}gb=c+32|0;d=(e|0)==(h|0);if(!d){sX(f)}f=-1;a:{if(!d){break a}f=0;if(!wX(g)){break a}f=Oe(a,b,vX(g),jb)}gb=g+576|0;return f|0}function Joa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;g=gb-192|0;gb=g;c=gb-32|0;gb=c;f=g;d=c+24|0;Qr(d,g);h=yb(d);d=v[c+28>>2];e=v[c+24>>2];v[c+8>>2]=e;v[c+12>>2]=d;v[c>>2]=e;v[c+4>>2]=d;e=c+16|0;d=a;hd(e,d,c);e=yb(e);if((e|0)==(h|0)){bd(d,yb(c+24|0))}gb=c+32|0;d=(e|0)==(h|0);if(!d){TW(f)}f=-1;a:{if(!d){break a}f=0;if(!rX(g)){break a}f=Oe(a,b,qX(g),jb)}gb=g+192|0;return f|0}function F8(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=gb-48|0;gb=d;e=v[b+4>>2];b=v[b>>2];v[d+16>>2]=b;v[d+20>>2]=e;v[d+32>>2]=b;v[d+36>>2]=e;rh(d+40|0,d+16|0);b=Xf(d+24|0,c);v[22656]=0;e=v[d+44>>2];v[d+8>>2]=v[d+40>>2];v[d+12>>2]=e;e=v[b+4>>2];v[d>>2]=v[b>>2];v[d+4>>2]=e;W(207,a|0,d+8|0,d|0)|0;a=v[22656];v[22656]=0;if((a|0)!=1){Kd(c);gb=d+48|0;return}a=P()|0;O()|0;Kd(c);S(a|0);L()}function xJ(a,b,c){a=a|0;b=b|0;c=c|0;a=a^-1;if(c>>>0>3){while(1){a=v[((w[b|0]^a&255)<<2)+60160>>2]^a>>>8;a=a>>>8^v[((w[b+1|0]^a&255)<<2)+60160>>2];a=a>>>8^v[((w[b+2|0]^a&255)<<2)+60160>>2];a=a>>>8^v[((w[b+3|0]^a&255)<<2)+60160>>2];b=b+4|0;c=c-4|0;if(c>>>0>3){continue}break}}if(c){while(1){a=v[((w[b|0]^a&255)<<2)+60160>>2]^a>>>8;b=b+1|0;c=c-1|0;if(c){continue}break}}return a^-1}function tH(a,b,c){var d=0,e=0,f=0,g=0,h=0;h=gb-16|0;gb=h;e=gb-16|0;gb=e;d=a;a:{if(b>>>0<=1073741807){b:{if(b>>>0<=1){_e(d,b);f=d;break b}g=om(b)+1|0;f=Si(d,g);ef(d,f);rg(d,g);de(d,b)}g=f;c:{d:{d=b;if(d){v[22656]=0;DH(g,c,d);c=v[22656];v[22656]=0;if((c|0)==1){break d}}break c}V(0)|0;O()|0;Bb();L()}v[e+12>>2]=0;Ge((b<<2)+f|0,e+12|0);gb=e+16|0;break a}vg();L()}gb=h+16|0;return a}function lpa(a,b){a=a|0;b=b|0;var c=0,d=0;if(v[a+4>>2]!=v[wb(a)>>2]){d=gb-16|0;gb=d;c=Ai(d,a,1);wb(a);mp(v[c+4>>2],b);v[c+4>>2]=v[c+4>>2]+1;$b(c);gb=d+16|0;return}d=gb-32|0;gb=d;c=wb(a);c=Zg(d+8|0,qh(a,oc(a)+1|0),oc(a),c);mp(v[c+8>>2],b);v[c+8>>2]=v[c+8>>2]+1;v[22656]=0;R(396,a|0,c|0);a=v[22656];v[22656]=0;a:{if((a|0)!=1){be(c);gb=d+32|0;break a}a=P()|0;O()|0;be(c);S(a|0);L()}}function Uca(a){a=a|0;var b=0,c=0,d=0,e=0;c=gb-16|0;gb=c;v[v[a+20>>2]+148>>2]=-1;v[22656]=0;tn(c+8|0,a+4228|0);b=v[22656];v[22656]=0;a:{b:{if((b|0)!=1){b=v[a+20>>2];d=c+8|0;e=v[d>>2];d=v[d+4>>2];v[22656]=0;U(1667,b+4|0,e|0,d|0);b=v[22656];v[22656]=0;if((b|0)!=1){break b}}b=V(89116)|0;if((O()|0)!=(ea(89116)|0)){break a}Z(b|0)|0;yr(v[a+20>>2]+4|0);$()}gb=c+16|0;return}S(b|0);L()}function MJ(a,b){a=a|0;b=+b;var c=0,d=0;c=gb-16|0;gb=c;a:{b:{c:{if(b<=0|b>4){a=ba(8)|0;v[22656]=0;c=Q(70,c|0,4918)|0;d=v[22656];v[22656]=0;if((d|0)==1){break c}rc(a,c);v[22656]=0;U(186,a|0,54952,1936);a=v[22656];v[22656]=0;if((a|0)!=1){break a}d=P()|0;O()|0;vb(c);break b}d=Ah(65536/b);a=a+32|0;v[v[a>>2]+480244>>2]=d;yq(v[a>>2]);gb=c+16|0;return}d=P()|0;O()|0;ca(a|0)}S(d|0)}L()}function JJ(a,b){a=a|0;b=+b;var c=0,d=0;c=gb-16|0;gb=c;a:{b:{c:{if(b<=0|b>4){a=ba(8)|0;v[22656]=0;c=Q(70,c|0,4939)|0;d=v[22656];v[22656]=0;if((d|0)==1){break c}rc(a,c);v[22656]=0;U(186,a|0,54952,1936);a=v[22656];v[22656]=0;if((a|0)!=1){break a}d=P()|0;O()|0;vb(c);break b}d=Ah(b*65536);a=a+32|0;v[v[a>>2]+480240>>2]=d;yq(v[a>>2]);gb=c+16|0;return}d=P()|0;O()|0;ca(a|0)}S(d|0)}L()}function eka(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;g=gb-80|0;gb=g;c=gb-32|0;gb=c;f=g;d=c+24|0;_V(d,g);h=yb(d);d=v[c+28>>2];e=v[c+24>>2];v[c+8>>2]=e;v[c+12>>2]=d;v[c>>2]=e;v[c+4>>2]=d;e=c+16|0;d=a;hd(e,d,c);e=yb(e);if((e|0)==(h|0)){bd(d,yb(c+24|0))}gb=c+32|0;d=(e|0)==(h|0);if(!d){yC(f)}f=-1;a:{if(!d){break a}f=0;if(!cT(g)){break a}f=Oe(a,b,bT(g),jb)}gb=g+80|0;return f|0}function tG(a,b,c,d,e){var f=0,g=0,h=0,i=0;if(b>>>0>=d>>>0){if(!e){return d}d=a+d|0;h=a+b|0;b=h;f=gb-16|0;gb=f;e=(c+e|0)-c|0;a:{if(!e){b=d;break a}g=b-d|0;if((g|0)<(e|0)){break a}t[f+15|0]=w[c|0];i=1-e|0;while(1){d=tp(d,g+i|0,f+15|0);if(!d){break a}if(!Wo(d,c,e)){b=d;break a}d=d+1|0;g=b-d|0;if((g|0)>=(e|0)){continue}break}}gb=f+16|0;a=(b|0)==(h|0)?-1:b-a|0}else{a=-1}return a}function qma(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;g=gb-128|0;gb=g;c=gb-32|0;gb=c;f=g;d=c+24|0;eV(d,g);h=yb(d);d=v[c+28>>2];e=v[c+24>>2];v[c+8>>2]=e;v[c+12>>2]=d;v[c>>2]=e;v[c+4>>2]=d;e=c+16|0;d=a;hd(e,d,c);e=yb(e);if((e|0)==(h|0)){bd(d,yb(c+24|0))}gb=c+32|0;d=(e|0)==(h|0);if(!d){dV(f)}f=-1;a:{if(!d){break a}f=0;if(!hV(g)){break a}f=Oe(a,b,256,0)}gb=g+128|0;return f|0}function Xaa(a,b){a=a|0;b=b|0;var c=0;v[22656]=0;_(1934,a|0);c=v[22656];v[22656]=0;a:{b:{if((c|0)!=1){v[a+16>>2]=b;b=v[a+20>>2];if(!b){break b}Yb(b);v[a+20>>2]=0;return}b=V(0)|0;O()|0;Z(b|0)|0;v[22656]=0;Y(1911,2752,a|0,0,0);a=v[22656];v[22656]=0;if((a|0)==1){break a}$()}return}a=P()|0;O()|0;v[22656]=0;X(20);b=v[22656];v[22656]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}function Vda(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=gb-16|0;gb=d;c=sf(64);v[22656]=0;e=T(1316,c|0)|0;f=v[22656];v[22656]=0;a:{if((f|0)!=1){c=os(d,e);e=v[c>>2];v[22656]=0;a=W(1530,e|0,a|0,b|0)|0;b=v[22656];v[22656]=0;b:{c:{if((b|0)!=1){if((a|0)==1){break c}gA(d+8|0);break b}a=P()|0;O()|0;Jg(c);break a}pi(d+8|0,c)}Jg(c);gb=d+16|0;return v[d+8>>2]}a=P()|0;O()|0;Yb(c)}S(a|0);L()}function JI(a,b){var c=0,d=0;b=!v[a+24>>2]|b;v[a+16>>2]=b;if(b&v[a+20>>2]){c=gb-16|0;gb=c;b=ba(16)|0;a=gb-16|0;gb=a;a:{if(t[460856]&1){break a}if(!Qd(460856)){break a}Pd(460856)}td(a+8|0,1,90304);d=v[a+12>>2];c=c+8|0;v[c>>2]=v[a+8>>2];v[c+4>>2]=d;gb=a+16|0;v[22656]=0;Q(2294,b|0,c|0)|0;a=v[22656];v[22656]=0;if((a|0)!=1){ia(b|0,74440,2295);L()}a=P()|0;O()|0;ca(b|0);S(a|0);L()}}function tha(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;c=gb-16|0;gb=c;wb(a);v[c+12>>2]=268435455;v[22656]=0;v[c+8>>2]=2147483647;d=Fb(c+12|0,c+8|0);e=v[22656];v[22656]=0;a:{if((e|0)!=1){gb=c+16|0;c=v[d>>2];break a}V(0)|0;O()|0;Bb();L()}if(b>>>0>c>>>0){Sc();L()}wb(a);c=b;if(c>>>0>268435455){rd(8445);L()}c=Mc(c<<4,8);v[a>>2]=c;v[a+4>>2]=c;f=wb(a),g=c+(b<<4)|0,v[f>>2]=g;rI(a,0)}function tca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;b=Fi(a,b,c,d);v[a+4224>>2]=1049951732;c=a+4216|0;v[c>>2]=1065353216;v[c+4>>2]=1049951732;v[a+4208>>2]=1060320051;v[a+4212>>2]=1041865114;v[a>>2]=51464;v[22656]=0;W(1532,a+44|0,2,2)|0;c=v[22656];v[22656]=0;a:{if((c|0)==1){break a}v[22656]=0;Th(b);c=v[22656];v[22656]=0;if((c|0)==1){break a}return a|0}a=P()|0;O()|0;Lf(b);S(a|0);L()}function Cla(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=gb-16|0;gb=c;LU(a,c+11|0);if((w[c+11|0]|w[c+12|0]<<8|(w[c+13|0]<<16|w[c+14|0]<<24))==1414807888){LU(a,c+11|0);t[b|0]=1;a=0}else{a=1}b=gb-16|0;gb=b;a:{b:{a=(c+11|0)+a|0;if(a){a=Tb(b,a);v[22656]=0;d=T(865,a|0)|0;e=v[22656];v[22656]=0;if((e|0)==1){break b}vb(a)}gb=b+16|0;break a}b=P()|0;O()|0;vb(a);S(b|0);L()}gb=c+16|0;return d|0}function $Y(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=gb-32|0;gb=c;e=c+24|0;bc(e,b,10);e=yb(e);d=v[c+28>>2];f=v[c+24>>2];v[c+8>>2]=f;v[c+12>>2]=d;v[c>>2]=f;v[c+4>>2]=d;d=c+16|0;cc(d,a,c);d=yb(d);if((d|0)==(e|0)){Rb(a,yb(c+24|0))}gb=c+32|0;a=(d|0)==(e|0);if(!a){t[b|0]=0;t[b+1|0]=0;t[b+2|0]=0;t[b+3|0]=0;t[b+4|0]=0;t[b+5|0]=0;t[b+6|0]=0;t[b+7|0]=0;t[b+8|0]=0;t[b+9|0]=0}return a|0}function T3(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;if(y[a+4>>2]<y[wb(a)>>2]){yG(a,b);return}c=gb-32|0;gb=c;e=a;d=wb(a);a=us(c+8|0,bx(a,Ec(a)+1|0),Ec(a),d);f=v[a+8>>2];v[22656]=0;Pn(d,f,b);b=v[22656];v[22656]=0;a:{b:{if((b|0)==1){break b}v[a+8>>2]=v[a+8>>2]+12;v[22656]=0;On(e,a);b=v[22656];v[22656]=0;if((b|0)==1){break b}ts(a);gb=c+32|0;break a}b=P()|0;O()|0;ts(a);S(b|0);L()}}function SQ(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;if(y[a+4>>2]<y[wb(a)>>2]){yG(a,b);return}c=gb-32|0;gb=c;e=a;d=wb(a);a=us(c+8|0,bx(a,Ec(a)+1|0),Ec(a),d);f=v[a+8>>2];v[22656]=0;Pn(d,f,b);b=v[22656];v[22656]=0;a:{b:{if((b|0)==1){break b}v[a+8>>2]=v[a+8>>2]+12;v[22656]=0;On(e,a);b=v[22656];v[22656]=0;if((b|0)==1){break b}yu(a);gb=c+32|0;break a}b=P()|0;O()|0;yu(a);S(b|0);L()}}function vda(a,b){a=a|0;b=b|0;var c=C(0);a:{switch(b|0){case 0:return C(z[a+4220>>2]);case 1:return C(z[a+4224>>2]);case 2:return C(z[a+4228>>2]);case 3:return C(w[a+4240|0]?C(1):C(0));case 4:return C(C(C(v[a+4232>>2])*C(.03125)));case 5:return C(w[a+4241|0]?C(1):C(0));case 6:return C(w[a+4242|0]?C(1):C(0));case 7:c=w[a+4244|0]?C(1):C(0);break;default:break a}}return C(c)}function Rla(a,b){a=a|0;b=b|0;var c=0,d=0;if(v[a+4>>2]!=v[wb(a)>>2]){d=gb-16|0;gb=d;c=gw(d,a,1);wb(a);WU(v[c+4>>2],b);v[c+4>>2]=v[c+4>>2]+20;$b(c);gb=d+16|0;return}d=gb-32|0;gb=d;c=wb(a);c=iD(d+8|0,jD(a,Je(a)+1|0),Je(a),c);WU(v[c+8>>2],b);v[c+8>>2]=v[c+8>>2]+20;v[22656]=0;Ev(a,c);a=v[22656];v[22656]=0;a:{if((a|0)!=1){jp(c);gb=d+32|0;break a}a=P()|0;O()|0;jp(c);S(a|0);L()}}function TJ(a){var b=0,c=0,d=0,e=0,f=0,g=0,h=0;b=gb-32|0;gb=b;if(!w[a+20|0]){if(!(kb[v[v[a>>2]+40>>2]](a)|0)){d=a+4|0;while(1){SJ(a,65536);c=wd(b+16|0,lc(d,v[a+16>>2]),65536);e=v[v[a>>2]+44>>2];f=v[c+4>>2];v[b+8>>2]=v[c>>2];v[b+12>>2]=f;c=b+24|0;kb[e|0](c,a,b+8|0);g=a,h=yb(c)+v[a+16>>2]|0,v[g+16>>2]=h;if(!(kb[v[v[a>>2]+40>>2]](a)|0)){continue}break}}t[a+20|0]=1}gb=b+32|0}function _0(){var a=0;a:{if(t[464600]&1){break a}if(!Qd(464600)){break a}a=464432;while(1){a=Kb(a)+12|0;if((a|0)!=464600){continue}break}Pd(464600)}Xc(464432,2336);Xc(464444,2343);Xc(464456,2309);Xc(464468,2317);Xc(464480,2300);Xc(464492,2350);Xc(464504,2327);Xc(464516,6900);Xc(464528,7234);Xc(464540,8584);Xc(464552,10177);Xc(464564,2595);Xc(464576,8051);Xc(464588,3644)}function Mna(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;e=gb-16|0;gb=e;d=e;v[d>>2]=v[a+8>>2];f=v[a+8>>2];v[d+8>>2]=a+8;v[d+4>>2]=f+B(b,6);a:{if(v[d>>2]!=v[d+4>>2]){while(1){f=v[a+16>>2];b=v[d>>2];v[22656]=0;JC(f,b,c);b=v[22656];v[22656]=0;if((b|0)==1){break a}b=v[d>>2]+6|0;v[d>>2]=b;if((b|0)!=v[d+4>>2]){continue}break}}_c(d);gb=e+16|0;return}a=P()|0;O()|0;_c(d);S(a|0);L()}function tna(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=gb-16|0;gb=d;c=d;v[c>>2]=v[a+8>>2];e=v[a+8>>2];v[c+8>>2]=a+8;v[c+4>>2]=e+B(b,20);a:{if(v[c>>2]!=v[c+4>>2]){while(1){e=v[a+16>>2];b=v[c>>2];v[22656]=0;R(342,e|0,b|0);b=v[22656];v[22656]=0;if((b|0)==1){break a}b=v[c>>2]+20|0;v[c>>2]=b;if((b|0)!=v[c+4>>2]){continue}break}}_c(c);gb=d+16|0;return}a=P()|0;O()|0;_c(c);S(a|0);L()}function dca(a,b,c){a=a|0;b=b|0;c=C(c);var d=0;d=gb-16|0;gb=d;z[d+12>>2]=c;if((b|0)<=6){Hi(d+12|0);a:{b:{switch(b-1|0){default:c=z[d+12>>2];break a;case 0:c=fe(z[d+12>>2]);z[d+12>>2]=c;if(z[a+4212>>2]==c){break a}v[a+4236>>2]=0;z[a+4240>>2]=C(c*C(.5))+C(.5);break a;case 3:break b}}c=C(fe(C(z[d+12>>2]*C(4)))*C(.25));z[d+12>>2]=c}z[((b<<2)+a|0)+4208>>2]=c;bz(a)}gb=d+16|0}function aga(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=gb-32|0;gb=d;a:{a=v[a+1298424>>2];b:{if(a){kb[v[v[a>>2]+8>>2]](a,b,c);break b}v[d+8>>2]=0;if(!LF(iu(d+8|0),b)){break b}v[d+8>>2]=0;e=d+8|0;iu(e);v[d+24>>2]=0;a=iu(d+24|0);WO(e,6310,8124,133,42);v[22656]=0;ha(33,a|0,e|0,b|0,10590,c|0);a=v[22656];v[22656]=0;if((a|0)==1){break a}}gb=d+32|0;return}a=P()|0;O()|0;S(a|0);L()}function Kca(a,b,c){a=a|0;b=b|0;c=C(c);var d=0;d=gb-16|0;gb=d;z[d+12>>2]=c;if((b|0)<=6){Hi(d+12|0);a:{b:{switch(b-3|0){default:c=z[d+12>>2];break a;case 0:c=fe(z[d+12>>2]);z[d+12>>2]=c;if(z[a+4220>>2]==c){break a}v[a+4236>>2]=0;z[a+4240>>2]=C(c*C(.5))+C(.5);break a;case 1:break b}}c=C(fe(C(z[d+12>>2]*C(4)))*C(.25));z[d+12>>2]=c}z[((b<<2)+a|0)+4208>>2]=c;bz(a)}gb=d+16|0}function vA(a,b,c,d){a:{if(v[a+1074392>>2]!=(c|0)){break a}b:{if(d){c=B(b,872)+a|0;v[c+1075688>>2]=0;d=c+1075e3|0;v[d>>2]=0;v[d+4>>2]=0;d=c+1075080|0;c=v[d>>2]|4096;v[d>>2]=c;break b}c=B(b,872)+a|0;v[c+1075680>>2]=0;c=v[c+1075080>>2]}d=B(b,872)+a|0;v[d+1075080>>2]=c|2097152;Mm(a,b,255,0);if(!(w[d+1075081|0]&2)){break a}a=a+1298260|0;if(!Dd(a)){break a}Oi(v[a>>2],b,0)}}function $I(a,b){a:{if((b|0)>=128){a=C(a*C(1.7014118346046923e38));if(b>>>0<255){b=b-127|0;break a}a=C(a*C(1.7014118346046923e38));b=(b>>>0<381?b:381)-254|0;break a}if((b|0)>-127){break a}a=C(a*C(1.1754943508222875e-38));if(b>>>0>4294967043){b=b+126|0;break a}a=C(a*C(1.1754943508222875e-38));b=(b>>>0>4294966918?b:-378)+252|0}return C(a*(l(2,(b<<23)+1065353216|0),q()))}function wD(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0;e=gb-16|0;gb=e;f=Vb(b);g=Zb(b);d=gb-32|0;gb=d;v[d+16>>2]=g;v[d+24>>2]=f;v[d+8>>2]=c;if(Gb(d+24|0,d+16|0)){while(1){if(!pD(d+8|0,v[d+24>>2])){c=d+24|0;pn(c);if(Gb(c,d+16|0)){continue}}break}f=v[d+24>>2]}gb=d+32|0;v[e+8>>2]=f;h=e,i=Zb(b),v[h>>2]=i;a:{if(Sj(e+8|0,e)){Jh(a);break a}rn(a,v[e+8>>2])}gb=e+16|0}function kq(a,b){var c=0,d=0,e=0,f=0;if(y[a+4>>2]<y[wb(a)>>2]){oM(a,b);return}c=gb-32|0;gb=c;e=a;d=wb(a);a=Zg(c+8|0,qh(a,oc(a)+1|0),oc(a),d);f=v[a+8>>2];v[22656]=0;rl(d,f,b);b=v[22656];v[22656]=0;a:{b:{if((b|0)==1){break b}v[a+8>>2]=v[a+8>>2]+1;v[22656]=0;R(120,e|0,a|0);b=v[22656];v[22656]=0;if((b|0)==1){break b}be(a);gb=c+32|0;break a}b=P()|0;O()|0;be(a);S(b|0);L()}}function Waa(a){a=a|0;var b=0;v[22656]=0;_(1934,a|0);b=v[22656];v[22656]=0;a:{b:{if((b|0)!=1){v[a+16>>2]=0;b=v[a+20>>2];if(!b){break b}Yb(b);v[a+20>>2]=0;return}b=V(0)|0;O()|0;Z(b|0)|0;v[22656]=0;Y(1911,6047,a|0,0,0);a=v[22656];v[22656]=0;if((a|0)==1){break a}$()}return}a=P()|0;O()|0;v[22656]=0;X(20);b=v[22656];v[22656]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}function Pq(a){var b=0,c=0,d=0,e=0,f=0,g=0,h=0;c=gb-16|0;gb=c;e=Vb(a);f=Zb(a);b=gb-16|0;gb=b;v[b>>2]=f;v[b+8>>2]=e;if(Gb(b+8|0,b)){while(1){e=b+8|0;d=d+A[v[e>>2]>>3];Eu(e);if(Gb(e,b)){continue}break}}gb=b+16|0;g=c,h=Vb(a),v[g+8>>2]=h;g=c,h=Zb(a),v[g>>2]=h;if(Gb(c+8|0,c)){d=-d;while(1){a=c+8|0;b=v[a>>2];d=d+A[b>>3];A[b>>3]=d;Eu(a);if(Gb(a,c)){continue}break}}gb=c+16|0}function ul(a,b,c){var d=0,e=0,f=0,g=0,h=0;e=gb-16|0;gb=e;v[e+8>>2]=c;a:{if((a|0)==(b|0)){break a}while(1){c=gb-32|0;gb=c;f=uc(c+24|0,v[a>>2]);d=v[e+8>>2];g=v[d+4>>2];d=v[d>>2];v[c+16>>2]=d;v[c+20>>2]=g;h=v[f+4>>2];v[c+8>>2]=v[f>>2];v[c+12>>2]=h;v[c>>2]=d;v[c+4>>2]=g;f=Gc(c+8|0,c);gb=c+32|0;if(f){break a}a=a+8|0;if((b|0)!=(a|0)){continue}break}a=b}gb=e+16|0;return a}function uB(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;e=gb-32|0;gb=e;v[e+8>>2]=c;f=e,g=nf(b),v[f+28>>2]=g;c=e+8|0;Re(c,b,v[Fb(c,e+28|0)>>2]);v[22656]=0;b=Sd(c);c=v[22656];v[22656]=0;a:{if((c|0)==1){break a}c=v[e+8>>2];v[22656]=0;da(908,a|0,b|0,c|0,d|0)|0;a=v[22656];v[22656]=0;if((a|0)==1){break a}zc(e+8|0);gb=e+32|0;return 1}a=P()|0;O()|0;zc(e+8|0);S(a|0);L()}function kN(a,b){var c=0,d=0,e=0,f=C(0),g=0,h=C(0);c=gb-16|0;gb=c;e=0;a:{if(!_f(v[v[a>>2]-12>>2]+a|0)){break a}v[c+12>>2]=0;Ik(a,c+12|0);d=v[c+12>>2];e=0;if(d>>>0>65535){break a}El(b,d);if(v[c+12>>2]){d=0;while(1){v[c+8>>2]=0;mq(a,c+8|0);f=z[c+8>>2];g=Mb(b,d),h=f,z[g>>2]=h;d=d+1|0;if(d>>>0<y[c+12>>2]){continue}break}}e=_f(v[v[a>>2]-12>>2]+a|0)}d=e;gb=c+16|0;return d}function jN(a,b){var c=0,d=0,e=0,f=C(0),g=0,h=C(0);c=gb-16|0;gb=c;e=0;a:{if(!_f(v[v[a>>2]-12>>2]+a|0)){break a}u[c+14>>1]=0;ag(a,c+14|0);d=x[c+14>>1];e=0;if(d>>>0>65535){break a}El(b,d);if(x[c+14>>1]){d=0;while(1){v[c+8>>2]=0;mq(a,c+8|0);f=z[c+8>>2];g=Mb(b,d),h=f,z[g>>2]=h;d=d+1|0;if(d>>>0<x[c+14>>1]){continue}break}}e=_f(v[v[a>>2]-12>>2]+a|0)}a=e;gb=c+16|0;return a}function _la(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;f=gb-1120|0;gb=f;d=gb-32|0;gb=d;c=d+24|0;YU(c,f+8|0);g=yb(c);c=v[d+28>>2];e=v[d+24>>2];v[d+8>>2]=e;v[d+12>>2]=c;v[d>>2]=e;v[d+4>>2]=c;e=d+16|0;c=a;hd(e,c,d);e=yb(e);if((e|0)==(g|0)){bd(c,yb(d+24|0))}gb=d+32|0;c=-1;a:{if((e|0)!=(g|0)){break a}c=0;if(!$U(f+8|0)){break a}c=Oe(a,b,_U(f+8|0),jb)}gb=f+1120|0;return c|0}function Dm(a){if((a|0)>=0){if(a>>>0<=16383){if(a>>>0<=15){return t[a+69712|0]}if(a>>>0<=511){return t[(a>>>5|0)+69712|0]+5|0}return t[(a>>>10|0)+69712|0]+10|0}if(a>>>0<=16777215){if(a>>>0<=524287){return t[(a>>>15|0)+69712|0]+15|0}return t[(a>>>20|0)+69712|0]+20|0}if(a>>>0<=536870911){return t[(a>>>25|0)+69712|0]+25|0}a=t[(a>>>30|0)+69712|0]+30|0}else{a=0}return a}function DA(a,b,c,d){var e=0,f=0;e=gb-32|0;gb=e;a:{if(v[b+480180>>2]&64671904){b=w[c+4|0];t[e+31|0]=0;u[a>>1]=w[(b&15)+39104|0];t[a+2|0]=w[e+31|0];break a}t[e+30|0]=0;f=w[c+4|0];if(!(w[c+3|0]!=4|v[b+480180>>2]!=4)){t[e+30|0]=1;f=f<<1}c=e+16|0;Db(c,b+1074312|0,66);if(!(!Cb(c)|!d)){u[e+14>>1]=0;AC(a,e+14|0,e+30|0);break a}u[e+12>>1]=f<<4;AC(a,e+12|0,e+30|0)}gb=e+32|0}function Yaa(a){a=a|0;var b=0;v[22656]=0;_(1934,a|0);b=v[22656];v[22656]=0;a:{b:{if((b|0)!=1){a=v[a+20>>2];if(!a){break b}return ie(a)|0}b=V(0)|0;O()|0;Z(b|0)|0;v[22656]=0;Y(1911,9429,a|0,0,0);a=v[22656];v[22656]=0;if((a|0)==1){break a}$();return 0}return ie(18726)|0}a=P()|0;O()|0;v[22656]=0;X(20);b=v[22656];v[22656]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}function tea(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;e=gb-16|0;gb=e;d=e;v[d>>2]=v[a+8>>2];f=v[a+8>>2];v[d+8>>2]=a+8;v[d+4>>2]=B(b,52)+f;a:{a=v[d>>2];if((a|0)!=v[d+4>>2]){while(1){v[22656]=0;R(1488,a|0,c|0);a=v[22656];v[22656]=0;if((a|0)==1){break a}a=v[d>>2]+52|0;v[d>>2]=a;if(v[d+4>>2]!=(a|0)){continue}break}}_c(d);gb=e+16|0;return}a=P()|0;O()|0;_c(d);S(a|0);L()}function c3(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0;e=gb-16|0;gb=e;f=v[fc(a)>>2];d=v[c>>2]-v[a>>2]|0;a:{if(d>>>0<2147483647){d=d<<1;break a}d=-1}d=d?d:4;h=v[b>>2];i=v[a>>2];g=Vp((f|0)==2479?0:v[a>>2],d);if(g){if((f|0)!=2479){ce(a)}v[e+4>>2]=2428;f=ge(e+8|0,g,e+4|0);fH(a,f);Ic(f);v[b>>2]=v[a>>2]+(h-i|0);v[c>>2]=v[a>>2]+(d&-4);gb=e+16|0;return}Gs();L()}function bz(a){var b=C(0),c=C(0),d=0,e=C(0),f=0;b=C(wf(v[a+16>>2])>>>0);c=C(C(C(kb[v[v[a>>2]+204>>2]](a))*b)/C(1e3));d=a,e=C(C(c*C(kb[v[v[a>>2]+196>>2]](a)))*C(2048)),z[d+4248>>2]=e;d=a,f=Xh(C(C(c+C(2))*C(4096))),v[d+4256>>2]=f;c=C(kb[v[v[a>>2]+208>>2]](a));z[a+4252>>2]=c;b=C(c/b);if(!(kb[v[v[a>>2]+192>>2]](a)|0)){b=AG(C(b*C(3.1415927410125732)))}z[a+4244>>2]=b+b}function c7(a,b){a=a|0;b=b|0;var c=0,d=0;d=gb-16|0;gb=d;Jp(a);v[a>>2]=59232;c=v[b+12>>2];v[d+8>>2]=v[b+8>>2];v[d+12>>2]=c;c=v[b+4>>2];v[d>>2]=v[b>>2];v[d+4>>2]=c;c=dc(a);Ip(c);v[c>>2]=59596;mc(c+4|0);t[c+20|0]=0;v[c+16>>2]=0;v[c>>2]=59396;b=v[d+4>>2];v[c+24>>2]=v[d>>2];v[c+28>>2]=b;b=v[d+12>>2];v[c+32>>2]=v[d+8>>2];v[c+36>>2]=b;t[c+40|0]=0;gb=d+16|0;return a|0}function WF(a,b){var c=0,d=0,e=0,f=0;c=gb-16|0;gb=c;v[c+12>>2]=b;d=b;b=gb-16|0;gb=b;wb(a);v[b+12>>2]=119304647;v[22656]=0;v[b+8>>2]=2147483647;e=Fb(b+12|0,b+8|0);f=v[22656];v[22656]=0;a:{if((f|0)!=1){gb=b+16|0;b=v[e>>2];break a}V(0)|0;O()|0;Bb();L()}if(b>>>0>=d>>>0){a=$k(a);if(a>>>0<b>>>1>>>0){v[c+8>>2]=a<<1;b=v[Lc(c+8|0,c+12|0)>>2]}gb=c+16|0;return b}Sc();L()}function JU(a){var b=0,c=0,d=0;a:{if((w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24))!=-28486832|w[a+63|0]!=26|(w[a+66|0]|w[a+65|0]!=16&w[a+65|0]!=1)){break a}if(w[a- -64|0]&3){break a}b=a+78|0;if((w[b|0]|w[b+1|0]<<8)>>>0>127){break a}a=a+80|0;if((w[a|0]|w[a+1|0]<<8)>>>0>127){break a}c=gb-16|0;gb=c;d=uE(b,a);gb=c+16|0;a=d?a:b;c=(w[a|0]|w[a+1|0]<<8)!=0}return c}function vka(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;c=gb-16|0;gb=c;v[c+12>>2]=119304647;v[22656]=0;v[c+8>>2]=2147483647;d=Fb(c+12|0,c+8|0);e=v[22656];v[22656]=0;a:{if((e|0)!=1){gb=c+16|0;c=v[d>>2];break a}V(0)|0;O()|0;Bb();L()}if(b>>>0>c>>>0){Sc();L()}c=b;if(c>>>0>=119304648){rd(8445);L()}c=Mc(B(c,36),4);v[a>>2]=c;v[a+4>>2]=c;f=wb(a),g=c+B(b,36)|0,v[f>>2]=g}function jfa(a){a=a|0;var b=0,c=0,d=0,e=0;b=gb-48|0;gb=b;t[b+39|0]=0;t[b+40|0]=0;t[b+41|0]=0;t[b+42|0]=0;t[b+43|0]=0;t[b+44|0]=0;t[b+45|0]=0;t[b+46|0]=0;v[b+32>>2]=0;v[b+36>>2]=0;c=wd(b+16|0,b+32|0,15);d=v[c+4>>2];v[b+8>>2]=v[c>>2];v[b+12>>2]=d;c=b+24|0;cc(c,a,b+8|0);a:{if((yb(c)|0)!=15){break a}if(sd(b+32|0,5672,15)){break a}Rb(a,15);e=1}gb=b+48|0;return e|0}function iY(a,b){var c=0,d=0,e=0,f=0;c=gb-16|0;gb=c;v[c+12>>2]=b;d=b;b=gb-16|0;gb=b;wb(a);v[b+12>>2]=89478485;v[22656]=0;v[b+8>>2]=2147483647;e=Fb(b+12|0,b+8|0);f=v[22656];v[22656]=0;a:{if((f|0)!=1){gb=b+16|0;b=v[e>>2];break a}V(0)|0;O()|0;Bb();L()}if(b>>>0>=d>>>0){a=mn(a);if(a>>>0<b>>>1>>>0){v[c+8>>2]=a<<1;b=v[Lc(c+8|0,c+12|0)>>2]}gb=c+16|0;return b}Sc();L()}function Gq(a,b,c,d){a:{if(v[a+480180>>2]==4){if(c){t[b+810|0]=w[b+810|0]&15|c<<4;break a}c=w[b+810|0]>>>4|0;break a}if(d){if(c){t[b+834|0]=c;break a}c=w[b+834|0];break a}if(c){t[b+810|0]=c;break a}c=w[b+810|0]}b:{if(!(t[b+851|0]&1)){break b}c=v[b+688>>2]+((c&255)<<2)|0;v[b+688>>2]=(c|0)<256?c:256;if(!(v[a+480180>>2]&1)){break b}v[b+88>>2]=v[b+88>>2]|2097152}}function npa(a){a=a|0;var b=0,c=0,d=0,e=0;c=vh(a);v[22656]=0;_(517,a|0);d=v[22656];v[22656]=0;if((d|0)!=1){d=gb-16|0;gb=d;c=d;v[c>>2]=a;b=v[a+4>>2];v[c+4>>2]=b;v[c+8>>2]=b+32768;b=v[c+4>>2];e=v[c+8>>2];if((b|0)!=(e|0)){while(1){u[b>>1]=0;u[b+2>>1]=0;b=b+4|0;v[c+4>>2]=b;if((b|0)!=(e|0)){continue}break}}$b(c);gb=d+16|0;return a|0}a=P()|0;O()|0;mD(c);S(a|0);L()}function d3(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0;e=gb-16|0;gb=e;f=v[fc(a)>>2];d=v[c>>2]-v[a>>2]|0;a:{if(d>>>0<2147483647){d=d<<1;break a}d=-1}d=d?d:1;h=v[b>>2];i=v[a>>2];g=Vp((f|0)==2479?0:v[a>>2],d);if(g){if((f|0)!=2479){ce(a)}v[e+4>>2]=2428;f=ge(e+8|0,g,e+4|0);fH(a,f);Ic(f);v[b>>2]=v[a>>2]+(h-i|0);v[c>>2]=d+v[a>>2];gb=e+16|0;return}Gs();L()}function tka(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;c=gb-16|0;gb=c;v[c+12>>2]=4925421;v[22656]=0;v[c+8>>2]=2147483647;d=Fb(c+12|0,c+8|0);e=v[22656];v[22656]=0;a:{if((e|0)!=1){gb=c+16|0;c=v[d>>2];break a}V(0)|0;O()|0;Bb();L()}if(b>>>0>c>>>0){Sc();L()}c=b;if(c>>>0>=4925422){rd(8445);L()}c=Mc(B(c,872),8);v[a>>2]=c;v[a+4>>2]=c;f=wb(a),g=c+B(b,872)|0,v[f>>2]=g}function tL(a,b,c){var d=0,e=0,f=0;d=gb-16|0;gb=d;v[d+8>>2]=c;a:{if((a|0)==(b|0)){break a}while(1){c=v[d+8>>2];b:{c:{e=v[a>>2];f=Nf(e);if((f|0)==(Ab(c)|0)){v[22656]=0;c=fa(552,c|0,0,-1,e|0,f|0)|0;e=v[22656];v[22656]=0;if((e|0)==1){break c}c=!c}else{c=0}break b}V(0)|0;O()|0;Bb();L()}if(c){break a}a=a+8|0;if((b|0)!=(a|0)){continue}break}a=b}gb=d+16|0;return a}function Uka(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;c=gb-16|0;gb=c;v[c+12>>2]=477218588;v[22656]=0;v[c+8>>2]=2147483647;d=Fb(c+12|0,c+8|0);e=v[22656];v[22656]=0;a:{if((e|0)!=1){gb=c+16|0;c=v[d>>2];break a}V(0)|0;O()|0;Bb();L()}if(b>>>0>c>>>0){Sc();L()}c=b;if(c>>>0>=477218589){rd(8445);L()}c=Mc(B(c,9),1);v[a>>2]=c;v[a+4>>2]=c;f=wb(a),g=c+B(b,9)|0,v[f>>2]=g}function HJ(a,b){a=a|0;b=+b;var c=0,d=0;c=gb-16|0;gb=c;a:{b:{c:{if(b<0|b>1){a=ba(8)|0;v[22656]=0;c=Q(70,c|0,9006)|0;d=v[22656];v[22656]=0;if((d|0)==1){break c}rc(a,c);v[22656]=0;U(186,a|0,54952,1936);a=v[22656];v[22656]=0;if((a|0)!=1){break a}d=P()|0;O()|0;vb(c);break b}d=Ah(b*256);v[v[a+32>>2]+1074456>>2]=d;gb=c+16|0;return}d=P()|0;O()|0;ca(a|0)}S(d|0)}L()}function Fpa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;c=gb-16|0;gb=c;v[c+12>>2]=715827882;v[22656]=0;v[c+8>>2]=2147483647;d=Fb(c+12|0,c+8|0);e=v[22656];v[22656]=0;a:{if((e|0)!=1){gb=c+16|0;c=v[d>>2];break a}V(0)|0;O()|0;Bb();L()}if(b>>>0>c>>>0){Sc();L()}c=b;if(c>>>0>=715827883){rd(8445);L()}c=Mc(B(c,6),1);v[a>>2]=c;v[a+4>>2]=c;f=wb(a),g=c+B(b,6)|0,v[f>>2]=g}function Vla(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=gb-32|0;gb=c;Eg(c+24|0,a);ZU(c+16|0,b);a=v[c+28>>2];v[c+8>>2]=v[c+24>>2];v[c+12>>2]=a;a=v[c+20>>2];v[c>>2]=v[c+16>>2];v[c+4>>2]=a;b=gb-16|0;gb=b;a=1;d=c;e=c+8|0;if(v[e+4>>2]==v[c+4>>2]){f=v[d+4>>2];a=b;d=v[d>>2];v[a>>2]=d;v[a+4>>2]=f;v[a+8>>2]=d;v[a+12>>2]=f;a=(HW(e,a)|0)!=0}gb=b+16|0;gb=c+32|0;return a|0}function TE(a,b){var c=0,d=0,e=0,f=0;c=gb-16|0;gb=c;if(b>>>0<5){a:{if(!b){break a}if(!Pb(a,b)){break a}while(1){t[c+11|0]=0;f=(c+12|0)+d|0;if(b>>>0>d>>>0){Ng(a,c+11|0);e=w[c+11|0]}else{e=0}t[f|0]=e;d=d+1|0;if((d|0)!=4){continue}break}v[c+4>>2]=v[c+12>>2];a=c+4|0;d=w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24)}gb=c+16|0;return d}aa(8513,6236,136,11437);L()}function NJ(a,b){a=a|0;b=b|0;var c=0;c=gb-16|0;gb=c;a:{b:{c:{if(b-32>>>0>=481){b=ba(8)|0;v[22656]=0;c=Q(70,c|0,6520)|0;a=v[22656];v[22656]=0;if((a|0)==1){break c}rc(b,c);v[22656]=0;U(186,b|0,54952,1936);a=v[22656];v[22656]=0;if((a|0)!=1){break a}a=P()|0;O()|0;vb(c);break b}v[v[a+32>>2]+1074420>>2]=B(b,1e4);gb=c+16|0;return}a=P()|0;O()|0;ca(b|0)}S(a|0)}L()}function MY(a,b){var c=0,d=0,e=0,f=0;c=gb-16|0;gb=c;v[c+12>>2]=b;d=b;b=gb-16|0;gb=b;v[b+12>>2]=2147483647;v[22656]=0;v[b+8>>2]=2147483647;e=Fb(b+12|0,b+8|0);f=v[22656];v[22656]=0;a:{if((f|0)!=1){gb=b+16|0;b=v[e>>2];break a}V(0)|0;O()|0;Bb();L()}if(b>>>0>=d>>>0){a=Pg(a);if(a>>>0<b>>>1>>>0){v[c+8>>2]=a<<1;b=v[Lc(c+8|0,c+12|0)>>2]}gb=c+16|0;return b}Sc();L()}function rO(a,b){var c=0,d=0;a:{if(x[a+480188>>1]<=b>>>0){break a}b:{c:{c=B(b,872)+a|0;d=w[c+1075783|0];switch(d-31|0){case 1:break b;case 0:break c;default:break a}}if(!(w[a+480209|0]&16)){break a}}c=t[c+1075785|0];if((c|0)>=0){kP(a,b,(d|0)==32,((w[(B(b,872)+a|0)+1075836|0]<<5)+a|0)+901692|0,c&255);return}kP(a,b,(d|0)==32,(((c&127)<<5)+a|0)+902204|0,0)}}function UB(a,b){var c=0,d=0,e=0,f=0;c=gb-16|0;gb=c;v[c+12>>2]=b;d=b;b=gb-16|0;gb=b;v[b+12>>2]=357913941;v[22656]=0;v[b+8>>2]=2147483647;e=Fb(b+12|0,b+8|0);f=v[22656];v[22656]=0;a:{if((f|0)!=1){gb=b+16|0;b=v[e>>2];break a}V(0)|0;O()|0;Bb();L()}if(b>>>0>=d>>>0){a=ug(a);if(a>>>0<b>>>1>>>0){v[c+8>>2]=a<<1;b=v[Lc(c+8|0,c+12|0)>>2]}gb=c+16|0;return b}Sc();L()}function JY(a,b){var c=0,d=0,e=0,f=0;c=gb-16|0;gb=c;v[c+12>>2]=b;d=b;b=gb-16|0;gb=b;v[b+12>>2]=153391689;v[22656]=0;v[b+8>>2]=2147483647;e=Fb(b+12|0,b+8|0);f=v[22656];v[22656]=0;a:{if((f|0)!=1){gb=b+16|0;b=v[e>>2];break a}V(0)|0;O()|0;Bb();L()}if(b>>>0>=d>>>0){a=$i(a);if(a>>>0<b>>>1>>>0){v[c+8>>2]=a<<1;b=v[Lc(c+8|0,c+12|0)>>2]}gb=c+16|0;return b}Sc();L()}function Voa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;f=gb-224|0;gb=f;d=gb-32|0;gb=d;c=d+24|0;AX(c,f);g=yb(c);c=v[d+28>>2];e=v[d+24>>2];v[d+8>>2]=e;v[d+12>>2]=c;v[d>>2]=e;v[d+4>>2]=c;e=d+16|0;c=a;hd(e,c,d);e=yb(e);if((e|0)==(g|0)){bd(c,yb(d+24|0))}gb=d+32|0;c=-1;a:{if((e|0)!=(g|0)){break a}c=0;if(!EX(f)){break a}c=Oe(a,b,DX(f),jb)}gb=f+224|0;return c|0}function tz(a,b,c,d){var e=0,f=0;a:{e=w[a|0];f=w[c|0];b:{if(!(w[d|0]|((e|0)!=11|(f-5&255)>>>0>1))){t[a|0]=(f|0)==5?7:6;break b}if((f|0)==11){if(w[b|0]|(e-5&255)>>>0>1){break a}t[a|0]=(e|0)==5?7:6;t[b|0]=w[d|0];break b}if(!((e|0)!=10|(f|0)!=20|w[d|0]!=159)){t[a|0]=42;break b}if(w[b|0]!=159|(f|0)!=10|(e|0)!=20){break a}t[a|0]=42;t[b|0]=w[d|0]}t[c|0]=0}}function eE(a){var b=0,c=0,d=0,e=0,f=0;b=a+9|0;d=w[b|0]|w[b+1|0]<<8;c=kqa(w[a+3|0],0,18,0);d=d+c|0;b=jb;b=c>>>0>d>>>0?b+1|0:b;c=d;d=b;f=c;b=a+6|0;c=w[b|0]|w[b+1|0]<<8;b=c>>>31|0;e=c<<1;c=f+e|0;b=b+d|0;b=c>>>0<e>>>0?b+1|0:b;d=b;a=a+4|0;a=w[a|0]|w[a+1|0]<<8;b=a>>>30|0;e=a<<2;c=e+c|0;a=b+d|0;a=c>>>0<e>>>0?a+1|0:a;b=c+3|0;a=b>>>0<3?a+1|0:a;jb=a;return b}function OJ(a,b){a=a|0;b=b|0;var c=0;c=gb-16|0;gb=c;a:{b:{c:{if(b-1>>>0>=65535){b=ba(8)|0;v[22656]=0;c=Q(70,c|0,2940)|0;a=v[22656];v[22656]=0;if((a|0)==1){break c}rc(b,c);v[22656]=0;U(186,b|0,54952,1936);a=v[22656];v[22656]=0;if((a|0)!=1){break a}a=P()|0;O()|0;vb(c);break b}v[v[a+32>>2]+1074416>>2]=b;gb=c+16|0;return}a=P()|0;O()|0;ca(b|0)}S(a|0)}L()}function Ada(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=gb-16|0;gb=d;c=d;v[c>>2]=v[a+8>>2];e=v[a+8>>2];v[c+8>>2]=a+8;v[c+4>>2]=(b<<11)+e;a:{if(v[c>>2]!=v[c+4>>2]){while(1){a=v[c>>2];v[22656]=0;fz(a);a=v[22656];v[22656]=0;if((a|0)==1){break a}a=v[c>>2]+2048|0;v[c>>2]=a;if((a|0)!=v[c+4>>2]){continue}break}}_c(c);gb=d+16|0;return}a=P()|0;O()|0;_c(c);S(a|0);L()}function x7(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=C(0),g=0,h=0;c=gb-16|0;gb=c;f=z[a+24>>2];if(!(!v[b+8>>2]|f==C(1))){h=+f;while(1){d=0;if(v[b+4>>2]){while(1){g=Wg(b,d,e);A[g>>3]=A[g>>3]*h;d=d+1|0;if(d>>>0<y[b+4>>2]){continue}break}}e=e+1|0;if(e>>>0<y[b+8>>2]){continue}break}}v[c+8>>2]=v[b+8>>2];d=v[b+4>>2];v[c>>2]=v[b>>2];v[c+4>>2]=d;gK(a,c);gb=c+16|0}function u7(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=C(0),g=0,h=0;c=gb-16|0;gb=c;f=z[a+24>>2];if(!(!v[b+8>>2]|f==C(1))){h=+f;while(1){d=0;if(v[b+4>>2]){while(1){g=Wg(b,d,e);A[g>>3]=A[g>>3]*h;d=d+1|0;if(d>>>0<y[b+4>>2]){continue}break}}e=e+1|0;if(e>>>0<y[b+8>>2]){continue}break}}v[c+8>>2]=v[b+8>>2];d=v[b+4>>2];v[c>>2]=v[b>>2];v[c+4>>2]=d;eK(a,c);gb=c+16|0}function sea(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0;b=gb-16|0;gb=b;u[a>>1]=0;c=mc(a+4|0);d=mc(a+16|0);v[a+36>>2]=0;e=Kb(a+40|0);f=Jk(a+52|0);Gg(c);u[a+28>>1]=65472;v[22656]=0;v[b+12>>2]=1065353216;R(1498,c|0,b+12|0);g=v[22656];v[22656]=0;if((g|0)!=1){v[a+32>>2]=0;u[a+30>>1]=0;Gg(d);gb=b+16|0;return a|0}a=P()|0;O()|0;XW(f);vb(e);Nc(d);Nc(c);S(a|0);L()}function o7(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=C(0),g=0,h=0;c=gb-16|0;gb=c;f=z[a+24>>2];if(!(!v[b+8>>2]|f==C(1))){h=+f;while(1){d=0;if(v[b+4>>2]){while(1){g=Wg(b,d,e);A[g>>3]=A[g>>3]*h;d=d+1|0;if(d>>>0<y[b+4>>2]){continue}break}}e=e+1|0;if(e>>>0<y[b+8>>2]){continue}break}}v[c+8>>2]=v[b+8>>2];d=v[b+4>>2];v[c>>2]=v[b>>2];v[c+4>>2]=d;aK(a,c);gb=c+16|0}function _aa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;v[22656]=0;_(1934,a|0);d=v[22656];v[22656]=0;if((d|0)!=1){v[a+16>>2]=0;v[a+12>>2]=c;v[a+8>>2]=b;return}b=V(0)|0;O()|0;Z(b|0)|0;v[22656]=0;Y(1911,10383,a|0,0,0);a=v[22656];v[22656]=0;if((a|0)!=1){$();return}a=P()|0;O()|0;v[22656]=0;X(20);b=v[22656];v[22656]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}function Vn(a,b,c){var d=0,e=0,f=0;e=gb-16|0;gb=e;d=e+8|0;Fc(d,b);v[22656]=0;b=T(2453,d|0)|0;d=v[22656];v[22656]=0;a:{if((d|0)==1){break a}v[22656]=0;d=T(2462,b|0)|0;f=v[22656];v[22656]=0;if((f|0)==1){break a}v[c>>2]=d;v[22656]=0;R(2463,a|0,b|0);a=v[22656];v[22656]=0;if((a|0)==1){break a}Wb(e+8|0);gb=e+16|0;return}a=P()|0;O()|0;Wb(e+8|0);S(a|0);L()}function D7(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=C(0),g=0,h=0;c=gb-16|0;gb=c;f=z[a+24>>2];if(!(!v[b+8>>2]|f==C(1))){h=+f;while(1){d=0;if(v[b+4>>2]){while(1){g=Wg(b,d,e);A[g>>3]=A[g>>3]*h;d=d+1|0;if(d>>>0<y[b+4>>2]){continue}break}}e=e+1|0;if(e>>>0<y[b+8>>2]){continue}break}}v[c+8>>2]=v[b+8>>2];d=v[b+4>>2];v[c>>2]=v[b>>2];v[c+4>>2]=d;lK(a,c);gb=c+16|0}function upa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=gb-16|0;gb=d;a:{e=Ae(a);b:{if(e>>>0>1){break b}c:{if(e){v[22656]=0;U(507,d|0,a|0,c|0);a=v[22656];v[22656]=0;if((a|0)!=1){op(b,d);gc(d);break c}a=V(27364)|0;if((O()|0)!=(ea(27364)|0)){break a}Z(a|0)|0;$();break b}if(!Pb(a,c)){break b}WX(a,b,c)}f=oc(b)>>>0>=c>>>0}gb=d+16|0;return f|0}S(a|0);L()}function lQ(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;e=gb-16|0;gb=e;v[e+12>>2]=c>>>2;v[e+8>>2]=v[a>>2];f=v[Fb(e+12|0,e+8|0)>>2];b=zb(b);if(f){a=v[a+20>>2];c=f;g=d;while(1){g=(zb(w[b|0])+g|0)+(zb(w[b+1|0])<<8)|0;u[a>>1]=g;d=(zb(w[b+2|0])+d|0)+(zb(w[b+3|0])<<8)|0;u[a+2>>1]=d;a=a+4|0;b=b+4|0;c=c-1|0;if(c){continue}break}}gb=e+16|0;return f<<2}function ii(a,b){a:{if((b|0)>=1024){a=a*8.98846567431158e307;if(b>>>0<2047){b=b-1023|0;break a}a=a*8.98846567431158e307;b=(b>>>0<3069?b:3069)-2046|0;break a}if((b|0)>-1023){break a}a=a*2.2250738585072014e-308;if(b>>>0>4294965251){b=b+1022|0;break a}a=a*2.2250738585072014e-308;b=(b>>>0>4294964230?b:-3066)+2044|0}l(0,0);l(1,b+1023<<20);return a*+n()}function iQ(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;e=gb-16|0;gb=e;v[e+12>>2]=c>>>2;v[e+8>>2]=v[a>>2];f=v[Fb(e+12|0,e+8|0)>>2];b=zb(b);if(f){a=v[a+20>>2];c=f;g=d;while(1){g=(zb(w[b+1|0])+g|0)+(zb(w[b|0])<<8)|0;u[a>>1]=g;d=(zb(w[b+3|0])+d|0)+(zb(w[b+2|0])<<8)|0;u[a+2>>1]=d;a=a+4|0;b=b+4|0;c=c-1|0;if(c){continue}break}}gb=e+16|0;return f<<2}function _na(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=v[b>>2];e=v[b>>2]+yb(b)|0;f=Ig(a);v[22656]=0;b=Zh(d,e);c=v[22656];v[22656]=0;a:{b:{if((c|0)==1){break b}if(!b){break a}v[22656]=0;R(518,a|0,b|0);c=v[22656];v[22656]=0;if((c|0)==1){break b}v[22656]=0;Y(665,a|0,d|0,e|0,b|0);a=v[22656];v[22656]=0;if((a|0)!=1){break a}}a=P()|0;O()|0;km(f);S(a|0);L()}}function Ym(a,b,c,d,e,f,g){var h=0,i=0,j=0,k=0;h=gb-16|0;gb=h;if(-17-b>>>0>=c>>>0){i=Jb(a);k=a;a:{if(b>>>0<2147483623){v[h+8>>2]=b<<1;v[h+12>>2]=b+c;c=Xk(v[Lc(h+12|0,h+8|0)>>2]);break a}c=-18}j=c+1|0;c=oi(k,j);if(e){Qg(c,i,e)}d=d-(e+f|0)|0;if(d){Qg((c+e|0)+g|0,(e+i|0)+f|0,d)}b=b+1|0;if((b|0)!=11){al(a,i,b)}ef(a,c);rg(a,j);gb=h+16|0;return}vg();L()}function YA(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=A[b+8>>3];d=$g(A[b>>3]);e=A[b>>3];a:{if(d){if(e<0){c=AR(c)?c:1;break a}if(c!=0){if(AR(c)){break a}}d=$g(c);Vm(a,A[b>>3],d?M:c);return}if(!Ni(e)|A[b+8>>3]!=0){break a}d=v[b+4>>2];v[a>>2]=v[b>>2];v[a+4>>2]=d;d=v[b+12>>2];v[a+8>>2]=v[b+8>>2];v[a+12>>2]=d;return}e=cx(A[b>>3]);f=ri(c);Vm(a,e*Me(c),f*e)}function Xn(a,b,c){var d=0,e=0,f=0;e=gb-16|0;gb=e;d=e+8|0;Fc(d,b);v[22656]=0;b=T(2424,d|0)|0;d=v[22656];v[22656]=0;a:{if((d|0)==1){break a}v[22656]=0;d=T(2436,b|0)|0;f=v[22656];v[22656]=0;if((f|0)==1){break a}t[c|0]=d;v[22656]=0;R(2437,a|0,b|0);a=v[22656];v[22656]=0;if((a|0)==1){break a}Wb(e+8|0);gb=e+16|0;return}a=P()|0;O()|0;Wb(e+8|0);S(a|0);L()}function Gba(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;b=Fi(a,b,c,d);v[a+4272>>2]=1065353216;v[a>>2]=52848;v[a+4216>>2]=1056964608;v[a+4208>>2]=1056880300;v[a+4212>>2]=1050733080;v[22656]=0;W(1532,a+44|0,2,2)|0;c=v[22656];v[22656]=0;a:{if((c|0)==1){break a}v[22656]=0;Th(b);c=v[22656];v[22656]=0;if((c|0)==1){break a}return a|0}a=P()|0;O()|0;Lf(b);S(a|0);L()}function oz(a,b,c){var d=0,e=0,f=0,g=0;f=gb-16|0;gb=f;d=f;v[d>>2]=a;e=v[a+4>>2];v[d+4>>2]=e;v[d+8>>2]=e+B(b,52);a:{b=v[d+4>>2];g=v[d+8>>2];if((b|0)!=(g|0)){while(1){wb(a);v[22656]=0;R(1488,b|0,c|0);e=v[22656];v[22656]=0;if((e|0)==1){break a}b=b+52|0;v[d+4>>2]=b;if((b|0)!=(g|0)){continue}break}}$b(d);gb=f+16|0;return}a=P()|0;O()|0;$b(d);S(a|0);L()}function o0(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0;f=gb-16|0;gb=f;v[f+8>>2]=e;v[f+12>>2]=c;c=Ab(a);if(!((e|0)==-1|c>>>0<b>>>0)){v[f>>2]=c-b;g=f,h=v[Fb(f+12|0,f)>>2],v[g+4>>2]=h;b=Wo(Jb(a)+b|0,d,v[Fb(f+4|0,f+8|0)>>2]);a:{if(b){break a}b=-1;a=v[f+4>>2];c=v[f+8>>2];if(a>>>0<c>>>0){break a}b=a>>>0>c>>>0}gb=f+16|0;return b|0}Qn();L()}function hha(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;d=gb-16|0;gb=d;a:{if(!(w[c+1|0]&4)){break a}c=v[c+4>>2];g=d,h=zd(b),v[g+8>>2]=h;b:{if(!Ab(b)){break b}if(w[pc(b,0)|0]!=(hg(43)&255)){if(w[pc(b,0)|0]!=(hg(45)&255)){break b}}c=c+1|0;Pe(d+8|0)}if(Ab(b)>>>0>=c>>>0){break a}e=Fd(d,d+8|0);f=Ab(b);Zz(b,v[e>>2],c-f|0,hg(48))}Dc(a,b);gb=d+16|0}function fL(a){var b=0,c=0,d=0,e=0,f=0,g=0;a:{b=v[a>>2];b:{if(!b){break b}c=v[a+8>>2];if(!c){break b}a=v[a+12>>2];if(!a){break b}e=kb[a|0](b)|0;d=jb;f=d;if((d|0)<0){break b}if((kb[c|0](b,0,0,0)|0)<0){break a}if((kb[c|0](b,0,0,2)|0)<0){break a}d=kb[a|0](b)|0;a=jb;kb[c|0](b,e,f,0)|0;if((a|0)<0){break b}g=OA(d,a)}return g}kb[c|0](b,e,f,0)|0;return 0}function N_(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0;g=gb-16|0;gb=g;f=gb-16|0;gb=f;e=gb-16|0;gb=e;v[f+4>>2]=1;i=f,j=Mc(32,4),v[i+8>>2]=j;gb=e+16|0;e=f;h=v[e+8>>2];v[22656]=0;da(223,h|0,b|0,c|0,d|0)|0;b=v[22656];v[22656]=0;a:{if((b|0)!=1){b=a;a=Kp(e);Rw(b,dc(a),a);DF(e);gb=f+16|0;break a}a=P()|0;O()|0;DF(e);S(a|0);L()}gb=g+16|0}function Lda(a,b){a=a|0;b=b|0;var c=0;a:{b:{if((oc(v[a+20>>2]+4|0)|0)!=8){break b}c=v[v[a+20>>2]+4>>2];if((w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24))!=1869112133){break b}b=v[v[a+20>>2]+4>>2];c=w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24);b=w[b+4|0]|w[b+5|0]<<8|(w[b+6|0]<<16|w[b+7|0]<<24);v[a+4260>>2]=c;v[a+4264>>2]=b;break a}cz(a,b)}Ut(a)}function Cma(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=gb-16|0;gb=d;c=d;v[c>>2]=a;a=v[a+4>>2];v[c+4>>2]=a;v[c+8>>2]=a+B(b,24);b=c;a:{a=v[c+4>>2];c=v[c+8>>2];if((a|0)!=(c|0)){while(1){v[22656]=0;_(779,a|0);e=v[22656];v[22656]=0;if((e|0)==1){break a}a=a+24|0;v[b+4>>2]=a;if((a|0)!=(c|0)){continue}break}}$b(b);gb=d+16|0;return}a=P()|0;O()|0;$b(b);S(a|0);L()}function Fq(a,b,c,d){a:{if(v[a+480180>>2]==4){d=w[b+810|0];if(c){t[b+810|0]=d&240|c;break a}c=d&15;break a}if(d){if(c){t[b+834|0]=c;break a}c=w[b+834|0];break a}if(c){t[b+810|0]=c;break a}c=w[b+810|0]}b:{if(!(t[b+851|0]&1)){break b}c=v[b+688>>2]-((c&255)<<2)|0;v[b+688>>2]=(c|0)>0?c:0;if(!(v[a+480180>>2]&1)){break b}v[b+88>>2]=v[b+88>>2]|2097152}}function gg(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;e=gb-16|0;gb=e;c=a;a:{if(!De(b)){v[c+8>>2]=v[b+8>>2];d=v[b+4>>2];v[c>>2]=v[b>>2];v[c+4>>2]=d;break a}g=v[b>>2];b:{c:{d=v[b+4>>2];d:{if(d>>>0<=10){b=c;_e(c,d);break d}if(d>>>0>4294967279){break c}f=Xk(d)+1|0;b=oi(c,f);ef(c,b);rg(c,f);de(c,d)}Qg(b,g,d+1|0);break b}vg();L()}}gb=e+16|0;return a|0}function HG(a,b,c,d,e){var f=0,g=0,h=0,i=0;f=gb-16|0;gb=f;if(1073741807-b>>>0>=c>>>0){g=Jb(a);i=a;a:{if(b>>>0<536870887){v[f+8>>2]=b<<1;v[f+12>>2]=b+c;c=om(v[Lc(f+12|0,f+8|0)>>2]);break a}c=1073741806}h=c+1|0;c=Si(i,h);if(e){yi(c,g,e)}d=d-e|0;if(d){e=e<<2;yi(e+c|0,e+g|0,d)}b=b+1|0;if((b|0)!=2){ai(a,g,b)}ef(a,c);rg(a,h);gb=f+16|0;return}vg();L()}function ska(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=gb-16|0;gb=d;c=d;v[c>>2]=a;a=v[a+4>>2];v[c+4>>2]=a;v[c+8>>2]=a+B(b,872);b=c;a:{a=v[c+4>>2];c=v[c+8>>2];if((a|0)!=(c|0)){while(1){v[22656]=0;ET(a);e=v[22656];v[22656]=0;if((e|0)==1){break a}a=a+872|0;v[b+4>>2]=a;if((a|0)!=(c|0)){continue}break}}$b(b);gb=d+16|0;return}a=P()|0;O()|0;$b(b);S(a|0);L()}function mQ(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=gb-16|0;gb=d;v[d+12>>2]=c>>>2;v[d+8>>2]=v[a>>2];e=v[Fb(d+12|0,d+8|0)>>2];b=zb(b);if(e){a=v[a+20>>2];c=e;while(1){f=a,g=(zb(w[b|0])|zb(w[b+1|0])<<8)^32768,u[f>>1]=g;f=a,g=(zb(w[b+2|0])|zb(w[b+3|0])<<8)^32768,u[f+2>>1]=g;a=a+4|0;b=b+4|0;c=c-1|0;if(c){continue}break}}gb=d+16|0;return e<<2}function jQ(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=gb-16|0;gb=d;v[d+12>>2]=c>>>2;v[d+8>>2]=v[a>>2];e=v[Fb(d+12|0,d+8|0)>>2];b=zb(b);if(e){a=v[a+20>>2];c=e;while(1){f=a,g=(zb(w[b+1|0])|zb(w[b|0])<<8)^32768,u[f>>1]=g;f=a,g=(zb(w[b+3|0])|zb(w[b+2|0])<<8)^32768,u[f+2>>1]=g;a=a+4|0;b=b+4|0;c=c-1|0;if(c){continue}break}}gb=d+16|0;return e<<2}function gx(a,b,c,d){t[a+53|0]=1;a:{if(v[a+4>>2]!=(c|0)){break a}t[a+52|0]=1;c=v[a+16>>2];b:{if(!c){v[a+36>>2]=1;v[a+24>>2]=d;v[a+16>>2]=b;if(v[a+48>>2]!=1){break a}if((d|0)==1){break b}break a}if((b|0)==(c|0)){c=v[a+24>>2];if((c|0)==2){v[a+24>>2]=d;c=d}if(v[a+48>>2]!=1){break a}if((c|0)==1){break b}break a}v[a+36>>2]=v[a+36>>2]+1}t[a+54|0]=1}}function Sq(a,b){var c=0,d=0;if(a-1>>>0<=268435455){a=a+208|0;kqa(b,0,a,0);a=jb?0:B(a,b)}else{a=0}a:{if(!a){break a}v[22656]=0;b=T(2806,a|0)|0;c=v[22656];v[22656]=0;b:{c:{if((c|0)==1){b=V(0)|0;O()|0;Z(b|0)|0;v[22656]=0;X(20);c=v[22656];v[22656]=0;b=0;if((c|0)==1){break c}}break b}V(0)|0;O()|0;Bb();L()}if(!b){break a}d=Qb(b,0,a)- -64|0}return d}function lU(a){var b=0,c=0;a:{if(w[a+29|0]!=2){break a}b=w[a+28|0];if((b|0)!=26&(b|0)!=2|w[a+30|0]!=2){break a}b=w[a+31|0];if(b>>>0>21|!(1<<b&3146753)|w[a+33|0]>64){break a}b=w[a+34|0];if(b>>>0>=65&(b|0)!=88){break a}b=a+28|0;a=a+20|0;while(1){c=w[a|0]-32|0;if((c&255)>>>0<=94){a=a+1|0;if((b|0)!=(a|0)){continue}}break}c=(c&255)>>>0<95}return c}function Us(a,b,c,d){var e=0,f=0;e=gb-160|0;gb=e;hc(e+8|0,76824,144);a:{b:{if((b|0)<=0){if(b){break b}b=1;a=e+159|0}v[e+52>>2]=a;v[e+28>>2]=a;f=-2-a|0;b=b>>>0>f>>>0?f:b;v[e+56>>2]=b;a=a+b|0;v[e+36>>2]=a;v[e+24>>2]=a;a=VI(e+8|0,c,d,2288,2289);if(!b){break a}b=v[e+28>>2];t[b-((b|0)==v[e+24>>2])|0]=0;break a}v[115137]=61;a=-1}gb=e+160|0;return a}function Rga(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;d=gb-16|0;gb=d;a:{if(!(w[c+1|0]&4)){break a}c=v[c+4>>2];g=d,h=zd(b),v[g+8>>2]=h;b:{if(!Ab(b)){break b}if(w[Jb(b)|0]!=(hg(43)&255)){if(w[Jb(b)|0]!=(hg(45)&255)){break b}}c=c+1|0;Pe(d+8|0)}if(Ab(b)>>>0>=c>>>0){break a}e=Fd(d,d+8|0);f=Ab(b);VN(b,v[e>>2],c-f|0,hg(48))}Dc(a,b);gb=d+16|0}function Ml(a,b,c){var d=0,e=0,f=0,g=0,h=0;d=gb-16|0;gb=d;a:{if(!(w[c|0]&32)){break a}g=d,h=zd(b),v[g+8>>2]=h;g=d,h=gf(b),v[g>>2]=h;if(!Gb(d+8|0,d)){break a}while(1){e=v[d+8>>2];c=t[e|0];f=hg(97);b:{if((c|0)<(f|0)){break b}if((hg(122)|0)<(c|0)){break b}g=e,h=hg(65)+(c-f|0)|0,t[g|0]=h}c=d+8|0;Pe(c);if(Gb(c,d)){continue}break}}Dc(a,b);gb=d+16|0}function zba(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;b=Fi(a,b,c,d);c=a+4216|0;v[c>>2]=1051372203;v[c+4>>2]=0;v[a+4208>>2]=1065353216;v[a+4212>>2]=1065353216;v[a>>2]=53080;v[22656]=0;W(1532,a+44|0,2,2)|0;c=v[22656];v[22656]=0;a:{if((c|0)==1){break a}v[22656]=0;Th(b);c=v[22656];v[22656]=0;if((c|0)==1){break a}return a|0}a=P()|0;O()|0;Lf(b);S(a|0);L()}function Q8(a){a=a|0;var b=0,c=0,d=0,e=0;c=gb-32|0;gb=c;a=mc(a);v[22656]=0;R(2068,c+16|0,0);b=v[22656];v[22656]=0;a:{b:{if((b|0)!=1){b=c+16|0;d=Vb(b);b=Zb(b);e=v[yc(c+8|0,a)>>2];v[22656]=0;U(2069,d|0,b|0,e|0);b=v[22656];v[22656]=0;if((b|0)==1){break b}Nc(c+16|0);gb=c+32|0;return}b=P()|0;O()|0;break a}b=P()|0;O()|0;Nc(c+16|0)}yd(a);S(b|0);L()}function e5(a){a=a|0;a:{v[22656]=0;T(2400,463112)|0;a=v[22656];v[22656]=0;b:{if((a|0)==1){break b}v[22656]=0;T(2401,463196)|0;a=v[22656];v[22656]=0;if((a|0)==1){break b}v[22656]=0;T(2400,463448)|0;a=v[22656];v[22656]=0;if((a|0)==1){break b}v[22656]=0;T(2401,463532)|0;a=v[22656];v[22656]=0;if((a|0)==1){break b}break a}V(0)|0;O()|0;Bb();L()}}function aV(a){var b=0,c=0,d=0,e=0,f=0;b=a+28|0;e=w[b|0]|w[b+1|0]<<8;b=kqa(w[a+30|0],0,37,0);c=jb;d=b;b=a+24|0;b=kqa(w[b|0]|w[b+1|0]<<8,0,192,0);d=d+b|0;c=jb+c|0;c=b>>>0>d>>>0?c+1|0:c;b=c;f=e;e=d;a=w[a+26|0];c=a>>>26|0;d=a<<6;e=e+d|0;a=b+c|0;a=d>>>0>e>>>0?a+1|0:a;b=e;c=f+b|0;a=b>>>0>c>>>0?a+1|0:a;b=c+192|0;a=b>>>0<192?a+1|0:a;jb=a;return b}function Vw(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=gb-32|0;gb=d;e=v[b+4>>2];b=v[b>>2];v[d+8>>2]=b;v[d+12>>2]=e;v[d+16>>2]=b;v[d+20>>2]=e;rh(d+24|0,d+8|0);v[22656]=0;b=v[d+28>>2];v[d>>2]=v[d+24>>2];v[d+4>>2]=b;R(212,a|0,d|0);b=v[22656];v[22656]=0;if((b|0)!=1){v[a+8>>2]=0;Xf(a+12|0,c);Kd(c);gb=d+32|0;return a|0}a=P()|0;O()|0;Kd(c);S(a|0);L()}function J7(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=gb-16|0;gb=c;a:{b:{if((Ky(a)|0)!=1){break b}if((EK(a)|0)!=(b|0)){break b}d=a+120|0;Bi(d);b=gb-16|0;gb=b;v[b+8>>2]=c+8;a=gb-16|0;gb=a;e=v[13846];v[a+8>>2]=v[13845];v[a+12>>2]=e;e=v[13844];v[a>>2]=v[13843];v[a+4>>2]=e;kb[v[Rh(a,Yg(d))>>2]](b+8|0,d);gb=a+16|0;gb=b+16|0;break a}DK(a,1,b)}gb=c+16|0}function $aa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;v[22656]=0;_(1934,a|0);d=v[22656];v[22656]=0;if((d|0)!=1){v[a+4>>2]=c;v[a>>2]=b?b:1919;return}b=V(0)|0;O()|0;Z(b|0)|0;v[22656]=0;Y(1911,10413,a|0,0,0);a=v[22656];v[22656]=0;if((a|0)!=1){$();return}a=P()|0;O()|0;v[22656]=0;X(20);b=v[22656];v[22656]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}function yK(a,b,c){var d=0,e=0,f=0;a:{d=v[c>>2];c=a;e=vh(c);b:{if(!d){break b}v[22656]=0;R(2109,c|0,d|0);f=v[22656];v[22656]=0;if((f|0)!=1){v[22656]=0;xK(c,d);d=v[22656];v[22656]=0;if((d|0)!=1){break b}}a=P()|0;O()|0;Hl(e);S(a|0);L()}v[22656]=0;b=wK(b);d=v[22656];v[22656]=0;if((d|0)!=1){v[a+12>>2]=b;break a}a=P()|0;O()|0;Hl(c);S(a|0);L()}}function ika(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=gb-48|0;gb=c;a:{if(Pu(a)>>>0<b>>>0){wb(a);d=CB(c+32|0);v[22656]=0;R(955,d|0,b|0);b=v[22656];v[22656]=0;if((b|0)==1){break a}b=c+16|0;Ak(b,a);e=c+8|0;Vl(e,a);v[22656]=0;U(956,d|0,b|0,e|0);b=v[22656];v[22656]=0;if((b|0)==1){break a}BB(a,d);Ye(d)}gb=c+48|0;return}a=P()|0;O()|0;Ye(d);S(a|0);L()}function R$(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;e=gb+-64|0;gb=e;d=1;a:{if(Sg(a,b,0)){break a}d=0;if(!b){break a}b=jx(b,89656,89704);d=0;if(!b){break a}d=e+8|0;Qb(d|4,0,52);v[e+56>>2]=1;v[e+20>>2]=-1;v[e+16>>2]=a;v[e+8>>2]=b;kb[v[v[b>>2]+28>>2]](b,d,v[c>>2],1);a=v[e+32>>2];if((a|0)==1){v[c>>2]=v[e+24>>2]}d=(a|0)==1}gb=e- -64|0;return d|0}function Jha(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;e=gb-32|0;gb=e;v[e+24>>2]=d;f=fg(a,c);se(e,v[a+28>>2]);d=v[e+12>>2];v[e+16>>2]=v[e+8>>2];v[e+20>>2]=d;a:{if(!f){if(nd(a,5)){break a}}g=v[a+28>>2];d=0;BE(b,v[e+24>>2]);if(v[e+24>>2]){while(1){fB(g,sc(b,d));d=d+1|0;if(d>>>0<y[e+24>>2]){continue}break}}}Zf(a,f,c,e+16|0);gb=e+32|0}function wla(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;b=gb-160|0;gb=b;f=-1;c=gb-32|0;gb=c;e=c+24|0;g=b+8|0;zU(e,g);e=yb(e);d=v[c+28>>2];h=v[c+24>>2];v[c+8>>2]=h;v[c+12>>2]=d;v[c>>2]=h;v[c+4>>2]=d;d=c+16|0;hd(d,a,c);d=yb(d);if((d|0)==(e|0)){bd(a,yb(c+24|0))}gb=c+32|0;a=(d|0)==(e|0);if(!a){yU(g)}if(a){f=JU(b+8|0)}gb=b+160|0;return f|0}function p5(a,b){a=a|0;b=b|0;var c=0;c=v[a+24>>2];if(c>>>0>y[a+44>>2]){v[a+44>>2]=c}a:{if(y[a+8>>2]>=y[a+12>>2]){break a}if(Ie(b,-1)){$n(a,v[a+8>>2],v[a+12>>2]-1|0,v[a+44>>2]);return Zs(b)|0}if(!(w[a+48|0]&16)){if(!Ie(Wh(b),t[v[a+12>>2]-1|0])){break a}}$n(a,v[a+8>>2],v[a+12>>2]-1|0,v[a+44>>2]);c=Wh(b);t[v[a+12>>2]]=c;return b|0}return-1}function _pa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;b=gb-624|0;gb=b;f=-1;c=gb-32|0;gb=c;e=c+24|0;g=b+8|0;zY(e,g);e=yb(e);d=v[c+28>>2];h=v[c+24>>2];v[c+8>>2]=h;v[c+12>>2]=d;v[c>>2]=h;v[c+4>>2]=d;d=c+16|0;hd(d,a,c);d=yb(d);if((d|0)==(e|0)){bd(a,yb(c+24|0))}gb=c+32|0;a=(d|0)==(e|0);if(!a){yY(g)}if(a){f=BY(b+8|0)}gb=b+624|0;return f|0}function _A(a){t[a|0]=0;t[a+1|0]=0;t[a+2|0]=0;t[a+3|0]=0;t[a+4|0]=0;t[a+5|0]=0;t[a+6|0]=0;t[a+7|0]=0;t[a+23|0]=0;t[a+24|0]=0;t[a+25|0]=0;t[a+26|0]=0;t[a+16|0]=0;t[a+17|0]=0;t[a+18|0]=0;t[a+19|0]=0;t[a+20|0]=0;t[a+21|0]=0;t[a+22|0]=0;t[a+23|0]=0;t[a+8|0]=0;t[a+9|0]=0;t[a+10|0]=0;t[a+11|0]=0;t[a+12|0]=0;t[a+13|0]=0;t[a+14|0]=0;t[a+15|0]=0}function J2(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;d=gb-16|0;gb=d;b=a;a:{if(!De(f)){v[b+8>>2]=v[f+8>>2];a=v[f+4>>2];v[b>>2]=v[f>>2];v[b+4>>2]=a;break a}e=v[f>>2];b:{c:{c=v[f+4>>2];d:{if(c>>>0<=1){_e(a,c);break d}if(c>>>0>1073741807){break c}f=om(c)+1|0;b=Si(a,f);ef(a,b);rg(a,f);de(a,c)}yi(b,e,c+1|0);break b}vg();L()}}gb=d+16|0}function D_(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0;e=gb-32|0;gb=e;a:{if(y[b+16>>2]<=c>>>0){ok(a,d,0);break a}f=v[b+4>>2];g=v[b+12>>2];h=e,i=yb(d),v[h+20>>2]=i;v[e+16>>2]=v[b+16>>2]-c;ok(e+24|0,d,v[Fb(e+20|0,e+16|0)>>2]);b=v[v[f>>2]+28>>2];d=v[e+28>>2];v[e+8>>2]=v[e+24>>2];v[e+12>>2]=d;kb[b|0](a,f,c+g|0,e+8|0)}gb=e+32|0}function Zma(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=gb-32|0;gb=d;e=v[b+4>>2];v[d+24>>2]=v[b>>2];v[d+28>>2]=e;b=Xf(d+16|0,c);v[22656]=0;e=v[d+28>>2];v[d+8>>2]=v[d+24>>2];v[d+12>>2]=e;e=v[b+4>>2];v[d>>2]=v[b>>2];v[d+4>>2]=e;W(772,a|0,d+8|0,d|0)|0;b=v[22656];v[22656]=0;if((b|0)!=1){Kd(c);gb=d+32|0;return a|0}a=P()|0;O()|0;Kd(c);S(a|0);L()}function Zha(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0;Fk(a);i=v[b+4>>2];f=b+4|0;Dk(wb(a),v[a>>2],c,f);j=wb(a);g=b+8|0;d=g;h=v[a+4>>2];if((h|0)!=(c|0)){e=v[d>>2];while(1){hn(j,e,c);e=v[d>>2]+4|0;v[d>>2]=e;c=c+4|0;if((h|0)!=(c|0)){continue}break}}xc(a,f);xc(a+4|0,g);xc(wb(a),dc(b));v[b>>2]=v[b+4>>2];dn(a,Nb(a));return i|0}function UH(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0;b=gb-16|0;gb=b;e=b+16|0;a:{while(1){d=v[a+36>>2];c=b+8|0;f=kb[v[v[d>>2]+20>>2]](d,v[a+40>>2],c,e,b+4|0)|0;d=-1;g=c;c=v[b+4>>2]-c|0;if((Lk(g,1,c,v[a+32>>2])|0)!=(c|0)){break a}b:{switch(f-1|0){case 1:break a;case 0:continue;default:break b}}break}d=nt(v[a+32>>2])?-1:0}gb=b+16|0;return d|0}function Oo(a,b){a=a|0;b=b|0;var c=0,d=0;d=gb-16|0;gb=d;t[d+15|0]=b;a:{b:{c:{d:{if(De(a)){c=gk(a);b=v[a+4>>2];c=c-1|0;if((b|0)==(c|0)){break d}break b}c=10;b=w[a+11|0];if((b|0)!=10){break c}}Ym(a,c,1,c,c,0,0);b=c;if(De(a)){break b}}c=a;_e(a,b+1|0);break a}c=v[a>>2];de(a,b+1|0)}a=b+c|0;Bd(a,d+15|0);t[d+14|0]=0;Bd(a+1|0,d+14|0);gb=d+16|0}function ps(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=gb-32|0;gb=d;e=v[b+4>>2];v[d+24>>2]=v[b>>2];v[d+28>>2]=e;b=Xf(d+16|0,c);v[22656]=0;e=v[d+28>>2];v[d+8>>2]=v[d+24>>2];v[d+12>>2]=e;e=v[b+4>>2];v[d>>2]=v[b>>2];v[d+4>>2]=e;W(207,a|0,d+8|0,d|0)|0;b=v[22656];v[22656]=0;if((b|0)!=1){Kd(c);gb=d+32|0;return a|0}a=P()|0;O()|0;Kd(c);S(a|0);L()}function k0(a,b){a=a|0;b=b|0;var c=0,d=0;d=gb-16|0;gb=d;v[d+12>>2]=b;a:{b:{c:{d:{if(De(a)){c=gk(a);b=v[a+4>>2];c=c-1|0;if((b|0)==(c|0)){break d}break b}c=1;b=w[a+11|0];if((b|0)!=1){break c}}HG(a,c,1,c,c);b=c;if(De(a)){break b}}c=a;_e(a,b+1|0);break a}c=v[a>>2];de(a,b+1|0)}a=(b<<2)+c|0;Ge(a,d+12|0);v[d+8>>2]=0;Ge(a+4|0,d+8|0);gb=d+16|0}function jpa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;b=gb-32|0;gb=b;f=-1;c=gb-32|0;gb=c;e=c+24|0;g=b+8|0;Gv(e,g);e=yb(e);d=v[c+28>>2];h=v[c+24>>2];v[c+8>>2]=h;v[c+12>>2]=d;v[c>>2]=h;v[c+4>>2]=d;d=c+16|0;hd(d,a,c);d=yb(d);if((d|0)==(e|0)){bd(a,yb(c+24|0))}gb=c+32|0;a=(d|0)==(e|0);if(!a){OX(g)}if(a){f=RX(b+8|0)}gb=b+32|0;return f|0}function VX(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=gb-32|0;gb=d;e=v[b+4>>2];v[d+24>>2]=v[b>>2];v[d+28>>2]=e;b=Xf(d+16|0,c);v[22656]=0;e=v[d+28>>2];v[d+8>>2]=v[d+24>>2];v[d+12>>2]=e;e=v[b+4>>2];v[d>>2]=v[b>>2];v[d+4>>2]=e;W(516,a|0,d+8|0,d|0)|0;b=v[22656];v[22656]=0;if((b|0)!=1){Kd(c);gb=d+32|0;return a|0}a=P()|0;O()|0;Kd(c);S(a|0);L()}function Kna(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;b=gb-16|0;gb=b;f=-1;c=gb-32|0;gb=c;e=c+24|0;g=b+8|0;_v(e,g);e=yb(e);d=v[c+28>>2];h=v[c+24>>2];v[c+8>>2]=h;v[c+12>>2]=d;v[c>>2]=h;v[c+4>>2]=d;d=c+16|0;hd(d,a,c);d=yb(d);if((d|0)==(e|0)){bd(a,yb(c+24|0))}gb=c+32|0;a=(d|0)==(e|0);if(!a){pW(g)}if(a){f=AW(b+8|0)}gb=b+16|0;return f|0}function Cu(a){var b=0,c=0,d=0,e=0,f=0,g=0,h=0;d=gb-16|0;gb=d;e=d+8|0;b=gb-16|0;gb=b;v[22656]=0;c=a;PQ(c+4|0);f=v[22656];v[22656]=0;a:{b:{c:{if((f|0)!=1){v[22656]=0;v[b+12>>2]=0;ff(c+8|0,b+12|0,e);e=v[22656];v[22656]=0;if((e|0)!=1){break c}break b}break b}g=c,h=fc(c),v[g>>2]=h;gb=b+16|0;break a}V(0)|0;O()|0;Bb();L()}gb=d+16|0;return a}function soa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;a:{d=gb-32|0;gb=d;e=d+16|0;LC(e,c);v[22656]=0;mj(d+8|0,e);c=v[22656];v[22656]=0;b:{if((c|0)==1){break b}v[22656]=0;c=v[d+12>>2];v[d>>2]=v[d+8>>2];v[d+4>>2]=c;U(146,a|0,b|0,d|0);a=v[22656];v[22656]=0;if((a|0)==1){break b}Hb(d+16|0);gb=d+32|0;break a}a=P()|0;O()|0;Hb(d+16|0);S(a|0);L()}}function ooa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;a:{d=gb-32|0;gb=d;e=d+16|0;Rn(e,c);v[22656]=0;mj(d+8|0,e);c=v[22656];v[22656]=0;b:{if((c|0)==1){break b}v[22656]=0;c=v[d+12>>2];v[d>>2]=v[d+8>>2];v[d+4>>2]=c;U(146,a|0,b|0,d|0);a=v[22656];v[22656]=0;if((a|0)==1){break b}Hb(d+16|0);gb=d+32|0;break a}a=P()|0;O()|0;Hb(d+16|0);S(a|0);L()}}function lma(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;a:{d=gb-32|0;gb=d;e=d+16|0;Mq(e,c);v[22656]=0;mj(d+8|0,e);c=v[22656];v[22656]=0;b:{if((c|0)==1){break b}v[22656]=0;c=v[d+12>>2];v[d>>2]=v[d+8>>2];v[d+4>>2]=c;U(453,a|0,b|0,d|0);a=v[22656];v[22656]=0;if((a|0)==1){break b}Hb(d+16|0);gb=d+32|0;break a}a=P()|0;O()|0;Hb(d+16|0);S(a|0);L()}}function fqa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;a:{d=gb-32|0;gb=d;e=d+16|0;Kh(e,c);v[22656]=0;mj(d+8|0,e);c=v[22656];v[22656]=0;b:{if((c|0)==1){break b}v[22656]=0;c=v[d+12>>2];v[d>>2]=v[d+8>>2];v[d+4>>2]=c;U(453,a|0,b|0,d|0);a=v[22656];v[22656]=0;if((a|0)==1){break b}Hb(d+16|0);gb=d+32|0;break a}a=P()|0;O()|0;Hb(d+16|0);S(a|0);L()}}function uY(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;a:{d=gb-32|0;gb=d;e=d+16|0;OD(e,c);v[22656]=0;mj(d+8|0,e);c=v[22656];v[22656]=0;b:{if((c|0)==1){break b}v[22656]=0;c=v[d+12>>2];v[d>>2]=v[d+8>>2];v[d+4>>2]=c;U(146,a|0,b|0,d|0);a=v[22656];v[22656]=0;if((a|0)==1){break b}Hb(d+16|0);gb=d+32|0;break a}a=P()|0;O()|0;Hb(d+16|0);S(a|0);L()}}function WZ(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;a:{d=gb-32|0;gb=d;e=d+16|0;kw(e,c);v[22656]=0;mj(d+8|0,e);c=v[22656];v[22656]=0;b:{if((c|0)==1){break b}v[22656]=0;c=v[d+12>>2];v[d>>2]=v[d+8>>2];v[d+4>>2]=c;U(146,a|0,b|0,d|0);a=v[22656];v[22656]=0;if((a|0)==1){break b}Hb(d+16|0);gb=d+32|0;break a}a=P()|0;O()|0;Hb(d+16|0);S(a|0);L()}}function DG(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;a:{d=gb-32|0;gb=d;e=d+16|0;Kh(e,c);v[22656]=0;mj(d+8|0,e);c=v[22656];v[22656]=0;b:{if((c|0)==1){break b}v[22656]=0;c=v[d+12>>2];v[d>>2]=v[d+8>>2];v[d+4>>2]=c;U(146,a|0,b|0,d|0);a=v[22656];v[22656]=0;if((a|0)==1){break b}Hb(d+16|0);gb=d+32|0;break a}a=P()|0;O()|0;Hb(d+16|0);S(a|0);L()}}function _r(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;c=gb-16|0;gb=c;d=Jb(b);e=Jb(b);g=c,h=Ab(b),v[g+12>>2]=h;v[c+8>>2]=v[a+4>>2]-1;Rg(d,e+v[Fb(c+12|0,c+8|0)>>2]|0,v[a>>2]);d=v[a>>2];g=c,h=Ab(b),v[g+12>>2]=h;v[c+8>>2]=v[a+4>>2]-1;b=v[Fb(c+12|0,c+8|0)>>2];e=v[a+4>>2];f=v[a>>2];t[c+7|0]=0;Lo(b+d|0,e+f|0,c+7|0);gb=c+16|0;return a|0}function SE(a,b){var c=0,d=0,e=0,f=0;c=gb-16|0;gb=c;if(b>>>0<3){a:{if(!b){break a}if(!Pb(a,b)){break a}f=1;while(1){t[c+13|0]=0;e=(c+14|0)+d|0;if(b>>>0>d>>>0){Ng(a,c+13|0);d=w[c+13|0]}else{d=0}t[e|0]=d;d=1;e=f;f=0;if(e){continue}break}u[c+10>>1]=x[c+14>>1];a=c+10|0;d=w[a|0]|w[a+1|0]<<8}gb=c+16|0;return d}aa(8513,6236,136,11437);L()}function mK(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;d=gb-16|0;gb=d;v[d+12>>2]=b;v[d+8>>2]=a;f=tl(v[a+8>>2]);Bi(f);e=gb-16|0;gb=e;v[e+8>>2]=d+8;c=gb-16|0;gb=c;g=v[14080];v[c+8>>2]=v[14079];v[c+12>>2]=g;g=v[14078];v[c>>2]=v[14077];v[c+4>>2]=g;kb[v[Rh(c,Yg(f))>>2]](e+8|0,f);gb=c+16|0;gb=e+16|0;v[a+4>>2]=v[b+8>>2]+v[a+4>>2];gb=d+16|0}function lK(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;d=gb-16|0;gb=d;v[d+12>>2]=b;v[d+8>>2]=a;f=tl(v[a+8>>2]);Bi(f);e=gb-16|0;gb=e;v[e+8>>2]=d+8;c=gb-16|0;gb=c;g=v[14084];v[c+8>>2]=v[14083];v[c+12>>2]=g;g=v[14082];v[c>>2]=v[14081];v[c+4>>2]=g;kb[v[Rh(c,Yg(f))>>2]](e+8|0,f);gb=c+16|0;gb=e+16|0;v[a+4>>2]=v[b+8>>2]+v[a+4>>2];gb=d+16|0}function iK(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;d=gb-16|0;gb=d;v[d+12>>2]=b;v[d+8>>2]=a;f=tl(v[a+8>>2]);Bi(f);e=gb-16|0;gb=e;v[e+8>>2]=d+8;c=gb-16|0;gb=c;g=v[14285];v[c+8>>2]=v[14284];v[c+12>>2]=g;g=v[14283];v[c>>2]=v[14282];v[c+4>>2]=g;kb[v[Rh(c,Yg(f))>>2]](e+8|0,f);gb=c+16|0;gb=e+16|0;v[a+4>>2]=v[b+8>>2]+v[a+4>>2];gb=d+16|0}function gK(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;d=gb-16|0;gb=d;v[d+12>>2]=b;v[d+8>>2]=a;f=tl(v[a+8>>2]);Bi(f);e=gb-16|0;gb=e;v[e+8>>2]=d+8;c=gb-16|0;gb=c;g=v[14289];v[c+8>>2]=v[14288];v[c+12>>2]=g;g=v[14287];v[c>>2]=v[14286];v[c+4>>2]=g;kb[v[Rh(c,Yg(f))>>2]](e+8|0,f);gb=c+16|0;gb=e+16|0;v[a+4>>2]=v[b+8>>2]+v[a+4>>2];gb=d+16|0}function fK(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;d=gb-16|0;gb=d;v[d+12>>2]=b;v[d+8>>2]=a;f=tl(v[a+8>>2]);Bi(f);e=gb-16|0;gb=e;v[e+8>>2]=d+8;c=gb-16|0;gb=c;g=v[14492];v[c+8>>2]=v[14491];v[c+12>>2]=g;g=v[14490];v[c>>2]=v[14489];v[c+4>>2]=g;kb[v[Rh(c,Yg(f))>>2]](e+8|0,f);gb=c+16|0;gb=e+16|0;v[a+4>>2]=v[b+8>>2]+v[a+4>>2];gb=d+16|0}function eK(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;d=gb-16|0;gb=d;v[d+12>>2]=b;v[d+8>>2]=a;f=tl(v[a+8>>2]);Bi(f);e=gb-16|0;gb=e;v[e+8>>2]=d+8;c=gb-16|0;gb=c;g=v[14496];v[c+8>>2]=v[14495];v[c+12>>2]=g;g=v[14494];v[c>>2]=v[14493];v[c+4>>2]=g;kb[v[Rh(c,Yg(f))>>2]](e+8|0,f);gb=c+16|0;gb=e+16|0;v[a+4>>2]=v[b+8>>2]+v[a+4>>2];gb=d+16|0}function bma(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=gb-32|0;gb=c;e=Pb(a,6);a:{if(!e){a=gb-16|0;gb=a;d=gb-16|0;gb=d;f=b+6|0;while(1){Hf(b);b=b+1|0;if((f|0)!=(b|0)){continue}break}gb=d+16|0;gb=a+16|0;break a}d=gb-16|0;gb=d;bc(c+24|0,b,6);gb=d+16|0;b=v[c+28>>2];v[c+8>>2]=v[c+24>>2];v[c+12>>2]=b;kd(c+16|0,a,c+8|0)}gb=c+32|0;return e|0}function bK(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;d=gb-16|0;gb=d;v[d+12>>2]=b;v[d+8>>2]=a;f=tl(v[a+8>>2]);Bi(f);e=gb-16|0;gb=e;v[e+8>>2]=d+8;c=gb-16|0;gb=c;g=v[14699];v[c+8>>2]=v[14698];v[c+12>>2]=g;g=v[14697];v[c>>2]=v[14696];v[c+4>>2]=g;kb[v[Rh(c,Yg(f))>>2]](e+8|0,f);gb=c+16|0;gb=e+16|0;v[a+4>>2]=v[b+8>>2]+v[a+4>>2];gb=d+16|0}function aK(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;d=gb-16|0;gb=d;v[d+12>>2]=b;v[d+8>>2]=a;f=tl(v[a+8>>2]);Bi(f);e=gb-16|0;gb=e;v[e+8>>2]=d+8;c=gb-16|0;gb=c;g=v[14703];v[c+8>>2]=v[14702];v[c+12>>2]=g;g=v[14701];v[c>>2]=v[14700];v[c+4>>2]=g;kb[v[Rh(c,Yg(f))>>2]](e+8|0,f);gb=c+16|0;gb=e+16|0;v[a+4>>2]=v[b+8>>2]+v[a+4>>2];gb=d+16|0}function cla(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;b=gb-208|0;gb=b;f=-1;c=gb-32|0;gb=c;h=b;e=c+24|0;aU(e,b);e=yb(e);d=v[c+28>>2];g=v[c+24>>2];v[c+8>>2]=g;v[c+12>>2]=d;v[c>>2]=g;v[c+4>>2]=d;d=c+16|0;hd(d,a,c);d=yb(d);if((d|0)==(e|0)){bd(a,yb(c+24|0))}gb=c+32|0;a=(d|0)==(e|0);if(!a){$T(h)}if(a){f=iU(b)}gb=b+208|0;return f|0}function Zja(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=gb-32|0;gb=c;e=gb-16|0;gb=e;d=c+24|0;bc(d,b,40);gb=e+16|0;e=yb(d);d=v[c+28>>2];f=v[c+24>>2];v[c+8>>2]=f;v[c+12>>2]=d;v[c>>2]=f;v[c+4>>2]=d;d=c+16|0;cc(d,a,c);d=yb(d);if((d|0)==(e|0)){Rb(a,yb(c+24|0))}gb=c+32|0;a=(d|0)==(e|0);if(!a){c=gb-16|0;gb=c;Qb(b,0,40);gb=c+16|0}return a|0}function Toa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;b=gb-160|0;gb=b;f=-1;c=gb-32|0;gb=c;h=b;e=c+24|0;yX(e,b);e=yb(e);d=v[c+28>>2];g=v[c+24>>2];v[c+8>>2]=g;v[c+12>>2]=d;v[c>>2]=g;v[c+4>>2]=d;d=c+16|0;hd(d,a,c);d=yb(d);if((d|0)==(e|0)){bd(a,yb(c+24|0))}gb=c+32|0;a=(d|0)==(e|0);if(!a){xX(h)}if(a){f=zX(b)}gb=b+160|0;return f|0}function Mz(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;c=F(c,.999);h=c*3.141592653589793;i=qq(b);while(1){j=a;k=c;f=((e<<12^-1)&28672)+(e>>>3|0)|0;if((f|0)!=16384){d=+(f-16384|0)*.000244140625;g=h*d;d=ri(g)*qq(K(d*d*-.0625+1)*b)/(i*g)}else{d=1}l=j,m=JT(k*d*32768),u[l>>1]=m;a=a+2|0;e=e+1|0;if((e|0)!=32768){continue}break}}function zX(a){var b=0;a:{if((w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24))!=-28490681|w[a+68|0]!=13|(w[a+69|0]!=10|w[a+70|0]!=26)){break a}if(w[a+76|0]|((w[a+71|0]|w[a+72|0]<<8|(w[a+73|0]<<16|w[a+74|0]<<24))!=1397116231|w[a+75|0]!=1)){break a}a=a+116|0;if((w[a|0]|w[a+1|0]<<8)>>>0>9){break a}b=(w[a|0]|w[a+1|0]<<8)!=0}return b}function pX(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=gb-32|0;gb=c;e=gb-16|0;gb=e;d=c+24|0;bc(d,b,80);gb=e+16|0;e=yb(d);d=v[c+28>>2];f=v[c+24>>2];v[c+8>>2]=f;v[c+12>>2]=d;v[c>>2]=f;v[c+4>>2]=d;d=c+16|0;cc(d,a,c);d=yb(d);if((d|0)==(e|0)){Rb(a,yb(c+24|0))}gb=c+32|0;a=(d|0)==(e|0);if(!a){c=gb-16|0;gb=c;Qb(b,0,80);gb=c+16|0}return a|0}function nQ(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=gb-16|0;gb=d;v[d+12>>2]=c>>>2;v[d+8>>2]=v[a>>2];e=v[Fb(d+12|0,d+8|0)>>2];b=zb(b);if(e){a=v[a+20>>2];c=e;while(1){f=a,g=zb(w[b|0])|zb(w[b+1|0])<<8,u[f>>1]=g;f=a,g=zb(w[b+2|0])|zb(w[b+3|0])<<8,u[f+2>>1]=g;a=a+4|0;b=b+4|0;c=c-1|0;if(c){continue}break}}gb=d+16|0;return e<<2}function kQ(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=gb-16|0;gb=d;v[d+12>>2]=c>>>2;v[d+8>>2]=v[a>>2];e=v[Fb(d+12|0,d+8|0)>>2];b=zb(b);if(e){a=v[a+20>>2];c=e;while(1){f=a,g=zb(w[b+1|0])|zb(w[b|0])<<8,u[f>>1]=g;f=a,g=zb(w[b+3|0])|zb(w[b+2|0])<<8,u[f+2>>1]=g;a=a+4|0;b=b+4|0;c=c-1|0;if(c){continue}break}}gb=d+16|0;return e<<2}function k7(a,b){a=a|0;b=b|0;var c=0,d=0;d=gb-16|0;gb=d;c=v[b+12>>2];v[d+8>>2]=v[b+8>>2];v[d+12>>2]=c;c=v[b+4>>2];v[d>>2]=v[b>>2];v[d+4>>2]=c;c=fL(d);Ip(a);t[a+8|0]=0;v[a+4>>2]=c;v[a>>2]=59180;mc(a+12|0);v[a>>2]=58988;c=v[b+4>>2];v[a+24>>2]=v[b>>2];v[a+28>>2]=c;c=v[b+12>>2];v[a+32>>2]=v[b+8>>2];v[a+36>>2]=c;gb=d+16|0;return a|0}function ZE(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=b+18|0;b=b+46|0;a=Rc(a,w[d|0]&2?16:8,1,0,(w[b|0]^-1)&1);if(!(!(w[d|0]&4)|c>>>0<532)){Bp(a,3)}a:{b:{if(w[d|0]&8){b=w[b|0]&4?5:4;break b}if(!(w[d|0]&2|w[b|0]!=255)){b=10;break b}if(w[b|0]&2){t[a+2|0]=1}if(w[b|0]&4){Bf(a,2)}if(!(w[b|0]&8)){break a}b=9;if(!(w[d|0]&2)){break a}}Bf(a,b)}}function jM(a){var b=C(0),c=0,d=C(0),e=0;b=z[a+4224>>2];z[a+4260>>2]=K(C(C(1)-C(b*b)));t[a+4264|0]=z[a+4236>>2]>C(.5);c=a;d=C(v[a+4256>>2]<<1>>>0);b=C(z[a+4228>>2]*d);a:{if(b<C(4294967296)&b>=C(0)){e=~~b>>>0;break a}e=0}v[c+4248>>2]=e;c=a+4252|0;b=C(z[a+4232>>2]*d);b:{if(b<C(4294967296)&b>=C(0)){a=~~b>>>0;break b}a=0}v[c>>2]=a}function Una(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=gb-16|0;gb=d;Se(b);v[d+12>>2]=0;a:{if(!Ik(a,d+12|0)){break a}f=c;c=v[d+12>>2];if(f>>>0<c>>>0){break a}if(!c){e=1;break a}c=0;while(1){b:{t[d+11|0]=0;if(!Uh(a,d+11|0)){break b}Oo(b,t[d+11|0]);e=1;c=c+1|0;if((c|0)!=v[d+12>>2]){continue}break a}break}e=0}gb=d+16|0;return e|0}function Ac(a,b){var c=0;c=gb-32|0;gb=c;v[c+24>>2]=a;v[c+28>>2]=b;v[c+16>>2]=-2147483648;v[c+20>>2]=-1;v[22656]=0;v[c+8>>2]=2147483647;v[c+12>>2]=0;a=Pr(c+24|0,c+8|0);b=v[22656];v[22656]=0;a:{if((b|0)==1){break a}v[22656]=0;a=Py(c+16|0,a);b=v[22656];v[22656]=0;if((b|0)==1){break a}gb=c+32|0;return v[a>>2]}V(0)|0;O()|0;Bb();L()}function gL(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0;b=v[a>>2];a:{if(!b){break a}c=v[a+8>>2];if(!c){break a}d=v[a+12>>2];if(!d){break a}e=kb[d|0](b)|0;a=jb;f=a;if((a|0)<0){break a}a=0;b:{if((kb[c|0](b,0,0,0)|0)<0){break b}a=0;if((kb[c|0](b,0,0,2)|0)<0){break b}kb[d|0](b)|0;a=jb;a=(a|0)>0|(a|0)>=0}g=a;kb[c|0](b,e,f,0)|0}return g|0}function YZ(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;b=gb-48|0;gb=b;f=-1;c=gb-32|0;gb=c;h=b;e=c+24|0;rE(e,b);e=yb(e);d=v[c+28>>2];g=v[c+24>>2];v[c+8>>2]=g;v[c+12>>2]=d;v[c>>2]=g;v[c+4>>2]=d;d=c+16|0;hd(d,a,c);d=yb(d);if((d|0)==(e|0)){bd(a,yb(c+24|0))}gb=c+32|0;a=(d|0)==(e|0);if(!a){qE(h)}if(a){f=DE(b)}gb=b+48|0;return f|0}function Sna(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=gb-16|0;gb=d;Se(b);t[d+15|0]=0;a:{if(!Uh(a,d+15|0)){break a}f=c;c=w[d+15|0];if(f>>>0<c>>>0){break a}if(!c){e=1;break a}c=0;while(1){b:{t[d+14|0]=0;if(!Uh(a,d+14|0)){break b}Oo(b,t[d+14|0]);e=1;c=c+1|0;if(w[d+15|0]!=(c&255)){continue}break a}break}e=0}gb=d+16|0;return e|0}function rM(a){a=a|0;var b=0,c=0;c=gb-16|0;gb=c;b=(wf(v[a+16>>2])|0)/5|0;b=Ac(b,b>>31);v[a+4272>>2]=b;v[22656]=0;v[c+12>>2]=0;U(1540,a+4256|0,b<<1,c+12|0);b=v[22656];v[22656]=0;a:{if((b|0)==1){b=V(89116)|0;if((O()|0)!=(ea(89116)|0)){break a}Z(b|0)|0;v[a+4272>>2]=0;$()}v[a+4276>>2]=0;v[a+4268>>2]=0;gb=c+16|0;return}S(b|0);L()}function hQ(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;d=gb-16|0;gb=d;v[d+12>>2]=(c>>>0)/3;v[d+8>>2]=v[a>>2];e=v[Fb(d+12|0,d+8|0)>>2];b=zb(b);if(e){a=v[a+20>>2];c=e;while(1){f=zb(w[b|0]);g=a,h=id(zb(w[b+1|0])<<16|f<<8|zb(w[b+2|0])<<24,16),u[g>>1]=h;a=a+2|0;b=b+3|0;c=c-1|0;if(c){continue}break}}gb=d+16|0;return B(e,3)|0}function gQ(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;d=gb-16|0;gb=d;v[d+12>>2]=(c>>>0)/3;v[d+8>>2]=v[a>>2];e=v[Fb(d+12|0,d+8|0)>>2];b=zb(b);if(e){a=v[a+20>>2];c=e;while(1){f=zb(w[b+2|0]);g=a,h=id(zb(w[b+1|0])<<16|f<<8|zb(w[b|0])<<24,16),u[g>>1]=h;a=a+2|0;b=b+3|0;c=c-1|0;if(c){continue}break}}gb=d+16|0;return B(e,3)|0}function cy(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0;g=gb-240|0;gb=g;v[g>>2]=a;h=1;a:{if((c|0)<2){break a}e=a;while(1){e=e-4|0;i=c-2|0;f=e-v[(i<<2)+d>>2]|0;if((kb[b|0](a,f)|0)>=0){if((kb[b|0](a,e)|0)>=0){break a}}j=f;f=(kb[b|0](f,e)|0)>=0;e=f?j:e;v[(h<<2)+g>>2]=e;h=h+1|0;c=f?c-1|0:i;if(c>>>0>1){continue}break}}PI(g,h);gb=g+240|0}function Jf(a,b,c){var d=0,e=0;d=gb-16|0;gb=d;a:{if(y[b+8>>2]<c>>>0){v[22656]=0;Y(2116,14456,6267,394,3438);a=v[22656];v[22656]=0;if((a|0)==1){break a}L()}v[d+8>>2]=v[b+8>>2];e=v[b+4>>2];v[d>>2]=v[b>>2];v[d+4>>2]=e;b=v[d+4>>2];v[a>>2]=v[d>>2];v[a+4>>2]=b;v[a+8>>2]=v[d+8>>2];v[a+12>>2]=c;gb=d+16|0;return}V(0)|0;O()|0;Bb();L()}function PI(a,b){var c=0,d=0,e=0,f=0,g=0,h=0;d=4;e=gb-256|0;gb=e;a:{if((b|0)<2){break a}h=(b<<2)+a|0;v[h>>2]=e;c=e;while(1){f=d>>>0<256?d:256;hc(c,v[a>>2],f);c=0;while(1){g=(c<<2)+a|0;c=c+1|0;hc(v[g>>2],v[(c<<2)+a>>2],f);v[g>>2]=v[g>>2]+f;if((b|0)!=(c|0)){continue}break}d=d-f|0;if(!d){break a}c=v[h>>2];continue}}gb=e+256|0}function Jla(a,b){a=a|0;b=b|0;var c=0;b=gb-32|0;gb=b;c=-1;a:{if(!oD(a,b+16|0)){break a}c=0;if(!PU(b+16|0)){break a}c=-1;if(!ek(a,b+8|0)){break a}a=b+8|4;c=0;if(!(w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24))){break a}a=b+8|0;a=w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24);c=(a&2139062143)==(a|0)}a=c;gb=b+32|0;return a|0}function dQ(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=gb-16|0;gb=d;v[d+12>>2]=c>>>2;v[d+8>>2]=v[a>>2];e=v[Fb(d+12|0,d+8|0)>>2];b=zb(b);if(e){a=v[a+20>>2];c=e;while(1){f=a,g=id(zb(w[b|0])|zb(w[b+1|0])<<8|zb(w[b+2|0])<<16|zb(w[b+3|0])<<24,16),u[f>>1]=g;a=a+2|0;b=b+4|0;c=c-1|0;if(c){continue}break}}gb=d+16|0;return e<<2}function cQ(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=gb-16|0;gb=d;v[d+12>>2]=c>>>2;v[d+8>>2]=v[a>>2];e=v[Fb(d+12|0,d+8|0)>>2];b=zb(b);if(e){a=v[a+20>>2];c=e;while(1){f=a,g=id(zb(w[b+3|0])|zb(w[b+2|0])<<8|zb(w[b+1|0])<<16|zb(w[b|0])<<24,16),u[f>>1]=g;a=a+2|0;b=b+4|0;c=c-1|0;if(c){continue}break}}gb=d+16|0;return e<<2}function Vka(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0;a:{if(!Jd(a)){break a}f=v[a>>2];if(f>>>0<=c>>>0|f-c>>>0<d>>>0){break a}Pl(b);bp(b,a);v[b+20>>2]=0;v[b>>2]=d;if(!Ql(b)){break a}if(v[a>>2]!=(d|0)){Gw(b+68|0)}hc(zb(v[b+20>>2]),zb(v[a+20>>2])+c|0,d);v[b+8>>2]=e?d:0;v[b+4>>2]=0;u[b+34>>1]=x[b+34>>1]&65533|(e?2:0)}}function cY(){var a=0,b=0;a=gb-240|0;gb=a;a:{b:{if(t[90784]&1){break b}if(!Qd(90784)){break b}v[22656]=0;X(43);b=v[22656];v[22656]=0;if((b|0)==1){break a}v[22656]=0;_(44,a+120|0);b=v[22656];v[22656]=0;if((b|0)==1){break a}hc(90664,hc(a,a+120|0,120),116);Pd(90784)}gb=a+240|0;return 90664}a=P()|0;O()|0;$e(90784);S(a|0);L()}function Qga(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=gb-32|0;gb=d;b=gg(d,b);v[22656]=0;U(1165,d+16|0,b|0,c|0);e=v[22656];v[22656]=0;a:{b:{if((e|0)!=1){v[22656]=0;U(71,a|0,d+16|0,c|0);a=v[22656];v[22656]=0;if((a|0)==1){break b}vb(d+16|0);vb(b);gb=d+32|0;return}c=P()|0;O()|0;break a}c=P()|0;O()|0;vb(d+16|0)}vb(b);S(c|0);L()}function m8(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=Ig(a);a:{c=v[b+4>>2];if(!c){break a}v[22656]=0;R(2087,a|0,c|0);c=v[22656];v[22656]=0;if((c|0)!=1){c=v[b>>2];e=v[b>>2];f=B(v[b+4>>2],12);b=v[b+4>>2];v[22656]=0;Y(2088,a|0,c|0,e+f|0,b|0);b=v[22656];v[22656]=0;if((b|0)!=1){break a}}a=P()|0;O()|0;xF(d);S(a|0);L()}return a|0}function cea(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;e=gb-16|0;gb=e;a:{b=Tk(e,a+8|0,b);if(v[b>>2]!=v[b+4>>2]){while(1){d=v[a+16>>2];f=v[b>>2];v[22656]=0;lq(d,f,c);d=v[22656];v[22656]=0;if((d|0)==1){break a}d=v[b>>2]+4|0;v[b>>2]=d;if((d|0)!=v[b+4>>2]){continue}break}}_c(b);gb=e+16|0;return}a=P()|0;O()|0;_c(b);S(a|0);L()}function Nna(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;e=gb-16|0;gb=e;a:{b=Cy(e,a+8|0,b);if(v[b>>2]!=v[b+4>>2]){while(1){d=v[a+16>>2];f=v[b>>2];v[22656]=0;rl(d,f,c);d=v[22656];v[22656]=0;if((d|0)==1){break a}d=v[b>>2]+1|0;v[b>>2]=d;if((d|0)!=v[b+4>>2]){continue}break}}_c(b);gb=e+16|0;return}a=P()|0;O()|0;_c(b);S(a|0);L()}function Hfa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;e=gb-16|0;gb=e;a:{b=Tk(e,a+8|0,b);if(v[b>>2]!=v[b+4>>2]){while(1){d=v[a+16>>2];f=v[b>>2];v[22656]=0;ep(d,f,c);d=v[22656];v[22656]=0;if((d|0)==1){break a}d=v[b>>2]+4|0;v[b>>2]=d;if((d|0)!=v[b+4>>2]){continue}break}}_c(b);gb=e+16|0;return}a=P()|0;O()|0;_c(b);S(a|0);L()}function ou(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;f=gb-16|0;gb=f;if(b){e=f+8|0;Db(e,a+1074312|0,73);k=Cb(e)?c- -64|0:c;i=Hj(a);l=i^1;c=120;g=1;while(1){e=c>>>1|0;j=e+g|0;h=_g(a,j,k,d);a:{if(!((h>>>0<=b>>>0|i)==1&((h|0)!=0&l|b>>>0<=h>>>0))){g=j+1|0;c=(e^-1)+c|0;break a}c=e}if(c){continue}break}}gb=f+16|0;return g}function ofa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=ju(a+60|0);v[a>>2]=75688;v[d>>2]=75708;v[22656]=0;e=a+8|0;W(106,a|0,75720,e|0)|0;f=v[22656];v[22656]=0;if((f|0)!=1){a:{v[a>>2]=75688;v[d>>2]=75708;v[22656]=0;W(107,e|0,b|0,c|8)|0;b=v[22656];v[22656]=0;if((b|0)==1){break a}return a|0}}a=P()|0;O()|0;oh(d);S(a|0);L()}function Wfa(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0;b=gb-16|0;gb=b;d=a+1298260|0;if(!Dd(d)){f=b;c=gb-16|0;gb=c;e=sf(532);a=v[a+24620>>2];v[22656]=0;g=Q(1313,e|0,a|0)|0;a=v[22656];v[22656]=0;a:{if((a|0)!=1){a=v[Wi(c+8|0,g)>>2];gb=c+16|0;break a}a=P()|0;O()|0;Yb(e);S(a|0);L()}v[f+8>>2]=a;a=b+8|0;XO(d,ce(a));ku(a)}gb=b+16|0}function $Z(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;e=gb-16|0;gb=e;a:{b=Fn(e,a+8|0,b);if(v[b>>2]!=v[b+4>>2]){while(1){d=v[a+16>>2];f=v[b>>2];v[22656]=0;xn(d,f,c);d=v[22656];v[22656]=0;if((d|0)==1){break a}d=v[b>>2]+2|0;v[b>>2]=d;if((d|0)!=v[b+4>>2]){continue}break}}_c(b);gb=e+16|0;return}a=P()|0;O()|0;_c(b);S(a|0);L()}function jda(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=gb-48|0;gb=d;v[d+44>>2]=c;v[d+24>>2]=33;c=v[Fb(d+44|0,d+24|0)>>2];if(!Pb(a,c)){c=nf(a)}e=d+24|0;GC(e,b);f=wd(d+32|0,v[e>>2],c);g=v[f+4>>2];v[d+8>>2]=v[f>>2];v[d+12>>2]=g;cc(d+16|0,a,d+8|0);GC(e,b);Qb(v[e>>2]+c|0,0,33-c|0);Rb(a,v[d+44>>2]);gb=d+48|0;return c|0}function eA(a,b){var c=0,d=0,e=0;VV(a);lp(a,b);v[a>>2]=v[b>>2];v[a+4>>2]=v[b+4>>2];c=v[wb(b)>>2];d=wb(a),e=c,v[d>>2]=e;d=wb(b),e=0,v[d>>2]=e;v[b>>2]=0;v[b+4>>2]=0;t[a+12|0]=w[b+12|0];c=w[b+13|0]|w[b+14|0]<<8|(w[b+15|0]<<16|w[b+16|0]<<24);t[a+13|0]=c;t[a+14|0]=c>>>8;t[a+15|0]=c>>>16;t[a+16|0]=c>>>24;t[a+17|0]=w[b+17|0]}function d7(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0;a:{if(!v[b+28>>2]){break a}if((kb[v[b+32>>2]](v[b+24>>2],c,0,0)|0)<0){break a}c=v[d>>2];f=yb(d);if(!f){break a}while(1){b:{e=kb[v[b+28>>2]](v[b+24>>2],c,f)|0;g=e+g|0;h=g>>>0<e>>>0?h+1|0:h;if(!e){break b}c=c+e|0;f=f-e|0;if(f){continue}}break}e=g}ok(a,d,e)}function C$(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=gb-32|0;gb=d;b=gg(d,b);v[22656]=0;U(176,d+16|0,b|0,c|0);e=v[22656];v[22656]=0;a:{b:{if((e|0)!=1){v[22656]=0;U(5,a|0,d+16|0,c|0);a=v[22656];v[22656]=0;if((a|0)==1){break b}vb(d+16|0);vb(b);gb=d+32|0;return}c=P()|0;O()|0;break a}c=P()|0;O()|0;vb(d+16|0)}vb(b);S(c|0);L()}function gO(a,b,c,d,e){var f=0,g=0,h=0;if((e|0)!=10){f=c;while(1){a:{if((b|0)==(f|0)){f=b;g=d;break a}f=f-1|0;g=(d>>>0)/(e>>>0)|0;t[f|0]=w[(d-B(g,e)|0)+1991|0];h=d>>>0>=e>>>0;d=g;if(h){continue}}break}b:{if(!g){d=c-f|0;if(d){break b}}v[a+4>>2]=61;v[a>>2]=c;return}b=yh(b,f,d);v[a+4>>2]=0;v[a>>2]=b+d;return}JA(a,b,c,d)}function J$(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;if(Sg(a,v[b+8>>2],e)){fx(b,c,d);return}a:{if(!Sg(a,v[b>>2],e)){break a}if(!(v[b+16>>2]!=(c|0)&v[b+20>>2]!=(c|0))){if((d|0)!=1){break a}v[b+32>>2]=1;return}v[b+20>>2]=c;v[b+32>>2]=d;v[b+40>>2]=v[b+40>>2]+1;if(!(v[b+36>>2]!=1|v[b+24>>2]!=2)){t[b+54|0]=1}v[b+44>>2]=4}}function Yka(a,b){a=a|0;b=b|0;var c=0,d=0;if(v[a+4>>2]!=v[wb(a)>>2]){c=gb-16|0;gb=c;v[c>>2]=a;a=v[a+4>>2];v[c+4>>2]=a;v[c+8>>2]=a+12;UT(v[c+4>>2],b);v[c+4>>2]=v[c+4>>2]+12;$b(c);gb=c+16|0;return}d=gb-32|0;gb=d;c=wb(a);c=Zu(d+8|0,UB(a,Ec(a)+1|0),Ec(a),c);UT(v[c+8>>2],b);v[c+8>>2]=v[c+8>>2]+12;eU(a,c);dU(c);gb=d+32|0}function Gx(a,b,c,d){var e=0,f=0,g=0,h=0;e=gb-160|0;gb=e;f=e+16|0;Qb(f,0,144);v[e+92>>2]=-1;v[e+60>>2]=b;v[e+24>>2]=-1;v[e+20>>2]=b;wi(f,0,0);RH(e,f,d,1);d=v[e+8>>2];f=v[e+12>>2];g=v[e>>2];h=v[e+4>>2];if(c){v[c>>2]=((v[e+20>>2]+v[e+136>>2]|0)-v[e+24>>2]|0)+b}v[a>>2]=g;v[a+4>>2]=h;v[a+8>>2]=d;v[a+12>>2]=f;gb=e+160|0}function yE(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;e=gb-16|0;gb=e;a:{d=Fg(e,a,b);b=v[d+4>>2];g=v[d+8>>2];if((b|0)!=(g|0)){while(1){f=wb(a);v[22656]=0;ep(f,b,c);f=v[22656];v[22656]=0;if((f|0)==1){break a}b=b+4|0;v[d+4>>2]=b;if((b|0)!=(g|0)){continue}break}}$b(d);gb=e+16|0;return}a=P()|0;O()|0;$b(d);S(a|0);L()}function up(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;e=gb-16|0;gb=e;a:{d=li(e,a,b);b=v[d+4>>2];g=v[d+8>>2];if((b|0)!=(g|0)){while(1){f=wb(a);v[22656]=0;xn(f,b,c);f=v[22656];v[22656]=0;if((f|0)==1){break a}b=b+2|0;v[d+4>>2]=b;if((b|0)!=(g|0)){continue}break}}$b(d);gb=e+16|0;return}a=P()|0;O()|0;$b(d);S(a|0);L()}function ld(a,b){var c=0,d=0,e=0,f=0,g=0;d=b;b=JH(b);e=gb-16|0;gb=e;c=Xp(a);a:{if(c>>>0>=b>>>0){f=Jb(a);g=f;c=b;b:{c:{if(b){v[22656]=0;CH(g,d,c);d=v[22656];v[22656]=0;if((d|0)==1){break c}}break b}V(0)|0;O()|0;Bb();L()}v[e+12>>2]=0;Ge((b<<2)+f|0,e+12|0);jh(a,b);break a}f=a;a=Ab(a);IG(f,c,b-c|0,a,0,a,b,d)}gb=e+16|0}function iU(a){var b=0,c=0;a:{if((w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24))!=860902483){break a}b=a+4|0;if(Ib(w[b|0]|w[b+1|0]<<8)>>>0>2|w[a+6|0]>128){break a}b=a+200|0;if(Ib(w[b|0]|w[b+1|0]<<8)>>>0>3999){break a}b=a+140|0;if(!Ib(w[b|0]|w[b+1|0]<<8)){break a}a=a+148|0;c=(Ib(w[a|0]|w[a+1|0]<<8)|0)==50}return c}function eO(a,b,c,d,e){var f=0,g=0;a:{f=a;if((e|0)!=10){a=c;while(1){b:{if((a|0)==(b|0)){a=b;break b}g=d&255;d=(g|0)/(e|0)|0;a=a-1|0;t[a|0]=w[(g-B(d,e)|0)+1991|0];if(d&255){continue}}break}c:{if(!(d&255)){d=c-a|0;if(d){break c}}v[f+4>>2]=61;v[f>>2]=c;break a}a=yh(b,a,d);v[f+4>>2]=0;v[f>>2]=a+d;break a}XP(f,b,c,d)}}function XC(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;e=gb-16|0;gb=e;a:{d=Br(e,a,b);b=v[d+4>>2];g=v[d+8>>2];if((b|0)!=(g|0)){while(1){f=wb(a);v[22656]=0;JC(f,b,c);f=v[22656];v[22656]=0;if((f|0)==1){break a}b=b+6|0;v[d+4>>2]=b;if((b|0)!=(g|0)){continue}break}}$b(d);gb=e+16|0;return}a=P()|0;O()|0;$b(d);S(a|0);L()}function En(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;e=gb-16|0;gb=e;a:{d=Ai(e,a,b);b=v[d+4>>2];g=v[d+8>>2];if((b|0)!=(g|0)){while(1){f=wb(a);v[22656]=0;rl(f,b,c);f=v[22656];v[22656]=0;if((f|0)==1){break a}b=b+1|0;v[d+4>>2]=b;if((b|0)!=(g|0)){continue}break}}$b(d);gb=e+16|0;return}a=P()|0;O()|0;$b(d);S(a|0);L()}function mY(a,b){a=a|0;b=b|0;var c=0,d=0;c=gb-16|0;gb=c;b=Br(c,a,b);a=v[b+4>>2];d=v[b+8>>2];if((a|0)!=(d|0)){while(1){t[a|0]=0;t[a+1|0]=0;t[a+2|0]=0;t[a+3|0]=0;t[a+4|0]=0;t[a+5|0]=0;t[a+4|0]=6;t[a+5|0]=0;t[a|0]=0;t[a+1|0]=0;t[a+2|0]=8;t[a+3|0]=4;a=a+6|0;v[b+4>>2]=a;if((a|0)!=(d|0)){continue}break}}$b(b);gb=c+16|0}function dka(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;a:{b:{c:{d:{e:{f:{if((b|0)<=28590){if((b|0)==437){break c}if((b|0)==1252){break b}if((b|0)!=20127){break f}e=1;break a}if((b|0)==28591){break e}if((b|0)==28605){break d}e=0;if((b|0)==65001){break a}}e=c;break a}e=2;break a}e=3;break a}e=5;break a}e=8}sT(a,e,d)}function P8(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;a:{a=$l(a);d=$l(b);b=gb-32|0;gb=b;v[b+24>>2]=c;b:{if((a|0)!=(d|0)){while(1){c=Tb(b+8|0,v[a>>2]);v[22656]=0;R(2117,b+24|0,c|0);e=v[22656];v[22656]=0;if((e|0)==1){break b}vb(c);a=a+4|0;if((d|0)!=(a|0)){continue}break}}gb=b+32|0;break a}a=P()|0;O()|0;vb(c);S(a|0);L()}}function xE(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=gb-16|0;gb=d;a:{c=gw(d,a,b);b=v[c+4>>2];f=v[c+8>>2];if((b|0)!=(f|0)){while(1){e=wb(a);v[22656]=0;R(342,e|0,b|0);e=v[22656];v[22656]=0;if((e|0)==1){break a}b=b+20|0;v[c+4>>2]=b;if((b|0)!=(f|0)){continue}break}}$b(c);gb=d+16|0;return}a=P()|0;O()|0;$b(c);S(a|0);L()}function Rt(a){var b=0,c=0,d=0,e=0;b=Ek(+z[a+4228>>2]*8)*.25+-.25;A[a+4248>>3]=b;if(w[a+4240|0]){d=a;if(b>45e-5){c=Tp(b)/.6931471805599453;b=c-H(c);e=c-b;c=0;a:{if(b<.2075187496394219){break a}c=.4150374992788438;if(b<.5){break a}c=b<.792481250360578?.5849625007211562:1}b=Ek(e+c)*.5}else{b=0}A[d+4248>>3]=b}Qt(a)}function XX(a){var b=0,c=0;a:{if((w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24))!=320012546|(w[a+4|0]|w[a+5|0]<<8|(w[a+6|0]<<16|w[a+7|0]<<24))!=184619540|w[a+8|0]>1){break a}b=a+9|0;if(!w[b|0]|w[b|0]>8){break a}b=a+10|0;if((w[b|0]|w[b+1|0]<<8)>>>0>4096){break a}a=a+12|0;c=(w[a|0]|w[a+1|0]<<8)>>>0<4097}return c}function Wja(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=gb-48|0;gb=d;v[d+44>>2]=c;v[d+24>>2]=4896;c=v[Fb(d+44|0,d+24|0)>>2];if(!Pb(a,c)){c=nf(a)}e=d+24|0;MC(e,b);f=wd(d+32|0,v[e>>2],c);g=v[f+4>>2];v[d+8>>2]=v[f>>2];v[d+12>>2]=g;cc(d+16|0,a,d+8|0);MC(e,b);Qb(v[e>>2]+c|0,0,4896-c|0);Rb(a,v[d+44>>2]);gb=d+48|0}function Xpa(a,b){a=a|0;b=b|0;var c=0;jv(a,b);Of(b);a=w[b+3|0];a:{if((a|0)!=9){if((a|0)!=19){break a}a=w[b+5|0];c=a&240;if((c|0)!=128){if((c|0)!=64){if((c|0)!=48|a>>>0>49){break a}t[b+5|0]=159;t[b+3|0]=20;return}if((a|0)!=64){break a}t[b+3|0]=0;t[b|0]=254;return}t[b+3|0]=20;t[b+5|0]=a&15|160;return}t[b+3|0]=0}}function CC(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;hW(a,b);e=b+8|0;Wc(a,Xb(w[e|0]|w[e+1|0]<<8|(w[e+2|0]<<16|w[e+3|0]<<24))+504|0);gW(a,d);a:{b=b+32|0;if(!Xb(w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24))){break a}if(!Wc(a,Xb(w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24)))){break a}EC(a,c);return}Qb(c,0,80)}function aka(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=gb-48|0;gb=d;v[d+44>>2]=c;v[d+24>>2]=263;c=v[Fb(d+44|0,d+24|0)>>2];if(!Pb(a,c)){c=nf(a)}e=d+24|0;ZS(e,b);f=wd(d+32|0,v[e>>2],c);g=v[f+4>>2];v[d+8>>2]=v[f>>2];v[d+12>>2]=g;cc(d+16|0,a,d+8|0);ZS(e,b);Qb(v[e>>2]+c|0,0,263-c|0);Rb(a,v[d+44>>2]);gb=d+48|0}function U6(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;a:{if(w[b+40|0]){break a}if(!v[b+28>>2]){t[b+40|0]=1;break a}d=v[c>>2];e=yb(c);b:{if(!e){break b}while(1){f=kb[v[b+28>>2]](v[b+24>>2],d,e)|0;if(!f){t[b+40|0]=1;break b}d=d+f|0;g=f+g|0;h=g>>>0<f>>>0?h+1|0:h;e=e-f|0;if(e){continue}break}}d=g}ok(a,c,d)}function Nfa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=gb-16|0;gb=c;e=gb-16|0;gb=e;d=gb-16|0;gb=d;_e(c,1);Ir(c,1,b<<24>>24);t[d+15|0]=0;Bd(c+1|0,d+15|0);gb=d+16|0;gb=e+16|0;b=c;d=Jb(c);e=Ab(c);v[22656]=0;W(117,a|0,d|0,e|0)|0;d=v[22656];v[22656]=0;if((d|0)!=1){vb(b);gb=c+16|0;return a|0}a=P()|0;O()|0;vb(b);S(a|0);L()}function ES(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=gb-16|0;gb=c;e=Jk(a);a=b+236|0;b=Ou(a);a:{if((a|0)!=(b|0)){while(1){d=x[a>>1];u[c+14>>1]=d;if(d){v[22656]=0;U(1084,c|0,e|0,c+14|0);d=v[22656];v[22656]=0;if((d|0)==1){break a}}a=a+2|0;if((b|0)!=(a|0)){continue}break}}gb=c+16|0;return}a=P()|0;O()|0;nr(e);S(a|0);L()}function q3(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0;g=gb-32|0;gb=g;h=v[20315];v[g+24>>2]=v[20314];v[g+28>>2]=h;h=v[20313];v[g+16>>2]=v[20312];v[g+20>>2]=h;h=v[20311];v[g+8>>2]=v[20310];v[g+12>>2]=h;h=v[20309];v[g>>2]=v[20308];v[g+4>>2]=h;h=a;a=g+32|0;b=jk(h,b,c,d,e,f,g,a);gb=a;return b|0}function Vo(a,b,c,d){var e=0,f=0,g=0;a:{e=v[c>>2];if(e|v[d>>2]){if(!b){break a}while(1){e=id((id(0-e|0,31)&255)+e|0,8);f=v[d>>2];f=id((id(0-f|0,31)&255)+f|0,8);v[c>>2]=v[c>>2]-e;v[d>>2]=v[d>>2]-f;e=(g<<3)+a|0;v[e>>2]=v[c>>2];v[e+4>>2]=v[d>>2];g=g+1|0;if((g|0)==(b|0)){break a}e=v[c>>2];continue}}Qb(a,0,b<<3)}}function OA(a,b){var c=0;c=gb-32|0;gb=c;v[c+24>>2]=a;v[c+28>>2]=b;v[c+16>>2]=0;v[c+20>>2]=0;v[22656]=0;v[c+8>>2]=-1;v[c+12>>2]=0;a=Pr(c+24|0,c+8|0);b=v[22656];v[22656]=0;a:{if((b|0)==1){break a}v[22656]=0;a=Py(c+16|0,a);b=v[22656];v[22656]=0;if((b|0)==1){break a}gb=c+32|0;return v[a>>2]}V(0)|0;O()|0;Bb();L()}function Kfa(a,b){a=a|0;b=b|0;var c=0,d=0;a=Kb(a);c=Ab(b);v[22656]=0;R(65,a|0,c|0);c=v[22656];v[22656]=0;if((c|0)!=1){a:{if(Ab(b)){while(1){c=t[pc(b,d)|0];v[22656]=0;R(66,a|0,hg(c)|0);c=v[22656];v[22656]=0;if((c|0)==1){break a}d=d+1|0;if(Ab(b)>>>0>d>>>0){continue}break}}return}}b=P()|0;O()|0;vb(a);S(b|0);L()}function HW(a,b){var c=0,d=0,e=0;d=gb-16|0;gb=d;v[d+12>>2]=v[a+4>>2];c=v[b+4>>2];v[22656]=0;v[d+8>>2]=c;c=Fb(d+12|0,d+8|0);e=v[22656];v[22656]=0;if((e|0)!=1){c=Wo(v[a>>2],v[b>>2],v[c>>2]);a:{if(c){break a}c=0;if(v[a+4>>2]==v[b+4>>2]){break a}c=y[a+4>>2]<y[b+4>>2]?-1:1}gb=d+16|0;return c}V(0)|0;O()|0;Bb();L()}function nna(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=gb-48|0;gb=d;v[d+44>>2]=c;v[d+24>>2]=22;c=v[Fb(d+44|0,d+24|0)>>2];if(!Pb(a,c)){c=nf(a)}e=d+24|0;Gv(e,b);f=wd(d+32|0,v[e>>2],c);g=v[f+4>>2];v[d+8>>2]=v[f>>2];v[d+12>>2]=g;cc(d+16|0,a,d+8|0);Gv(e,b);Qb(v[e>>2]+c|0,0,22-c|0);Rb(a,v[d+44>>2]);gb=d+48|0}function kna(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=gb-48|0;gb=d;v[d+44>>2]=c;v[d+24>>2]=40;c=v[Fb(d+44|0,d+24|0)>>2];if(!Pb(a,c)){c=nf(a)}e=d+24|0;vC(e,b);f=wd(d+32|0,v[e>>2],c);g=v[f+4>>2];v[d+8>>2]=v[f>>2];v[d+12>>2]=g;cc(d+16|0,a,d+8|0);vC(e,b);Qb(v[e>>2]+c|0,0,40-c|0);Rb(a,v[d+44>>2]);gb=d+48|0}function Zaa(a){a=a|0;var b=0;v[22656]=0;_(1934,a|0);b=v[22656];v[22656]=0;if((b|0)!=1){return v[a+16>>2]}b=V(0)|0;O()|0;Z(b|0)|0;v[22656]=0;Y(1911,2782,a|0,0,0);a=v[22656];v[22656]=0;if((a|0)!=1){$();return-1}a=P()|0;O()|0;v[22656]=0;X(20);b=v[22656];v[22656]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}function WB(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;c=a;d=gb-96|0;gb=d;SU(b,d,d+96|0);b=0;while(1){e=b<<3;f=e+c|0;g=d+e|0;e=v[g+4>>2];v[f>>2]=v[g>>2];v[f+4>>2]=e&65535;b=b+1|0;if((b|0)!=12){continue}break}v[c+104>>2]=0;v[c+96>>2]=!(v[c+88>>2]|v[c+92>>2]);v[c+100>>2]=0;gb=d+96|0;v[a+112>>2]=0;return a|0}function HN(a,b){var c=0,d=0,e=0,f=0;if((a|0)!=(b|0)){d=gb-16|0;gb=d;c=v[b>>2];e=v[b+4>>2];b=kr(c,e);a:{if(b>>>0<=pe(a)>>>0){if(Nb(a)>>>0<b>>>0){v[d+12>>2]=c;XV(d+12|0,Nb(a));f=c;c=v[d+12>>2];Rg(f,c,v[a>>2]);rz(a,c,e,b-Nb(a)|0);break a}hj(a,Rg(c,e,v[a>>2]));break a}EN(a);lw(a,fh(a,b));rz(a,c,e,b)}gb=d+16|0}}function kS(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;a:{switch(c+1|0){case 0:case 3:fB(a,b);return;default:break a}}d=gb-32|0;gb=d;v[d+28>>2]=c;u[d+26>>1]=0;v[d+12>>2]=2;c=d+16|0;e=a;a=d+28|0;eo(c,e,d+26|0,v[Fb(a,d+12|0)>>2]);yb(c);v[d+16>>2]=2;Fb(a,c);u[d+16>>1]=x[d+26>>1];u[b>>1]=w[c|0]|w[c+1|0]<<8;gb=d+32|0}function g8(a){a=a|0;var b=0,c=0,d=0;b=gb-32|0;gb=b;a:{b:{if(Bj(a)){zh(b+24|0);break b}c=b+8|0;po(c,a);v[22656]=0;c=T(2084,c|0)|0;d=v[22656];v[22656]=0;if((d|0)==1){break a}v[b+24>>2]=c;Yf(b+8|0)}if(Bj(a)){a=a+36|0}else{a=v[b+24>>2]}a=ko(a);xl(b+24|0);gb=b+32|0;return a|0}a=P()|0;O()|0;Yf(b+8|0);S(a|0);L()}function WM(a){a=a|0;var b=0,c=0;c=gb-16|0;gb=c;b=v[a+4232>>2];b=(b>>>1)+(b>>>6)|0;v[a+4220>>2]=b;v[22656]=0;v[c+12>>2]=0;U(1540,a+4208|0,b<<1,c+12|0);b=v[22656];v[22656]=0;a:{if((b|0)==1){b=V(89116)|0;if((O()|0)!=(ea(89116)|0)){break a}Z(b|0)|0;v[a+4220>>2]=0;$()}v[a+4224>>2]=0;gb=c+16|0;return}S(b|0);L()}function QZ(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=gb-48|0;gb=d;v[d+44>>2]=c;v[d+24>>2]=65;c=v[Fb(d+44|0,d+24|0)>>2];if(!Pb(a,c)){c=nf(a)}e=d+24|0;hw(e,b);f=wd(d+32|0,v[e>>2],c);g=v[f+4>>2];v[d+8>>2]=v[f>>2];v[d+12>>2]=g;cc(d+16|0,a,d+8|0);hw(e,b);Qb(v[e>>2]+c|0,0,65-c|0);Rb(a,v[d+44>>2]);gb=d+48|0}function rba(){var a=0,b=0;v[22656]=0;a=v[22656];v[22656]=0;a:{if((a|0)==1){a=V(0)|0;O()|0;Z(a|0)|0;v[22656]=0;Y(1911,7167,0,0,0);a=v[22656];v[22656]=0;if((a|0)==1){break a}$();a=0}else{a=19923028}return a|0}a=P()|0;O()|0;v[22656]=0;X(20);b=v[22656];v[22656]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}function nw(a,b){var c=0,d=0,e=0;c=gb-32|0;gb=c;a:{if(!Pb(a,256)){a=gb-16|0;gb=a;d=gb-16|0;gb=d;e=b+256|0;while(1){Hf(b);b=b+1|0;if((e|0)!=(b|0)){continue}break}gb=d+16|0;gb=a+16|0;break a}d=gb-16|0;gb=d;bc(c+24|0,b,256);gb=d+16|0;b=v[c+28>>2];v[c+8>>2]=v[c+24>>2];v[c+12>>2]=b;kd(c+16|0,a,c+8|0)}gb=c+32|0}function k3(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;c=gb-128|0;gb=c;v[c+12>>2]=c+116;d=a+8|0;a=c+16|0;lH(d,a,c+12|0,e,f,g);e=v[c+12>>2];d=gb-16|0;gb=d;v[d+8>>2]=b;if((a|0)!=(e|0)){while(1){lI(d+8|0,t[a|0]);a=a+1|0;if((e|0)!=(a|0)){continue}break}b=v[d+8>>2]}gb=d+16|0;gb=c+128|0;return b|0}function jC(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0;g=gb-1024|0;gb=g;d=gb-32|0;gb=d;f=d+24|0;eC(f,g);f=yb(f);e=v[d+28>>2];h=v[d+24>>2];v[d+8>>2]=h;v[d+12>>2]=e;v[d>>2]=h;v[d+4>>2]=e;e=d+16|0;cc(e,a,d);e=yb(e);if((e|0)==(f|0)){Rb(a,yb(d+24|0))}gb=d+32|0;if((e|0)==(f|0)){i=hC(g,c)>>>0<=b>>>0}gb=g+1024|0;return i}function J9(a){a=a|0;var b=0;v[22656]=0;_(2007,a|0);b=v[22656];v[22656]=0;a:{if((b|0)==1){b=V(0)|0;O()|0;Z(b|0)|0;v[22656]=0;Y(1911,9228,a|0,0,0);a=v[22656];v[22656]=0;if((a|0)==1){break a}$();a=0}return a|0}a=P()|0;O()|0;v[22656]=0;X(20);b=v[22656];v[22656]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}function Vg(a,b){var c=0,d=0,e=0,f=0,g=0,h=0;d=gb-16|0;gb=d;g=a;h=a;a:{if(!b){b=0;break a}c=b>>31;e=c+b^c;c=E(e);Kf(d,e,0,0,0,c+81|0);e=0+v[d+8>>2]|0;c=(v[d+12>>2]^65536)+(16414-c<<16)|0;c=e>>>0<f>>>0?c+1|0:c;f=b&-2147483648|c;c=v[d+4>>2];b=v[d>>2]}v[h>>2]=b;v[g+4>>2]=c;v[a+8>>2]=e;v[a+12>>2]=f;gb=d+16|0}function Tca(a,b){a=a|0;b=b|0;var c=0,d=0;d=gb-16|0;gb=d;a:{b:{if((oc(v[a+20>>2]+4|0)|0)!=7){break b}c=v[v[a+20>>2]+4>>2];if((w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24))!=1869112133){break b}b=Vb(v[a+20>>2]+4|0);c=Zb(v[a+20>>2]+4|0);tn(d+8|0,a+4228|0);Vi(b,c,v[d+8>>2]);break a}cz(a,b)}Mt(a);gb=d+16|0}function Cha(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=gb-16|0;gb=d;a:{b=yT(d,a+8|0,b);a=v[b>>2];if((a|0)!=v[b+4>>2]){while(1){v[22656]=0;R(1090,a|0,c|0);a=v[22656];v[22656]=0;if((a|0)==1){break a}a=v[b>>2]+32|0;v[b>>2]=a;if(v[b+4>>2]!=(a|0)){continue}break}}_c(b);gb=d+16|0;return}a=P()|0;O()|0;_c(b);S(a|0);L()}function Ama(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=gb+-64|0;gb=d;b=-1;a:{if(!Wf(a,1084)){break a}Wl(a,1080);e=d+60|0;DV(a,e);c=e;e=CV(d+40|0);b=0;if(!BV(c,e)){break a}Wl(a,20);b=1;while(1){c=d+8|0;AV(a,c);f=lC(c)+f|0;c=b&65535;b=b+1|0;if(c>>>0<31){continue}break}b=y[e+4>>2]>=f>>>0}gb=d- -64|0;return b|0}function tba(){var a=0,b=0;v[22656]=0;a=v[22656];v[22656]=0;a:{if((a|0)==1){a=V(0)|0;O()|0;Z(a|0)|0;v[22656]=0;Y(1911,7139,0,0,0);a=v[22656];v[22656]=0;if((a|0)==1){break a}$();a=0}else{a=393216}return a|0}a=P()|0;O()|0;v[22656]=0;X(20);b=v[22656];v[22656]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}function PY(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=gb-32|0;gb=c;d=Pb(a,8);a:{if(!d){a=gb-16|0;gb=a;e=gb-16|0;gb=e;f=b+8|0;while(1){Hf(b);b=b+1|0;if((f|0)!=(b|0)){continue}break}gb=e+16|0;gb=a+16|0;break a}zD(c+24|0,b);b=v[c+28>>2];v[c+8>>2]=v[c+24>>2];v[c+12>>2]=b;kd(c+16|0,a,c+8|0)}gb=c+32|0;return d|0}function MM(a){a=a|0;var b=0,c=0,d=0,e=0;c=A[a+4264>>3]*+y[v[a+16>>2]+1074376>>2];a:{if(D(c)<0x8000000000000000){b=c;e=~~b>>>0;d=D(b)>=1?~~(b>0?F(H(b*2.3283064365386963e-10),4294967295):I((b-+(~~b>>>0>>>0))*2.3283064365386963e-10))>>>0:0;break a}d=-2147483648}A[a+4256>>3]=c-(+(e>>>0)+ +(d|0)*4294967296)}function Doa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=gb-32|0;gb=c;e=c+24|0;MC(e,b);e=yb(e);d=v[c+28>>2];f=v[c+24>>2];v[c+8>>2]=f;v[c+12>>2]=d;v[c>>2]=f;v[c+4>>2]=d;d=c+16|0;cc(d,a,c);d=yb(d);if((d|0)==(e|0)){Rb(a,yb(c+24|0))}gb=c+32|0;a=(d|0)==(e|0);if(!a){c=gb-16|0;gb=c;Qb(b,0,4896);gb=c+16|0}return a|0}function yl(a,b){a=a|0;b=b|0;var c=0;c=gb-32|0;gb=c;$f(c,b);v[22656]=0;R(2041,c+16|0,c|0);b=v[22656];v[22656]=0;a:{b:{if((b|0)!=1){v[22656]=0;U(2042,a|0,0,c+16|0);a=v[22656];v[22656]=0;if((a|0)==1){break b}Hc(c+16|0);vb(c);gb=c+32|0;return}b=P()|0;O()|0;break a}b=P()|0;O()|0;Hc(c+16|0)}vb(c);S(b|0);L()}function sha(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=gb-16|0;gb=d;a:{c=cq(d,a,b);b=v[c+4>>2];e=v[c+8>>2];if((b|0)!=(e|0)){while(1){wb(a);v[22656]=0;zR(b);f=v[22656];v[22656]=0;if((f|0)==1){break a}b=b+16|0;v[c+4>>2]=b;if((b|0)!=(e|0)){continue}break}}$b(c);gb=d+16|0;return}a=P()|0;O()|0;$b(c);S(a|0);L()}function rP(a,b,c){var d=0,e=0,f=0,g=0,h=0;e=v[a+1074416>>2];a=v[a+1074392>>2];t[b+851|0]=w[b+851|0]|32;g=b;d=a?w[b+813|0]:0;h=v[b+852>>2]+((c|0)>=0?0-d|0:d)|0;f=(+(a>>>0)+1)*+(c|0)/+(e>>>0);a:{if(D(f)<2147483648){d=~~f;break a}d=-2147483648}v[g+852>>2]=h+d;c=(a+1|0)==(e|0)?c:d;a=c>>31;t[b+813|0]=a^a+c}function oK(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;c=gb-16|0;gb=c;v[c+12>>2]=-1;v[22656]=0;v[c+8>>2]=2147483647;d=Fb(c+12|0,c+8|0);e=v[22656];v[22656]=0;a:{if((e|0)!=1){gb=c+16|0;c=v[d>>2];break a}V(0)|0;O()|0;Bb();L()}if(b>>>0>c>>>0){Sc();L()}c=Mc(b,1);v[a>>2]=c;v[a+4>>2]=c;f=wb(a),g=b+c|0,v[f>>2]=g}function mN(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=gb-16|0;gb=d;v[d+12>>2]=b;a:{if(pe(a)>>>0>=b>>>0){f=d,g=Nb(a),v[f+8>>2]=g;lN(v[a>>2],v[Fb(d+12|0,d+8|0)>>2],c);e=v[d+8>>2];b=v[d+12>>2];if(e>>>0<b>>>0){jz(a,b-e|0,c);break a}hj(a,v[a>>2]+(b<<2)|0);break a}EN(a);lw(a,fh(a,b));jz(a,b,c)}gb=d+16|0}function SJ(a,b){var c=0,d=0,e=0,f=0,g=0;d=gb-16|0;gb=d;c=a+4|0;a:{if(oc(c)>>>0>=v[a+16>>2]+b>>>0){break a}if(!oc(c)){Ok(c,yy(v[a+16>>2]+b|0,65536));break a}f=d,g=oc(c),v[f+12>>2]=g;e=xf(d+12|0);a=v[a+16>>2]+b|0;if(e>>>0<a>>>0){Ok(c,yy(a,65536));break a}f=d,g=oc(c),v[f+8>>2]=g;Ok(c,xf(d+8|0))}gb=d+16|0}function CQ(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=gb-16|0;gb=d;v[d+12>>2]=c>>>1;v[d+8>>2]=v[a>>2];e=v[Fb(d+12|0,d+8|0)>>2];b=zb(b);if(e){a=v[a+20>>2];c=e;while(1){f=a,g=zb(w[b|0])^128,t[f|0]=g;f=a,g=zb(w[b+1|0])^128,t[f+1|0]=g;a=a+2|0;b=b+2|0;c=c-1|0;if(c){continue}break}}gb=d+16|0;return e<<1}function BQ(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;e=gb-16|0;gb=e;v[e+12>>2]=c>>>1;v[e+8>>2]=v[a>>2];f=v[Fb(e+12|0,e+8|0)>>2];b=zb(b);if(f){a=v[a+20>>2];c=f;g=d;while(1){g=zb(w[b|0])+g|0;t[a|0]=g;d=zb(w[b+1|0])+d|0;t[a+1|0]=d;a=a+2|0;b=b+2|0;c=c-1|0;if(c){continue}break}}gb=e+16|0;return f<<1}function zH(a,b,c){var d=0,e=0,f=0,g=0;f=gb-16|0;gb=f;e=kr(b,c);if(e>>>0<=1073741807){a:{if(e>>>0<=1){_e(a,e);d=a;break a}g=om(e)+1|0;d=Si(a,g);ef(a,d);rg(a,g);de(a,e)}if((b|0)!=(c|0)){while(1){Ge(d,b);d=d+4|0;b=b+4|0;if((c|0)!=(b|0)){continue}break}}v[f+12>>2]=0;Ge(d,f+12|0);gb=f+16|0;return}vg();L()}function rx(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;f=gb-16|0;gb=f;h=b;c=JH(b);d=gb-16|0;gb=d;b=a;a:{if(c>>>0<=1073741807){b:{if(c>>>0<=1){_e(b,c);e=b;break b}g=om(c)+1|0;e=Si(b,g);ef(b,e);rg(b,g);de(b,c)}yi(e,h,c);v[d+12>>2]=0;Ge((c<<2)+e|0,d+12|0);gb=d+16|0;break a}vg();L()}gb=f+16|0;return a|0}function jB(a,b,c){var d=0,e=0,f=0,g=0;e=gb-16|0;gb=e;a:{d=IB(e,a,b);b=v[d+4>>2];f=v[d+8>>2];if((b|0)!=(f|0)){while(1){wb(a);v[22656]=0;R(1090,b|0,c|0);g=v[22656];v[22656]=0;if((g|0)==1){break a}b=b+32|0;v[d+4>>2]=b;if((b|0)!=(f|0)){continue}break}}$b(d);gb=e+16|0;return}a=P()|0;O()|0;$b(d);S(a|0);L()}function hba(){var a=0,b=0;v[22656]=0;a=v[22656];v[22656]=0;a:{if((a|0)==1){a=V(0)|0;O()|0;Z(a|0)|0;v[22656]=0;Y(1911,8398,0,0,0);a=v[22656];v[22656]=0;if((a|0)==1){break a}$();a=0}else{a=2048}return a|0}a=P()|0;O()|0;v[22656]=0;X(20);b=v[22656];v[22656]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}function FS(a,b,c){var d=0,e=0,f=0,g=0;f=gb-16|0;gb=f;e=Zh(b,c);if(e>>>0<=4294967279){a:{if(e>>>0<=10){_e(a,e);d=a;break a}g=Xk(e)+1|0;d=oi(a,g);ef(a,d);rg(a,g);de(a,e)}if((b|0)!=(c|0)){while(1){Bd(d,b);d=d+1|0;b=b+1|0;if((c|0)!=(b|0)){continue}break}}t[f+15|0]=0;Bd(d,f+15|0);gb=f+16|0;return}vg();L()}function oE(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=gb-16|0;gb=d;a:{c=li(d,a,b);b=v[c+4>>2];e=v[c+8>>2];if((b|0)!=(e|0)){while(1){wb(a);v[22656]=0;iw(b);f=v[22656];v[22656]=0;if((f|0)==1){break a}b=b+2|0;v[c+4>>2]=b;if((b|0)!=(e|0)){continue}break}}$b(c);gb=d+16|0;return}a=P()|0;O()|0;$b(c);S(a|0);L()}function iv(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=gb-16|0;gb=d;u[d+14>>1]=b;u[d+12>>1]=c;if((b|0)!=(c|0)){b=Vb(a);c=Zb(a);a=gb-16|0;gb=a;v[a>>2]=c;v[a+8>>2]=b;if(Gb(a+8|0,a)){while(1){if(x[v[a+8>>2]>>1]==x[d+14>>1]){u[v[a+8>>2]>>1]=x[d+12>>1]}b=a+8|0;of(b);if(Gb(b,a)){continue}break}}gb=a+16|0}gb=d+16|0}function gq(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=gb-16|0;gb=d;a:{c=Ai(d,a,b);b=v[c+4>>2];e=v[c+8>>2];if((b|0)!=(e|0)){while(1){wb(a);v[22656]=0;Hf(b);f=v[22656];v[22656]=0;if((f|0)==1){break a}b=b+1|0;v[c+4>>2]=b;if((b|0)!=(e|0)){continue}break}}$b(c);gb=d+16|0;return}a=P()|0;O()|0;$b(c);S(a|0);L()}function Zf(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;c=gb-48|0;gb=c;a:{if(!b){b=1;if(nd(a,5)){break a}b=ML(c+32|0);e=v[a+8>>2];f=v[d>>2];v[b+4>>2]=f-e;se(c,v[a+28>>2]);e=c+16|0;$L(e,c,v[d>>2],v[d+4>>2]);v[b+8>>2]=v[e+8>>2]}v[a>>2]=v[a>>2]|134217728;v[a+20>>2]=v[a+20>>2]+1;b=0}gb=c+48|0;return b|0}function Ur(a,b,c,d,e){var f=0,g=0,h=0,i=0,j=0;f=gb-16|0;gb=f;v[f+12>>2]=c;c=f+12|0;qc(c,256);qc(c,65535);h=x[f+12>>1];Af(a,h);if(h){c=0;while(1){g=w[b+c|0];a:{if((g|0)==(d|0)){g=65535;break a}if((e|0)!=(g|0)){break a}g=65534}i=fj(a,c),j=g,u[i>>1]=j;c=c+1|0;if((h|0)!=(c|0)){continue}break}}gb=f+16|0}function xea(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=gb-48|0;gb=c;d=c+40|0;b=x[b>>1];t[d|0]=b;t[d+1|0]=b>>>8;b=c+16|0;Cn(b,d);b=zb(v[b>>2]);e=c+8|0;Cn(e,d);b=Pj(c+24|0,b,zb(v[e>>2]+2|0));v[22656]=0;Q(1101,a|0,b|0)|0;a=v[22656];v[22656]=0;if((a|0)!=1){vb(b);gb=c+48|0;return}a=P()|0;O()|0;vb(b);S(a|0);L()}function qka(a,b,c){a=a|0;b=b|0;c=c|0;a:{switch(b|0){case 0:Rl(a,0,c);return;case 1:Rl(a,1,c);return;case 2:Rl(a,2,c);return;case 3:Rl(a,3,c);return;case 4:Rl(a,4,c);return;case 5:Rl(a,5,c);return;case 6:zS(a,24992,c);return;case 7:zS(a,26016,c);return;case 8:Rl(a,6,c);return;default:break a}}Kb(a)}function lha(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=gb-16|0;gb=d;v[d+12>>2]=b;a:{if(dg(a)>>>0>=b>>>0){f=d,g=oc(a),v[f+8>>2]=g;ni(v[a>>2],v[Fb(d+12|0,d+8|0)>>2],c);e=v[d+8>>2];b=v[d+12>>2];if(e>>>0<b>>>0){En(a,b-e|0,c);break a}Em(a,b+v[a>>2]|0);break a}Hv(a);Dn(a,qh(a,b));En(a,b,c)}gb=d+16|0}function eea(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=gb-16|0;gb=d;a=Kb(a);e=Ab(b);f=Ab(c);b=Jb(b);v[22656]=0;Y(116,a|0,b|0,e|0,e+f|0);b=v[22656];v[22656]=0;a:{if((b|0)!=1){b=Jb(c);v[22656]=0;W(117,a|0,b|0,f|0)|0;b=v[22656];v[22656]=0;if((b|0)!=1){break a}}b=P()|0;O()|0;vb(a);S(b|0);L()}gb=d+16|0}function R6(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0;f=gb-16|0;gb=f;v[f+8>>2]=d;d=v[pi(f,f+8|0)>>2];v[22656]=0;fa(1933,a+8|0,b|0,c|0,d|0,e|0)|0;b=v[22656];v[22656]=0;if((b|0)!=1){RJ(a);b=QJ(a+88|0);v[a>>2]=59720;v[b>>2]=59808;eg(f+8|0);gb=f+16|0;return a|0}a=P()|0;O()|0;eg(f+8|0);S(a|0);L()}function LG(a,b,c){var d=0,e=0,f=0,g=0,h=0;g=gb-16|0;gb=g;d=Ab(a);f=Kc(a);a:{if(f-d>>>0>=c>>>0){if(!c){break a}e=Jb(a);h=e;f=d;if(d){fm(c+e|0,e,f);b=(b>>>0>=e>>>0?d+e>>>0>b>>>0?c:0:0)+b|0}fm(h,b,c);b=c+d|0;jh(a,b);t[g+15|0]=0;Bd(b+e|0,g+15|0);break a}wp(a,f,(c+d|0)-f|0,d,0,0,c,b)}gb=g+16|0;return a}function S_(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;OF(a);h=wb(a);f=b+4|0;d=f;c=v[a+4>>2];g=v[a>>2];if((c|0)!=(g|0)){e=v[d>>2];while(1){c=c-36|0;NF(h,e-36|0,c);e=v[d>>2]-36|0;v[d>>2]=e;if((c|0)!=(g|0)){continue}break}}xc(a,f);xc(a+4|0,b+8|0);xc(wb(a),dc(b));v[b>>2]=v[b+4>>2];bl(a);$k(a);$k(a)}function RQ(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;fT(a);h=wb(a);f=b+4|0;d=f;c=v[a+4>>2];g=v[a>>2];if((c|0)!=(g|0)){e=v[d>>2];while(1){c=c-28|0;Au(h,e-28|0,c);e=v[d>>2]-28|0;v[d>>2]=e;if((c|0)!=(g|0)){continue}break}}xc(a,f);xc(a+4|0,b+8|0);xc(wb(a),dc(b));v[b>>2]=v[b+4>>2];_i(a);$i(a);$i(a)}function KQ(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;e=gb-16|0;gb=e;v[e+12>>2]=c>>>1;v[e+8>>2]=v[a>>2];f=v[Fb(e+12|0,e+8|0)>>2];b=zb(b);if(f){a=v[a+20>>2];c=f;while(1){g=zb(w[b|0])+d|0;d=g+zb(w[b+1|0])|0;u[a>>1]=d<<8|g&255;a=a+2|0;b=b+2|0;c=c-1|0;if(c){continue}break}}gb=e+16|0;return f<<1}function vea(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;wb(b);e=a;f=vh(a);a:{c=Nb(b);if(!c){break a}v[22656]=0;R(333,e|0,c|0);d=v[22656];v[22656]=0;if((d|0)!=1){d=v[b+4>>2];b=v[b>>2];v[22656]=0;Y(1497,e|0,b|0,d|0,c|0);b=v[22656];v[22656]=0;if((b|0)!=1){break a}}a=P()|0;O()|0;vv(f);S(a|0);L()}return a|0}function jz(a,b,c){var d=0,e=0,f=0,g=0;e=gb-16|0;gb=e;a:{d=Fg(e,a,b);b=v[d+4>>2];g=v[d+8>>2];if((b|0)!=(g|0)){while(1){f=wb(a);v[22656]=0;lq(f,b,c);f=v[22656];v[22656]=0;if((f|0)==1){break a}b=b+4|0;v[d+4>>2]=b;if((b|0)!=(g|0)){continue}break}}$b(d);gb=e+16|0;return}a=P()|0;O()|0;$b(d);S(a|0);L()}function dR(a,b,c){var d=0,e=0,f=0;d=Yd(a);e=fc(a);a:{if(d){f=wb(a);b:{while(1){c:{a=d+16|0;d:{if(Nl(f,c,a)){if(!v[d>>2]){break a}a=d;break d}if(!Nl(f,a,c)){break b}a=d+4|0;if(!v[d+4>>2]){break c}d=a;a=d}e=a;d=v[d>>2];continue}break}v[b>>2]=d;return a}v[b>>2]=d;return e}d=fc(a)}v[b>>2]=d;return d}function Lf(a){a=a|0;var b=0,c=0;v[a>>2]=50156;b=v[a+12>>2];if(v[b>>2]==(a|0)){v[b>>2]=v[a+4>>2]}b=v[a+20>>2];if(b){v[b>>2]=0;v[a+20>>2]=0}b=v[a+4>>2];if(b){v[b+8>>2]=v[a+8>>2]}c=v[a+8>>2];if(c){v[c+4>>2]=b}v[a+4>>2]=0;v[a+8>>2]=0;b=v[a+16>>2];v[b+946300>>2]=v[b+946300>>2]-1;HM(a+44|0);return a|0}function ms(a){var b=0,c=0,d=0,e=0;b=a;e=v[a+4>>2];a:{while(1){if(v[b+8>>2]==(e|0)){break a}c=v[b+16>>2];d=v[b+8>>2]-36|0;v[b+8>>2]=d;v[22656]=0;R(214,c|0,d|0);c=v[22656];v[22656]=0;if((c|0)!=1){continue}break}V(0)|0;O()|0;Bb();L()}if(v[a>>2]){ls(v[a+16>>2],v[a>>2],(v[dc(a)>>2]-v[a>>2]|0)/36|0)}}function jp(a){var b=0,c=0,d=0,e=0;b=a;e=v[a+4>>2];a:{while(1){if(v[b+8>>2]==(e|0)){break a}c=v[b+16>>2];d=v[b+8>>2]-20|0;v[b+8>>2]=d;v[22656]=0;R(348,c|0,d|0);c=v[22656];v[22656]=0;if((c|0)!=1){continue}break}V(0)|0;O()|0;Bb();L()}if(v[a>>2]){iE(v[a+16>>2],v[a>>2],(v[dc(a)>>2]-v[a>>2]|0)/20|0)}}function Er(a,b,c){var d=0,e=0,f=0,g=0,h=0;d=gb-16|0;gb=d;v[d+12>>2]=c;c=d+12|0;qc(c,128);qc(c,65535);f=x[d+12>>1];Af(a,f);if(f){c=0;while(1){e=w[b+c|0];a:{if((e|0)==65535){e=65535;break a}if((e|0)!=65535){break a}e=65534}g=fj(a,c),h=e,u[g>>1]=h;c=c+1|0;if((f|0)!=(c|0)){continue}break}}gb=d+16|0}function rN(a){var b=0,c=0,d=0,e=0;c=a;d=v[a+4>>2];a:{while(1){b=v[c+8>>2];if((b|0)==(d|0)){break a}e=v[c+16>>2];b=b-52|0;v[c+8>>2]=b;v[22656]=0;R(1325,e|0,b|0);b=v[22656];v[22656]=0;if((b|0)!=1){continue}break}V(0)|0;O()|0;Bb();L()}c=v[a>>2];if(c){dA(v[a+16>>2],c,(v[dc(a)>>2]-v[a>>2]|0)/52|0)}}function Hm(a,b){a=a|0;b=b|0;v[a>>2]=0;v[a+4>>2]=0;v[a+20>>2]=0;u[a+16>>1]=65535;v[a+8>>2]=0;v[a+12>>2]=0;v[a+24>>2]=11;v[a+28>>2]=b;mc(a+32|0);dd(a+44|0);v[a+72>>2]=0;v[a+76>>2]=0;v[a+64>>2]=0;v[a+56>>2]=0;v[a+60>>2]=0;v[a+80>>2]=0;v[a+84>>2]=0;v[a+88>>2]=0;v[a+92>>2]=0;v[a+96>>2]=0;return a|0}function DQ(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=gb-16|0;gb=d;v[d+12>>2]=c>>>1;v[d+8>>2]=v[a>>2];e=v[Fb(d+12|0,d+8|0)>>2];b=zb(b);if(e){a=v[a+20>>2];c=e;while(1){f=a,g=Wh(w[b|0]),t[f|0]=g;f=a,g=Wh(w[b+1|0]),t[f+1|0]=g;a=a+2|0;b=b+2|0;c=c-1|0;if(c){continue}break}}gb=d+16|0;return e<<1}function sd(a,b,c){var d=0,e=0;a:{b:{if(c>>>0>=4){if((a|b)&3){break b}while(1){if(v[a>>2]!=v[b>>2]){break b}b=b+4|0;a=a+4|0;c=c-4|0;if(c>>>0>3){continue}break}}if(!c){break a}}while(1){d=w[a|0];e=w[b|0];if((d|0)==(e|0)){b=b+1|0;a=a+1|0;c=c-1|0;if(c){continue}break a}break}return d-e|0}return 0}function fe(a){var b=C(0),c=C(0),d=0,e=0;d=(p(a),j(2));e=d>>>23&255;if(e>>>0<=149){if(e>>>0<=125){return C(a*C(0))}a=(d|0)>=0?a:C(-a);b=C(C(C(a+C(8388608))+C(-8388608))-a);a:{if(b>C(.5)){c=C(C(a+b)+C(-1));break a}a=C(a+b);c=a;if(!(b<=C(-.5))){break a}c=C(a+C(1))}a=c;a=(d|0)>=0?a:C(-a)}return a}function LS(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0;d=v[a+92>>2];e=v[a+96>>2];if(d|e){if(c){while(1){h=id((id(0-d|0,31)&255)+d|0,8);i=id((id(0-e|0,31)&255)+e|0,8);f=(g<<3)+b|0;d=d-h|0;v[f>>2]=d+v[f>>2];e=e-i|0;v[f+4>>2]=e+v[f+4>>2];g=g+1|0;if((g|0)!=(c|0)){continue}break}}v[a+96>>2]=e;v[a+92>>2]=d}}function EP(a,b,c,d){var e=0,f=0;f=gb-16|0;gb=f;e=-2147483648;e=!c|!(t[c+15|0]&1)?e:v[c+8>>2];a:{b:{if(!(!d|!(w[d+34|0]&32))){e=x[d+28>>1];break b}if((e|0)==-2147483648){break a}}Uo(b,e,a);c=f+8|0;Db(c,a+1074312|0,10);if(!Cb(c)|v[a+480208>>2]&16384){break a}v[b+88>>2]=v[b+88>>2]&-257}gb=f+16|0}function _d(a,b){var c=0,d=0,e=0,f=0;d=gb-16|0;gb=d;Ln(a);a=Wi(d+8|0,a);a:{if(Nb(465776)>>>0<=b>>>0){v[22656]=0;_(2533,b+1|0);c=v[22656];v[22656]=0;if((c|0)==1){break a}}c=v[Mb(465776,b)>>2];if(c){Nn(c)}c=ce(a);e=Mb(465776,b),f=c,v[e>>2]=f;_G(a);gb=d+16|0;return}b=P()|0;O()|0;_G(a);S(b|0);L()}function RX(a){var b=0,c=0;a:{if((w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24))!=777268804){break a}b=a+4|0;if(Xb(w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24))>>>0<14){break a}if(Xb(w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24))>>>0>256){break a}a=a+8|0;c=!Ib(w[a|0]|w[a+1|0]<<8)}return c}function wB(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=gb-16|0;gb=c;d=v[b+4>>2];v[c+8>>2]=v[b>>2];v[c+12>>2]=d;e=c,f=Ab(a),v[e+4>>2]=f;v[c>>2]=v[c+12>>2];a=Wo(Jb(a),v[c+8>>2],v[Fb(c+4|0,c)>>2]);a:{if(a){break a}a=-1;b=v[c>>2];d=v[c+4>>2];if(b>>>0>d>>>0){break a}a=b>>>0<d>>>0}gb=c+16|0;return a|0}function Zna(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;a:{switch(c+1|0){case 0:case 2:Vh(a,b);return;default:break a}}d=gb-32|0;gb=d;v[d+28>>2]=c;t[d+24|0]=0;v[d+12>>2]=1;c=d+16|0;e=a;a=d+28|0;eo(c,e,d+24|0,v[Fb(a,d+12|0)>>2]);yb(c);v[d+16>>2]=1;Fb(a,c);t[d+16|0]=w[d+24|0];t[b|0]=w[c|0];gb=d+32|0}function Zba(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;b=Fi(a,b,c,d);v[a+4208>>2]=1017370378;v[a+4212>>2]=0;v[a>>2]=52328;v[22656]=0;W(1532,a+44|0,2,2)|0;c=v[22656];v[22656]=0;a:{if((c|0)==1){break a}v[22656]=0;Th(b);c=v[22656];v[22656]=0;if((c|0)==1){break a}return a|0}a=P()|0;O()|0;Lf(b);S(a|0);L()}function On(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;$p(a);h=wb(a);f=b+4|0;d=f;c=v[a+4>>2];g=v[a>>2];if((c|0)!=(g|0)){e=v[d>>2];while(1){c=c-12|0;Pn(h,e-12|0,c);e=v[d>>2]-12|0;v[d>>2]=e;if((c|0)!=(g|0)){continue}break}}xc(a,f);xc(a+4|0,b+8|0);xc(wb(a),dc(b));v[b>>2]=v[b+4>>2];ax(a,Ec(a))}function OE(a,b,c){var d=0,e=0,f=0,g=0,h=0;d=gb-16|0;gb=d;v[d+12>>2]=c;c=d+12|0;qc(c,128);qc(c,65535);f=x[d+12>>1];Af(a,f);if(f){c=0;while(1){e=w[b+c|0];a:{if((e|0)==255){e=65535;break a}if((e|0)!=254){break a}e=65534}g=fj(a,c),h=e,u[g>>1]=h;c=c+1|0;if((f|0)!=(c|0)){continue}break}}gb=d+16|0}function JX(a,b,c){var d=0,e=0,f=0,g=0,h=0;d=gb-16|0;gb=d;v[d+12>>2]=c;c=d+12|0;qc(c,256);qc(c,65535);f=x[d+12>>1];Af(a,f);if(f){c=0;while(1){e=w[b+c|0];a:{if((e|0)==255){e=65535;break a}if((e|0)!=254){break a}e=65534}g=fj(a,c),h=e,u[g>>1]=h;c=c+1|0;if((f|0)!=(c|0)){continue}break}}gb=d+16|0}function GG(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=gb-16|0;gb=d;a=Kb(a);e=Nf(b);f=Ab(c);v[22656]=0;Y(2810,a|0,b|0,e|0,e+f|0);b=v[22656];v[22656]=0;a:{if((b|0)!=1){b=Jb(c);v[22656]=0;W(2487,a|0,b|0,f|0)|0;b=v[22656];v[22656]=0;if((b|0)!=1){break a}}b=P()|0;O()|0;vb(a);S(b|0);L()}gb=d+16|0}function Ev(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;vE(a);h=wb(a);f=b+4|0;d=f;c=v[a+4>>2];g=v[a>>2];if((c|0)!=(g|0)){e=v[d>>2];while(1){c=c-20|0;Fv(h,e-20|0,c);e=v[d>>2]-20|0;v[d>>2]=e;if((c|0)!=(g|0)){continue}break}}xc(a,f);xc(a+4|0,b+8|0);xc(wb(a),dc(b));v[b>>2]=v[b+4>>2];jE(a,Je(a))}function ZD(a,b,c){var d=0,e=0,f=0,g=0;d=gb-48|0;gb=d;v[d+44>>2]=c;v[d+24>>2]=192;c=v[Fb(d+44|0,d+24|0)>>2];if(!Pb(a,c)){c=nf(a)}e=d+24|0;Qr(e,b);f=wd(d+32|0,v[e>>2],c);g=v[f+4>>2];v[d+8>>2]=v[f>>2];v[d+12>>2]=g;cc(d+16|0,a,d+8|0);Qr(e,b);Qb(v[e>>2]+c|0,0,192-c|0);Rb(a,v[d+44>>2]);gb=d+48|0}function CL(a,b){var c=0;c=gb-32|0;gb=c;$f(c,b);v[22656]=0;U(2047,c+16|0,0,c|0);b=v[22656];v[22656]=0;a:{b:{if((b|0)!=1){v[22656]=0;R(2048,a|0,c+16|0);a=v[22656];v[22656]=0;if((a|0)==1){break b}Hc(c+16|0);vb(c);gb=c+32|0;return}b=P()|0;O()|0;break a}b=P()|0;O()|0;Hc(c+16|0)}vb(c);S(b|0);L()}function zQ(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=gb-16|0;gb=d;v[d+12>>2]=c>>>1;v[d+8>>2]=v[a>>2];e=v[Fb(d+12|0,d+8|0)>>2];b=zb(b);if(e){a=v[a+20>>2];c=e;while(1){f=a,g=(zb(w[b|0])|zb(w[b+1|0])<<8)^32768,u[f>>1]=g;a=a+2|0;b=b+2|0;c=c-1|0;if(c){continue}break}}gb=d+16|0;return e<<1}function wQ(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=gb-16|0;gb=d;v[d+12>>2]=c>>>1;v[d+8>>2]=v[a>>2];e=v[Fb(d+12|0,d+8|0)>>2];b=zb(b);if(e){a=v[a+20>>2];c=e;while(1){f=a,g=(zb(w[b+1|0])|zb(w[b|0])<<8)^32768,u[f>>1]=g;a=a+2|0;b=b+2|0;c=c-1|0;if(c){continue}break}}gb=d+16|0;return e<<1}function oP(a,b,c){var d=0;a:{if(v[a+480180>>2]==4){d=w[b+813|0];if(c){t[b+813|0]=d&15|c<<4;break a}c=(d&240)>>>4|0;break a}if(v[a+480180>>2]!=1048576){break a}if(c){t[b+813|0]=c;break a}c=w[b+813|0]}b:{if(!(t[b+851|0]&1)|!v[b+700>>2]){break b}c=c&255;if(!c){break b}sk(a,b,b+700|0,c<<2,0)}}function nM(a,b,c){var d=0,e=0,f=0;if(C(D(a))<C(0x8000000000000000)){d=~~a>>>0}else{d=0}f=d&-2147483648;e=f?0-d|0:d;a:{if(!((e|0)<0|(b|0)<=0)){while(1){d=b-1|0;e=e<<1;if(b>>>0<2){break a}b=d;if((e|0)>=0){continue}break a}}d=b}b=(e>>>31|0)+d<<31-c|(e&2147483647)>>>c;return C((f?b^-1|f:b)|0)}function iM(a){a=a|0;var b=0,c=0;c=gb-16|0;gb=c;b=v[a+4256>>2];v[a+4240>>2]=b<<1;v[22656]=0;v[c+12>>2]=0;U(1540,a+4208|0,b<<2,c+12|0);b=v[22656];v[22656]=0;a:{if((b|0)==1){b=V(89116)|0;if((O()|0)!=(ea(89116)|0)){break a}Z(b|0)|0;v[a+4240>>2]=0;$()}v[a+4244>>2]=0;gb=c+16|0;return}S(b|0);L()}function Vz(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=gb-16|0;gb=d;e=v[b+48>>2]+1|0;v[b+52>>2]=e;a:{if(y[_b(a+484344|0,x[b+70>>1])+12>>2]>e>>>0){break a}if(!c){u[b+74>>1]=x[b+72>>1]+1}v[b+52>>2]=0;c=d+8|0;Db(c,a+1074312|0,63);if(!Cb(c)){break a}a=v[b+56>>2];v[b+56>>2]=0;v[b+52>>2]=a}gb=d+16|0}function Pw(a){t[a|0]=0;t[a+1|0]=0;t[a+2|0]=0;t[a+3|0]=0;t[a+4|0]=0;t[a+5|0]=0;t[a+6|0]=0;t[a+7|0]=0;t[a+16|0]=0;t[a+17|0]=0;t[a+18|0]=0;t[a+19|0]=0;t[a+20|0]=0;t[a+21|0]=0;t[a+22|0]=0;t[a+23|0]=0;t[a+8|0]=0;t[a+9|0]=0;t[a+10|0]=0;t[a+11|0]=0;t[a+12|0]=0;t[a+13|0]=0;t[a+14|0]=0;t[a+15|0]=0}function OX(a){t[a|0]=0;t[a+1|0]=0;t[a+2|0]=0;t[a+3|0]=0;t[a+4|0]=0;t[a+5|0]=0;t[a+6|0]=0;t[a+7|0]=0;t[a+14|0]=0;t[a+15|0]=0;t[a+16|0]=0;t[a+17|0]=0;t[a+18|0]=0;t[a+19|0]=0;t[a+20|0]=0;t[a+21|0]=0;t[a+8|0]=0;t[a+9|0]=0;t[a+10|0]=0;t[a+11|0]=0;t[a+12|0]=0;t[a+13|0]=0;t[a+14|0]=0;t[a+15|0]=0}function hN(a,b){var c=0,d=0,e=0,f=0;d=gb-16|0;gb=d;a:{c=Fg(d,a,b);b=v[c+4>>2];e=v[c+8>>2];if((b|0)!=(e|0)){while(1){wb(a);v[22656]=0;Zo(b);f=v[22656];v[22656]=0;if((f|0)==1){break a}b=b+4|0;v[c+4>>2]=b;if((b|0)!=(e|0)){continue}break}}$b(c);gb=d+16|0;return}a=P()|0;O()|0;$b(c);S(a|0);L()}function ew(a){var b=0,c=0,d=0,e=0,f=0;e=gb-16|0;gb=e;b=gb-32|0;gb=b;d=b+24|0;Wr(d,e+15|0);d=yb(d);c=v[b+28>>2];f=v[b+24>>2];v[b+8>>2]=f;v[b+12>>2]=c;v[b>>2]=f;v[b+4>>2]=c;c=b+16|0;hd(c,a,b);c=yb(c);if((c|0)==(d|0)){bd(a,yb(b+24|0))}gb=b+32|0;gb=e+16|0;return((c|0)==(d|0)?w[e+15|0]:0)&255}function Wn(a,b){var c=0,d=0;c=gb-16|0;gb=c;d=c+8|0;Fc(d,a);v[22656]=0;a=T(2452,d|0)|0;d=v[22656];v[22656]=0;a:{b:{if((d|0)==1){break b}v[22656]=0;Y(2464,a|0,81024,81050,b|0);a=v[22656];v[22656]=0;if((a|0)==1){break b}Wb(c+8|0);gb=c+16|0;break a}a=P()|0;O()|0;Wb(c+8|0);S(a|0);L()}return b}function He(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;g=gb-16|0;gb=g;e=gb-16|0;gb=e;d=a;a:{if(b>>>0<=4294967279){b:{if(b>>>0<=10){_e(d,b);f=d;break b}h=Xk(b)+1|0;f=oi(d,h);ef(d,f);rg(d,h);de(d,b)}Ir(f,b,c);t[e+15|0]=0;Bd(b+f|0,e+15|0);gb=e+16|0;break a}vg();L()}gb=g+16|0;return a|0}function D4(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0;a:{if((d|0)!=(e|0)){f=d;a=b;while(1){g=-1;if((a|0)==(c|0)){break a}h=t[a|0];i=t[f|0];if((h|0)<(i|0)){break a}if((h|0)>(i|0)){return 1}a=a+1|0;f=f+1|0;if((f|0)!=(e|0)){continue}break}}g=((e-d|0)+b|0)!=(c|0)}return g|0}function yQ(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;e=gb-16|0;gb=e;v[e+12>>2]=c>>>1;v[e+8>>2]=v[a>>2];f=v[Fb(e+12|0,e+8|0)>>2];b=zb(b);if(f){a=v[a+20>>2];c=f;while(1){d=(zb(w[b|0])+d|0)+(zb(w[b+1|0])<<8)|0;u[a>>1]=d;a=a+2|0;b=b+2|0;c=c-1|0;if(c){continue}break}}gb=e+16|0;return f<<1}function vQ(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;e=gb-16|0;gb=e;v[e+12>>2]=c>>>1;v[e+8>>2]=v[a>>2];f=v[Fb(e+12|0,e+8|0)>>2];b=zb(b);if(f){a=v[a+20>>2];c=f;while(1){d=(zb(w[b+1|0])+d|0)+(zb(w[b|0])<<8)|0;u[a>>1]=d;a=a+2|0;b=b+2|0;c=c-1|0;if(c){continue}break}}gb=e+16|0;return f<<1}function dI(a,b,c){var d=0,e=0,f=0,g=0,h=0;d=gb-16|0;gb=d;e=et(a);v[a+32>>2]=b;v[a>>2]=76064;b=d+8|0;_s(b,e);v[22656]=0;b=T(2398,b|0)|0;f=v[22656];v[22656]=0;if((f|0)!=1){Wb(d+8|0);v[a+40>>2]=c;v[a+36>>2]=b;g=a,h=Zn(b),t[g+44|0]=h;gb=d+16|0;return}a=P()|0;O()|0;Wb(d+8|0);Am(e);S(a|0);L()}function cI(a,b,c){var d=0,e=0,f=0,g=0,h=0;d=gb-16|0;gb=d;e=AI(a);v[a+32>>2]=b;v[a>>2]=76168;b=d+8|0;_s(b,e);v[22656]=0;b=T(2399,b|0)|0;f=v[22656];v[22656]=0;if((f|0)!=1){Wb(d+8|0);v[a+40>>2]=c;v[a+36>>2]=b;g=a,h=Zn(b),t[g+44|0]=h;gb=d+16|0;return}a=P()|0;O()|0;Wb(d+8|0);bq(e);S(a|0);L()}function Pna(a,b){a=a|0;b=b|0;var c=0;c=gb-16|0;gb=c;a:{a=Tk(c,a+8|0,b);if(v[a>>2]!=v[a+4>>2]){while(1){b=v[a>>2];v[22656]=0;ak(b);b=v[22656];v[22656]=0;if((b|0)==1){break a}b=v[a>>2]+4|0;v[a>>2]=b;if((b|0)!=v[a+4>>2]){continue}break}}_c(a);gb=c+16|0;return}b=P()|0;O()|0;_c(a);S(b|0);L()}function tP(a,b,c){var d=0;a:{if(v[a+480180>>2]==4){d=w[b+814|0];if(c){t[b+814|0]=d&15|c<<4;break a}c=(d&240)>>>4|0;break a}if(v[a+480180>>2]!=1048576){break a}if(c){t[b+813|0]=c;break a}c=w[b+813|0]}b:{if(!(t[b+851|0]&1)|!v[b+700>>2]){break b}c=c&255;if(!c){break b}sk(a,b,b+700|0,c,0)}}function h_(a,b){a=a|0;b=b|0;var c=0;c=gb-16|0;gb=c;a:{a=Tk(c,a+8|0,b);if(v[a>>2]!=v[a+4>>2]){while(1){b=v[a>>2];v[22656]=0;Xr(b);b=v[22656];v[22656]=0;if((b|0)==1){break a}b=v[a>>2]+4|0;v[a>>2]=b;if((b|0)!=v[a+4>>2]){continue}break}}_c(a);gb=c+16|0;return}b=P()|0;O()|0;_c(a);S(b|0);L()}function gN(a,b){a=a|0;b=b|0;var c=0;c=gb-16|0;gb=c;a:{a=Tk(c,a+8|0,b);if(v[a>>2]!=v[a+4>>2]){while(1){b=v[a>>2];v[22656]=0;Zo(b);b=v[22656];v[22656]=0;if((b|0)==1){break a}b=v[a>>2]+4|0;v[a>>2]=b;if((b|0)!=v[a+4>>2]){continue}break}}_c(a);gb=c+16|0;return}b=P()|0;O()|0;_c(a);S(b|0);L()}function Yn(a,b){var c=0,d=0,e=0,f=0,g=0,h=0;c=gb-16|0;gb=c;g=a;h=a;a:{if(!b){b=0;e=0;break a}d=b;b=E(b);Kf(c,d,0,0,0,b+81|0);d=0+v[c+8>>2]|0;b=(v[c+12>>2]^65536)+(16414-b<<16)|0;b=d>>>0<f>>>0?b+1|0:b;f=d;d=b;b=v[c+4>>2];e=v[c>>2]}v[h>>2]=e;v[g+4>>2]=b;v[a+8>>2]=f;v[a+12>>2]=d;gb=c+16|0}function KZ(a,b){a=a|0;b=b|0;var c=0;c=gb-16|0;gb=c;a:{a=Fn(c,a+8|0,b);if(v[a>>2]!=v[a+4>>2]){while(1){b=v[a>>2];v[22656]=0;iw(b);b=v[22656];v[22656]=0;if((b|0)==1){break a}b=v[a>>2]+2|0;v[a>>2]=b;if((b|0)!=v[a+4>>2]){continue}break}}_c(a);gb=c+16|0;return}b=P()|0;O()|0;_c(a);S(b|0);L()}function IZ(a,b){a=a|0;b=b|0;var c=0;c=gb-16|0;gb=c;a:{a=Fn(c,a+8|0,b);if(v[a>>2]!=v[a+4>>2]){while(1){b=v[a>>2];v[22656]=0;Pk(b);b=v[22656];v[22656]=0;if((b|0)==1){break a}b=v[a>>2]+2|0;v[a>>2]=b;if((b|0)!=v[a+4>>2]){continue}break}}_c(a);gb=c+16|0;return}b=P()|0;O()|0;_c(a);S(b|0);L()}function Hy(a,b){a=a|0;b=b|0;var c=0;c=gb-16|0;gb=c;a:{a=Cy(c,a+8|0,b);if(v[a>>2]!=v[a+4>>2]){while(1){b=v[a>>2];v[22656]=0;Hf(b);b=v[22656];v[22656]=0;if((b|0)==1){break a}b=v[a>>2]+1|0;v[a>>2]=b;if((b|0)!=v[a+4>>2]){continue}break}}_c(a);gb=c+16|0;return}b=P()|0;O()|0;_c(a);S(b|0);L()}function uz(a,b){a=a|0;b=b|0;var c=0,d=0;a:{b:{a=a-12|0;c:{if(a>>>0>31){break c}d=1<<a;c=1;if(d&-2145904587){break a}if(d&65792){break b}if((a|0)!=7){break c}b=b&240;c=1;if(!b|(b|0)==96|(b|0)==224){break a}}return 0}b=(b&240)-96|0;c=0;if(b>>>0>=144){break a}c=297>>>(b>>>4)&1}return c|0}function ee(a){var b=0,c=0,d=0,e=0;o(+a);c=j(1)|0;j(0)|0;b=c;c=b>>>20&2047;if(c>>>0<=1074){if(c>>>0<=1021){return a*0}a=(b|0)>0|(b|0)>=0?a:-a;d=a+4503599627370496+-4503599627370496-a;a:{if(d>.5){e=a+d+-1;break a}a=a+d;e=a;if(!(d<=-.5)){break a}e=a+1}a=e;a=(b|0)>0|(b|0)>=0?a:-a}return a}function Jc(a,b,c){var d=0,e=0;d=b^-2147483648;e=a;b=c&31;if((c&63)>>>0>=32){a=0;b=d>>>b|0}else{a=d>>>b|0;b=((1<<b)-1&d)<<32-b|e>>>b}e=b;d=c&31;if((c&63)>>>0>=32){c=0;d=-2147483648>>>d|0}else{c=-2147483648>>>d|0;d=((1<<d)-1&-2147483648)<<32-d}e=e-d|0;jb=a-(c+(b>>>0<d>>>0)|0)|0;return e}function TF(a){a=a|0;var b=0,c=0;b=Kb(a);v[22656]=0;T(215,a+12|0)|0;c=v[22656];v[22656]=0;if((c|0)!=1){b=gb-16|0;gb=b;v[b+12>>2]=0;v[22656]=0;ff(a+32|0,b+12|0,b+8|0);c=v[22656];v[22656]=0;a:{if((c|0)!=1){gb=b+16|0;break a}V(0)|0;O()|0;Bb();L()}return a|0}a=P()|0;O()|0;vb(b);S(a|0);L()}function yv(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0;f=gb-32|0;gb=f;g=fg(a,c);e=f+8|0;se(e,v[a+28>>2]);h=v[e+12>>2];v[f+24>>2]=v[e+8>>2];v[f+28>>2]=h;a:{b:{if(!g){e=-1;if(!nd(a,5)){break b}break a}e=v[g+8>>2]}kb[d|0](v[a+28>>2],b,e)}a=Zf(a,g,c,f+24|0);gb=f+32|0;return a|0}function tD(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=gb-16|0;gb=d;t[d+15|0]=1;t[d+14|0]=a>>>2;a=w[df(d+15|0,d+14|0)|0];e=a>>>0<15|b>>>0<2;if(!e){t[d+13|0]=1;t[d+12|0]=(((a+b|0)-2&65535)>>>0)/((b-1&65535)>>>0);a=w[df(d+13|0,d+12|0)|0]}gb=d+16|0;return(c?a<<4|(e?15:0):a&15|(e?-16:0))&255}function dma(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=gb-32|0;gb=c;e=c+24|0;bc(e,b,1030);e=yb(e);d=v[c+28>>2];f=v[c+24>>2];v[c+8>>2]=f;v[c+12>>2]=d;v[c>>2]=f;v[c+4>>2]=d;d=c+16|0;cc(d,a,c);d=yb(d);if((d|0)==(e|0)){Rb(a,yb(c+24|0))}gb=c+32|0;a=(d|0)==(e|0);if(!a){Qb(b,0,1030)}return a|0}function Nha(a,b){a=a|0;b=b|0;var c=0,d=0;if(y[a+4>>2]<y[wb(a)>>2]){d=gb-16|0;gb=d;c=IB(d,a,1);wb(a);hB(v[c+4>>2],b);v[c+4>>2]=v[c+4>>2]+32;$b(c);gb=d+16|0;return}d=gb-32|0;gb=d;c=wb(a);c=bS(d+8|0,_q(a,ze(a)+1|0),ze(a),c);hB(v[c+8>>2],b);v[c+8>>2]=v[c+8>>2]+32;aS(a,c);gB(c);gb=d+32|0}function nZ(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=gb-32|0;gb=c;d=Pb(a,120);a:{if(!d){a=gb-16|0;gb=a;e=b+120|0;while(1){Hf(b);b=b+1|0;if((e|0)!=(b|0)){continue}break}gb=a+16|0;break a}bc(c+24|0,b,120);b=v[c+28>>2];v[c+8>>2]=v[c+24>>2];v[c+12>>2]=b;kd(c+16|0,a,c+8|0)}gb=c+32|0;return d|0}function xQ(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=gb-16|0;gb=d;v[d+12>>2]=c>>>1;v[d+8>>2]=v[a>>2];e=v[Fb(d+12|0,d+8|0)>>2];b=zb(b);if(e){a=v[a+20>>2];c=e;while(1){f=a,g=zb(w[b+1|0])|zb(w[b|0])<<8,u[f>>1]=g;a=a+2|0;b=b+2|0;c=c-1|0;if(c){continue}break}}gb=d+16|0;return e<<1}function Zea(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=gb-32|0;gb=c;e=c+24|0;bc(e,b,225);e=yb(e);d=v[c+28>>2];f=v[c+24>>2];v[c+8>>2]=f;v[c+12>>2]=d;v[c>>2]=f;v[c+4>>2]=d;d=c+16|0;cc(d,a,c);d=yb(d);if((d|0)==(e|0)){Rb(a,yb(c+24|0))}gb=c+32|0;a=(d|0)==(e|0);if(!a){Qb(b,0,225)}return a|0}function Yma(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=gb-32|0;gb=c;e=c+24|0;bc(e,b,422);e=yb(e);d=v[c+28>>2];f=v[c+24>>2];v[c+8>>2]=f;v[c+12>>2]=d;v[c>>2]=f;v[c+4>>2]=d;d=c+16|0;cc(d,a,c);d=yb(d);if((d|0)==(e|0)){Rb(a,yb(c+24|0))}gb=c+32|0;a=(d|0)==(e|0);if(!a){Qb(b,0,422)}return a|0}function Wea(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=gb-32|0;gb=c;e=c+24|0;bc(e,b,326);e=yb(e);d=v[c+28>>2];f=v[c+24>>2];v[c+8>>2]=f;v[c+12>>2]=d;v[c>>2]=f;v[c+4>>2]=d;d=c+16|0;cc(d,a,c);d=yb(d);if((d|0)==(e|0)){Rb(a,yb(c+24|0))}gb=c+32|0;a=(d|0)==(e|0);if(!a){Qb(b,0,326)}return a|0}function We(a){a=a|0;var b=0,c=0;b=gb-32|0;gb=b;t[b+8|0]=0;v[b>>2]=0;v[b+4>>2]=4194432;LE(b+9|0);v[a>>2]=v[b>>2];c=v[b+8>>2];v[a+4>>2]=v[b+4>>2];v[a+8>>2]=c;c=v[b+16>>2];v[a+12>>2]=v[b+12>>2];v[a+16>>2]=c;c=v[b+24>>2];v[a+20>>2]=v[b+20>>2];v[a+24>>2]=c;t[a+28|0]=w[b+28|0];gb=b+32|0}function Sma(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=gb-32|0;gb=c;e=c+24|0;bc(e,b,826);e=yb(e);d=v[c+28>>2];f=v[c+24>>2];v[c+8>>2]=f;v[c+12>>2]=d;v[c>>2]=f;v[c+4>>2]=d;d=c+16|0;cc(d,a,c);d=yb(d);if((d|0)==(e|0)){Rb(a,yb(c+24|0))}gb=c+32|0;a=(d|0)==(e|0);if(!a){Qb(b,0,826)}return a|0}function Ppa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=gb-32|0;gb=c;e=c+24|0;eY(e,b);e=yb(e);d=v[c+28>>2];f=v[c+24>>2];v[c+8>>2]=f;v[c+12>>2]=d;v[c>>2]=f;v[c+4>>2]=d;d=c+16|0;cc(d,a,c);d=yb(d);if((d|0)==(e|0)){Rb(a,yb(c+24|0))}gb=c+32|0;if((d|0)!=(e|0)){t[b+2|0]=0;t[b|0]=0;t[b+1|0]=0}}function Nf(a){var b=0,c=0,d=0;b=a;a:{if(b&3){while(1){if(!w[b|0]){break a}b=b+1|0;if(b&3){continue}break}}while(1){c=b;b=b+4|0;d=v[c>>2];if(!((d^-1)&d-16843009&-2139062144)){continue}break}if(!(d&255)){return c-a|0}while(1){d=w[c+1|0];b=c+1|0;c=b;if(d){continue}break}}return b-a|0}function Bha(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;e=gb-16|0;gb=e;f=Zh(b,c);d=Kc(a);if(f>>>0>d>>>0){g=d;h=f-d|0;d=Ab(a);Ym(a,g,h,d,0,d,0)}d=Jb(a);if((b|0)!=(c|0)){while(1){Bd(d,b);d=d+1|0;b=b+1|0;if((c|0)!=(b|0)){continue}break}}t[e+15|0]=0;Bd(d,e+15|0);jh(a,f);gb=e+16|0}function AQ(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=gb-16|0;gb=d;v[d+12>>2]=c>>>1;v[d+8>>2]=v[a>>2];e=v[Fb(d+12|0,d+8|0)>>2];b=zb(b);if(e){a=v[a+20>>2];c=e;while(1){f=a,g=zb(w[b|0])|zb(w[b+1|0])<<8,u[f>>1]=g;a=a+2|0;b=b+2|0;c=c-1|0;if(c){continue}break}}gb=d+16|0;return e<<1}function yO(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=gb-16|0;gb=d;e=Zh(b,c);a:{if(e>>>0<=dg(a)>>>0){if(oc(a)>>>0<e>>>0){v[d+12>>2]=b;xO(d+12|0,oc(a));Rg(b,v[d+12>>2],v[a>>2]);rr(a,v[d+12>>2],c,e-oc(a)|0);break a}Em(a,Rg(b,c,v[a>>2]));break a}Hv(a);Dn(a,qh(a,e));rr(a,b,c,e)}gb=d+16|0}function qX(a){var b=0,c=0,d=0,e=0;b=a+32|0;d=w[b|0]|w[b+1|0]<<8;b=a+38|0;e=w[b|0]|w[b+1|0]<<8;b=a+34|0;a=a+36|0;c=w[a|0]|w[a+1|0]<<8;b=(w[b|0]|w[b+1|0]<<8)+c|0;a=0;a=b>>>0<c>>>0?1:a;c=b;b=e+b|0;a=b>>>0<c>>>0?a+1|0:a;a=a<<2|b>>>30;c=b<<2;b=d+c|0;a=b>>>0<c>>>0?a+1|0:a;jb=a;return b}function f9(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;e=vh(a);a:{b=b+4|0;c=uf(b);if(!c){break a}v[22656]=0;R(2043,a|0,c|0);d=v[22656];v[22656]=0;if((d|0)!=1){d=v[b+4>>2];b=v[b>>2];v[22656]=0;Y(2044,a|0,b|0,d|0,c|0);a=v[22656];v[22656]=0;if((a|0)!=1){break a}}a=P()|0;O()|0;Kt(e);S(a|0);L()}}function a0(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=gb-16|0;gb=d;a:{if(v[b>>2]){if(!gd(c)){ux(c,14864)}e=v[b+4>>2];kb[v[v[e>>2]+24>>2]](d,e,v[b>>2]);v[22656]=0;Q(1168,c|0,d|0)|0;b=v[22656];v[22656]=0;if((b|0)==1){break a}vb(d)}Dc(a,c);gb=d+16|0;return}a=P()|0;O()|0;vb(d);S(a|0);L()}function Qla(a,b){a=a|0;b=b|0;var c=0,d=0;c=gb-32|0;gb=c;a:{if(!Pb(b,8)){u[c+16>>1]=0;b=4;while(1){d=w[c+16|0]|w[c+17|0]<<8;t[a|0]=d;t[a+1|0]=d>>>8;a=a+2|0;b=b-1|0;if(b){continue}break}break a}zD(c+24|0,a);a=v[c+28>>2];v[c+8>>2]=v[c+24>>2];v[c+12>>2]=a;kd(c+16|0,b,c+8|0)}gb=c+32|0}function rh(a,b){var c=0,d=0,e=0;c=gb-32|0;gb=c;d=v[b+4>>2];b=v[b>>2];v[c+8>>2]=b;v[c+12>>2]=d;v[c+16>>2]=b;v[c+20>>2]=d;d=gb-16|0;gb=d;b=c+8|0;e=v[b>>2];b=v[b>>2]+yb(b)|0;v[22656]=0;lo(a,e,b);a=v[22656];v[22656]=0;a:{if((a|0)!=1){gb=d+16|0;break a}V(0)|0;O()|0;Bb();L()}gb=c+32|0}function gpa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=gb-32|0;gb=c;d=Pb(a,64);a:{if(!d){a=gb-16|0;gb=a;e=b- -64|0;while(1){Pk(b);b=b+2|0;if((e|0)!=(b|0)){continue}break}gb=a+16|0;break a}yD(c+24|0,b);b=v[c+28>>2];v[c+8>>2]=v[c+24>>2];v[c+12>>2]=b;kd(c+16|0,a,c+8|0)}gb=c+32|0;return d|0}function Tea(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=gb-32|0;gb=c;e=c+24|0;bc(e,b,60);e=yb(e);d=v[c+28>>2];f=v[c+24>>2];v[c+8>>2]=f;v[c+12>>2]=d;v[c>>2]=f;v[c+4>>2]=d;d=c+16|0;cc(d,a,c);d=yb(d);if((d|0)==(e|0)){Rb(a,yb(c+24|0))}gb=c+32|0;a=(d|0)==(e|0);if(!a){Qb(b,0,60)}return a|0}function Lla(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=gb-32|0;gb=c;e=c+24|0;bc(e,b,71);e=yb(e);d=v[c+28>>2];f=v[c+24>>2];v[c+8>>2]=f;v[c+12>>2]=d;v[c>>2]=f;v[c+4>>2]=d;d=c+16|0;cc(d,a,c);d=yb(d);if((d|0)==(e|0)){Rb(a,yb(c+24|0))}gb=c+32|0;a=(d|0)==(e|0);if(!a){Qb(b,0,71)}return a|0}function Gna(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=gb-32|0;gb=c;e=c+24|0;bc(e,b,91);e=yb(e);d=v[c+28>>2];f=v[c+24>>2];v[c+8>>2]=f;v[c+12>>2]=d;v[c>>2]=f;v[c+4>>2]=d;d=c+16|0;cc(d,a,c);d=yb(d);if((d|0)==(e|0)){Rb(a,yb(c+24|0))}gb=c+32|0;a=(d|0)==(e|0);if(!a){Qb(b,0,91)}return a|0}function CT(a,b,c){a:{switch(b|0){case 0:zk(a,0,c);return;case 1:zk(a,1,c);return;case 2:zk(a,2,c);return;case 3:zk(a,3,c);return;case 4:zk(a,4,c);return;case 5:zk(a,5,c);return;case 6:yS(a,24992,c);return;case 7:yS(a,26016,c);return;case 8:zk(a,6,c);return;default:break a}}Kb(a)}function $ea(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=gb-32|0;gb=c;e=c+24|0;bc(e,b,73);e=yb(e);d=v[c+28>>2];f=v[c+24>>2];v[c+8>>2]=f;v[c+12>>2]=d;v[c>>2]=f;v[c+4>>2]=d;d=c+16|0;cc(d,a,c);d=yb(d);if((d|0)==(e|0)){Rb(a,yb(c+24|0))}gb=c+32|0;a=(d|0)==(e|0);if(!a){Qb(b,0,73)}return a|0}function fk(a,b){var c=0,d=0,e=0,f=0,g=0;if(b){g=v[a+8>>2];c=v[a>>2];while(1){a:{if(c){d=v[a+4>>2];break a}v[a>>2]=8;c=g;d=v[a+12>>2];if((c|0)!=(d|0)){c=d-1|0;v[a+12>>2]=c}d=w[c|0];c=8}c=c-1|0;v[a>>2]=c;v[a+4>>2]=d>>>1;e=d&1|e<<1;f=f+1|0;if((f|0)!=(b|0)){continue}break}}return e}function Gha(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=gb-48|0;gb=c;d=c+40|0;t[d|0]=w[b|0];b=c+16|0;Wr(b,d);b=zb(v[b>>2]);e=c+8|0;Wr(e,d);b=Pj(c+24|0,b,zb(v[e>>2]+1|0));v[22656]=0;Q(1101,a|0,b|0)|0;a=v[22656];v[22656]=0;if((a|0)!=1){vb(b);gb=c+48|0;return}a=P()|0;O()|0;vb(b);S(a|0);L()}function hda(a){a=a|0;var b=0,c=0,d=0,e=0;b=gb-16|0;gb=b;v[b+12>>2]=a;v[b+8>>2]=4104;d=v[b+8>>2];c=0;a:{if(d>>>0<4096){break a}a=v[b+12>>2];e=a+7&-8;a=e-a|0;c=0;if(a>>>0>d-4096>>>0){break a}v[b+12>>2]=e;v[b+8>>2]=d-a;c=e}a=c;if(!a){aa(3145,6145,88,4444);L()}gb=b+16|0;return a|0}function ae(a,b){var c=0,d=0,e=0,f=0;c=v[a+4>>2];d=c+b|0;v[a+4>>2]=d;if((d|0)<=v[a+8>>2]){d=v[a>>2]+(c>>3)|0;a=c&7;c=w[d|0]&255>>>a;a=a+b|0;a:{if((a|0)<9){b=a;break a}while(1){b=a-8|0;e=c<<b|e;f=a>>>0>16;c=w[d+1|0];a=b;d=d+1|0;if(f){continue}break}}a=c>>>8-b|e}else{a=0}return a}function Vs(a,b){var c=0,d=0;c=-1;a:{if((a|0)==-1){break a}d=v[b+76>>2]>=0;b:{c:{c=v[b+4>>2];d:{if(!c){HI(b);c=v[b+4>>2];if(!c){break d}}if(v[b+44>>2]-8>>>0<c>>>0){break c}}c=-1;if(d){break b}break a}c=c-1|0;v[b+4>>2]=c;t[c|0]=a;v[b>>2]=v[b>>2]&-17;c=a;if(!d){break a}}}return c}function Uc(a){var b=0,c=0;b=gb-16|0;gb=b;v[b+12>>2]=a;v[b+8>>2]=-32768;v[22656]=0;v[b+4>>2]=32767;a=pd(b+12|0,b+4|0);c=v[22656];v[22656]=0;a:{if((c|0)==1){break a}v[22656]=0;a=Gf(b+8|0,a);c=v[22656];v[22656]=0;if((c|0)==1){break a}gb=b+16|0;return u[a>>1]}V(0)|0;O()|0;Bb();L()}function Tda(a,b){a=a|0;b=b|0;var c=0,d=0;c=gb-16|0;gb=c;v[c+8>>2]=b;b=0;a:{if(Nb(a)>>>0>511){break a}if(!Dd(c+8|0)){break a}d=c+8|0;b=v[d>>2];v[22656]=0;R(1528,a|0,d|0);a=v[22656];v[22656]=0;if((a|0)!=1){break a}a=P()|0;O()|0;Jg(c+8|0);S(a|0);L()}Jg(c+8|0);gb=c+16|0;return b|0}function Mm(a,b,c,d){var e=0,f=0;a:{f=v[(B(b,872)+a|0)+1075648>>2];if(!f){break a}if(!Kj(f)){break a}e=w[f+34|0];if((e-1&255)>>>0>249){break a}e=v[(B(e,160)+a|0)+906140>>2];if(!e){break a}kb[v[v[e>>2]+92>>2]](e,f,c,d,b);if(c>>>0>250){break a}u[(B(b,872)+a|0)+1075834>>1]=65535}}function c9(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=gb-48|0;gb=d;v[d+44>>2]=b;b=d+8|0;yl(b,c);c=d+24|0;v[c>>2]=v[d+44>>2];Dc(c+4|0,b);v[22656]=0;R(2046,a+4|0,c|0);a=v[22656];v[22656]=0;if((a|0)!=1){Gk(d+24|0);vb(d+8|0);gb=d+48|0;return}a=P()|0;O()|0;Gk(d+24|0);vb(d+8|0);S(a|0);L()}function UZ(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=gb-32|0;gb=c;e=c+24|0;hw(e,b);e=yb(e);d=v[c+28>>2];f=v[c+24>>2];v[c+8>>2]=f;v[c+12>>2]=d;v[c>>2]=f;v[c+4>>2]=d;d=c+16|0;cc(d,a,c);d=yb(d);if((d|0)==(e|0)){Rb(a,yb(c+24|0))}gb=c+32|0;a=(d|0)==(e|0);if(!a){Qb(b,0,65)}return a|0}function U4(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;if(!w[a+44|0]){e=(c|0)>0;c=e?c:0;if(e){while(1){if(((g=a,h=Mg(t[b|0]),f=v[v[a>>2]+52>>2],kb[f](g|0,h|0)|0)|0)==-1){return d|0}b=b+1|0;d=d+1|0;if((c|0)!=(d|0)){continue}break}}return c|0}return Lk(b,1,c,v[a+32>>2])|0}function Rka(a,b){a=a|0;b=b|0;var c=0,d=0;b=gb-16|0;gb=b;c=-1;a:{if(!ek(a,b+8|0)){break a}c=0;if(!TT(b+8|0)){break a}c=-1;if(!Wf(a,4)){break a}c=gb-16|0;gb=c;if(DT(a,c+8|0)){a=c+8|0;d=Xb(w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24))}gb=c+16|0;c=d>>>31|0}gb=b+16|0;return c|0}function v1(a){a=a|0;var b=0,c=0;b=v[a+8>>2];v[22656]=0;b=T(2547,b|0)|0;c=v[22656];v[22656]=0;a:{if((c|0)==1){break a}if(b){a=-1}else{a=v[a+8>>2];if(!a){return 1}v[22656]=0;a=T(2548,a|0)|0;b=v[22656];v[22656]=0;if((b|0)==1){break a}a=(a|0)==1}return a|0}V(0)|0;O()|0;Bb();L()}function l7(a,b){a=a|0;b=b|0;var c=0,d=0;c=gb-16|0;gb=c;Jp(a);v[a>>2]=58824;v[22656]=0;d=v[b+12>>2];v[c+8>>2]=v[b+8>>2];v[c+12>>2]=d;d=v[b+4>>2];v[c>>2]=v[b>>2];v[c+4>>2]=d;Q(2120,dc(a)|0,c|0)|0;b=v[22656];v[22656]=0;if((b|0)!=1){gb=c+16|0;return a|0}a=P()|0;O()|0;S(a|0);L()}function VL(a,b,c){t[a+12|0]=0;v[c>>2]=0;v[b>>2]=0;v[a+28>>2]=0;v[a+32>>2]=0;u[a+24>>1]=0;v[a+36>>2]=0;v[a+40>>2]=0;v[a+44>>2]=0;v[a+48>>2]=0;UL(a+60|0);UL(a+52|0);Aq(a+49956|0);Aq(a+58148|0);Aq(a+66340|0);Aq(a+74532|0);Qb(a+228|0,0,32768);vB(a+32996|0);Qb(a+33508|0,0,16384)}function Opa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=a;d=vh(a);a:{if(!b){break a}v[22656]=0;R(486,c|0,b|0);e=v[22656];v[22656]=0;if((e|0)!=1){v[22656]=0;mY(c,b);b=v[22656];v[22656]=0;if((b|0)!=1){break a}}a=P()|0;O()|0;rD(d);S(a|0);L()}t[a+16|0]=6;v[a+12>>2]=2015363072;return a|0}function AM(a){a=a|0;var b=0,c=0;c=gb-16|0;gb=c;b=v[v[a+16>>2]+1074404>>2];v[22656]=0;v[c+12>>2]=0;U(1540,a+4208|0,B(b,254)|0,c+12|0);b=v[22656];v[22656]=0;a:{if((b|0)==1){b=V(89116)|0;if((O()|0)!=(ea(89116)|0)){break a}Z(b|0)|0;$()}v[a+4220>>2]=0;gb=c+16|0;return}S(b|0);L()}function rX(a){var b=0,c=0;a:{if((w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24))!=1297108297){b=0;if((w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24))!=778924148){break a}}c=a+34|0;b=0;if((w[c|0]|w[c+1|0]<<8)>>>0>255){break a}a=a+36|0;b=(w[a|0]|w[a+1|0]<<8)>>>0<4e3}return b}function mF(a,b,c,d){var e=0,f=0;b=v[a+1076>>2]+((b&c?0-(c<<1)|0:0)+b|0)|0;v[a+1076>>2]=b;c=b+v[a+1080>>2]|0;v[a+1080>>2]=c;u[(v[a+1068>>2]<<1)+d>>1]=w[a+1084|0]?c:b;v[a+1064>>2]=v[a+1064>>2]+1;e=a,f=fd(v[a+1060>>2])+v[a+1068>>2]|0,v[e+1068>>2]=f;v[a+1072>>2]=v[a+1072>>2]-1}function M_(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;e=gb-32|0;gb=e;Jp(a);v[a>>2]=28048;f=dc(a);b=im(e+16|0,b);c=v[c>>2];d=v[d>>2];g=v[b+4>>2];v[e+8>>2]=v[b>>2];v[e+12>>2]=g;Ip(f);v[f>>2]=28184;b=e+8|0;im(f+4|0,b);v[f+16>>2]=d;v[f+12>>2]=c;Kd(b);gb=e+32|0;return a|0}function yu(a){var b=0,c=0,d=0,e=0;b=a;e=v[a+4>>2];a:{while(1){if(v[b+8>>2]==(e|0)){break a}c=v[b+16>>2];d=v[b+8>>2]-12|0;v[b+8>>2]=d;v[22656]=0;R(279,c|0,d|0);c=v[22656];v[22656]=0;if((c|0)!=1){continue}break}V(0)|0;O()|0;Bb();L()}if(v[a>>2]){mm(v[a+16>>2],v[a>>2],Mp(a))}}function ts(a){var b=0,c=0,d=0,e=0;b=a;e=v[a+4>>2];a:{while(1){if(v[b+8>>2]==(e|0)){break a}c=v[b+16>>2];d=v[b+8>>2]-12|0;v[b+8>>2]=d;v[22656]=0;R(181,c|0,d|0);c=v[22656];v[22656]=0;if((c|0)!=1){continue}break}V(0)|0;O()|0;Bb();L()}if(v[a>>2]){mm(v[a+16>>2],v[a>>2],Mp(a))}}function QQ(a){var b=0,c=0,d=0,e=0;b=a;e=v[a+4>>2];a:{while(1){if(v[b+8>>2]==(e|0)){break a}c=v[b+16>>2];d=v[b+8>>2]-28|0;v[b+8>>2]=d;v[22656]=0;R(957,c|0,d|0);c=v[22656];v[22656]=0;if((c|0)!=1){continue}break}V(0)|0;O()|0;Bb();L()}if(v[a>>2]){yB(v[a+16>>2],v[a>>2],GY(a))}}function FV(a){var b=0,c=0;b=gb-16|0;gb=b;v[b+12>>2]=a;v[b+8>>2]=-128;v[22656]=0;v[b+4>>2]=127;a=pd(b+12|0,b+4|0);c=v[22656];v[22656]=0;a:{if((c|0)==1){break a}v[22656]=0;a=Gf(b+8|0,a);c=v[22656];v[22656]=0;if((c|0)==1){break a}gb=b+16|0;return t[a|0]}V(0)|0;O()|0;Bb();L()}function zha(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=gb-32|0;gb=c;e=c+24|0;NR(e,b);e=yb(e);d=v[c+28>>2];f=v[c+24>>2];v[c+8>>2]=f;v[c+12>>2]=d;v[c>>2]=f;v[c+4>>2]=d;d=c+16|0;cc(d,a,c);d=yb(d);if((d|0)==(e|0)){Rb(a,yb(c+24|0))}gb=c+32|0;a=(d|0)==(e|0);if(!a){_A(b)}return a|0}function xf(a){a=a|0;var b=0,c=0,d=0,e=0;c=gb-16|0;gb=c;v[c+12>>2]=-1;b=gb-16|0;gb=b;d=2;e=v[a>>2];if(e>>>0>=2){v[b+12>>2]=e>>>1;v[b+8>>2]=-1-v[a>>2];d=Fb(b+12|0,b+8|0);v[b+12>>2]=v[a>>2]+v[d>>2];v[b+8>>2]=v[c+12>>2];d=v[Fb(b+12|0,b+8|0)>>2]}gb=b+16|0;gb=c+16|0;return d|0}function wna(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=gb-32|0;gb=c;e=c+24|0;GC(e,b);e=yb(e);d=v[c+28>>2];f=v[c+24>>2];v[c+8>>2]=f;v[c+12>>2]=d;v[c>>2]=f;v[c+4>>2]=d;d=c+16|0;cc(d,a,c);d=yb(d);if((d|0)==(e|0)){Rb(a,yb(c+24|0))}gb=c+32|0;a=(d|0)==(e|0);if(!a){HC(b)}return a|0}function hR(a){var b=0,c=0,d=0,e=0;b=a;d=v[b+4>>2];a:{while(1){c=v[b+8>>2];if((c|0)==(d|0)){break a}e=v[b+16>>2];c=c-12|0;v[b+8>>2]=c;v[22656]=0;R(1133,e|0,c|0);c=v[22656];v[22656]=0;if((c|0)!=1){continue}break}V(0)|0;O()|0;Bb();L()}b=v[a>>2];if(b){mm(v[a+16>>2],b,Mp(a))}}function gB(a){var b=0,c=0,d=0,e=0;b=a;d=v[b+4>>2];a:{while(1){c=v[b+8>>2];if((c|0)==(d|0)){break a}e=v[b+16>>2];c=c-32|0;v[b+8>>2]=c;v[22656]=0;R(1103,e|0,c|0);c=v[22656];v[22656]=0;if((c|0)!=1){continue}break}V(0)|0;O()|0;Bb();L()}b=v[a>>2];if(b){Yk(v[a+16>>2],b,HB(a))}}function aS(a,b){var c=0,d=0,e=0,f=0,g=0;hv(a);wb(a);f=b+4|0;d=f;c=v[a+4>>2];g=v[a>>2];if((c|0)!=(g|0)){e=v[d>>2];while(1){c=c-32|0;hB(e-32|0,c);e=v[d>>2]-32|0;v[d>>2]=e;if((c|0)!=(g|0)){continue}break}}wc(a,f);wc(a+4|0,b+8|0);wc(wb(a),dc(b));v[b>>2]=v[b+4>>2];iB(a,ze(a))}function fw(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=gb-32|0;gb=c;e=c+24|0;XD(e,b);e=yb(e);d=v[c+28>>2];f=v[c+24>>2];v[c+8>>2]=f;v[c+12>>2]=d;v[c>>2]=f;v[c+4>>2]=d;d=c+16|0;cc(d,a,c);d=yb(d);if((d|0)==(e|0)){Rb(a,yb(c+24|0))}gb=c+32|0;a=(d|0)==(e|0);if(!a){WD(b)}return a|0}function ev(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=gb-32|0;gb=c;e=c+24|0;QU(e,b);e=yb(e);d=v[c+28>>2];f=v[c+24>>2];v[c+8>>2]=f;v[c+12>>2]=d;v[c>>2]=f;v[c+4>>2]=d;d=c+16|0;cc(d,a,c);d=yb(d);if((d|0)==(e|0)){Rb(a,yb(c+24|0))}gb=c+32|0;a=(d|0)==(e|0);if(!a){RU(b)}return a|0}function ao(a,b,c){var d=0,e=0,f=0;a:{if(!b){d=a;break a}while(1){d=nqa(a,b,10,0);e=jb;f=e;e=kqa(d,e,10,0);c=c-1|0;t[c|0]=a-e|48;e=b>>>0>9;a=d;b=f;if(e){continue}break}}if(d){while(1){c=c-1|0;a=(d>>>0)/10|0;t[c|0]=d-B(a,10)|48;b=d>>>0>9;d=a;if(b){continue}break}}return c}function X8(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=gb-16|0;gb=c;po(c,a);a=b;if(v[a>>2]){Od(a);Iy(v[a>>2],kv(a));d=wb(a),e=0,v[d>>2]=e;v[a>>2]=0;v[a+4>>2]=0}v[b>>2]=v[c>>2];v[b+4>>2]=v[c+4>>2];a=wb(c);d=wb(b),e=v[a>>2],v[d>>2]=e;v[a>>2]=0;v[c>>2]=0;v[c+4>>2]=0;Yf(c);gb=c+16|0}function K8(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;a:{c=gb-16|0;gb=c;v[c+4>>2]=1;f=c,g=Mc(52,4),v[f+8>>2]=g;d=c;e=v[c+8>>2];v[22656]=0;Q(2118,e|0,b|0)|0;b=v[22656];v[22656]=0;if((b|0)!=1){b=a;a=Kp(d);$J(b,dc(a),a);_J(d);gb=c+16|0;break a}a=P()|0;O()|0;_J(d);S(a|0);L()}}function J8(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;a:{c=gb-16|0;gb=c;v[c+4>>2]=1;f=c,g=Mc(56,4),v[f+8>>2]=g;d=c;e=v[c+8>>2];v[22656]=0;Q(2119,e|0,b|0)|0;b=v[22656];v[22656]=0;if((b|0)!=1){b=a;a=Kp(d);$J(b,dc(a),a);WJ(d);gb=c+16|0;break a}a=P()|0;O()|0;WJ(d);S(a|0);L()}}function FU(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;wb(b);d=vh(a);a:{c=oc(b);if(c){v[22656]=0;R(488,a|0,c|0);e=v[22656];v[22656]=0;if((e|0)==1){break a}d=v[b>>2];e=v[b+4>>2];b=gb-16|0;gb=b;c=Ai(b,a,c);wb(a);nv(d,e,c+4|0);$b(c);gb=b+16|0}return a|0}a=P()|0;O()|0;km(d);S(a|0);L()}function CE(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=gb-32|0;gb=c;e=c+24|0;rE(e,b);e=yb(e);d=v[c+28>>2];f=v[c+24>>2];v[c+8>>2]=f;v[c+12>>2]=d;v[c>>2]=f;v[c+4>>2]=d;d=c+16|0;cc(d,a,c);d=yb(d);if((d|0)==(e|0)){Rb(a,yb(c+24|0))}gb=c+32|0;a=(d|0)==(e|0);if(!a){qE(b)}return a|0}function uD(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=gb-16|0;gb=d;e=0;a:{if(!a){break a}b:{c:{if(a>>>0<=15){if(b>>>0<2|c){break c}break b}if(b>>>0>1){break b}}e=a|-16;break a}t[d+15|0]=1;t[d+14|0]=(a>>>0)/((b-1&255)>>>0);e=w[df(d+15|0,d+14|0)|0]}a=e;gb=d+16|0;return a&255}function gy(a){var b=0,c=0;a:{if(y[a+20>>2]<=y[a+28>>2]){break a}kb[v[a+36>>2]](a,0,0)|0;if(v[a+20>>2]){break a}return-1}b=v[a+4>>2];c=v[a+8>>2];if(b>>>0<c>>>0){b=b-c|0;kb[v[a+40>>2]](a,b,b>>31,1)|0}v[a+28>>2]=0;v[a+16>>2]=0;v[a+20>>2]=0;v[a+4>>2]=0;v[a+8>>2]=0;return 0}function Xi(a){var b=0,c=0;b=gb-16|0;gb=b;v[b+12>>2]=a;v[b+8>>2]=0;v[22656]=0;v[b+4>>2]=255;a=pd(b+12|0,b+4|0);c=v[22656];v[22656]=0;a:{if((c|0)==1){break a}v[22656]=0;a=Gf(b+8|0,a);c=v[22656];v[22656]=0;if((c|0)==1){break a}gb=b+16|0;return w[a|0]}V(0)|0;O()|0;Bb();L()}function Vha(a,b){a=a|0;b=b|0;var c=0,d=0;a:{if(!Jd(b)){break a}if(v[b+20>>2]==(zb(v[a+20>>2])|0)){v[a+20>>2]=0}qc(a,v[b>>2]);c=x[a+34>>1]&-2|u[b+34>>1]&1;u[a+34>>1]=c;u[a+34>>1]=c&65471|x[b+34>>1]&64;if(!Ql(a)){break a}hc(zb(v[a+20>>2]),v[b+20>>2],aj(a));d=1}return d|0}function nz(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;a:{if(!Sf(a)){break a}while(1){if(!hi(bf(a,e))){break a}d=d+1|0;e=d&65535;if(Sf(a)>>>0>e>>>0){continue}break}}b:{if(c){c=65535;if(x[v[v[a+12>>2]+8>>2]+10>>1]<=(d&65535)>>>0){break b}}c=wh(a,d&65535,b)?d:-1}return c&65535}function O_(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=gb-32|0;gb=e;v[e+24>>2]=d;v[e+28>>2]=c;v[22656]=0;Y(222,e+8|0,b|0,e+28|0,e+24|0);c=v[22656];v[22656]=0;if((c|0)!=1){c=e+16|0;d=e+8|0;Jw(c,d);Xf(a,c);Kd(c);Kd(d);Kd(b);gb=e+32|0;return}a=P()|0;O()|0;Kd(b);S(a|0);L()}function IT(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;a:{e=gb-16|0;gb=e;b:{c:{if((b|0)==(c|0)){b=a;a=Jb(d);Pj(b,a,Ab(d)+a|0);break c}CT(e,c,d);v[22656]=0;U(57,a|0,b|0,e|0);a=v[22656];v[22656]=0;if((a|0)==1){break b}Hc(e)}gb=e+16|0;break a}a=P()|0;O()|0;Hc(e);S(a|0);L()}}function lF(a,b,c,d){var e=0,f=0;b=v[a+1076>>2]+((b&c?0-(c<<1)|0:0)+b|0)|0;v[a+1076>>2]=b;c=b+v[a+1080>>2]|0;v[a+1080>>2]=c;t[v[a+1068>>2]+d|0]=w[a+1084|0]?c:b;v[a+1064>>2]=v[a+1064>>2]+1;e=a,f=fd(v[a+1060>>2])+v[a+1068>>2]|0,v[e+1068>>2]=f;v[a+1072>>2]=v[a+1072>>2]-1}function fca(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;zM(a,b,c,d,e^1);v[a+4232>>2]=1056964608;b=a+4224|0;v[b>>2]=1056964608;v[b+4>>2]=1048406533;b=a+4216|0;v[b>>2]=1020054733;v[b+4>>2]=1065353216;v[a+4208>>2]=1056964608;v[a+4212>>2]=1065353216;v[a>>2]=52068;return a|0}function ah(a,b){var c=0,d=0,e=0,f=0;c=Ab(a);a:{if((c|0)!=(Ab(b)|0)){break a}d=Jb(a);b=Jb(b);b:{if(!De(a)){if(c){break b}return 1}return!Wo(d,b,c)}while(1){a=w[b|0];e=w[d|0];f=(a|0)==(e|0);if((a|0)!=(e|0)){break a}b=b+1|0;d=d+1|0;c=c-1|0;if(c){continue}break}}return f}function Sp(a,b,c){var d=0,e=0,f=0;d=a*a;f=d*(d*d)*(d*1.58969099521155e-10+-2.5050760253406863e-8)+(d*(d*27557313707070068e-22+-.0001984126982985795)+.00833333333332249);e=d*a;if(!c){return e*(d*f+-.16666666666666632)+a}return a-(e*.16666666666666632+(d*(b*.5-e*f)-b))}function sm(a){var b=0,c=0,d=0,e=0;$p(a);if(v[a>>2]){d=a;e=v[a>>2];b=v[a+4>>2];a:{while(1){if((b|0)==(e|0)){break a}c=wb(d);v[22656]=0;b=b-12|0;R(181,c|0,b|0);c=v[22656];v[22656]=0;if((c|0)!=1){continue}break}V(0)|0;O()|0;Bb();L()}v[d+4>>2]=e;mm(wb(a),v[a>>2],ug(a))}}function mma(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=gb-32|0;gb=c;e=c+24|0;bc(e,b,274);e=yb(e);d=v[c+28>>2];f=v[c+24>>2];v[c+8>>2]=f;v[c+12>>2]=d;v[c>>2]=f;v[c+4>>2]=d;d=c+16|0;cc(d,a,c);d=yb(d);if((d|0)==(e|0)){Rb(a,yb(c+24|0))}gb=c+32|0;if((d|0)!=(e|0)){Qb(b,0,274)}}function ima(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=gb-32|0;gb=c;e=c+24|0;bc(e,b,106);e=yb(e);d=v[c+28>>2];f=v[c+24>>2];v[c+8>>2]=f;v[c+12>>2]=d;v[c>>2]=f;v[c+4>>2]=d;d=c+16|0;cc(d,a,c);d=yb(d);if((d|0)==(e|0)){Rb(a,yb(c+24|0))}gb=c+32|0;if((d|0)!=(e|0)){Qb(b,0,106)}}function eqa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=gb-32|0;gb=c;e=c+24|0;bc(e,b,136);e=yb(e);d=v[c+28>>2];f=v[c+24>>2];v[c+8>>2]=f;v[c+12>>2]=d;v[c>>2]=f;v[c+4>>2]=d;d=c+16|0;cc(d,a,c);d=yb(d);if((d|0)==(e|0)){Rb(a,yb(c+24|0))}gb=c+32|0;if((d|0)!=(e|0)){Qb(b,0,136)}}function Zca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;v[a+4>>2]=b;v[a>>2]=0;b=Iu(a+8|0,d);v[22656]=0;Q(1651,a+20|0,c|0)|0;c=v[22656];v[22656]=0;if((c|0)!=1){v[a+32>>2]=0;v[a+36>>2]=0;t[a+42|0]=0;t[a+40|0]=0;t[a+41|0]=w[a+41|0]&224|25;return a|0}a=P()|0;O()|0;Hb(b);S(a|0);L()}function A4(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0;a:{if((d|0)!=(e|0)){while(1){a=-1;if((b|0)==(c|0)){break a}f=v[b>>2];g=v[d>>2];if((f|0)<(g|0)){break a}if((f|0)>(g|0)){return 1}b=b+4|0;d=d+4|0;if((e|0)!=(d|0)){continue}break}}a=(b|0)!=(c|0)}return a|0}function gW(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=gb-32|0;gb=c;e=c+24|0;bc(e,b,284);e=yb(e);d=v[c+28>>2];f=v[c+24>>2];v[c+8>>2]=f;v[c+12>>2]=d;v[c>>2]=f;v[c+4>>2]=d;d=c+16|0;cc(d,a,c);d=yb(d);if((d|0)==(e|0)){Rb(a,yb(c+24|0))}gb=c+32|0;if((d|0)!=(e|0)){Qb(b,0,284)}}function XS(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=zd(b);f=gf(b);e=zd(b);c=gb-32|0;gb=c;v[c+16>>2]=f;v[c+24>>2]=d;v[c+8>>2]=e;if(Gb(c+24|0,c+16|0)){while(1){d=c+24|0;f=Zq(t[v[d>>2]]);e=c+8|0;t[v[e>>2]]=f;Pe(d);Pe(e);if(Gb(d,c+16|0)){continue}break}}gb=c+32|0;Dc(a,b)}function UF(a,b){var c=0,d=0;c=gb-16|0;gb=c;d=c+8|0;Fc(d,a);v[22656]=0;a=T(21,d|0)|0;d=v[22656];v[22656]=0;a:{if((d|0)==1){break a}v[22656]=0;a=Q(22,a|0,b|0)|0;b=v[22656];v[22656]=0;if((b|0)==1){break a}Wb(c+8|0);gb=c+16|0;return a}a=P()|0;O()|0;Wb(c+8|0);S(a|0);L()}function EK(a){var b=0,c=0,d=0,e=0;d=gb-16|0;gb=d;b=a+120|0;Bi(b);c=gb-16|0;gb=c;v[c+8>>2]=d+8;a=gb-16|0;gb=a;e=v[13842];v[a+8>>2]=v[13841];v[a+12>>2]=e;e=v[13840];v[a>>2]=v[13839];v[a+4>>2]=e;b=kb[v[Rh(a,Yg(b))>>2]](c+8|0,b)|0;gb=a+16|0;gb=c+16|0;gb=d+16|0;return b}function vha(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=vh(a);a:{d=rf(b);if(d){v[22656]=0;R(1117,a|0,d|0);e=v[22656];v[22656]=0;if((e|0)==1){break a}c=gb-16|0;gb=c;e=v[b>>2];f=v[b+4>>2];b=gs(c,a,d);nv(e,f,b+4|0);$b(b);gb=c+16|0}return a|0}a=P()|0;O()|0;Mf(c);S(a|0);L()}function hna(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=gb-32|0;gb=c;e=c+24|0;bc(e,b,42);e=yb(e);d=v[c+28>>2];f=v[c+24>>2];v[c+8>>2]=f;v[c+12>>2]=d;v[c>>2]=f;v[c+4>>2]=d;d=c+16|0;cc(d,a,c);d=yb(d);if((d|0)==(e|0)){Rb(a,yb(c+24|0))}gb=c+32|0;if((d|0)!=(e|0)){Qb(b,0,42)}}function hma(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=gb-32|0;gb=c;e=c+24|0;bc(e,b,72);e=yb(e);d=v[c+28>>2];f=v[c+24>>2];v[c+8>>2]=f;v[c+12>>2]=d;v[c>>2]=f;v[c+4>>2]=d;d=c+16|0;cc(d,a,c);d=yb(d);if((d|0)==(e|0)){Rb(a,yb(c+24|0))}gb=c+32|0;if((d|0)!=(e|0)){Qb(b,0,72)}}function cpa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=gb-32|0;gb=c;e=c+24|0;bc(e,b,34);e=yb(e);d=v[c+28>>2];f=v[c+24>>2];v[c+8>>2]=f;v[c+12>>2]=d;v[c>>2]=f;v[c+4>>2]=d;d=c+16|0;cc(d,a,c);d=yb(d);if((d|0)==(e|0)){Rb(a,yb(c+24|0))}gb=c+32|0;if((d|0)!=(e|0)){Qb(b,0,34)}}function il(a,b,c,d){var e=0;if(d&2048){t[a|0]=43;a=a+1|0}if(d&512){t[a|0]=35;a=a+1|0}e=w[b|0];if(e){while(1){t[a|0]=e;a=a+1|0;e=w[b+1|0];b=b+1|0;if(e){continue}break}}e=d&74;b=111;a:{if((e|0)==64){break a}b=d&16384?88:120;if((e|0)==8){break a}b=c?100:117}t[a|0]=b}function TN(a,b){var c=0,d=0,e=0;c=a;if(v[c>>2]){_i(c);eT(c);$i(c);_i(c);yB(wb(c),v[c>>2],$i(c));d=wb(c),e=0,v[d>>2]=e;v[c>>2]=0;v[c+4>>2]=0}lp(a,b);v[a>>2]=v[b>>2];v[a+4>>2]=v[b+4>>2];c=v[wb(b)>>2];d=wb(a),e=c,v[d>>2]=e;d=wb(b),e=0,v[d>>2]=e;v[b>>2]=0;v[b+4>>2]=0}function TK(a,b){a=a|0;b=b|0;var c=C(0),d=C(0);a:{if((b|0)<0){break a}a=a+24|0;if(x[v[a>>2]+480188>>1]<=b>>>0){break a}b=B(b,872);c=C(C(w[(b+v[a>>2]|0)+1075834|0])*C(.0078125));d=C(c*c);c=C(C(w[(b+v[a>>2]|0)+1075835|0])*C(.0078125));c=C(K(C(d+C(c*c))))}return C(c)}function SZ(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=gb-32|0;gb=c;e=c+24|0;bc(e,b,59);e=yb(e);d=v[c+28>>2];f=v[c+24>>2];v[c+8>>2]=f;v[c+12>>2]=d;v[c>>2]=f;v[c+4>>2]=d;d=c+16|0;cc(d,a,c);d=yb(d);if((d|0)==(e|0)){Rb(a,yb(c+24|0))}gb=c+32|0;if((d|0)!=(e|0)){Qb(b,0,59)}}function IQ(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=gb-16|0;gb=d;v[d+12>>2]=c;v[d+8>>2]=v[a>>2];e=v[Fb(d+12|0,d+8|0)>>2];b=zb(b);if(e){a=v[a+20>>2];c=e;while(1){f=a,g=zb(w[b|0])^128,t[f|0]=g;a=a+1|0;b=b+1|0;c=c-1|0;if(c){continue}break}}gb=d+16|0;return e|0}function HD(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=gb-32|0;gb=c;e=c+24|0;bc(e,b,50);e=yb(e);d=v[c+28>>2];f=v[c+24>>2];v[c+8>>2]=f;v[c+12>>2]=d;v[c>>2]=f;v[c+4>>2]=d;d=c+16|0;cc(d,a,c);d=yb(d);if((d|0)==(e|0)){Rb(a,yb(c+24|0))}gb=c+32|0;if((d|0)!=(e|0)){Qb(b,0,50)}}function ER(a,b){var c=0,d=0,e=0;u[a+24>>1]=0;v[a+20>>2]=0;v[a>>2]=0;v[a+4>>2]=0;v[a+8>>2]=0;v[a+12>>2]=0;e=a;c=3546895/+(b>>>0);d=c*.25;a:{if(D(d)<2147483648){b=~~d;break a}b=-2147483648}v[e+16>>2]=b;b=LT(c-+(b<<2));v[a>>2]=0;v[a+4>>2]=0;v[a+8>>2]=b;v[a+12>>2]=jb}function xh(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;if(b?1:v[a+480180>>2]&1){e=v[a+24616>>2]&524288;b=0;while(1){c=(b<<5)+a|0;u[c+480286>>1]=64;d=c+480280|0;v[d>>2]=v[d>>2]&-257;d=c+480284|0;c=(b&3)-1>>>0<2;u[d>>1]=e?c<<8:c?192:64;b=b+1|0;if((b|0)!=127){continue}break}}}function wka(a,b){a=a|0;b=b|0;var c=0,d=0;c=gb-32|0;gb=c;d=Pb(a,4);a:{if(!d){t[c+16|0]=0;a=4;while(1){t[b|0]=w[c+16|0];b=b+1|0;a=a-1|0;if(a){continue}break}break a}sC(c+24|0,b);b=v[c+28>>2];v[c+8>>2]=v[c+24>>2];v[c+12>>2]=b;kd(c+16|0,a,c+8|0)}gb=c+32|0;return d|0}function Mt(a){var b=0,c=C(0),d=0;if(w[a+4232|0]>=5){t[a+4232|0]=0}if(t[a+4233|0]<0){t[a+4233|0]=127}b=t[a+4234|0];if((b|0)<0){t[a+4234|0]=127;b=127}d=a;a:{if((CM(a)|0)==3){c=C(C(1)-oe(C(2),C(-C((b&255)+1|0))));break a}c=oe(C(2),C(-C((b&255)>>>0)))}z[d+4224>>2]=c}function xF(a){var b=0,c=0,d=0,e=0;if(v[a>>2]){d=v[a>>2];e=a;b=v[a+4>>2];a:{while(1){if((b|0)==(d|0)){break a}c=wb(e);v[22656]=0;b=b-12|0;R(279,c|0,b|0);c=v[22656];v[22656]=0;if((c|0)!=1){continue}break}V(0)|0;O()|0;Bb();L()}v[e+4>>2]=d;mm(wb(a),v[a>>2],ug(a))}}function Wpa(a,b){a=a|0;b=b|0;var c=0,d=0;c=gb-32|0;gb=c;a:{if(!Pb(a,64)){a=gb-16|0;gb=a;d=b- -64|0;while(1){Hf(b);b=b+1|0;if((d|0)!=(b|0)){continue}break}gb=a+16|0;break a}yD(c+24|0,b);b=v[c+28>>2];v[c+8>>2]=v[c+24>>2];v[c+12>>2]=b;kd(c+16|0,a,c+8|0)}gb=c+32|0}function RM(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0;e=gb-16|0;gb=e;v[e+12>>2]=0;Bh(a+12|0,d);if(b){d=b;if(b>>>0>2097151){rd(8445);L()}f=Mc(d<<11,4)}v[a>>2]=f;c=(c<<11)+f|0;v[a+8>>2]=c;v[a+4>>2]=c;g=dc(a),h=(b<<11)+f|0,v[g>>2]=h;gb=e+16|0;return a|0}function sl(a){var b=0,c=0;a:{b=v[a+1396>>2];if((b|0)>24){break a}if(!b){v[a+1392>>2]=0}while(1){if(w[a+1376|0]?0:v[a+1384>>2]){break a}c=rt(a);if((c|0)==-1){break a}b=v[a+1396>>2];v[a+1396>>2]=b+8;v[a+1392>>2]=v[a+1392>>2]+(c<<b);if((b|0)<17){continue}break}}}function JQ(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=gb-16|0;gb=d;v[d+12>>2]=c;v[d+8>>2]=v[a>>2];e=v[Fb(d+12|0,d+8|0)>>2];b=zb(b);if(e){a=v[a+20>>2];c=e;while(1){f=a,g=Wh(w[b|0]),t[f|0]=g;a=a+1|0;b=b+1|0;c=c-1|0;if(c){continue}break}}gb=d+16|0;return e|0}function HQ(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;e=gb-16|0;gb=e;v[e+12>>2]=c;v[e+8>>2]=v[a>>2];f=v[Fb(e+12|0,e+8|0)>>2];b=zb(b);if(f){a=v[a+20>>2];c=f;while(1){d=zb(w[b|0])+d|0;t[a|0]=d;a=a+1|0;b=b+1|0;c=c-1|0;if(c){continue}break}}gb=e+16|0;return f|0}function yha(a,b){a=a|0;b=b|0;var c=0,d=0;c=gb-32|0;gb=c;a:{if(!Pb(a,27)){a=gb-16|0;gb=a;d=b+27|0;while(1){Hf(b);b=b+1|0;if((d|0)!=(b|0)){continue}break}gb=a+16|0;break a}NR(c+24|0,b);b=v[c+28>>2];v[c+8>>2]=v[c+24>>2];v[c+12>>2]=b;kd(c+16|0,a,c+8|0)}gb=c+32|0}function Es(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=gb-16|0;gb=c;d=ba(16)|0;FG();a=td(c+8|0,a,90608);v[22656]=0;e=v[a+4>>2];v[c>>2]=v[a>>2];v[c+4>>2]=e;W(2813,d|0,c|0,b|0)|0;a=v[22656];v[22656]=0;if((a|0)!=1){ia(d|0,88800,2814);L()}a=P()|0;O()|0;ca(d|0);S(a|0);L()}function Eea(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;e=gb-32|0;gb=e;f=fg(a,c);d=e+8|0;se(d,v[a+28>>2]);g=v[d+12>>2];v[e+24>>2]=v[d+8>>2];v[e+28>>2]=g;a:{b:{if(!f){d=-1;if(!nd(a,5)){break b}break a}d=v[f+8>>2]}EO(v[a+28>>2],b,d)}Zf(a,f,c,e+24|0);gb=e+32|0}function mC(a){var b=0,c=0,d=0;if(v[a>>2]){c=a;b=v[a+4>>2];d=v[a>>2];if((b|0)!=(d|0)){while(1){b=b-24|0;xb(b);if((b|0)!=(d|0)){continue}break}}v[c+4>>2]=d;c=v[a>>2];a=kv(a);v[22656]=0;Oc(c,B(a,24),4);a=v[22656];v[22656]=0;if((a|0)==1){V(0)|0;O()|0;Bb();L()}}}function gV(a,b){a=a|0;b=b|0;var c=0,d=0;c=gb-32|0;gb=c;a:{if(!Pb(a,32)){a=gb-16|0;gb=a;d=b+32|0;while(1){Hf(b);b=b+1|0;if((d|0)!=(b|0)){continue}break}gb=a+16|0;break a}cV(c+24|0,b);b=v[c+28>>2];v[c+8>>2]=v[c+24>>2];v[c+12>>2]=b;kd(c+16|0,a,c+8|0)}gb=c+32|0}function RT(a,b){var c=0,d=0;v[a+4>>2]=b;v[a>>2]=90632;v[a+20>>2]=0;v[a+24>>2]=0;c=(b>>>5|0)+((b&31)!=0)|0;v[a+12>>2]=c;d=(b>>>0)/(c>>>0)|0;v[a+8>>2]=d;v[a+32>>2]=d>>>0<31?-1>>>31-d|0:-1;v[a+28>>2]=b>>>0<c>>>0?0:-1>>>32-d|0;v[a+16>>2]=(B(c,d)-b|0)+c;return a}function Oha(a){a=a|0;var b=0,c=0,d=0;c=gb-32|0;gb=c;b=255;a:{if(Pi(a)>>>0<=49){b=kB(c,v[a+12>>2]);v[22656]=0;R(1091,a|0,b|0);d=v[22656];v[22656]=0;if((d|0)==1){break a}Zm(b);Qi(a,Pi(a)-1&255);b=Pi(a)-1|0}gb=c+32|0;return b&255}a=P()|0;O()|0;Zm(b);S(a|0);L()}function N$(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;if(Sg(a,v[b+8>>2],0)){ix(b,c,d);return}e=v[a+12>>2];f=a+16|0;BG(f,b,c,d);a:{if((e|0)<2){break a}e=(e<<3)+f|0;a=a+24|0;while(1){BG(a,b,c,d);if(w[b+54|0]){break a}a=a+8|0;if(e>>>0>a>>>0){continue}break}}}function Kv(a){var b=0,c=0,d=0;b=a;c=v[a+4>>2];a:{while(1){if(v[b+8>>2]==(c|0)){break a}v[b+8>>2]=v[b+8>>2]-48;v[22656]=0;d=v[22656];v[22656]=0;if((d|0)!=1){continue}break}V(0)|0;O()|0;Bb();L()}if(v[a>>2]){fY(v[a+16>>2],v[a>>2],(v[dc(a)>>2]-v[a>>2]|0)/48|0)}}function xY(a,b){var c=0,d=0,e=0,f=0;c=gb-32|0;gb=c;e=c+24|0;Lv(e,b);e=yb(e);d=v[c+28>>2];f=v[c+24>>2];v[c+8>>2]=f;v[c+12>>2]=d;v[c>>2]=f;v[c+4>>2]=d;d=c+16|0;hd(d,a,c);d=yb(d);if((d|0)==(e|0)){bd(a,yb(c+24|0))}gb=c+32|0;a=(d|0)==(e|0);if(!a){qD(b)}return a}function oD(a,b){var c=0,d=0,e=0,f=0;c=gb-32|0;gb=c;e=c+24|0;_X(e,b);e=yb(e);d=v[c+28>>2];f=v[c+24>>2];v[c+8>>2]=f;v[c+12>>2]=d;v[c>>2]=f;v[c+4>>2]=d;d=c+16|0;hd(d,a,c);d=yb(d);if((d|0)==(e|0)){bd(a,yb(c+24|0))}gb=c+32|0;a=(d|0)==(e|0);if(!a){$X(b)}return a}function mU(a,b){var c=0,d=0,e=0,f=0;c=gb-32|0;gb=c;e=c+24|0;FX(e,b);e=yb(e);d=v[c+28>>2];f=v[c+24>>2];v[c+8>>2]=f;v[c+12>>2]=d;v[c>>2]=f;v[c+4>>2]=d;d=c+16|0;hd(d,a,c);d=yb(d);if((d|0)==(e|0)){bd(a,yb(c+24|0))}gb=c+32|0;a=(d|0)==(e|0);if(!a){GX(b)}return a}function lG(a,b){var c=0,d=0,e=0,f=0;c=gb-32|0;gb=c;e=c+24|0;YF(e,b);e=yb(e);d=v[c+28>>2];f=v[c+24>>2];v[c+8>>2]=f;v[c+12>>2]=d;v[c>>2]=f;v[c+4>>2]=d;d=c+16|0;hd(d,a,c);d=yb(d);if((d|0)==(e|0)){bd(a,yb(c+24|0))}gb=c+32|0;a=(d|0)==(e|0);if(!a){Pw(b)}return a}function l0(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;f=gb-16|0;gb=f;d=Xp(a);e=Ab(a);a:{if(d-e>>>0>=c>>>0){if(!c){break a}d=Jb(a);yi(d+(e<<2)|0,b,c);b=c+e|0;jh(a,b);v[f+12>>2]=0;Ge(d+(b<<2)|0,f+12|0);break a}IG(a,d,(c+e|0)-d|0,e,e,0,c,b)}gb=f+16|0;return a|0}function hW(a,b){var c=0,d=0,e=0,f=0;c=gb-32|0;gb=c;e=c+24|0;bW(e,b);e=yb(e);d=v[c+28>>2];f=v[c+24>>2];v[c+8>>2]=f;v[c+12>>2]=d;v[c>>2]=f;v[c+4>>2]=d;d=c+16|0;cc(d,a,c);d=yb(d);if((d|0)==(e|0)){Rb(a,yb(c+24|0))}gb=c+32|0;a=(d|0)==(e|0);if(!a){aW(b)}return a}function ena(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=gb-32|0;gb=c;e=c+24|0;PV(e,b);e=yb(e);d=v[c+28>>2];f=v[c+24>>2];v[c+8>>2]=f;v[c+12>>2]=d;v[c>>2]=f;v[c+4>>2]=d;d=c+16|0;cc(d,a,c);d=yb(d);if((d|0)==(e|0)){Rb(a,yb(c+24|0))}gb=c+32|0;if((d|0)!=(e|0)){Pk(b)}}function ek(a,b){var c=0,d=0,e=0,f=0;c=gb-32|0;gb=c;e=c+24|0;fs(e,b);e=yb(e);d=v[c+28>>2];f=v[c+24>>2];v[c+8>>2]=f;v[c+12>>2]=d;v[c>>2]=f;v[c+4>>2]=d;d=c+16|0;hd(d,a,c);d=yb(d);if((d|0)==(e|0)){bd(a,yb(c+24|0))}gb=c+32|0;a=(d|0)==(e|0);if(!a){jm(b)}return a}function dD(a,b){var c=0,d=0,e=0,f=0;c=gb-32|0;gb=c;e=c+24|0;FX(e,b);e=yb(e);d=v[c+28>>2];f=v[c+24>>2];v[c+8>>2]=f;v[c+12>>2]=d;v[c>>2]=f;v[c+4>>2]=d;d=c+16|0;cc(d,a,c);d=yb(d);if((d|0)==(e|0)){Rb(a,yb(c+24|0))}gb=c+32|0;a=(d|0)==(e|0);if(!a){GX(b)}return a}function cO(a,b){var c=0,d=0,e=0,f=0;c=gb-32|0;gb=c;if(v[a+4>>2]==v[b+4>>2]){d=v[a+4>>2];e=v[a>>2];v[c+24>>2]=e;v[c+28>>2]=d;f=v[b+4>>2];a=c;b=v[b>>2];v[a+16>>2]=b;v[a+20>>2]=f;v[a+8>>2]=e;v[a+12>>2]=d;v[a>>2]=b;v[a+4>>2]=f;d=!OS(a+8|0,a)}gb=c+32|0;return d}function VU(a,b){var c=0,d=0,e=0,f=0;c=gb-32|0;gb=c;e=c+24|0;QU(e,b);e=yb(e);d=v[c+28>>2];f=v[c+24>>2];v[c+8>>2]=f;v[c+12>>2]=d;v[c>>2]=f;v[c+4>>2]=d;d=c+16|0;hd(d,a,c);d=yb(d);if((d|0)==(e|0)){bd(a,yb(c+24|0))}gb=c+32|0;a=(d|0)==(e|0);if(!a){RU(b)}return a}function Uma(a,b){a=a|0;b=b|0;var c=0,d=0;c=gb-32|0;gb=c;a:{if(!Pb(a,2)){a=gb-16|0;gb=a;d=b+2|0;while(1){Hf(b);b=b+1|0;if((d|0)!=(b|0)){continue}break}gb=a+16|0;break a}PV(c+24|0,b);b=v[c+28>>2];v[c+8>>2]=v[c+24>>2];v[c+12>>2]=b;kd(c+16|0,a,c+8|0)}gb=c+32|0}function Nka(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=gb-16|0;gb=c;an(a,b);e=c,f=Vb(a),v[e+8>>2]=f;e=c,f=Zb(a),v[e>>2]=f;if(Gb(c+8|0,c)){b=0;while(1){a=c+8|0;d=v[a>>2];b=zb(w[d|0])+(b&255)|0;e=d,f=zb(b&255),t[e|0]=f;Pe(a);if(Gb(a,c)){continue}break}}gb=c+16|0}function AV(a,b){var c=0,d=0,e=0,f=0;c=gb-32|0;gb=c;e=c+24|0;oV(e,b);e=yb(e);d=v[c+28>>2];f=v[c+24>>2];v[c+8>>2]=f;v[c+12>>2]=d;v[c>>2]=f;v[c+4>>2]=d;d=c+16|0;hd(d,a,c);d=yb(d);if((d|0)==(e|0)){bd(a,yb(c+24|0))}gb=c+32|0;a=(d|0)==(e|0);if(!a){pV(b)}return a}function uv(a){var b=0,c=0,d=0;b=a;c=v[a+4>>2];a:{while(1){if(v[b+8>>2]==(c|0)){break a}v[b+8>>2]=v[b+8>>2]-6;v[22656]=0;d=v[22656];v[22656]=0;if((d|0)!=1){continue}break}V(0)|0;O()|0;Bb();L()}if(v[a>>2]){OC(v[a+16>>2],v[a>>2],(v[dc(a)>>2]-v[a>>2]|0)/6|0)}}function kd(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0;d=gb-16|0;gb=d;e=v[b>>2];g=v[b+8>>2];f=v[c+4>>2];c=v[c>>2];v[d+8>>2]=c;v[d+12>>2]=f;h=v[v[e>>2]+28>>2];v[d>>2]=c;v[d+4>>2]=f;kb[h|0](a,e,g,d);i=b,j=yb(a)+v[b+8>>2]|0,v[i+8>>2]=j;gb=d+16|0}function gv(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=gb-32|0;gb=c;e=c+24|0;cV(e,b);e=yb(e);d=v[c+28>>2];f=v[c+24>>2];v[c+8>>2]=f;v[c+12>>2]=d;v[c>>2]=f;v[c+4>>2]=d;d=c+16|0;cc(d,a,c);d=yb(d);if((d|0)==(e|0)){Rb(a,yb(c+24|0))}gb=c+32|0;if((d|0)!=(e|0)){$B(b)}}function zt(a){var b=0,c=0,d=0,e=0;b=gb-16|0;gb=b;v[b+12>>2]=12;v[b+8>>2]=32;if(v[Fb(b+12|0,b+8|0)>>2]){while(1){e=Ao(a);v[b+8>>2]=32;c=c<<15^e;d=d+15|0;if(d>>>0<y[Fb(b+12|0,b+8|0)>>2]){continue}break}}gb=b+16|0;a=v[b+12>>2];return(a>>>0>31?-1:-1<<a^-1)&c}function Wla(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=gb-32|0;gb=c;d=c+24|0;bc(d,b,1100);b=yb(d);d=v[c+28>>2];e=v[c+24>>2];v[c+8>>2]=e;v[c+12>>2]=d;v[c>>2]=e;v[c+4>>2]=d;d=c+16|0;cc(d,a,c);d=yb(d);if((d|0)==(b|0)){Rb(a,yb(c+24|0))}gb=c+32|0;return(b|0)==(d|0)|0}function UG(a){a=a|0;var b=0,c=0,d=0;v[a>>2]=81344;b=v[a+8>>2];v[22656]=0;c=ga(2448)|0;d=v[22656];v[22656]=0;a:{if((d|0)!=1){if((b|0)==(c|0)){break a}b=v[a+8>>2];v[22656]=0;Kx(b);b=v[22656];v[22656]=0;if((b|0)!=1){break a}}V(0)|0;O()|0;Bb();L()}return a|0}function Tz(a,b,c){var d=0,e=0,f=0,g=0;e=gb-16|0;gb=e;f=v[b+656>>2];d=0;a:{if(!f){break a}f=pw(f,c);d=e+8|0;g=a+1074312|0;Db(d,g,31);a=0;if(!Cb(d)){Db(e,g,93);a=Cb(e)^1}if(!(t[kO(b,c)+6|0]&1)){d=0;if(!(t[f+12|0]&1)|a){break a}}d=cd(f)^1}gb=e+16|0;return d}function Tu(a){var b=0,c=0;a:{if(w[a+4|0]|(w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24))!=1414687062){break a}b=a+6|0;if(Ib(w[b|0]|w[b+1|0]<<8)>>>0>1){break a}b=a+12|0;if(Ib(w[b|0]|w[b+1|0]<<8)){break a}a=a+16|0;c=(Ib(w[a|0]|w[a+1|0]<<8)|0)==20}return c}function St(a){var b=0,c=0,d=0;b=a;c=v[a+4>>2];a:{while(1){if(v[b+8>>2]==(c|0)){break a}v[b+8>>2]=v[b+8>>2]-2048;v[22656]=0;d=v[22656];v[22656]=0;if((d|0)!=1){continue}break}V(0)|0;O()|0;Bb();L()}if(v[a>>2]){OM(v[a+16>>2],v[a>>2],v[dc(a)>>2]-v[a>>2]>>11)}}function Qq(a,b,c,d){var e=0,f=0,g=0,h=0;a:{e=Ol(a,b);if((e|0)==255){break a}if(wk(a)){break a}b=aB(a+314|0,e);e=SR(e);if(f=1,g=t[ic(b,10)|0]&1,h=d,h?f:g){Yh(v[a>>2],e- -64&65535,RR(c,w[ic(b,2)|0]))}if(d){break a}Yh(v[a>>2],e+67&65535,RR(c,w[ic(b,3)|0]))}}function o3(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0;g=gb-16|0;gb=g;v[g+8>>2]=b;Fc(g,d);v[22656]=0;b=T(2452,g|0)|0;d=v[22656];v[22656]=0;if((d|0)!=1){Wb(g);oH(a,f+24|0,g+8|0,c,e,b);gb=g+16|0;return v[g+8>>2]}a=P()|0;O()|0;Wb(g);S(a|0);L()}function n3(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0;g=gb-16|0;gb=g;v[g+8>>2]=b;Fc(g,d);v[22656]=0;b=T(2452,g|0)|0;d=v[22656];v[22656]=0;if((d|0)!=1){Wb(g);nH(a,f+16|0,g+8|0,c,e,b);gb=g+16|0;return v[g+8>>2]}a=P()|0;O()|0;Wb(g);S(a|0);L()}function _M(a,b,c){var d=0,e=0;d=gb-32|0;gb=d;v[d+28>>2]=c;v[d+24>>2]=0;v[d+12>>2]=4;c=d+16|0;e=a;a=d+28|0;eo(c,e,d+24|0,v[Fb(a,d+12|0)>>2]);yb(c);v[d+16>>2]=4;Fb(a,c);v[d+16>>2]=v[d+24>>2];v[b>>2]=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);gb=d+32|0}function XI(a,b){var c=0,d=0,e=0;o(+a);c=j(1)|0;d=j(0)|0;e=c;c=c>>>20&2047;if((c|0)!=2047){if(!c){c=b;if(a==0){b=0}else{a=XI(a*0x10000000000000000,b);b=v[b>>2]+-64|0}v[c>>2]=b;return a}v[b>>2]=c-1022;l(0,d|0);l(1,e&-2146435073|1071644672);a=+n()}return a}function JK(a,b){a=a|0;b=b|0;var c=0,d=0;c=gb-16|0;gb=c;v[c+12>>2]=b;u[c+10>>1]=0;u[c+8>>1]=65535;a:{if(Ft(c+12|0,c+10|0,c+8|0)){a=a+24|0;d=0;if(!me(v[a>>2]+484344|0,b&65535)){break a}d=v[_b(v[a>>2]+484344|0,b)+12>>2];break a}d=0}a=d;gb=c+16|0;return a|0}function xka(a){a=a|0;var b=0,c=0,d=0,e=0;b=gb-32|0;gb=b;u[b+28>>1]=0;v[b+24>>2]=0;c=wd(b+8|0,b+24|0,6);d=v[c+4>>2];v[b>>2]=v[c>>2];v[b+4>>2]=d;c=b+16|0;cc(c,a,b);a:{if((yb(c)|0)!=6){break a}if(sd(b+24|0,1024,6)){break a}Rb(a,6);e=1}gb=b+32|0;return e|0}function poa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=gb-32|0;gb=c;d=gb-16|0;gb=d;e=d+8|0;_E(e,a);GW(c+24|0,e);gb=d+16|0;Eg(c+16|0,b);a=v[c+28>>2];v[c+8>>2]=v[c+24>>2];v[c+12>>2]=a;a=v[c+20>>2];v[c>>2]=v[c+16>>2];v[c+4>>2]=a;a=Gc(c+8|0,c);gb=c+32|0;return a|0}function Hoa(a){a=a|0;var b=0,c=0,d=0,e=0;b=gb-32|0;gb=b;t[b+30|0]=0;u[b+28>>1]=0;c=wd(b+8|0,b+28|0,3);d=v[c+4>>2];v[b>>2]=v[c>>2];v[b+4>>2]=d;c=b+16|0;cc(c,a,b);a:{if((yb(c)|0)!=3){break a}if(sd(b+28|0,11950,3)){break a}Rb(a,3);e=1}gb=b+32|0;return e|0}function zA(a,b){a=a|0;b=b|0;var c=0,d=0;d=gb-16|0;gb=d;c=v[a+104>>2];a:{if(!c){break a}c=v[c>>2];if(!c){break a}v[a+76>>2]=c;v[a+88>>2]=v[a+88>>2]&-131|128;v[d+12>>2]=b<<8;v[d+8>>2]=c-1;b=c+(v[Fb(d+12|0,d+8|0)>>2]^-1)|0;v[a>>2]=0;v[a+4>>2]=b}gb=d+16|0}function u3(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0;g=gb-16|0;gb=g;v[g+8>>2]=b;Fc(g,d);v[22656]=0;b=T(21,g|0)|0;d=v[22656];v[22656]=0;if((d|0)!=1){Wb(g);sH(a,f+24|0,g+8|0,c,e,b);gb=g+16|0;return v[g+8>>2]}a=P()|0;O()|0;Wb(g);S(a|0);L()}function t3(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0;g=gb-16|0;gb=g;v[g+8>>2]=b;Fc(g,d);v[22656]=0;b=T(21,g|0)|0;d=v[22656];v[22656]=0;if((d|0)!=1){Wb(g);qH(a,f+16|0,g+8|0,c,e,b);gb=g+16|0;return v[g+8>>2]}a=P()|0;O()|0;Wb(g);S(a|0);L()}function qx(a){a=a|0;var b=0,c=0,d=0;b=v[a+8>>2];v[22656]=0;c=ga(2448)|0;d=v[22656];v[22656]=0;a:{b:{if((d|0)==1){break b}if((b|0)!=(c|0)){b=v[a+8>>2];v[22656]=0;Kx(b);b=v[22656];v[22656]=0;if((b|0)==1){break b}}break a}V(0)|0;O()|0;Bb();L()}return a|0}function kma(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=Ig(a);a:{if(!b){break a}v[22656]=0;R(814,a|0,b|0);e=v[22656];v[22656]=0;if((e|0)!=1){v[22656]=0;U(815,a|0,b|0,c|0);b=v[22656];v[22656]=0;if((b|0)!=1){break a}}a=P()|0;O()|0;cs(d);S(a|0);L()}return a|0}function bE(a){var b=0,c=0,d=0,e=0;b=a+5|0;b=w[b|0]|w[b+1|0]<<8;c=b+w[a+2|0]|0;d=b>>>0>c>>>0?1:d;b=c;c=b<<1;b=d<<1|b>>>31;e=c;a=a+3|0;a=w[a|0]|w[a+1|0]<<8;d=a>>>30|0;c=a<<2;e=e+c|0;a=b+d|0;a=c>>>0>e>>>0?a+1|0:a;b=e+47|0;a=b>>>0<47?a+1|0:a;jb=a;return b}function Hga(a,b){a=a|0;b=b|0;var c=0,d=0;c=gb-32|0;gb=c;d=Pb(a,16);a:{if(!d){a=b+16|0;while(1){t[b|0]=0;b=b+1|0;if((a|0)!=(b|0)){continue}break}break a}jw(c+24|0,b);b=v[c+28>>2];v[c+8>>2]=v[c+24>>2];v[c+12>>2]=b;kd(c+16|0,a,c+8|0)}gb=c+32|0;return d|0}function EE(a,b){var c=0,d=0,e=0,f=0;c=gb-32|0;gb=c;e=c+24|0;bc(e,b,37);e=yb(e);d=v[c+28>>2];f=v[c+24>>2];v[c+8>>2]=f;v[c+12>>2]=d;v[c>>2]=f;v[c+4>>2]=d;d=c+16|0;cc(d,a,c);d=yb(d);if((d|0)==(e|0)){Rb(a,yb(c+24|0))}gb=c+32|0;if((d|0)!=(e|0)){Qb(b,0,37)}}function vW(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=gb-16|0;gb=d;c=d;v[c>>2]=v[a+8>>2];e=v[a+8>>2];v[c+8>>2]=a+8;v[c+4>>2]=B(b,33)+e;a=v[c>>2];if((a|0)!=v[c+4>>2]){while(1){HC(a);a=v[c>>2]+33|0;v[c>>2]=a;if(v[c+4>>2]!=(a|0)){continue}break}}_c(c);gb=d+16|0}function vT(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=gb-16|0;gb=d;c=d;v[c>>2]=v[a+8>>2];e=v[a+8>>2];v[c+8>>2]=a+8;v[c+4>>2]=(b<<8)+e;a=v[c>>2];if((a|0)!=v[c+4>>2]){while(1){GB(a);a=v[c>>2]+256|0;v[c>>2]=a;if(v[c+4>>2]!=(a|0)){continue}break}}_c(c);gb=d+16|0}function q5(a){a=a|0;var b=0,c=0;c=v[a+44>>2];b=v[a+24>>2];if(c>>>0<b>>>0){v[a+44>>2]=b;c=b}a:{if(!(w[a+48|0]&8)){break a}if(y[a+16>>2]<c>>>0){$n(a,v[a+8>>2],v[a+12>>2],c)}b=v[a+16>>2];a=v[a+12>>2];if(b>>>0<=a>>>0){break a}return Mg(t[a|0])|0}return-1}function mX(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=Ig(a);a:{if(!b){break a}v[22656]=0;R(617,a|0,b|0);e=v[22656];v[22656]=0;if((e|0)!=1){v[22656]=0;U(618,a|0,b|0,c|0);b=v[22656];v[22656]=0;if((b|0)!=1){break a}}a=P()|0;O()|0;zv(d);S(a|0);L()}return a|0}function YD(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=Ig(a);a:{if(!b){break a}v[22656]=0;R(389,a|0,b|0);e=v[22656];v[22656]=0;if((e|0)!=1){v[22656]=0;U(390,a|0,b|0,c|0);b=v[22656];v[22656]=0;if((b|0)!=1){break a}}a=P()|0;O()|0;km(d);S(a|0);L()}return a|0}function TZ(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=Ig(a);a:{if(!b){break a}v[22656]=0;R(333,a|0,b|0);e=v[22656];v[22656]=0;if((e|0)!=1){v[22656]=0;U(334,a|0,b|0,c|0);b=v[22656];v[22656]=0;if((b|0)!=1){break a}}a=P()|0;O()|0;vv(d);S(a|0);L()}return a|0}function Qna(a,b){a=a|0;b=b|0;var c=0,d=0;c=gb-2496|0;gb=c;SU(b,c,c+2496|0);b=hc(a,c,2496);v[b+2496>>2]=0;a:{if(v[b>>2]<0){break a}d=1;while(1){if(v[b+(d<<2)>>2]){break a}d=d+1|0;if((d|0)!=624){continue}break}v[b>>2]=-2147483648}gb=c+2496|0;return a|0}function Pv(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=Ig(a);a:{if(!b){break a}v[22656]=0;R(488,a|0,b|0);e=v[22656];v[22656]=0;if((e|0)!=1){v[22656]=0;U(489,a|0,b|0,c|0);b=v[22656];v[22656]=0;if((b|0)!=1){break a}}a=P()|0;O()|0;km(d);S(a|0);L()}return a|0}function Ez(a){a=a|0;var b=0,c=0,d=0,e=0,f=0;b=gb-16|0;gb=b;c=uf(a);e=b,f=Vb(a),v[e+8>>2]=f;e=b,f=Zb(a),v[e>>2]=f;if(Gb(b+8|0,b)){d=+(c>>>0);while(1){c=b+8|0;a=v[c>>2];A[a>>3]=A[a>>3]/d;A[a+8>>3]=A[a+8>>3]/d;_o(c);if(Gb(c,b)){continue}break}}gb=b+16|0}function AP(a,b,c){var d=0,e=0;d=v[(B(b,872)+a|0)+1075080>>2];a:{if(!(!(d&134218752)|(c|0)!=1)|d&67108864){break a}if(x[a+480188>>1]<=b>>>0){c=x[(B(b,872)+a|0)+1075778>>1];b=c?c-1|0:b}b=b&65535;if(b>>>0>126){break a}e=w[((b<<5)+a|0)+480288|0]}return e}function en(a){var b=0,c=0,d=0,e=0;hv(a);if(v[a>>2]){c=a;d=v[a>>2];b=v[a+4>>2];a:{while(1){if((b|0)==(d|0)){break a}wb(c);v[22656]=0;b=b-32|0;e=v[22656];v[22656]=0;if((e|0)!=1){continue}break}V(0)|0;O()|0;Bb();L()}v[c+4>>2]=d;lV(wb(a),v[a>>2],bi(a))}}function be(a){var b=0,c=0,d=0;b=a;c=v[a+4>>2];a:{while(1){if(v[b+8>>2]==(c|0)){break a}v[b+8>>2]=v[b+8>>2]-1;v[22656]=0;d=v[22656];v[22656]=0;if((d|0)!=1){continue}break}V(0)|0;O()|0;Bb();L()}if(v[a>>2]){al(v[a+16>>2],v[a>>2],v[dc(a)>>2]-v[a>>2]|0)}}function ag(a,b){a=a|0;b=b|0;var c=0,d=0;c=gb-32|0;gb=c;u[c+30>>1]=0;d=c+30|0;v[c+8>>2]=d;v[c+12>>2]=d+2;d=v[c+12>>2];v[c>>2]=v[c+8>>2];v[c+4>>2]=d;d=c+16|0;ot(d,a,c);a=yb(d);u[c+16>>1]=x[c+30>>1];u[b>>1]=w[d|0]|w[d+1|0]<<8;gb=c+32|0;return(a|0)==2|0}function Xla(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=gb-32|0;gb=c;d=c+24|0;vC(d,b);b=yb(d);d=v[c+28>>2];e=v[c+24>>2];v[c+8>>2]=e;v[c+12>>2]=d;v[c>>2]=e;v[c+4>>2]=d;d=c+16|0;cc(d,a,c);d=yb(d);if((d|0)==(b|0)){Rb(a,yb(c+24|0))}gb=c+32|0;return(b|0)==(d|0)|0}function Kga(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=gb-32|0;gb=c;d=c+24|0;zD(d,b);b=yb(d);d=v[c+28>>2];e=v[c+24>>2];v[c+8>>2]=e;v[c+12>>2]=d;v[c>>2]=e;v[c+4>>2]=d;d=c+16|0;cc(d,a,c);d=yb(d);if((d|0)==(b|0)){Rb(a,yb(c+24|0))}gb=c+32|0;return(b|0)==(d|0)|0}function HI(a){var b=0,c=0;b=w[a+74|0];t[a+74|0]=b-1|b;if(y[a+20>>2]>y[a+28>>2]){kb[v[a+36>>2]](a,0,0)|0}v[a+28>>2]=0;v[a+16>>2]=0;v[a+20>>2]=0;b=v[a>>2];if(b&4){v[a>>2]=b|32;return-1}c=v[a+44>>2]+v[a+48>>2]|0;v[a+8>>2]=c;v[a+4>>2]=c;return b<<27>>31}function oW(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=gb-32|0;gb=c;d=c+24|0;NX(d,b);b=yb(d);d=v[c+28>>2];e=v[c+24>>2];v[c+8>>2]=e;v[c+12>>2]=d;v[c>>2]=e;v[c+4>>2]=d;d=c+16|0;cc(d,a,c);d=yb(d);if((d|0)==(b|0)){Rb(a,yb(c+24|0))}gb=c+32|0;return(b|0)==(d|0)|0}function kj(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=gb-32|0;gb=c;d=c+24|0;fs(d,b);b=yb(d);d=v[c+28>>2];e=v[c+24>>2];v[c+8>>2]=e;v[c+12>>2]=d;v[c>>2]=e;v[c+4>>2]=d;d=c+16|0;cc(d,a,c);d=yb(d);if((d|0)==(b|0)){Rb(a,yb(c+24|0))}gb=c+32|0;return(b|0)==(d|0)|0}function jT(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;a:{d=gb-16|0;gb=d;b:{c:{if(!b){b=a;a=Jb(c);Pj(b,a,Ab(c)+a|0);break c}gT(d,c);v[22656]=0;U(57,a|0,b|0,d|0);a=v[22656];v[22656]=0;if((a|0)==1){break b}Hc(d)}gb=d+16|0;break a}a=P()|0;O()|0;Hc(d);S(a|0);L()}}function QW(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=gb-16|0;gb=d;c=d;v[c>>2]=v[a+8>>2];e=v[a+8>>2];v[c+8>>2]=a+8;v[c+4>>2]=B(b,48)+e;if(v[c>>2]!=v[c+4>>2]){while(1){PW(v[c>>2]);a=v[c>>2]+48|0;v[c>>2]=a;if((a|0)!=v[c+4>>2]){continue}break}}_c(c);gb=d+16|0}function Mw(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=gb-16|0;gb=d;c=d;v[c>>2]=v[a+8>>2];e=v[a+8>>2];v[c+8>>2]=a+8;v[c+4>>2]=(b<<3)+e;a=v[c>>2];if((a|0)!=v[c+4>>2]){while(1){jm(a);a=v[c>>2]+8|0;v[c>>2]=a;if(v[c+4>>2]!=(a|0)){continue}break}}_c(c);gb=d+16|0}function Lm(a,b,c,d){var e=0;a:{if(b>>>0>255){break a}b:{switch(c|0){case 2:e=BP(a,b,d);if((e-1&255)>>>0<250){break a}case 0:return AP(a,b,d);case 3:e=AP(a,b,d);if((e-1&255)>>>0<250){break a}break;case 1:break b;default:break a}}e=BP(a,b,d)}return e}function hC(a,b){var c=0,d=0,e=0,f=0;c=a;d=a+1024|0;if((d|0)!=(a|0)){f=b?224:240;while(1){a=c;b=a+16|0;if((a|0)!=(b|0)){while(1){e=((f&w[ic(a,0)|0])!=0)+e|0;a=a+4|0;if((b|0)!=(a|0)){continue}break}}c=c+16|0;if((d|0)!=(c|0)){continue}break}}return e}function Oea(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=gb-16|0;gb=d;e=et(a);v[a>>2]=74808;f=Kb(a+32|0);v[a+48>>2]=c;v[a+44>>2]=0;v[22656]=0;R(108,a|0,b|0);b=v[22656];v[22656]=0;if((b|0)!=1){gb=d+16|0;return a|0}a=P()|0;O()|0;vb(f);Am(e);S(a|0);L()}function MD(a,b){var c=0,d=0;c=gb-32|0;gb=c;a:{if(!Pb(a,512)){a=gb-16|0;gb=a;d=b+512|0;while(1){ak(b);b=b+4|0;if((d|0)!=(b|0)){continue}break}gb=a+16|0;break a}Vv(c+24|0,b);b=v[c+28>>2];v[c+8>>2]=v[c+24>>2];v[c+12>>2]=b;kd(c+16|0,a,c+8|0)}gb=c+32|0}function DY(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=gb-32|0;gb=d;v[d+24>>2]=b;a=Fn(d+8|0,a+8|0,AD(b,c));c=v[a>>2];if((c|0)!=v[a+4>>2]){while(1){b=d+24|0;Fr(c,v[b>>2]);v[a>>2]=v[a>>2]+2;Tv(b);c=v[a>>2];if((c|0)!=v[a+4>>2]){continue}break}}_c(a);gb=d+32|0}function sT(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;a:{d=gb-16|0;gb=d;b:{c:{if(!b){b=a;a=Jb(c);Pj(b,a,Ab(c)+a|0);break c}CT(d,b,c);v[22656]=0;R(58,a|0,d|0);a=v[22656];v[22656]=0;if((a|0)==1){break b}Hc(d)}gb=d+16|0;break a}a=P()|0;O()|0;Hc(d);S(a|0);L()}}function gX(a,b,c){var d=0,e=0,f=0,g=0;if((b|0)!=(c|0)){while(1){d=zb(w[b|0]);e=v[a+4>>2];g=e>>>8|0;f=v[a>>2];e=(e&255)<<24|f>>>8;d=(((d^f)&255)<<3)+18848|0;f=v[d>>2];d=v[d+4>>2]^g;v[a>>2]=e^f;v[a+4>>2]=d;b=b+1|0;if((c|0)!=(b|0)){continue}break}}}
function coa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;e=gb-32|0;gb=e;v[e+24>>2]=d;d=fg(a,c);se(e,v[a+28>>2]);f=v[e+12>>2];v[e+16>>2]=v[e+8>>2];v[e+20>>2]=f;a:{if(!d){if(nd(a,5)){break a}}hX(v[a+28>>2],b,v[e+24>>2],0)}Zf(a,d,c,e+16|0);gb=e+32|0}function jna(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;d=gb-16|0;gb=d;v[d+12>>2]=c;c=d+12|0;qc(c,256);qc(c,65535);e=x[d+12>>1];Af(a,e);if(e){c=0;while(1){f=w[b+c|0];g=fj(a,c),h=f,u[g>>1]=h;c=c+1|0;if((e|0)!=(c|0)){continue}break}}gb=d+16|0}function Gt(a){var b=0,c=0;b=a+24|0;c=v[b>>2];v[22656]=0;T(1291,c|0)|0;c=v[22656];v[22656]=0;if((c|0)!=1){yd(a+68|0);Yf(a+36|0);iq(a+32|0);Di(b);Ci(a+4|0);eg(a);return a}V(0)|0;O()|0;yd(a+68|0);Yf(a+36|0);iq(a+32|0);Di(b);Ci(a+4|0);eg(a);Bb();L()}function Cp(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;f=gb-16|0;gb=f;d=Kc(a);e=Ab(a);a:{if(d-e>>>0>=c>>>0){if(!c){break a}d=Jb(a);Qg(d+e|0,b,c);b=c+e|0;jh(a,b);t[f+15|0]=0;Bd(b+d|0,f+15|0);break a}wp(a,d,(c+e|0)-d|0,e,e,0,c,b)}gb=f+16|0;return a|0}function kea(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;e=gb-32|0;gb=e;v[e+24>>2]=d;d=fg(a,c);se(e,v[a+28>>2]);f=v[e+12>>2];v[e+16>>2]=v[e+8>>2];v[e+20>>2]=f;a:{if(!d){if(nd(a,5)){break a}}iN(v[a+28>>2],b,v[e+24>>2])}Zf(a,d,c,e+16|0);gb=e+32|0}function JP(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;a=Uc(Qm(a,x[c+70>>1],v[c+48>>2],b,0)-32768|0);a:{if(!d){break a}d=uk(c)-v[c+16>>2]|0;if((d|0)<2){break a}e=a;a=u[(B(b,872)+c|0)+1390>>1];a=Uc(((e-a|0)/(d|0)|0)+a|0)}u[(B(b,872)+c|0)+1390>>1]=a}function Ik(a,b){var c=0,d=0;c=gb-32|0;gb=c;v[c+28>>2]=0;bX(c+8|0,c+28|0);d=v[c+12>>2];v[c>>2]=v[c+8>>2];v[c+4>>2]=d;d=c+16|0;ot(d,a,c);a=yb(d);v[c+16>>2]=v[c+28>>2];v[b>>2]=w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24);gb=c+32|0;return(a|0)==4}function uV(a,b){var c=0,d=0,e=0,f=0;c=gb-32|0;gb=c;e=c+24|0;oV(e,b);e=yb(e);d=v[c+28>>2];f=v[c+24>>2];v[c+8>>2]=f;v[c+12>>2]=d;v[c>>2]=f;v[c+4>>2]=d;d=c+16|0;cc(d,a,c);d=yb(d);if((d|0)==(e|0)){Rb(a,yb(c+24|0))}gb=c+32|0;if((d|0)!=(e|0)){pV(b)}}function qO(a,b){var c=0,d=0,e=0;a:{if(!(w[a+89|0]&16)){break a}c=v[a+656>>2];if(!c){break a}d=b;c=v[c>>2];b:{if(c){e=a;a=v[a+696>>2]-(c<<1)|0;a=(a|0)>0?a:0;v[e+696>>2]=a;a=(B(a,v[b>>2])|0)/65536|0;break b}if(v[a+696>>2]){break a}a=0}v[d>>2]=a}}function m3(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;a=gb-16|0;gb=a;v[a+8>>2]=b;Fc(a,d);v[22656]=0;b=T(2452,a|0)|0;d=v[22656];v[22656]=0;if((d|0)!=1){Wb(a);mH(f+20|0,a+8|0,c,e,b);gb=a+16|0;return v[a+8>>2]}b=P()|0;O()|0;Wb(a);S(b|0);L()}function TC(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;a:{c=mc(a+8|0);v[22656]=0;d=T(467,b|0)|0;e=v[22656];v[22656]=0;b:{if((e|0)==1){break b}v[22656]=0;U(393,a|0,b|0,d|0);a=v[22656];v[22656]=0;if((a|0)==1){break b}break a}a=P()|0;O()|0;gc(c);S(a|0);L()}}function cB(a){a=a|0;var b=0,c=0,d=0;b=gb-16|0;gb=b;if(w[a+530|0]){while(1){d=c&65535;Oi(a,d,1);c=c+1|0;if(d>>>0<255){continue}break}t[a+530|0]=0}t[b+15|0]=0;ni(a+4|0,18,b+15|0);pv(a+22|0,18,35498);t[b+14|0]=255;ni(a+58|0,256,b+14|0);gb=b+16|0}function Nu(a){a=a|0;var b=0,c=0,d=0,e=0;c=SS(a);if((c|0)!=(a|0)){while(1){b=0;e=a;fX(a);a:{while(1){d=b+e|0;if(w[d|0]){b=b+1|0;if((b|0)!=32){continue}break a}break}if(b>>>0>31){break a}Qb(d,0,32-b|0)}a=a+32|0;if((c|0)!=(a|0)){continue}break}}}function Bpa(a,b){a=a|0;b=b|0;var c=0;b=gb-32|0;gb=b;c=-1;a:{if(!oD(a,b+16|0)){break a}c=0;if(!bY(b+16|0)){break a}if(v[b+16>>2]==1179472708){c=-1;if(!bd(a,4)){break a}}c=-1;if(!ek(a,b+8|0)){break a}c=v[b+8>>2]==1196314451}gb=b+32|0;return c|0}function s3(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;a=gb-16|0;gb=a;v[a+8>>2]=b;Fc(a,d);v[22656]=0;b=T(21,a|0)|0;d=v[22656];v[22656]=0;if((d|0)!=1){Wb(a);pH(f+20|0,a+8|0,c,e,b);gb=a+16|0;return v[a+8>>2]}b=P()|0;O()|0;Wb(a);S(b|0);L()}function f7(a){a=a|0;var b=0,c=0,d=0,e=0;b=gb-32|0;gb=b;c=a;if(!w[c+8|0]){d=c+12|0;Ok(d,v[c+4>>2]);Vd(b+24|0,d);d=v[v[c>>2]+40>>2];e=v[b+28>>2];v[b+8>>2]=v[b+24>>2];v[b+12>>2]=e;kb[d|0](b+16|0,c,0,b+8|0);t[c+8|0]=1}gb=b+32|0;return v[a+12>>2]}function Rp(a,b){var c=0,d=0,e=0,f=0;c=a*a;d=c*.5;e=1-d;f=1-e-d;d=c*c;return e+(f+(c*(c*(c*(c*2480158728947673e-20+-.001388888888887411)+.0416666666666666)+d*d*(c*(c*-1.1359647557788195e-11+2.087572321298175e-9)+-2.7557314351390663e-7))-a*b))}function IF(a){t[a|0]=0;t[a+1|0]=0;t[a+2|0]=0;t[a+3|0]=0;t[a+4|0]=0;t[a+5|0]=0;t[a+6|0]=0;t[a+7|0]=0;t[a+16|0]=0;t[a+17|0]=0;t[a+18|0]=0;t[a+19|0]=0;t[a+8|0]=0;t[a+9|0]=0;t[a+10|0]=0;t[a+11|0]=0;t[a+12|0]=0;t[a+13|0]=0;t[a+14|0]=0;t[a+15|0]=0}function aN(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;e=gb-16|0;gb=e;if(d>>>0<=4294967279){a:{if(d>>>0<=10){_e(a,c);d=a;break a}f=Xk(d)+1|0;d=oi(a,f);ef(a,d);rg(a,f);de(a,c)}Qg(d,b,c);t[e+15|0]=0;Bd(c+d|0,e+15|0);gb=e+16|0;return}vg();L()}function R4(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;if(!w[a+44|0]){e=(c|0)>0;c=e?c:0;if(e){while(1){if((kb[v[v[a>>2]+52>>2]](a,v[b>>2])|0)==-1){return d|0}b=b+4|0;d=d+1|0;if((c|0)!=(d|0)){continue}break}}return c|0}return Lk(b,4,c,v[a+32>>2])|0}function L3(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=gb-16|0;gb=e;v[e+12>>2]=b;v[e+8>>2]=d;b=vi(e,e+12|0);v[22656]=0;a=W(2469,a|0,c|0,v[e+8>>2])|0;c=v[22656];v[22656]=0;if((c|0)!=1){hf(b);gb=e+16|0;return a|0}a=P()|0;O()|0;hf(b);S(a|0);L()}function FL(a,b){var c=0,d=0,e=0;c=gb-16|0;gb=c;v[b>>2]=0;t[c+15|0]=0;Uh(a,c+15|0);d=w[c+15|0];v[b>>2]=d>>>2;d=d&3;if(d){while(1){t[c+15|0]=0;Uh(a,c+15|0);e=e+1|0;v[b>>2]=v[b>>2]|w[c+15|0]<<(e<<3)-2;if((d|0)!=(e|0)){continue}break}}gb=c+16|0}function xe(){var a=0,b=0;a:{b:{if(t[464160]&1){break b}if(!Qd(464160)){break b}v[22656]=0;a=W(2450,2147483647,11509,0)|0;b=v[22656];v[22656]=0;if((b|0)==1){break a}v[116039]=a;Pd(464160)}return v[116039]}a=P()|0;O()|0;$e(464160);S(a|0);L()}function mpa(a,b){a=a|0;b=b|0;var c=0,d=0;c=Ig(a);a:{if(!b){break a}v[22656]=0;R(518,a|0,b|0);d=v[22656];v[22656]=0;if((d|0)!=1){v[22656]=0;R(519,a|0,b|0);b=v[22656];v[22656]=0;if((b|0)!=1){break a}}a=P()|0;O()|0;km(c);S(a|0);L()}return a|0}function Zu(a,b,c,d){var e=0,f=0,g=0,h=0;e=gb-16|0;gb=e;v[e+12>>2]=0;kf(a+12|0,d);if(b){d=b;if(b>>>0>=357913942){rd(8445);L()}f=Mc(B(d,12),4)}v[a>>2]=f;c=B(c,12)+f|0;v[a+8>>2]=c;v[a+4>>2]=c;g=dc(a),h=B(b,12)+f|0,v[g>>2]=h;gb=e+16|0;return a}function Xfa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;b=(b-a|0)/160|0;if((b|0)>0){while(1){f=a;d=c;v[a>>2]=v[d>>2];e=a+4|0;if((e|0)!=(d+4|0)){yO(e,v[d+4>>2],v[d+8>>2])}hc(f+16|0,d+16|0,144);a=a+160|0;d=b>>>0>1;b=b-1|0;if(d){continue}break}}}function RP(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=gb-16|0;gb=d;a:{if(!c){break a}v[b+40>>2]=c;if(v[a+480180>>2]!=256){break a}v[d+12>>2]=c>>>4;v[d+8>>2]=1;e=b,f=v[Lc(d+12|0,d+8|0)>>2],v[e+40>>2]=f;e=b,f=FP(c&255),v[e+44>>2]=f}gb=d+16|0}function Qma(a,b){a=a|0;b=b|0;var c=0,d=0;c=vh(a);a:{if(!b){break a}v[22656]=0;R(775,a|0,b|0);d=v[22656];v[22656]=0;if((d|0)!=1){v[22656]=0;R(776,a|0,b|0);b=v[22656];v[22656]=0;if((b|0)!=1){break a}}a=P()|0;O()|0;mC(c);S(a|0);L()}return a|0}function IY(a,b,c,d){var e=0,f=0,g=0,h=0;e=gb-16|0;gb=e;v[e+12>>2]=0;kf(a+12|0,d);if(b){d=b;if(b>>>0>=153391690){rd(8445);L()}f=Mc(B(d,28),4)}v[a>>2]=f;c=B(c,28)+f|0;v[a+8>>2]=c;v[a+4>>2]=c;g=dc(a),h=B(b,28)+f|0,v[g>>2]=h;gb=e+16|0;return a}function oX(a,b){a=a|0;b=b|0;var c=0,d=0;c=Ig(a);a:{if(!b){break a}v[22656]=0;R(488,a|0,b|0);d=v[22656];v[22656]=0;if((d|0)!=1){v[22656]=0;R(606,a|0,b|0);b=v[22656];v[22656]=0;if((b|0)!=1){break a}}a=P()|0;O()|0;km(c);S(a|0);L()}return a|0}function VF(a,b,c,d){var e=0,f=0,g=0,h=0;e=gb-16|0;gb=e;v[e+12>>2]=0;Bh(a+12|0,d);if(b){d=b;if(b>>>0>119304647){rd(8445);L()}f=Mc(B(d,36),4)}v[a>>2]=f;c=B(c,36)+f|0;v[a+8>>2]=c;v[a+4>>2]=c;g=dc(a),h=B(b,36)+f|0,v[g>>2]=h;gb=e+16|0;return a}function NZ(a,b){a=a|0;b=b|0;var c=0,d=0;c=Ig(a);a:{if(!b){break a}v[22656]=0;R(335,a|0,b|0);d=v[22656];v[22656]=0;if((d|0)!=1){v[22656]=0;R(336,a|0,b|0);b=v[22656];v[22656]=0;if((b|0)!=1){break a}}a=P()|0;O()|0;wE(c);S(a|0);L()}return a|0}function lW(a,b){var c=0,d=0,e=0;c=gb-32|0;gb=c;d=c+24|0;bc(d,b,18);b=yb(d);d=v[c+28>>2];e=v[c+24>>2];v[c+8>>2]=e;v[c+12>>2]=d;v[c>>2]=e;v[c+4>>2]=d;d=c+16|0;cc(d,a,c);d=yb(d);if((d|0)==(b|0)){Rb(a,yb(c+24|0))}gb=c+32|0;return(b|0)==(d|0)}function hY(a,b,c,d){var e=0,f=0,g=0,h=0;e=gb-16|0;gb=e;v[e+12>>2]=0;Bh(a+12|0,d);if(b){d=b;if(b>>>0>89478485){rd(8445);L()}f=Mc(B(d,48),4)}v[a>>2]=f;c=B(c,48)+f|0;v[a+8>>2]=c;v[a+4>>2]=c;g=dc(a),h=B(b,48)+f|0,v[g>>2]=h;gb=e+16|0;return a}function gga(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;e=gb-32|0;gb=e;c=b+4|0;b=v[c+48>>2];a:{if(b&16){b=v[c+44>>2];d=v[c+24>>2];if(b>>>0<d>>>0){v[c+44>>2]=d;b=d}Pj(a,v[c+20>>2],b);break a}if(b&8){Pj(a,v[c+8>>2],v[c+16>>2]);break a}Kb(a)}gb=e+32|0}function Xt(a,b,c){var d=0,e=0;d=gb-32|0;gb=d;a:{e=!b|!c;if(!e){b=Tb(d,b);v[22656]=0;U(1476,d+16|0,b|0,c|0);c=v[22656];v[22656]=0;if((c|0)==1){break a}c=a+36|0;a=d+16|0;Eb(c,a);vb(a);vb(b)}gb=d+32|0;return!e}a=P()|0;O()|0;vb(b);S(a|0);L()}function SX(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=gb-32|0;gb=d;v[d+24>>2]=b;a=Cy(d+8|0,a+8|0,TX(b,c));if(v[a>>2]!=v[a+4>>2]){while(1){b=d+24|0;mp(v[a>>2],v[b>>2]);v[a>>2]=v[a>>2]+1;Pe(b);if(v[a>>2]!=v[a+4>>2]){continue}break}}_c(a);gb=d+32|0}function Re(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=mc(a+8|0);v[22656]=0;U(393,a|0,b|0,c|0);c=v[22656];v[22656]=0;a:{if((c|0)!=1){a=v[a>>2];v[22656]=0;Q(318,b|0,a|0)|0;a=v[22656];v[22656]=0;if((a|0)!=1){break a}}a=P()|0;O()|0;gc(d);S(a|0);L()}}function LQ(a,b){var c=0;c=w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24);t[a|0]=c;t[a+1|0]=c>>>8;t[a+2|0]=c>>>16;t[a+3|0]=c>>>24;b=w[b+3|0]|w[b+4|0]<<8|(w[b+5|0]<<16|w[b+6|0]<<24);t[a+3|0]=b;t[a+4|0]=b>>>8;t[a+5|0]=b>>>16;t[a+6|0]=b>>>24}function JF(a,b){var c=0,d=0,e=0;c=gb-32|0;gb=c;d=c+24|0;bc(d,b,20);b=yb(d);d=v[c+28>>2];e=v[c+24>>2];v[c+8>>2]=e;v[c+12>>2]=d;v[c>>2]=e;v[c+4>>2]=d;d=c+16|0;cc(d,a,c);d=yb(d);if((d|0)==(b|0)){Rb(a,yb(c+24|0))}gb=c+32|0;return(b|0)==(d|0)}function WQ(a,b,c,d){var e=0,f=0,g=0,h=0;e=gb-16|0;gb=e;v[e+12>>2]=0;kf(a+12|0,d);if(b){d=b;if(b>>>0>=613566757){rd(8445);L()}f=Mc(B(d,7),1)}v[a>>2]=f;c=B(c,7)+f|0;v[a+8>>2]=c;v[a+4>>2]=c;g=dc(a),h=B(b,7)+f|0,v[g>>2]=h;gb=e+16|0;return a}function Rea(a,b){a=a|0;b=b|0;var c=0,d=0;c=gb-32|0;gb=c;d=-1;a:{if(!lG(a,c+8|0)){break a}d=0;if(!NN(c+8|0)){break a}if(b){a=c+16|0;if(v[b>>2]!=(w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24))|v[b+4>>2]){break a}}d=1}gb=c+32|0;return d|0}function RE(a,b){var c=0,d=0,e=0;c=gb-32|0;gb=c;d=c+24|0;bc(d,b,1);b=yb(d);d=v[c+28>>2];e=v[c+24>>2];v[c+8>>2]=e;v[c+12>>2]=d;v[c>>2]=e;v[c+4>>2]=d;d=c+16|0;cc(d,a,c);d=yb(d);if((d|0)==(b|0)){Rb(a,yb(c+24|0))}gb=c+32|0;return(b|0)==(d|0)}function L7(a,b){a=a|0;b=b|0;var c=0,d=0;if(v[b+4>>2]){a=0;while(1){c=0;if(v[b+8>>2]){while(1){d=v[v[b>>2]+(a<<2)>>2]+(c<<3)|0;v[d>>2]=0;v[d+4>>2]=0;c=c+1|0;if(c>>>0<y[b+8>>2]){continue}break}}a=a+1|0;if(a>>>0<y[b+4>>2]){continue}break}}}function CH(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;a:{if(a-b>>2>>>0<c>>>0){while(1){c=c-1|0;d=c<<2;v[d+a>>2]=v[b+d>>2];if(c){continue}break a}}if(!c){break a}d=a;while(1){v[d>>2]=v[b>>2];d=d+4|0;b=b+4|0;c=c-1|0;if(c){continue}break}}return a|0}function aH(a){var b=0,c=0,d=0;d=gb-16|0;gb=d;b=d;v[b>>2]=465776;c=v[116445];v[b+4>>2]=c;v[b+8>>2]=c+(a<<2);c=b;a=v[b+4>>2];b=v[b+8>>2];if((a|0)!=(b|0)){while(1){Zo(a);a=a+4|0;v[c+4>>2]=a;if((a|0)!=(b|0)){continue}break}}$b(c);gb=d+16|0}function rF(a,b){var c=0,d=0,e=0;c=gb-32|0;gb=c;d=c+24|0;ds(d,b);b=yb(d);d=v[c+28>>2];e=v[c+24>>2];v[c+8>>2]=e;v[c+12>>2]=d;v[c>>2]=e;v[c+4>>2]=d;d=c+16|0;cc(d,a,c);d=yb(d);if((d|0)==(b|0)){Rb(a,yb(c+24|0))}gb=c+32|0;return(b|0)==(d|0)}function nV(a,b){var c=0,d=0,e=0;c=gb-32|0;gb=c;d=c+24|0;mV(d,b);b=yb(d);d=v[c+28>>2];e=v[c+24>>2];v[c+8>>2]=e;v[c+12>>2]=d;v[c>>2]=e;v[c+4>>2]=d;d=c+16|0;cc(d,a,c);d=yb(d);if((d|0)==(b|0)){Rb(a,yb(c+24|0))}gb=c+32|0;return(b|0)==(d|0)}function lY(a,b){var c=0,d=0,e=0;c=gb-32|0;gb=c;d=c+24|0;Lv(d,b);b=yb(d);d=v[c+28>>2];e=v[c+24>>2];v[c+8>>2]=e;v[c+12>>2]=d;v[c>>2]=e;v[c+4>>2]=d;d=c+16|0;cc(d,a,c);d=yb(d);if((d|0)==(b|0)){Rb(a,yb(c+24|0))}gb=c+32|0;return(b|0)==(d|0)}function js(a,b){var c=0,d=0,e=0;c=gb-32|0;gb=c;d=c+24|0;zi(d,b);b=yb(d);d=v[c+28>>2];e=v[c+24>>2];v[c+8>>2]=e;v[c+12>>2]=d;v[c>>2]=e;v[c+4>>2]=d;d=c+16|0;cc(d,a,c);d=yb(d);if((d|0)==(b|0)){Rb(a,yb(c+24|0))}gb=c+32|0;return(b|0)==(d|0)}function dY(a,b){var c=0,d=0,e=0;c=gb-32|0;gb=c;d=c+24|0;jw(d,b);b=yb(d);d=v[c+28>>2];e=v[c+24>>2];v[c+8>>2]=e;v[c+12>>2]=d;v[c>>2]=e;v[c+4>>2]=d;d=c+16|0;cc(d,a,c);d=yb(d);if((d|0)==(b|0)){Rb(a,yb(c+24|0))}gb=c+32|0;return(b|0)==(d|0)}function Z_(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0;e=gb-16|0;gb=e;f=v[b+8>>2];if(f>>>0>c>>>0){v[e+12>>2]=f-c;h=e,i=yb(d),v[h+8>>2]=i;f=Fb(e+12|0,e+8|0);b=v[b+4>>2]+c|0;g=v[f>>2];Rg(b,b+g|0,v[d>>2])}ok(a,d,g);gb=e+16|0}function ZX(a,b){var c=0,d=0,e=0;c=gb-32|0;gb=c;d=c+24|0;_X(d,b);b=yb(d);d=v[c+28>>2];e=v[c+24>>2];v[c+8>>2]=e;v[c+12>>2]=d;v[c>>2]=e;v[c+4>>2]=d;d=c+16|0;cc(d,a,c);d=yb(d);if((d|0)==(b|0)){Rb(a,yb(c+24|0))}gb=c+32|0;return(b|0)==(d|0)}function YX(a,b){var c=0,d=0,e=0;c=gb-32|0;gb=c;d=c+24|0;yD(d,b);b=yb(d);d=v[c+28>>2];e=v[c+24>>2];v[c+8>>2]=e;v[c+12>>2]=d;v[c>>2]=e;v[c+4>>2]=d;d=c+16|0;cc(d,a,c);d=yb(d);if((d|0)==(b|0)){Rb(a,yb(c+24|0))}gb=c+32|0;return(b|0)==(d|0)}function XF(a,b){var c=0,d=0,e=0;c=gb-32|0;gb=c;d=c+24|0;YF(d,b);b=yb(d);d=v[c+28>>2];e=v[c+24>>2];v[c+8>>2]=e;v[c+12>>2]=d;v[c>>2]=e;v[c+4>>2]=d;d=c+16|0;cc(d,a,c);d=yb(d);if((d|0)==(b|0)){Rb(a,yb(c+24|0))}gb=c+32|0;return(b|0)==(d|0)}function Wv(a,b){var c=0,d=0,e=0;c=gb-32|0;gb=c;d=c+24|0;tn(d,b);b=yb(d);d=v[c+28>>2];e=v[c+24>>2];v[c+8>>2]=e;v[c+12>>2]=d;v[c>>2]=e;v[c+4>>2]=d;d=c+16|0;cc(d,a,c);d=yb(d);if((d|0)==(b|0)){Rb(a,yb(c+24|0))}gb=c+32|0;return(b|0)==(d|0)}function VD(a,b){var c=0,d=0,e=0;c=gb-32|0;gb=c;d=c+24|0;UD(d,b);b=yb(d);d=v[c+28>>2];e=v[c+24>>2];v[c+8>>2]=e;v[c+12>>2]=d;v[c>>2]=e;v[c+4>>2]=d;d=c+16|0;cc(d,a,c);d=yb(d);if((d|0)==(b|0)){Rb(a,yb(c+24|0))}gb=c+32|0;return(b|0)==(d|0)}function QV(a,b){var c=0,d=0,e=0;c=gb-32|0;gb=c;d=c+24|0;sC(d,b);b=yb(d);d=v[c+28>>2];e=v[c+24>>2];v[c+8>>2]=e;v[c+12>>2]=d;v[c>>2]=e;v[c+4>>2]=d;d=c+16|0;cc(d,a,c);d=yb(d);if((d|0)==(b|0)){Rb(a,yb(c+24|0))}gb=c+32|0;return(b|0)==(d|0)}function Ng(a,b){var c=0,d=0,e=0;c=gb-32|0;gb=c;d=c+24|0;Wr(d,b);b=yb(d);d=v[c+28>>2];e=v[c+24>>2];v[c+8>>2]=e;v[c+12>>2]=d;v[c>>2]=e;v[c+4>>2]=d;d=c+16|0;cc(d,a,c);d=yb(d);if((d|0)==(b|0)){Rb(a,yb(c+24|0))}gb=c+32|0;return(b|0)==(d|0)}function Ep(a,b){var c=0,d=0,e=0;c=gb-32|0;gb=c;d=c+24|0;Cn(d,b);b=yb(d);d=v[c+28>>2];e=v[c+24>>2];v[c+8>>2]=e;v[c+12>>2]=d;v[c>>2]=e;v[c+4>>2]=d;d=c+16|0;cc(d,a,c);d=yb(d);if((d|0)==(b|0)){Rb(a,yb(c+24|0))}gb=c+32|0;return(b|0)==(d|0)}function DT(a,b){var c=0,d=0,e=0;c=gb-32|0;gb=c;d=c+24|0;sC(d,b);b=yb(d);d=v[c+28>>2];e=v[c+24>>2];v[c+8>>2]=e;v[c+12>>2]=d;v[c>>2]=e;v[c+4>>2]=d;d=c+16|0;hd(d,a,c);d=yb(d);if((d|0)==(b|0)){bd(a,yb(c+24|0))}gb=c+32|0;return(b|0)==(d|0)}function $v(a,b){var c=0,d=0,e=0;c=gb-32|0;gb=c;d=c+24|0;_v(d,b);b=yb(d);d=v[c+28>>2];e=v[c+24>>2];v[c+8>>2]=e;v[c+12>>2]=d;v[c>>2]=e;v[c+4>>2]=d;d=c+16|0;cc(d,a,c);d=yb(d);if((d|0)==(b|0)){Rb(a,yb(c+24|0))}gb=c+32|0;return(b|0)==(d|0)}function $V(a,b){var c=0,d=0,e=0;c=gb-32|0;gb=c;d=c+24|0;_V(d,b);b=yb(d);d=v[c+28>>2];e=v[c+24>>2];v[c+8>>2]=e;v[c+12>>2]=d;v[c>>2]=e;v[c+4>>2]=d;d=c+16|0;cc(d,a,c);d=yb(d);if((d|0)==(b|0)){Rb(a,yb(c+24|0))}gb=c+32|0;return(b|0)==(d|0)}function bea(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=gb-16|0;gb=d;c=0;a:{if(!Nb(a)){break a}while(1){gg(d,v[Mb(a,e)>>2]+40|0);c=vr(d,b);vb(d);if(c){c=v[Mb(a,e)>>2];break a}e=e+1|0;if(Nb(a)>>>0>e>>>0){continue}break}c=0}gb=d+16|0;return c|0}function Uh(a,b){a=a|0;b=b|0;var c=0,d=0;c=gb-32|0;gb=c;t[c+24|0]=0;d=c+24|0;v[c+8>>2]=d;v[c+12>>2]=d+1;d=v[c+12>>2];v[c>>2]=v[c+8>>2];v[c+4>>2]=d;d=c+16|0;ot(d,a,c);a=yb(d);t[c+16|0]=w[c+24|0];t[b|0]=w[d|0];gb=c+32|0;return(a|0)==1|0}function Oq(a,b){var c=0,d=0,e=0,f=0,g=0,h=0;f=131072/(A[v[a+4>>2]-8>>3]-A[v[a>>2]>>3]);while(1){d=-ee(f*A[ye(a,c)>>3]);a:{if(D(d)<2147483648){e=~~d;break a}e=-2147483648}g=Fe(b,c),h=e,v[g>>2]=h;c=c+1|0;if((c|0)!=2048){continue}break}}function iO(a,b,c){var d=0,e=0,f=0,g=0,h=0;if(b){g=c;h=c>>31;c=0;while(1){d=v[a>>2];e=v[a+4>>2];f=(d+e|0)/2|0;d=d-e|0;d=Ac(lqa(kqa(d,d>>31,g,h),jb,256,0),jb);v[a+4>>2]=f-d;v[a>>2]=d+f;a=a+8|0;c=c+1|0;if((c|0)!=(b|0)){continue}break}}}function _ja(a,b){a=a|0;b=b|0;var c=0,d=0;c=Ig(a);a:{if(!b){break a}v[22656]=0;R(333,a|0,b|0);d=v[22656];v[22656]=0;if((d|0)!=1){v[22656]=0;$S(a,b);b=v[22656];v[22656]=0;if((b|0)!=1){break a}}a=P()|0;O()|0;vv(c);S(a|0);L()}return a|0}function Tma(a,b){a=a|0;b=b|0;var c=0,d=0;c=vh(a);a:{if(!b){break a}v[22656]=0;R(773,a|0,b|0);d=v[22656];v[22656]=0;if((d|0)!=1){v[22656]=0;mr(a,b);b=v[22656];v[22656]=0;if((b|0)!=1){break a}}a=P()|0;O()|0;ci(c);S(a|0);L()}return a|0}function OI(a){var b=0,c=0,d=0;b=a;d=v[b+4>>2];a:{while(1){c=v[b+8>>2];if((c|0)==(d|0)){break a}v[b+8>>2]=c-16;v[22656]=0;c=v[22656];v[22656]=0;if((c|0)!=1){continue}break}V(0)|0;O()|0;Bb();L()}b=v[a>>2];if(b){_n(v[a+16>>2],b,Wx(a))}}function Cpa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;gY(a);wb(a);c=b+4|0;e=v[a>>2];d=v[a+4>>2]-e|0;f=v[c>>2]+B((d|0)/-48|0,48)|0;v[c>>2]=f;if((d|0)>0){hc(f,e,d)}xc(a,c);xc(a+4|0,b+8|0);xc(wb(a),dc(b));v[b>>2]=v[b+4>>2];Zj(a);mn(a);mn(a)}function spa(a,b){a=a|0;b=b|0;var c=0,d=0;c=gb-32|0;gb=c;a:{if(dg(a)>>>0<b>>>0){d=wb(a);b=Zg(c+8|0,b,oc(a),d);v[22656]=0;R(396,a|0,b|0);a=v[22656];v[22656]=0;if((a|0)==1){break a}be(b)}gb=c+32|0;return}a=P()|0;O()|0;be(b);S(a|0);L()}function UA(a){var b=0,c=0,d=0;b=a;d=v[b+4>>2];a:{while(1){c=v[b+8>>2];if((c|0)==(d|0)){break a}v[b+8>>2]=c-8;v[22656]=0;c=v[22656];v[22656]=0;if((c|0)!=1){continue}break}V(0)|0;O()|0;Bb();L()}b=v[a>>2];if(b){TA(v[a+16>>2],b,EF(a))}}function Tg(a,b,c){c=v[c+4>>2]&176;if((c|0)==32){return b}a:{if((c|0)!=16){break a}b:{c:{c=w[a|0];switch(c-43|0){case 0:case 2:break c;default:break b}}return a+1|0}if((c|0)!=48|(b-a|0)<2|(w[a+1|0]|32)!=120){break a}a=a+2|0}return a}function $ma(a,b){a=a|0;b=b|0;var c=0,d=0;c=gb-32|0;gb=c;a:{if(dg(a)>>>0<b>>>0){d=wb(a);b=Zg(c+8|0,b,oc(a),d);v[22656]=0;R(296,a|0,b|0);a=v[22656];v[22656]=0;if((a|0)==1){break a}be(b)}gb=c+32|0;return}a=P()|0;O()|0;be(b);S(a|0);L()}function dW(a,b){a=a|0;b=b|0;var c=0,d=0;c=gb-32|0;gb=c;a:{if(Pg(a)>>>0<b>>>0){d=wb(a);b=Gn(c+8|0,b,tc(a),d);v[22656]=0;R(313,a|0,b|0);a=v[22656];v[22656]=0;if((a|0)==1){break a}Hh(b)}gb=c+32|0;return}a=P()|0;O()|0;Hh(b);S(a|0);L()}function Hd(a,b){var c=0,d=0,e=0,f=0,g=0;c=x[a+20>>1];if(c){d=x[a+22>>1];g=c+d|0;c=d;while(1){e=((c&127)<<2)+a|0;f=x[e+28>>1]+b|0;u[e+28>>1]=f;if((f&65535)>>>0>=2048){u[a+20>>1]=c-d;return}c=c+1|0;if((g|0)!=(c|0)){continue}break}}}function $E(a,b,c){var d=0,e=0,f=0,g=0;f=gb-16|0;gb=f;e=v[a+4>>2];d=e+b|0;v[a+4>>2]=d;a:{b:{if(!e){g=d-1|0;break b}g=d-1|0;if((g^e-1)>>>0<32){break a}}v[v[a>>2]+((d>>>0<33?0:g>>>5|0)<<2)>>2]=0}d=f+8|0;zp(d,a,e);yp(d,b,c);gb=f+16|0}function ig(a,b){var c=0,d=0,e=0,f=0;c=x[a+24>>1]<<17;e=x[a+20>>1];if(e){d=x[a+22>>1];e=e+d|0;while(1){f=c;c=((d&127)<<2)+a|0;c=f-B(v[Fe(b,x[c+28>>1])>>2],u[c+26>>1])|0;d=d+1|0;if((e|0)!=(d|0)){continue}break}}return(c|0)/32768|0}function fn(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0;e=gb-16|0;gb=e;v[e+12>>2]=0;Bh(a+12|0,d);if(b){f=Si(v[a+16>>2],b)}v[a>>2]=f;c=(c<<2)+f|0;v[a+8>>2]=c;v[a+4>>2]=c;g=dc(a),h=(b<<2)+f|0,v[g>>2]=h;gb=e+16|0;return a|0}function eH(){var a=0,b=0,c=0;b=gb-16|0;gb=b;a=Tb(b,12139);a:{if(!Ab(a)){break a}c=1;if((xg(a,11846)|0)!=-1){break a}if((xg(a,13873)|0)!=-1){break a}if((xg(a,11038)|0)!=-1){break a}c=(xg(a,11081)|0)!=-1}vb(a);gb=b+16|0;return c|0}function dC(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0;d=gb-16|0;gb=d;f=v[b+12>>2];e=v[c+4>>2];c=v[c>>2];v[d+8>>2]=c;v[d+12>>2]=e;g=v[v[b>>2]+28>>2];v[d>>2]=c;v[d+4>>2]=e;kb[g|0](a,b,f,d);h=b,i=yb(a)+v[b+12>>2]|0,v[h+12>>2]=i;gb=d+16|0}function Xc(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;d=Nf(b);e=gb-16|0;gb=e;c=Kc(a);a:{if(c>>>0>=d>>>0){c=Jb(a);fm(c,b,d);t[e+15|0]=0;Bd(d+c|0,e+15|0);jh(a,d);break a}f=c;g=d-c|0;c=Ab(a);wp(a,f,g,c,0,c,d,b)}gb=e+16|0;return a|0}function Qd(a){var b=0,c=0,d=0;c=gb-16|0;gb=c;a=lx(c,a);d=gb-16|0;gb=d;if(!w[v[yc(d+8|0,v[a+4>>2])>>2]]){a:{b:{a=v[a+8>>2];b=w[a|0];if((b|0)!=1){if(b&2){break b}t[a|0]=2;a=1}else{a=0}break a}L()}b=a}gb=d+16|0;gb=c+16|0;return b}function JR(a,b){var c=0,d=0;c=Ig(a);a:{if(!b){break a}v[22656]=0;R(1119,a|0,b|0);d=v[22656];v[22656]=0;if((d|0)!=1){v[22656]=0;R(1120,a|0,b|0);b=v[22656];v[22656]=0;if((b|0)!=1){break a}}a=P()|0;O()|0;BR(c);S(a|0);L()}return a}function CU(a,b){var c=0,d=0,e=0,f=0;c=gb-32|0;gb=c;d=v[a+4>>2];e=v[a>>2];v[c+24>>2]=e;v[c+28>>2]=d;f=v[b+4>>2];a=v[b>>2];v[c+16>>2]=a;v[c+20>>2]=f;v[c+8>>2]=e;v[c+12>>2]=d;v[c>>2]=a;v[c+4>>2]=f;a=AU(c+8|0,c);gb=c+32|0;return a}function FD(a,b,c,d){var e=0,f=0,g=0,h=0;e=gb-16|0;gb=e;v[e+12>>2]=0;kf(a+12|0,d);if(b){d=b;if((b|0)<0){rd(8445);L()}f=Mc(d<<1,1)}v[a>>2]=f;c=(c<<1)+f|0;v[a+8>>2]=c;v[a+4>>2]=c;g=dc(a),h=(b<<1)+f|0,v[g>>2]=h;gb=e+16|0;return a}function xs(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;f=gb-16|0;gb=f;if(b){e=Kc(a);d=Ab(a);g=d+b|0;if(e-d>>>0<b>>>0){Ym(a,e,g-e|0,d,d,0,0)}e=d;d=Jb(a);Ir(e+d|0,b,c);jh(a,g);t[f+15|0]=0;Bd(d+g|0,f+15|0)}gb=f+16|0;return a|0}function wfa(a,b){a=a|0;b=b|0;var c=0,d=0;c=gb-32|0;gb=c;a:{if(ug(a)>>>0<b>>>0){d=wb(a);b=us(c+8|0,b,Ec(a),d);v[22656]=0;On(a,b);a=v[22656];v[22656]=0;if((a|0)==1){break a}yu(b)}gb=c+32|0;return}a=P()|0;O()|0;yu(b);S(a|0);L()}function lO(a){var b=0,c=0,d=0;b=gb-16|0;gb=b;v[b+12>>2]=7;v[b+8>>2]=32;if(v[Fb(b+12|0,b+8|0)>>2]){while(1){d=Ao(a);v[b+12>>2]=7;v[b+8>>2]=32;c=c+15|0;if(c>>>0<y[Fb(b+12|0,b+8|0)>>2]){continue}break}c=d&127}gb=b+16|0;return c}function Rpa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=gb-32|0;gb=c;d=c+24|0;fs(d,b);d=yb(d);b=v[c+28>>2];e=v[c+24>>2];v[c+8>>2]=e;v[c+12>>2]=b;v[c>>2]=e;v[c+4>>2]=b;b=c+16|0;cc(b,a,c);if((yb(b)|0)==(d|0)){Rb(a,yb(c+24|0))}gb=c+32|0}function QK(a,b){a=a|0;b=b|0;var c=C(0);a:{if((b|0)<0){break a}a=a+24|0;if(x[v[a>>2]+480188>>1]<=b>>>0){break a}b=B(b,872);if(!(t[(b+v[a>>2]|0)+1075081|0]&1)){break a}c=C(C(w[(b+v[a>>2]|0)+1075834|0])*C(.0078125))}return C(c)}function PK(a,b){a=a|0;b=b|0;var c=C(0);a:{if((b|0)<0){break a}a=a+24|0;if(x[v[a>>2]+480188>>1]<=b>>>0){break a}b=B(b,872);if(!(t[(b+v[a>>2]|0)+1075081|0]&1)){break a}c=C(C(w[(b+v[a>>2]|0)+1075835|0])*C(.0078125))}return C(c)}function hu(a,b){var c=0;a:{b:{c:{switch(b-2|0){default:c=49532;if((b|0)==16777216){break a}if((b|0)!=32){break b}c=49548;break a;case 2:c=49544;break a;case 1:break b;case 0:break c}}c=49540;break a}c=49536}v[a>>2]=v[c>>2]}function bY(a){if(!((w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24))!=1179011410|(w[a+8|0]|w[a+9|0]<<8|(w[a+10|0]<<16|w[a+11|0]<<24))!=1179472708)){return 1}return(w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24))==1179472708}function KN(a,b,c){var d=0,e=0,f=0;d=gb-32|0;gb=d;v[d+16>>2]=c;v[d+24>>2]=b;b=v[a>>2];e=d,f=Vb(a),v[e+8>>2]=f;c=d+24|0;b=b+B(Yt(c,d+8|0),6)|0;if(Gb(c,d+16|0)){WC(a,sz(b+B(Yt(d+16|0,d+24|0),6)|0,v[a+4>>2],b))}Hg(b);gb=d+32|0}function G4(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=gb-16|0;gb=d;v[d+12>>2]=c;v[d+8>>2]=c;e=-1;c=Us(0,0,b,c);a:{if((c|0)<0){break a}f=a;c=c+1|0;a=Cd(c);v[f>>2]=a;if(!a){break a}e=Us(a,c,b,v[d+12>>2])}gb=d+16|0;return e|0}function SK(a,b){a=a|0;b=b|0;var c=C(0);a:{if((b|0)<0){break a}a=a+24|0;if(x[v[a>>2]+480188>>1]<=b>>>0){break a}b=B(b,872);if(t[(b+v[a>>2]|0)+1075081|0]&1){break a}c=C(C(w[(b+v[a>>2]|0)+1075834|0])*C(.0078125))}return C(c)}function RK(a,b){a=a|0;b=b|0;var c=C(0);a:{if((b|0)<0){break a}a=a+24|0;if(x[v[a>>2]+480188>>1]<=b>>>0){break a}b=B(b,872);if(t[(b+v[a>>2]|0)+1075081|0]&1){break a}c=C(C(w[(b+v[a>>2]|0)+1075835|0])*C(.0078125))}return C(c)}function Mfa(a,b){a=a|0;b=b|0;var c=0,d=0;c=gb-16|0;gb=c;v[a+480180>>2]=b;oA(c,zq(a));d=v[c+12>>2];b=a+1074320|0;v[b>>2]=v[c+8>>2];v[b+4>>2]=d;b=v[c+4>>2];v[a+1074312>>2]=v[c>>2];v[a+1074316>>2]=b;hu(a+8|0,zq(a));gb=c+16|0}function GO(a,b){a=a|0;b=b|0;var c=0;c=65535;a:{if(x[v[a+8>>2]+58>>1]<b>>>0){break a}while(1){if(!v[(((b&65535)<<2)+a|0)+900380>>2]){c=b;break a}b=b+1|0;if(x[v[a+8>>2]+58>>1]>=(b&65535)>>>0){continue}break}}return c&65535}function sma(a){a=a|0;var b=0,c=0,d=0,e=0;b=gb-32|0;gb=b;u[b+30>>1]=0;c=wd(b+8|0,b+30|0,2);d=v[c+4>>2];v[b>>2]=v[c>>2];v[b+4>>2]=d;c=b+16|0;cc(c,a,b);if(!((yb(c)|0)!=2|x[b+30>>1]!=21584)){Rb(a,2);e=1}gb=b+32|0;return e|0}function fP(a,b,c){var d=0,e=0,f=0;d=gb-16|0;gb=d;b=gs(d,a,b);a=v[b+4>>2];e=v[b+8>>2];if((a|0)!=(e|0)){while(1){f=v[c+4>>2];v[a>>2]=v[c>>2];v[a+4>>2]=f;a=a+8|0;v[b+4>>2]=a;if((a|0)!=(e|0)){continue}break}}$b(b);gb=d+16|0}function OU(a,b){var c=0,d=0,e=0;c=a;if(v[c>>2]){LY(c);DD(v[c>>2],$i(c));d=wb(c),e=0,v[d>>2]=e;v[c>>2]=0;v[c+4>>2]=0}v[a>>2]=v[b>>2];v[a+4>>2]=v[b+4>>2];c=wb(b);d=wb(a),e=v[c>>2],v[d>>2]=e;v[c>>2]=0;v[b>>2]=0;v[b+4>>2]=0}function zs(a,b,c){var d=0,e=0,f=0;d=gb-16|0;gb=d;if(c>>>0<=4294967279){a:{if(c>>>0<=10){_e(a,c);e=a;break a}f=Xk(c)+1|0;e=oi(a,f);ef(a,e);rg(a,f);de(a,c)}Qg(e,b,c);t[d+15|0]=0;Bd(c+e|0,d+15|0);gb=d+16|0;return}vg();L()}function rt(a){var b=0;a:{b=w[a+1376|0];b:{if(!b){b=-1;if(v[a+1384>>2]){break b}if(!jy(a)){break b}b=w[a+1376|0];if(!b){break a}}t[a+1376|0]=b-1;v[a+1400>>2]=v[a+1400>>2]+1;b=Ne(a)}return b}aa(12806,10534,1578,2521);L()}function pu(a,b){var c=0,d=0;c=B(b,872)+a|0;a:{if(v[c+1075080>>2]&134218752){break a}if(!tk(c+1074992|0)){break a}b=w[v[(B(b,872)+a|0)+1075648>>2]+34|0];if((b+5&255)>>>0<6){break a}d=v[(B(b,160)+a|0)+906140>>2]}return d}function nU(a,b,c){var d=0;d=gb-16|0;gb=d;t[d+15|0]=a;a=0;if(!(c>>>0<25|b>>>0<25|b>>>0>=c>>>0|b>>>0>=109|c>>>0>=109)){t[d+14|0]=(x[(b<<1)+39070>>1]-x[(c<<1)+39070>>1]|0)/5;a=w[ac(d+15|0,d+14|0)|0]}gb=d+16|0;return a&255}function bT(a){var b=0,c=0,d=0;b=a- -64|0;d=w[b|0]|w[b+1|0]<<8;b=a+70|0;a=a+72|0;c=w[a|0]|w[a+1|0]<<8;a=(w[b|0]|w[b+1|0]<<8)+c|0;b=0;b=a>>>0<c>>>0?1:b;c=a;a=b<<2|a>>>30;c=c<<2;b=d+c|0;a=b>>>0<c>>>0?a+1|0:a;jb=a;return b}function Zg(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0;e=gb-16|0;gb=e;v[e+12>>2]=0;Bh(a+12|0,d);if(b){f=oi(v[a+16>>2],b)}v[a>>2]=f;c=c+f|0;v[a+8>>2]=c;v[a+4>>2]=c;g=dc(a),h=b+f|0,v[g>>2]=h;gb=e+16|0;return a|0}function Nt(a,b){var c=0,d=0;c=gb-32|0;gb=c;a:{if(dg(a)>>>0<b>>>0){d=wb(a);b=Zg(c+8|0,b,oc(a),d);v[22656]=0;R(120,a|0,b|0);a=v[22656];v[22656]=0;if((a|0)==1){break a}be(b)}gb=c+32|0;return}a=P()|0;O()|0;be(b);S(a|0);L()}function Jca(a){a=a|0;var b=0;kb[v[v[a>>2]+128>>2]](a);bz(a);v[a+4236>>2]=0;t[a+4202|0]=1;b=kb[v[v[a>>2]+192>>2]](a)|0;v[a+4328>>2]=0;v[a+4312>>2]=0;z[a+4240>>2]=b?C(.5):C(1);b=v[a+4256>>2];v[a+4324>>2]=b;v[a+4320>>2]=b}function FA(a,b){a=a|0;b=+b;var c=0,d=0,e=0;c=gb-16|0;gb=c;a=v[a+480208>>2];d=c,e=(Tp(b)+-4.8737671609324025)*(a&32768?28.85390081777927:34.624680981335125),A[d+8>>3]=e;WP(c+8|0,127);a=gn(A[c+8>>3]);gb=c+16|0;return a|0}function kW(a){t[a|0]=0;t[a+1|0]=0;t[a+2|0]=0;t[a+3|0]=0;t[a+4|0]=0;t[a+5|0]=0;t[a+6|0]=0;t[a+7|0]=0;t[a+16|0]=0;t[a+17|0]=0;t[a+8|0]=0;t[a+9|0]=0;t[a+10|0]=0;t[a+11|0]=0;t[a+12|0]=0;t[a+13|0]=0;t[a+14|0]=0;t[a+15|0]=0}function X1(){var a=0;a:{b:{if(t[464184]&1){break b}if(!Qd(464184)){break b}v[22656]=0;X(2536);a=v[22656];v[22656]=0;if((a|0)==1){break a}v[116045]=464176;Pd(464184)}return v[116045]}a=P()|0;O()|0;$e(464184);S(a|0);L()}function Uo(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=gb-16|0;gb=d;e=d+8|0;Db(e,c+1074312|0,102);a:{if(!Cb(e)){break a}c=x[a+692>>1]+1|0;u[a+784>>1]=c;if(!(t[a+89|0]&1)){break a}u[a+784>>1]=c|32768}v[a+692>>2]=b;gb=d+16|0}function OV(a){var b=0,c=0;a:{if(sd(a,12219,3)){break a}b=a+4|0;if((w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24))>>>0<423|(w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24))>>>0>2147483646){break a}c=w[a+3|0]<6}return c}function $G(){var a=0;a:{b:{if(t[464172]&1){break b}if(!Qd(464172)){break b}v[22656]=0;X(2535);a=v[22656];v[22656]=0;if((a|0)==1){break a}v[116042]=464164;Pd(464172)}return v[116042]}a=P()|0;O()|0;$e(464172);S(a|0);L()}function rU(a){var b=0,c=0,d=0;b=a+32|0;d=w[b|0]|w[b+1|0]<<8;b=a+34|0;a=a+36|0;c=w[a|0]|w[a+1|0]<<8;a=(w[b|0]|w[b+1|0]<<8)+c|0;b=0;b=a>>>0<c>>>0?1:b;c=a;a=b<<1|a>>>31;c=c<<1;b=d+c|0;a=b>>>0<c>>>0?a+1|0:a;jb=a;return b}function a1(a){a=a|0;a:{b:{if(t[464260]&1){break b}if(!Qd(464260)){break b}v[22656]=0;X(2552);a=v[22656];v[22656]=0;if((a|0)==1){break a}v[116064]=464432;Pd(464260)}return v[116064]}a=P()|0;O()|0;$e(464260);S(a|0);L()}function Y0(a){a=a|0;a:{b:{if(t[464268]&1){break b}if(!Qd(464268)){break b}v[22656]=0;X(2554);a=v[22656];v[22656]=0;if((a|0)==1){break a}v[116066]=464608;Pd(464268)}return v[116066]}a=P()|0;O()|0;$e(464268);S(a|0);L()}function V0(a){a=a|0;a:{b:{if(t[464276]&1){break b}if(!Qd(464276)){break b}v[22656]=0;X(2556);a=v[22656];v[22656]=0;if((a|0)==1){break a}v[116068]=464784;Pd(464276)}return v[116068]}a=P()|0;O()|0;$e(464276);S(a|0);L()}function UR(a,b){a:{if(w[a+76|0]==(b|0)){break a}t[a+76|0]=b;if(b){b=0;if(x[a+24>>1]==15){u[a+20>>1]=0;b=1}v[a+8>>2]=0;v[a+16>>2]=b;return}b:{switch(v[a+16>>2]+1|0){case 0:case 4:break a;default:break b}}v[a+16>>2]=3}}function S0(a){a=a|0;a:{b:{if(t[464284]&1){break b}if(!Qd(464284)){break b}v[22656]=0;X(2558);a=v[22656];v[22656]=0;if((a|0)==1){break a}v[116070]=465088;Pd(464284)}return v[116070]}a=P()|0;O()|0;$e(464284);S(a|0);L()}function P0(a){a=a|0;a:{b:{if(t[464292]&1){break b}if(!Qd(464292)){break b}v[22656]=0;X(2560);a=v[22656];v[22656]=0;if((a|0)==1){break a}v[116072]=465392;Pd(464292)}return v[116072]}a=P()|0;O()|0;$e(464292);S(a|0);L()}function M0(a){a=a|0;a:{b:{if(t[464300]&1){break b}if(!Qd(464300)){break b}v[22656]=0;X(2562);a=v[22656];v[22656]=0;if((a|0)==1){break a}v[116074]=465424;Pd(464300)}return v[116074]}a=P()|0;O()|0;$e(464300);S(a|0);L()}function xk(a){a=a|0;qc(a+16|0,v[a>>2]);qc(a+8|0,v[a>>2]);if(y[a+12>>2]>=y[a+16>>2]){v[a+12>>2]=0;v[a+16>>2]=0;u[a+34>>1]=x[a+34>>1]&65511}if(y[a+4>>2]>=y[a+8>>2]){v[a+4>>2]=0;v[a+8>>2]=0;u[a+34>>1]=x[a+34>>1]&65529}}function s0(a,b){a=a|0;b=b|0;var c=0;c=gb-16|0;gb=c;a:{if(xr(b,7535)){GG(c,14678,b);a=Jb(c);v[22656]=0;R(2807,44,a|0);a=v[22656];v[22656]=0;if((a|0)!=1){break a}a=P()|0;O()|0;vb(c);S(a|0);L()}gb=c+16|0;return a|0}L()}function pha(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=dd(a);e=Jk(a+12|0);t[a+32|0]=c;v[a+28>>2]=0;v[a+24>>2]=b;v[22656]=0;R(1124,a|0,1);b=v[22656];v[22656]=0;if((b|0)!=1){return a|0}a=P()|0;O()|0;sR(e);xR(d);S(a|0);L()}function kqa(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0;e=c>>>16|0;f=a>>>16|0;j=B(e,f);g=c&65535;h=a&65535;i=B(g,h);f=(i>>>16|0)+B(f,g)|0;e=(f&65535)+B(e,h)|0;jb=(B(b,c)+j|0)+B(a,d)+(f>>>16)+(e>>>16)|0;return i&65535|e<<16}function hG(a){var b=0,c=0,d=0;d=v[a>>2];b=v[a+4>>2];a:{while(1){if((b|0)==(d|0)){break a}c=wb(a);v[22656]=0;b=b-36|0;R(214,c|0,b|0);c=v[22656];v[22656]=0;if((c|0)!=1){continue}break}V(0)|0;O()|0;Bb();L()}v[a+4>>2]=d}function fA(a,b,c){var d=0;a:{if(x[a+480192>>1]){if(!ve(b)|x[a+480192>>1]<c>>>0){break a}c=v[((c<<2)+a|0)+900380>>2];if(!c){break a}d=x[vd(c+236|0,b-1|0)>>1];break a}d=c}return(x[a+480190>>1]<(d&65535)>>>0?0:d)&65535}function eT(a){var b=0,c=0,d=0;d=v[a>>2];b=v[a+4>>2];a:{while(1){if((b|0)==(d|0)){break a}c=wb(a);v[22656]=0;b=b-28|0;R(957,c|0,b|0);c=v[22656];v[22656]=0;if((c|0)!=1){continue}break}V(0)|0;O()|0;Bb();L()}v[a+4>>2]=d}function mka(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=gb-32|0;gb=d;e=Te(b);c=kT(d+8|0,c);v[22656]=0;Y(949,a|0,b|0,e-1&65535,c|0);a=v[22656];v[22656]=0;if((a|0)!=1){Ye(c);gb=d+32|0;return}a=P()|0;O()|0;Ye(c);S(a|0);L()}function ky(a){var b=0;a:{b:{while(1){if(v[a+1380>>2]!=-1){break b}b=0;if(!qt(a)){break a}if(!(t[a+1375|0]&1)){continue}break}ec(a,32);return 0}v[a+1396>>2]=0;v[a+1400>>2]=0;v[a+1384>>2]=0;t[a+1376|0]=0;b=1}return b}function Rca(a,b,c){a=a|0;b=b|0;c=C(c);var d=0,e=0,f=0;d=gb-16|0;gb=d;z[d+12>>2]=c;if((b|0)<=2){v[d+8>>2]=0;v[d+4>>2]=1065353216;e=(a+b|0)+4232|0,f=ch(C(z[zf(d+12|0,d+8|0,d+4|0)>>2]*C(127))),t[e|0]=f;Mt(a)}gb=d+16|0}function LT(a){a=+a;a=a*4294967296;if(D(a)<0x8000000000000000){jb=D(a)>=1?~~(a>0?F(H(a*2.3283064365386963e-10),4294967295):I((a-+(~~a>>>0>>>0))*2.3283064365386963e-10))>>>0:0;return~~a>>>0|0}jb=-2147483648;return 0}function LL(a,b){a=a|0;b=b|0;var c=0,d=0;c=gb-16|0;gb=c;d=sf(12);b=v[b>>2];a=v[a>>2];v[22656]=0;a=KL(d,a,b);b=v[22656];v[22656]=0;if((b|0)!=1){a=v[Wi(c+8|0,a)>>2];gb=c+16|0;return a|0}a=P()|0;O()|0;Yb(d);S(a|0);L()}function bo(a,b){var c=0,d=0,e=0;c=a*a;d=c*a;e=d*(c*.13339200271297674+.3333313950307914)+a;a=c*c;a=e+d*a*(c*.024528318116654728+.05338123784456704+a*(c*.009465647849436732+.002974357433599673));return C(b?-1/a:a)}function Rna(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=gb-32|0;gb=d;v[d+24>>2]=c;v[d+16>>2]=b;if(Gb(d+16|0,d+24|0)){while(1){b=d+16|0;v[d+12>>2]=v[v[b>>2]>>2];fD(a,d+12|0);Qe(b);if(Gb(b,d+24|0)){continue}break}}gb=d+32|0}function PX(a){var b=0,c=0,d=0;b=v[a>>2];c=lD(a);d=gb-16|0;gb=d;a:{if((b|0)==(c|0)){break a}a=b+4|0;if((c|0)==(a|0)){break a}while(1){b=zn(a,b)?a:b;a=a+4|0;if((c|0)!=(a|0)){continue}break}}gb=d+16|0;return v[b>>2]}function Mba(a,b,c){a=a|0;b=b|0;c=C(c);var d=0;d=gb-16|0;gb=d;z[d+12>>2]=c;if((b|0)<=12){Hi(d+12|0);c=z[d+12>>2];if((b|0)==12){c=C(fe(C(c*C(3)))/C(3));z[d+12>>2]=c}z[((b<<2)+a|0)+4208>>2]=c;t[a+5046|0]=1}gb=d+16|0}function M7(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;if(v[b+4>>2]){a=0;while(1){c=0;if(v[b+8>>2]){while(1){d=ir(b,a,c),e=0,v[d>>2]=e;c=c+1|0;if(c>>>0<y[b+8>>2]){continue}break}}a=a+1|0;if(a>>>0<y[b+4>>2]){continue}break}}}function Aoa(a,b){a=a|0;b=b|0;var c=0,d=0;c=gb-32|0;gb=c;d=Pb(a,12);a:{if(!d){t[c+16|0]=0;ni(b,12,c+16|0);break a}OW(c+24|0,b);b=v[c+28>>2];v[c+8>>2]=v[c+24>>2];v[c+12>>2]=b;kd(c+16|0,a,c+8|0)}gb=c+32|0;return d|0}function z0(a){a=a|0;a:{b:{if(t[464396]&1){break b}if(!Qd(464396)){break b}v[22656]=0;Q(2565,464384,81580)|0;a=v[22656];v[22656]=0;if((a|0)==1){break a}Pd(464396)}return 464384}a=P()|0;O()|0;$e(464396);S(a|0);L()}function yG(a,b){var c=0,d=0,e=0;d=gb-16|0;gb=d;c=Np(d,a,1);a=wb(a);e=v[c+4>>2];v[22656]=0;Pn(a,e,b);a=v[22656];v[22656]=0;if((a|0)!=1){v[c+4>>2]=v[c+4>>2]+12;$b(c);gb=d+16|0;return}a=P()|0;O()|0;$b(c);S(a|0);L()}function v0(a){a=a|0;a:{b:{if(t[464428]&1){break b}if(!Qd(464428)){break b}v[22656]=0;Q(2565,464416,81664)|0;a=v[22656];v[22656]=0;if((a|0)==1){break a}Pd(464428)}return 464416}a=P()|0;O()|0;$e(464428);S(a|0);L()}function kI(a,b){a=a|0;b=b|0;var c=0,d=0;c=v[a>>2];a:{if(!c){break a}d=v[c+24>>2];b:{if((d|0)==v[c+28>>2]){b=kb[v[v[c>>2]+52>>2]](c,b)|0;break b}v[c+24>>2]=d+4;v[d>>2]=b}if(!Ie(b,-1)){break a}v[a>>2]=0}return a|0}function cw(a,b,c){var d=0;a=a+3|0;a=(w[a|0]|w[a+1|0]<<8)>>>B(c,3)|0;d=a>>>2&1|w[b+12|0]&-8;t[b+12|0]=d|a<<1&6;if(!(!(a>>>9-(c<<1)&1)|(a&3)!=1)){a=w[b+13|0]|w[b+14|0]<<8;t[b+15|0]=a;t[b+16|0]=a>>>8;t[b+12|0]=d|4}}function YQ(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=gb-16|0;gb=d;a=Fn(d,a+8|0,$q(b,c));if(v[a>>2]!=v[a+4>>2]){while(1){To(v[a>>2],b);c=v[a>>2]+2|0;v[a>>2]=c;b=b+2|0;if(v[a+4>>2]!=(c|0)){continue}break}}_c(a);gb=d+16|0}function PP(a,b,c){var d=0,e=0;d=gb-16|0;gb=d;e=c&15;if(e){t[b+824|0]=e}c=c&240;if(c){t[b+823|0]=c>>>4}v[b+88>>2]=v[b+88>>2]|131072;c=d+8|0;Db(c,a+1074312|0,80);if(!(!Cb(c)|!e)){t[b+824|0]=w[b+824|0]<<2}gb=d+16|0}function H0(a){a=a|0;a:{b:{if(t[464332]&1){break b}if(!Qd(464332)){break b}v[22656]=0;Q(2565,464320,81508)|0;a=v[22656];v[22656]=0;if((a|0)==1){break a}Pd(464332)}return 464320}a=P()|0;O()|0;$e(464332);S(a|0);L()}function FR(a,b){var c=0,d=0,e=0,f=0;e=A[a+48>>3];c=A[a+40>>3];A[a+48>>3]=c;f=A[a+64>>3];d=A[a+56>>3];A[a+64>>3]=d;A[a+40>>3]=b;b=A[a>>3]*b+c*A[a+8>>3]+e*A[a+16>>3]-d*A[a+24>>3]-f*A[a+32>>3];A[a+56>>3]=b;return b}function D0(a){a=a|0;a:{b:{if(t[464364]&1){break b}if(!Qd(464364)){break b}v[22656]=0;Q(2565,464352,81544)|0;a=v[22656];v[22656]=0;if((a|0)==1){break a}Pd(464364)}return 464352}a=P()|0;O()|0;$e(464364);S(a|0);L()}function qW(a,b){var c=0,d=0,e=0;d=gb-16|0;gb=d;c=Fg(d,a,1);a=wb(a);e=v[c+4>>2];v[22656]=0;hn(a,e,b);a=v[22656];v[22656]=0;if((a|0)!=1){v[c+4>>2]=v[c+4>>2]+4;$b(c);gb=d+16|0;return}a=P()|0;O()|0;$b(c);S(a|0);L()}function oM(a,b){var c=0,d=0,e=0;d=gb-16|0;gb=d;c=Ai(d,a,1);a=wb(a);e=v[c+4>>2];v[22656]=0;rl(a,e,b);a=v[22656];v[22656]=0;if((a|0)!=1){v[c+4>>2]=v[c+4>>2]+1;$b(c);gb=d+16|0;return}a=P()|0;O()|0;$b(c);S(a|0);L()}function lqa(a,b,c,d){var e=0,f=0,g=0;f=(b^d)>>31;e=b>>31;a=a^e;g=a-e|0;a=(b^e)-((a>>>0<e>>>0)+e|0)|0;e=d>>31;b=c^e;a=nqa(g,a,b-e|0,(e^d)-((e>>>0>b>>>0)+e|0)|0)^f;b=a-f|0;jb=(f^jb)-((a>>>0<f>>>0)+f|0)|0;return b}function UC(a,b){var c=0,d=0,e=0,f=0;c=a<<8&16711680|a<<24;d=b<<24|a>>>8;e=d&65280;d=b<<8|a>>>24;c=d&255|e|c;a=((b&255)<<24|a>>>8)&-16777216|((b&16777215)<<8|a>>>24)&16711680|(b>>>8&65280|b>>>24)|f;jb=c;return a}function $z(a,b){var c=0;c=v[b+24>>2];c=c?c:1;v[a+24628>>2]=c>>>0<512?c:512;a:{if(!(v[b+16>>2]!=v[a+24620>>2]|v[b+20>>2]!=v[a+24624>>2])){c=0;if(v[b+12>>2]==v[a+24616>>2]){break a}}c=1}hc(a+24604|0,b,40);tO(a,c)}function uk(a){var b=0,c=0,d=0,e=0;b=gb-16|0;gb=b;c=v[a+24>>2];d=v[a+40>>2];v[22656]=0;v[b+12>>2]=1;a=Lc(a+20|0,b+12|0);e=v[22656];v[22656]=0;if((e|0)!=1){gb=b+16|0;return B(v[a>>2],c+d|0)}V(0)|0;O()|0;Bb();L()}function _z(a,b){var c=0,d=0;c=v[b+4>>2];v[a+24648>>2]=v[b>>2];v[a+24652>>2]=c;d=v[b+20>>2];c=a+24664|0;v[c>>2]=v[b+16>>2];v[c+4>>2]=d;d=v[b+12>>2];c=a+24656|0;v[c>>2]=v[b+8>>2];v[c+4>>2]=d;sO(a+24648|0);LO(a)}
function Iw(a,b){var c=0,d=0;c=gb-32|0;gb=c;a:{if(!Pb(b,3)){t[c+16|0]=0;ni(a,3,c+16|0);break a}d=gb-16|0;gb=d;bc(c+24|0,a,3);gb=d+16|0;a=v[c+28>>2];v[c+8>>2]=v[c+24>>2];v[c+12>>2]=a;kd(c+16|0,b,c+8|0)}gb=c+32|0}function I2(){var a=0;a=gb-16|0;gb=a;v[116444]=0;v[116445]=0;v[a+12>>2]=0;Zo(465784);t[465912]=0;gb=a+16|0;v[22656]=0;X(2531);a=v[22656];v[22656]=0;if((a|0)!=1){aH(30);return}a=P()|0;O()|0;wx(465776);S(a|0);L()}function F0(a){a=a|0;a:{b:{if(t[464348]&1){break b}if(!Qd(464348)){break b}v[22656]=0;Q(70,464336,11031)|0;a=v[22656];v[22656]=0;if((a|0)==1){break a}Pd(464348)}return 464336}a=P()|0;O()|0;$e(464348);S(a|0);L()}function B0(a){a=a|0;a:{b:{if(t[464380]&1){break b}if(!Qd(464380)){break b}v[22656]=0;Q(70,464368,10825)|0;a=v[22656];v[22656]=0;if((a|0)==1){break a}Pd(464380)}return 464368}a=P()|0;O()|0;$e(464380);S(a|0);L()}function x0(a){a=a|0;a:{b:{if(t[464412]&1){break b}if(!Qd(464412)){break b}v[22656]=0;Q(70,464400,6410)|0;a=v[22656];v[22656]=0;if((a|0)==1){break a}Pd(464412)}return 464400}a=P()|0;O()|0;$e(464412);S(a|0);L()}function sda(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=gb-16|0;gb=c;a=pk(a);if(a){d=v[b+4>>2];b=v[b>>2];v[c+8>>2]=b;v[c+12>>2]=d;e=v[v[a>>2]+72>>2];v[c>>2]=b;v[c+4>>2]=d;a=kb[e|0](a,c)|0}else{a=1}gb=c+16|0;return a|0}function J0(a){a=a|0;a:{b:{if(t[464316]&1){break b}if(!Qd(464316)){break b}v[22656]=0;Q(70,464304,2361)|0;a=v[22656];v[22656]=0;if((a|0)==1){break a}Pd(464316)}return 464304}a=P()|0;O()|0;$e(464316);S(a|0);L()}function mo(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=gb-16|0;gb=d;a:{if(c){Tb(d,c);break a}Kb(d)}v[22656]=0;U(13,a|0,b|0,d|0);a=v[22656];v[22656]=0;if((a|0)!=1){vb(d);gb=d+16|0;return}a=P()|0;O()|0;vb(d);S(a|0);L()}function ix(a,b,c){var d=0;d=v[a+16>>2];if(!d){v[a+36>>2]=1;v[a+24>>2]=c;v[a+16>>2]=b;return}a:{if((b|0)==(d|0)){if(v[a+24>>2]!=2){break a}v[a+24>>2]=c;return}t[a+54|0]=1;v[a+24>>2]=2;v[a+36>>2]=v[a+36>>2]+1}}function GU(a){var b=0,c=0,d=0;c=a;b=v[a+8>>2];d=v[a+4>>2];if((b|0)!=(d|0)){while(1){b=b-56|0;v[c+8>>2]=b;dv(b);b=v[c+8>>2];if((d|0)!=(b|0)){continue}break}}c=v[a>>2];if(c){av(c,(v[dc(a)>>2]-v[a>>2]|0)/56|0)}}function xd(a,b){var c=0,d=0;c=gb-16|0;gb=c;a:{if(b>>>0<2){b:{if(!b){break b}if(!Pb(a,1)){break b}t[c+15|0]=0;Ng(a,c+15|0);t[c+8|0]=w[c+15|0];d=w[c+8|0]}gb=c+16|0;break a}aa(8513,6236,136,11437);L()}return d}function wg(a){var b=0;v[22656]=0;a=T(1290,a|0)|0;b=v[22656];v[22656]=0;a:{if((b|0)==1){a=V(0)|0;O()|0;Z(a|0)|0;v[22656]=0;X(20);b=v[22656];v[22656]=0;a=0;if((b|0)==1){break a}}return a}V(0)|0;O()|0;Bb();L()}function k8(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=gb-16|0;gb=e;d=Np(e,a,d);wb(a);v[22656]=0;U(2089,b|0,c|0,d+4|0);a=v[22656];v[22656]=0;if((a|0)!=1){$b(d);gb=e+16|0;return}a=P()|0;O()|0;$b(d);S(a|0);L()}function UE(a,b){var c=0,d=0;c=gb-16|0;gb=c;a:{if(b>>>0<2){b:{if(!b){break b}if(!Pb(a,1)){break b}t[c+15|0]=0;Ng(a,c+15|0);t[c+8|0]=w[c+15|0];d=t[c+8|0]}gb=c+16|0;break a}aa(8513,6236,136,11437);L()}return d}function DR(a){a=a|0;var b=0,c=0,d=0;c=gb-16|0;gb=c;b=gs(c,a,2048);a=v[b+4>>2];d=v[b+8>>2];if((a|0)!=(d|0)){while(1){v[a>>2]=0;v[a+4>>2]=0;a=a+8|0;v[b+4>>2]=a;if((a|0)!=(d|0)){continue}break}}$b(b);gb=c+16|0}function D6(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;e=gb-16|0;gb=e;g=v[v[b>>2]+20>>2];f=v[c+12>>2];v[e+8>>2]=v[c+8>>2];v[e+12>>2]=f;f=v[c+4>>2];v[e>>2]=v[c>>2];v[e+4>>2]=f;kb[g|0](a,b,e,d);gb=e+16|0}function nt(a){var b=0;if(a){if(v[a+76>>2]<0){return gy(a)}return gy(a)}if(v[22650]){b=nt(v[22650])}a=v[115134];if(a){while(1){if(y[a+20>>2]>y[a+28>>2]){b=gy(a)|b}a=v[a+56>>2];if(a){continue}break}}return b}function iS(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=gb-16|0;gb=e;v[e>>2]=c;v[e+8>>2]=b;if(Gb(e+8|0,e)){while(1){b=e+8|0;xn(a,v[d>>2],v[b>>2]);of(b);v[d>>2]=v[d>>2]+2;if(Gb(b,e)){continue}break}}gb=e+16|0}function iC(a,b,c){var d=0;d=gb-16|0;gb=d;v[d>>2]=b;v[d+8>>2]=a;a:{if(!Gb(d+8|0,d)){break a}while(1){if(x[v[d+8>>2]>>1]==x[c>>1]){break a}a=d+8|0;of(a);if(Gb(a,d)){continue}break}}gb=d+16|0;return v[d+8>>2]}function eP(a,b){var c=0;c=v[b+4>>2];v[a>>2]=v[b>>2];v[a+4>>2]=c;c=v[b+28>>2];v[a+24>>2]=v[b+24>>2];v[a+28>>2]=c;c=v[b+20>>2];v[a+16>>2]=v[b+16>>2];v[a+20>>2]=c;c=v[b+12>>2];v[a+8>>2]=v[b+8>>2];v[a+12>>2]=c}function Zv(a){t[a|0]=0;t[a+1|0]=0;t[a+2|0]=0;t[a+3|0]=0;t[a+4|0]=0;t[a+5|0]=0;t[a+6|0]=0;t[a+7|0]=0;t[a+16|0]=0;t[a+8|0]=0;t[a+9|0]=0;t[a+10|0]=0;t[a+11|0]=0;t[a+12|0]=0;t[a+13|0]=0;t[a+14|0]=0;t[a+15|0]=0}function LO(a){var b=0,c=0;b=gb-544|0;gb=b;if(!(!(w[a+480210|0]&128)|!v[a+24668>>2])){ER(b,wf(a));c=a+1298224|0;a=a+1074992|0;while(1){hc(a+112|0,b,538);a=a+872|0;if((c|0)!=(a|0)){continue}break}}gb=b+544|0}function $x(a){a=a|0;var b=0;v[a>>2]=74376;v[22656]=0;R(2293,a|0,0);b=v[22656];v[22656]=0;if((b|0)!=1){Wb(a+28|0);Yb(v[a+32>>2]);Yb(v[a+36>>2]);Yb(v[a+48>>2]);Yb(v[a+60>>2]);return a|0}V(0)|0;O()|0;Bb();L()}function us(a,b,c,d){var e=0,f=0,g=0,h=0;e=gb-16|0;gb=e;v[e+12>>2]=0;Bh(a+12|0,d);if(b){f=mG(v[a+16>>2],b)}v[a>>2]=f;c=B(c,12)+f|0;v[a+8>>2]=c;v[a+4>>2]=c;g=dc(a),h=B(b,12)+f|0,v[g>>2]=h;gb=e+16|0;return a}function lR(a,b){var c=0,d=0;c=v[a+4>>2];a:{while(1){if((b|0)==(c|0)){break a}d=wb(a);v[22656]=0;c=c-12|0;R(1133,d|0,c|0);d=v[22656];v[22656]=0;if((d|0)!=1){continue}break}V(0)|0;O()|0;Bb();L()}v[a+4>>2]=b}function lH(a,b,c,d,e,f){var g=0,h=0,i=0;g=gb-16|0;gb=g;t[g+15|0]=0;t[g+14|0]=f;t[g+13|0]=e;t[g+12|0]=37;if(f){fi(g+13|0,g+14|0)}h=c,i=(bb(b|0,oS(b,v[c>>2])|0,g+12|0,d|0,v[a>>2])|0)+b|0,v[h>>2]=i;gb=g+16|0}function iD(a,b,c,d){var e=0,f=0,g=0,h=0;e=gb-16|0;gb=e;v[e+12>>2]=0;Bh(a+12|0,d);if(b){f=kE(v[a+16>>2],b)}v[a>>2]=f;c=B(c,20)+f|0;v[a+8>>2]=c;v[a+4>>2]=c;g=dc(a),h=B(b,20)+f|0,v[g>>2]=h;gb=e+16|0;return a}function fS(a,b){var c=0,d=0;c=v[a+4>>2];a:{while(1){if((b|0)==(c|0)){break a}d=wb(a);v[22656]=0;c=c-32|0;R(1103,d|0,c|0);d=v[22656];v[22656]=0;if((d|0)!=1){continue}break}V(0)|0;O()|0;Bb();L()}v[a+4>>2]=b}function Nv(a,b){a=a|0;b=b|0;var c=0;c=gb-16|0;gb=c;v[c+12>>2]=1;v[c+8>>2]=a>>>4;b=Lb(128/(B(v[Gf(c+12|0,c+8|0)>>2],b)|0)|0,1,15);t[c+7|0]=1;t[c+6|0]=a&15;a=w[df(c+7|0,c+6|0)|0];gb=c+16|0;return a|b<<4&240}function BO(a,b){var c=0,d=0;c=v[a+4>>2];a:{while(1){if((b|0)==(c|0)){break a}d=wb(a);v[22656]=0;c=c-52|0;R(1325,d|0,c|0);d=v[22656];v[22656]=0;if((d|0)!=1){continue}break}V(0)|0;O()|0;Bb();L()}v[a+4>>2]=b}function sfa(a,b){a=a|0;b=b|0;var c=0,d=0;if(v[a+4>>2]!=v[wb(a)>>2]){dO(a,b);return}d=gb-32|0;gb=d;c=wb(a);c=xo(d+8|0,lr(a,Nb(a)+1|0),Nb(a),c);xq(v[c+8>>2],b);v[c+8>>2]=v[c+8>>2]+4;UN(a,c);Kz(c);gb=d+32|0}function qu(a,b){a=hc(a,b,88);v[a+88>>2]=v[b+88>>2];hc(a+92|0,b+92|0,576);v[a+668>>2]=v[b+668>>2];hc(a+672|0,b+672|0,52);zo(a+724|0,b+724|0);zo(a+732|0,b+732|0);zo(a+740|0,b+740|0);hc(a+748|0,b+748|0,123)}function hE(a,b){var c=0,d=0;c=v[a+4>>2];a:{while(1){if((b|0)==(c|0)){break a}d=wb(a);v[22656]=0;c=c-20|0;R(348,d|0,c|0);d=v[22656];v[22656]=0;if((d|0)!=1){continue}break}V(0)|0;O()|0;Bb();L()}v[a+4>>2]=b}function fla(a,b){a=a|0;b=b|0;var c=0;c=gb-32|0;gb=c;ZU(c+24|0,a);Eg(c+16|0,b);a=v[c+28>>2];v[c+8>>2]=v[c+24>>2];v[c+12>>2]=a;a=v[c+20>>2];v[c>>2]=v[c+16>>2];v[c+4>>2]=a;a=Gc(c+8|0,c);gb=c+32|0;return a|0}function eB(a){var b=0,c=0,d=0;b=x[a+20>>1];u[a+28>>1]=x[a+22>>1]<<1|(w[v[a+16>>2]+3842|0]?b>>>9|0:b>>>8&1);b=0;while(1){c=(b<<2)+a|0;d=v[c>>2];if(d){No(d);VR(v[c>>2])}b=b+1|0;if((b|0)!=4){continue}break}}function S1(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;if((b|0)!=(c|0)){while(1){a=d;if(y[b>>2]<=127){e=x[Zp()+(v[b>>2]<<1)>>1]}else{e=0}u[a>>1]=e;d=d+2|0;b=b+4|0;if((c|0)!=(b|0)){continue}break}}return c|0}function Dfa(a,b){a=a|0;b=b|0;var c=0,d=0;if(v[a+4>>2]!=v[wb(a)>>2]){dO(a,b);return}d=gb-32|0;gb=d;c=wb(a);c=xo(d+8|0,lr(a,Nb(a)+1|0),Nb(a),c);xq(v[c+8>>2],b);v[c+8>>2]=v[c+8>>2]+4;WS(a,c);Kz(c);gb=d+32|0}function cg(a,b,c,d,e){var f=0;f=gb-256|0;gb=f;if(!(e&73728|(c|0)<=(d|0))){c=c-d|0;d=c>>>0<256;Qb(f,b&255,d?c:256);if(!d){while(1){tf(a,f,256);c=c-256|0;if(c>>>0>255){continue}break}}tf(a,f,c)}gb=f+256|0}function Rba(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0;f=gb-16|0;gb=f;b=Ac(lqa(kqa(d,d>>31,b,0),jb,1e3,0),jb);v[a+16>>2]=0;v[a+12>>2]=b+c;fM(a,e);b=v[a+12>>2];v[f+12>>2]=0;mN(a,b,f+12|0);gb=f+16|0}function NS(a,b){a=a|0;b=b|0;var c=0;c=gb-32|0;gb=c;Eg(c+24|0,a);Eg(c+16|0,b);a=v[c+28>>2];v[c+8>>2]=v[c+24>>2];v[c+12>>2]=a;a=v[c+20>>2];v[c>>2]=v[c+16>>2];v[c+4>>2]=a;a=OS(c+8|0,c);gb=c+32|0;return a|0}function KW(a,b,c,d){var e=0,f=0,g=0,h=0;e=gb-16|0;gb=e;v[e+12>>2]=0;Bh(a+12|0,d);if(b){f=LW(v[a+16>>2],b)}v[a>>2]=f;c=B(c,6)+f|0;v[a+8>>2]=c;v[a+4>>2]=c;g=dc(a),h=B(b,6)+f|0,v[g>>2]=h;gb=e+16|0;return a}function Gn(a,b,c,d){var e=0,f=0,g=0,h=0;e=gb-16|0;gb=e;v[e+12>>2]=0;Bh(a+12|0,d);if(b){f=iF(v[a+16>>2],b)}v[a>>2]=f;c=(c<<1)+f|0;v[a+8>>2]=c;v[a+4>>2]=c;g=dc(a),h=(b<<1)+f|0,v[g>>2]=h;gb=e+16|0;return a}function Ap(a,b,c,d){var e=0,f=0,g=0,h=0;e=gb-16|0;gb=e;v[e+12>>2]=0;Bh(a+12|0,d);if(b){f=XE(v[a+16>>2],b)}v[a>>2]=f;c=(c<<2)+f|0;v[a+8>>2]=c;v[a+4>>2]=c;g=dc(a),h=(b<<2)+f|0,v[g>>2]=h;gb=e+16|0;return a}function xK(a,b){a=a|0;b=b|0;var c=0,d=0;c=gb-16|0;gb=c;b=Fg(c,a,b);a=v[b+4>>2];d=v[b+8>>2];if((a|0)!=(d|0)){while(1){v[a>>2]=0;Ui(a);a=a+4|0;v[b+4>>2]=a;if((a|0)!=(d|0)){continue}break}}$b(b);gb=c+16|0}function oC(a){var b=0,c=0;b=gb-16|0;gb=b;wb(a);v[b+12>>2]=1073741823;v[22656]=0;v[b+8>>2]=2147483647;a=Fb(b+12|0,b+8|0);c=v[22656];v[22656]=0;if((c|0)!=1){gb=b+16|0;return v[a>>2]}V(0)|0;O()|0;Bb();L()}function lP(a,b){var c=0;c=gb-16|0;gb=c;v[c+8>>2]=a;v[c+12>>2]=b;v[22656]=0;v[c>>2]=2147483647;v[c+4>>2]=0;a=Uk(c+8|0,c);b=v[22656];v[22656]=0;if((b|0)!=1){gb=c+16|0;return v[a>>2]}V(0)|0;O()|0;Bb();L()}function jF(a){var b=0,c=0;b=gb-16|0;gb=b;wb(a);v[b+12>>2]=2147483647;v[22656]=0;v[b+8>>2]=2147483647;a=Fb(b+12|0,b+8|0);c=v[22656];v[22656]=0;if((c|0)!=1){gb=b+16|0;return v[a>>2]}V(0)|0;O()|0;Bb();L()}function FN(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=gb-16|0;gb=d;c=Br(d,a,b);b=v[c+4>>2];e=v[c+8>>2];if((b|0)!=(e|0)){while(1){wb(a);gi(b);b=b+6|0;v[c+4>>2]=b;if((b|0)!=(e|0)){continue}break}}$b(c);gb=d+16|0}function BN(a){var b=0,c=0,d=0;if(Sf(a)){while(1){b=a;d=c&65535;if(Sf(b)>>>0>d>>>0){b=bf(b,d);v[b+20>>2]=0;v[b+12>>2]=0;v[b+16>>2]=0;JN(b);Se(b+36|0)}c=c+1|0;if(Sf(a)>>>0>(c&65535)>>>0){continue}break}}}function $d(a,b){var c=0,d=0,e=0;b=b+7&-8;v[a+8>>2]=b+v[a+8>>2];d=v[a+80>>2];a:{if(d){c=b;b=v[a+88>>2];e=c+b|0;c=0;if((e|0)>v[a+92>>2]){break a}v[a+88>>2]=e;return b+d|0}if(!b){return 0}c=Cd(b)}return c}function $S(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=gb-16|0;gb=d;c=Fg(d,a,b);b=v[c+4>>2];e=v[c+8>>2];if((b|0)!=(e|0)){while(1){wb(a);Zo(b);b=b+4|0;v[c+4>>2]=b;if((b|0)!=(e|0)){continue}break}}$b(c);gb=d+16|0}function nG(a){var b=0,c=0;b=gb-16|0;gb=b;wb(a);v[b+12>>2]=357913941;v[22656]=0;v[b+8>>2]=2147483647;a=Fb(b+12|0,b+8|0);c=v[22656];v[22656]=0;if((c|0)!=1){gb=b+16|0;return v[a>>2]}V(0)|0;O()|0;Bb();L()}function lE(a){var b=0,c=0;b=gb-16|0;gb=b;wb(a);v[b+12>>2]=214748364;v[22656]=0;v[b+8>>2]=2147483647;a=Fb(b+12|0,b+8|0);c=v[22656];v[22656]=0;if((c|0)!=1){gb=b+16|0;return v[a>>2]}V(0)|0;O()|0;Bb();L()}function d9(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=gb-16|0;gb=e;a=cq(e,a,d);v[22656]=0;U(2045,b|0,c|0,a+4|0);b=v[22656];v[22656]=0;if((b|0)!=1){$b(a);gb=e+16|0;return}b=P()|0;O()|0;$b(a);S(b|0);L()}function Q1(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;a:{if((c|0)==(d|0)){break a}while(1){if(y[c>>2]>127){break a}if(!(x[Zp()+(v[c>>2]<<1)>>1]&b)){break a}c=c+4|0;if((d|0)!=(c|0)){continue}break}c=d}return c|0}function MW(a){var b=0,c=0;b=gb-16|0;gb=b;wb(a);v[b+12>>2]=715827882;v[22656]=0;v[b+8>>2]=2147483647;a=Fb(b+12|0,b+8|0);c=v[22656];v[22656]=0;if((c|0)!=1){gb=b+16|0;return v[a>>2]}V(0)|0;O()|0;Bb();L()}function vX(a){var b=0,c=0;b=a+36|0;c=kqa(w[b|0]|w[b+1|0]<<8,0,384,0);a=a+34|0;b=w[a|0]|w[a+1|0]<<8;a=b>>>30|0;b=b<<2;c=c+b|0;a=a+jb|0;a=b>>>0>c>>>0?a+1|0:a;b=c+256|0;a=b>>>0<256?a+1|0:a;jb=a;return b}function u1(a){a=a|0;var b=0,c=0,d=0;b=gb-16|0;gb=b;v[b+12>>2]=a;a=vi(b+8|0,b+12|0);v[22656]=0;c=GH(0,0,4);d=v[22656];v[22656]=0;if((d|0)!=1){hf(a);gb=b+16|0;return c|0}b=P()|0;O()|0;hf(a);S(b|0);L()}function ot(a,b,c){var d=0,e=0;d=gb-32|0;gb=d;e=v[c+4>>2];c=v[c>>2];v[d+8>>2]=c;v[d+12>>2]=e;v[d+16>>2]=c;v[d+20>>2]=e;rh(d+24|0,d+8|0);c=v[d+28>>2];v[d>>2]=v[d+24>>2];v[d+4>>2]=c;sy(a,b,d);gb=d+32|0}function np(){var a=0,b=0,c=0;a=gb-16|0;gb=a;v[a+12>>2]=1073741823;v[22656]=0;v[a+8>>2]=2147483647;b=Fb(a+12|0,a+8|0);c=v[22656];v[22656]=0;if((c|0)!=1){gb=a+16|0;return v[b>>2]}V(0)|0;O()|0;Bb();L()}function jka(a,b){a=a|0;b=b|0;var c=0,d=0;c=gb-16|0;gb=c;d=WE(a);if(d>>>0>=b>>>0){a=Pu(a);if(a>>>0<d>>>1>>>0){v[c+12>>2]=a<<1;v[c+8>>2]=b+31&-32;d=v[Lc(c+12|0,c+8|0)>>2]}gb=c+16|0;return d|0}Sc();L()}function TU(a){var b=0,c=0,d=0,e=0;jb=0;d=w[a+4|0];e=w[a+92|0];c=w[a+93|0];b=a+94|0;b=c+(w[b|0]|w[b+1|0]<<8)|0;a=0;a=b>>>0<c>>>0?1:a;c=b;b=e+b|0;a=b>>>0<c>>>0?a+1|0:a;c=b<<2;b=d+c|0;b=b-96|0;return b}function Ooa(a){a=a|0;var b=0,c=0,d=0;b=gb-16|0;gb=b;c=sf(2500);v[22656]=0;a=Q(48,c|0,a|0)|0;d=v[22656];v[22656]=0;if((d|0)!=1){a=v[Wi(b+8|0,a)>>2];gb=b+16|0;return a|0}a=P()|0;O()|0;Yb(c);S(a|0);L()}function $8(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=gb-16|0;gb=d;a=v[a+24>>2];CL(d,c);v[22656]=0;U(560,a|0,b|0,d|0);a=v[22656];v[22656]=0;if((a|0)!=1){vb(d);gb=d+16|0;return}a=P()|0;O()|0;vb(d);S(a|0);L()}function zT(){var a=0,b=0,c=0;a=gb-16|0;gb=a;v[a+12>>2]=134217727;v[22656]=0;v[a+8>>2]=2147483647;b=Fb(a+12|0,a+8|0);c=v[22656];v[22656]=0;if((c|0)!=1){gb=a+16|0;return v[b>>2]}V(0)|0;O()|0;Bb();L()}function sU(a){var b=0,c=0;a:{if((w[a+44|0]|w[a+45|0]<<8|(w[a+46|0]<<16|w[a+47|0]<<24))!=1297236819|w[a+29|0]!=16){break a}a=a+42|0;b=w[a+1|0]<<8;if((w[a|0]|b)!=1&(b|w[a|0])!=2){break a}c=1}return c}function eR(a){var b=0,c=0,d=0;c=v[a>>2];b=v[a+4>>2];a:{while(1){if((b|0)==(c|0)){break a}wb(a);v[22656]=0;b=b-8|0;d=v[22656];v[22656]=0;if((d|0)!=1){continue}break}V(0)|0;O()|0;Bb();L()}v[a+4>>2]=c}function cN(a){var b=0,c=0;b=v[a>>2];v[a>>2]=0;if(b){a:{b:{a=fc(a);if(w[a+4|0]){v[22656]=0;c=v[22656];v[22656]=0;if((c|0)==1){break b}Gk(b+16|0)}if(b){Yk(v[a>>2],b,1)}break a}V(0)|0;O()|0;Bb();L()}}}function TL(a){var b=0,c=0,d=C(0);if(!a){return C(1)}if((a|0)>=-99999){b=+(a|0)*3.321928094887362/2e3;c=b+.5;a:{if(D(c)<2147483648){a=~~c;break a}a=-2147483648}d=C(Ek(b-+(a|0)))}else{d=C(0)}return d}function SA(a){var b=0,c=0;b=v[a>>2];v[a>>2]=0;if(b){a:{b:{a=fc(a);if(w[a+4|0]){v[22656]=0;c=v[22656];v[22656]=0;if((c|0)==1){break b}jR(b+16|0)}if(b){ls(v[a>>2],b,1)}break a}V(0)|0;O()|0;Bb();L()}}}function MO(a){var b=0,c=0;c=a+946300|0;a=a+906300|0;while(1){b=v[a>>2];a:{if(!b){break a}if(!(kb[v[v[b>>2]+116>>2]](b)|0)){break a}kb[v[v[b>>2]+96>>2]](b)}a=a+160|0;if((c|0)!=(a|0)){continue}break}}function Lw(){var a=0,b=0,c=0;a=gb-16|0;gb=a;v[a+12>>2]=536870911;v[22656]=0;v[a+8>>2]=2147483647;b=Fb(a+12|0,a+8|0);c=v[22656];v[22656]=0;if((c|0)!=1){gb=a+16|0;return v[b>>2]}V(0)|0;O()|0;Bb();L()}function FI(){var a=0,b=0,c=0;a=gb-16|0;gb=a;v[a+12>>2]=268435455;v[22656]=0;v[a+8>>2]=2147483647;b=Fb(a+12|0,a+8|0);c=v[22656];v[22656]=0;if((c|0)!=1){gb=a+16|0;return v[b>>2]}V(0)|0;O()|0;Bb();L()}function EV(){var a=0,b=0,c=0;a=gb-16|0;gb=a;v[a+12>>2]=178956970;v[22656]=0;v[a+8>>2]=2147483647;b=Fb(a+12|0,a+8|0);c=v[22656];v[22656]=0;if((c|0)!=1){gb=a+16|0;return v[b>>2]}V(0)|0;O()|0;Bb();L()}function wi(a,b,c){var d=0,e=0,f=0,g=0;v[a+112>>2]=b;v[a+116>>2]=c;d=v[a+8>>2];g=v[a+4>>2];e=d-g|0;f=e>>31;v[a+120>>2]=e;v[a+124>>2]=f;v[a+104>>2]=b|c?b>>>0<e>>>0&(c|0)<=(f|0)|(c|0)<(f|0)?b+g|0:d:d}function vN(){var a=0,b=0,c=0;a=gb-16|0;gb=a;v[a+12>>2]=82595524;v[22656]=0;v[a+8>>2]=2147483647;b=Fb(a+12|0,a+8|0);c=v[22656];v[22656]=0;if((c|0)!=1){gb=a+16|0;return v[b>>2]}V(0)|0;O()|0;Bb();L()}function EO(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;c=gb-16|0;gb=c;ag(a,c+14|0);UO(b,x[c+14>>1],16777216);if(x[c+14>>1]){while(1){Ik(a,Mb(b,d));d=d+1|0;if(d>>>0<x[c+14>>1]){continue}break}}jA(b);gb=c+16|0}function zL(){var a=0,b=0,c=0,d=0;a=gb-16|0;gb=a;b=sf(1298432);v[22656]=0;c=T(2051,b|0)|0;d=v[22656];v[22656]=0;if((d|0)!=1){b=v[Wi(a+8|0,c)>>2];gb=a+16|0;return b|0}a=P()|0;O()|0;Yb(b);S(a|0);L()}function Id(a,b){var c=0,d=0,e=0;d=x[a+24>>1];if((d|0)!=(b&65535)){c=x[a+22>>1]-1&127;u[a+22>>1]=c;e=x[a+20>>1];if(e>>>0<=127){u[a+20>>1]=e+1}c=(c<<2)+a|0;u[c+26>>1]=b-d;u[c+28>>1]=0;u[a+24>>1]=b}}function GR(a,b,c,d,e,f){v[a+40>>2]=0;v[a+44>>2]=0;A[a+32>>3]=f;A[a+24>>3]=e;A[a+16>>3]=d;A[a+8>>3]=c;A[a>>3]=b;v[a+48>>2]=0;v[a+52>>2]=0;v[a+56>>2]=0;v[a+60>>2]=0;a=a- -64|0;v[a>>2]=0;v[a+4>>2]=0}function zj(a){var b=0;b=32767;a:{if(a>=C(32766.5)){break a}b=32768;if(a<=C(-32767.5)){break a}a=C(a+C(.5));b:{if(C(D(a))<C(2147483648)){b=~~a;break b}b=-2147483648}b=b+(b>>15)|0}return b<<16>>16}function Ws(a){var b=0;if(v[a+76>>2]<0){b=v[a+4>>2];if(b>>>0<y[a+8>>2]){v[a+4>>2]=b+1;return w[b|0]}return Sx(a)}b=v[a+4>>2];a:{if(b>>>0<y[a+8>>2]){v[a+4>>2]=b+1;a=w[b|0];break a}a=Sx(a)}return a}function BP(a,b,c){var d=0,e=0;d=v[(B(b,872)+a|0)+1075648>>2];a:{if(!d){break a}b:{if((c|0)!=1){break b}a=v[(B(b,872)+a|0)+1075096>>2];if(!a){break b}if(w[a+35|0]&4){break a}}e=w[d+34|0]}return e}function t1(a){a=a|0;var b=0,c=0,d=0;b=gb-16|0;gb=b;v[b+12>>2]=a;a=vi(b+8|0,b+12|0);v[22656]=0;c=FH();d=v[22656];v[22656]=0;if((d|0)!=1){hf(a);gb=b+16|0;return c|0}b=P()|0;O()|0;hf(a);S(b|0);L()}function mS(a){a=a|0;var b=0,c=0;b=gb-32|0;gb=b;t[a+16|0]=0;c=kB(b,v[a+12>>2]);v[22656]=0;R(1089,a|0,c|0);a=v[22656];v[22656]=0;if((a|0)!=1){Zm(c);gb=b+32|0;return}a=P()|0;O()|0;Zm(c);S(a|0);L()}function lh(a,b){a:{if(y[a+4>>2]<=b>>>0){a=ba(8)|0;v[22656]=0;T(283,a|0)|0;b=v[22656];v[22656]=0;if((b|0)!=1){break a}b=P()|0;O()|0;ca(a|0);S(b|0);L()}return w[v[a>>2]+b|0]}ia(a|0,28304,206);L()}function hK(a){var b=0,c=0;b=gb-16|0;gb=b;wb(a);v[b+12>>2]=-1;v[22656]=0;v[b+8>>2]=2147483647;a=Fb(b+12|0,b+8|0);c=v[22656];v[22656]=0;if((c|0)!=1){gb=b+16|0;return v[a>>2]}V(0)|0;O()|0;Bb();L()}function Qc(a,b){var c=0;c=gb-16|0;gb=c;v[c+8>>2]=a;v[c+12>>2]=b;v[22656]=0;v[c>>2]=-1;v[c+4>>2]=0;a=Uk(c+8|0,c);b=v[22656];v[22656]=0;if((b|0)!=1){gb=c+16|0;return v[a>>2]}V(0)|0;O()|0;Bb();L()}function Jv(a){t[a|0]=0;t[a+1|0]=0;t[a+2|0]=0;t[a+3|0]=0;t[a+4|0]=0;t[a+5|0]=0;t[a+6|0]=0;t[a+7|0]=0;t[a+8|0]=0;t[a+9|0]=0;t[a+10|0]=0;t[a+11|0]=0;t[a+12|0]=0;t[a+13|0]=0;t[a+14|0]=0;t[a+15|0]=0}function AF(a){var b=0;if(!((w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24))!=808603728|(w[a+4|0]-9&255)>>>0>6|((w[a+5|0]-9&255)>>>0>6|(w[a+6|0]-9&255)>>>0>6))){b=(w[a+7|0]-9&255)>>>0<7}return b}function b$(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=gb-32|0;gb=c;Jp(a);v[a>>2]=27480;e=dc(a);d=v[b+4>>2];b=v[b>>2];v[c+8>>2]=b;v[c+12>>2]=d;v[c+16>>2]=b;v[c+20>>2]=d;bG(e,c+8|0);gb=c+32|0;return a|0}function Zda(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=gb-16|0;gb=d;e=1;a=a+32|0;if(y[v[b>>2]>>2]<oc(a)>>>0){a=qo(d,lc(a,v[v[b>>2]>>2]),x[v[b>>2]+12>>1]);b=Xy(c,a);Hb(a);e=b^1}gb=d+16|0;return e|0}function WK(a){a=a|0;var b=0;a=a+24|0;b=XK(v[a>>2]);if(Ri(Sb(v[a>>2]+484360|0))>>>0<=b>>>0){return x[v[a>>2]+1074446>>1]}b=x[sc(Sb(v[a>>2]+484360|0),b)>>1];return(dm(v[a>>2]+484344|0,b)?b:-1)|0}function TG(a,b,c,d,e){var f=0;f=gb-16|0;gb=f;v[f+12>>2]=e;e=vi(f+8|0,f+12|0);v[22656]=0;a=aq(a,b,c,d);b=v[22656];v[22656]=0;if((b|0)!=1){hf(e);gb=f+16|0;return a}a=P()|0;O()|0;hf(e);S(a|0);L()}function xo(a,b,c,d){var e=0,f=0,g=0,h=0;e=gb-16|0;gb=e;v[e+12>>2]=0;kf(a+12|0,d);if(b){f=aA(b)}v[a>>2]=f;c=(c<<2)+f|0;v[a+8>>2]=c;v[a+4>>2]=c;g=dc(a),h=(b<<2)+f|0,v[g>>2]=h;gb=e+16|0;return a}function mr(a,b){a=a|0;b=b|0;var c=0,d=0;c=gb-16|0;gb=c;b=Fg(c,a,b);a=v[b+4>>2];d=v[b+8>>2];if((a|0)!=(d|0)){while(1){ak(a);a=a+4|0;v[b+4>>2]=a;if((a|0)!=(d|0)){continue}break}}$b(b);gb=c+16|0}function jha(a,b){a=a|0;b=b|0;var c=0;c=gb-16|0;gb=c;b=WT(c,a+8|0,b);a=v[b>>2];if((a|0)!=v[b+4>>2]){while(1){gR(a);a=v[b>>2]+12|0;v[b>>2]=a;if(v[b+4>>2]!=(a|0)){continue}break}}_c(b);gb=c+16|0}function ez(a){var b=0,c=0,d=0,e=0;A[a+4272>>3]=A[a+4280>>3];c=a;d=a+4296|0;a=0;while(1){a=Ao(d)^a<<15;e=b>>>0<17;b=b+15|0;if(e){continue}break}A[c+4280>>3]=C(C(a|0)*C(-4.656612873077393e-10))}function bS(a,b,c,d){var e=0,f=0,g=0,h=0;e=gb-16|0;gb=e;v[e+12>>2]=0;kf(a+12|0,d);if(b){f=dS(b)}v[a>>2]=f;c=(c<<5)+f|0;v[a+8>>2]=c;v[a+4>>2]=c;g=dc(a),h=(b<<5)+f|0,v[g>>2]=h;gb=e+16|0;return a}function apa(a,b){a=a|0;b=b|0;var c=0;c=gb-32|0;gb=c;a:{if(!Pb(b,6)){t[c+16|0]=0;ni(a,6,c+16|0);break a}NX(c+24|0,a);a=v[c+28>>2];v[c+8>>2]=v[c+24>>2];v[c+12>>2]=a;kd(c+16|0,b,c+8|0)}gb=c+32|0}function WI(a,b,c,d){var e=0,f=0,g=0,h=0;e=gb-16|0;gb=e;v[e+12>>2]=0;kf(a+12|0,d);if(b){f=bI(b)}v[a>>2]=f;c=(c<<4)+f|0;v[a+8>>2]=c;v[a+4>>2]=c;g=dc(a),h=(b<<4)+f|0,v[g>>2]=h;gb=e+16|0;return a}function WA(a,b,c,d){var e=0,f=0,g=0,h=0;e=gb-16|0;gb=e;v[e+12>>2]=0;kf(a+12|0,d);if(b){f=CR(b)}v[a>>2]=f;c=(c<<3)+f|0;v[a+8>>2]=c;v[a+4>>2]=c;g=dc(a),h=(b<<3)+f|0,v[g>>2]=h;gb=e+16|0;return a}function R1(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;a:{if((c|0)==(d|0)){break a}while(1){if(y[c>>2]<=127){if(x[Zp()+(v[c>>2]<<1)>>1]&b){break a}}c=c+4|0;if((d|0)!=(c|0)){continue}break}c=d}return c|0}function Kla(a,b){a=a|0;b=b|0;var c=0;c=gb-32|0;gb=c;a:{if(!Pb(b,5)){t[c+16|0]=0;ni(a,5,c+16|0);break a}_v(c+24|0,a);a=v[c+28>>2];v[c+8>>2]=v[c+24>>2];v[c+12>>2]=a;kd(c+16|0,b,c+8|0)}gb=c+32|0}function Ag(a,b){a=a|0;b=b|0;var c=0,d=0;c=gb+-64|0;gb=c;d=pz(c+8|0,a);v[22656]=0;U(1489,a|0,b|0,d|0);a=v[22656];v[22656]=0;if((a|0)!=1){Km(d);gb=c- -64|0;return}a=P()|0;O()|0;Km(d);S(a|0);L()}function xT(a,b){a=a|0;b=b|0;var c=0;c=gb-16|0;gb=c;b=zI(c,a+8|0,b);a=v[b>>2];if((a|0)!=v[b+4>>2]){while(1){Jv(a);a=v[b>>2]+16|0;v[b>>2]=a;if(v[b+4>>2]!=(a|0)){continue}break}}_c(b);gb=c+16|0}function wn(a,b){a=a|0;b=b|0;var c=0;c=gb-32|0;gb=c;a:{if(!Pb(b,4)){t[c+16|0]=0;ni(a,4,c+16|0);break a}zi(c+24|0,a);a=v[c+28>>2];v[c+8>>2]=v[c+24>>2];v[c+12>>2]=a;kd(c+16|0,b,c+8|0)}gb=c+32|0}function gca(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=wg(4332);if(!d){return 0}v[22656]=0;a=fa(1801,d|0,a|0,b|0,c|0,0)|0;b=v[22656];v[22656]=0;if((b|0)!=1){return a|0}a=P()|0;O()|0;Yb(d);S(a|0);L()}function eca(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=wg(4332);if(!d){return 0}v[22656]=0;a=fa(1801,d|0,a|0,b|0,c|0,1)|0;b=v[22656];v[22656]=0;if((b|0)!=1){return a|0}a=P()|0;O()|0;Yb(d);S(a|0);L()}function YT(a,b){a=a|0;b=b|0;var c=0;c=gb-16|0;gb=c;b=WT(c,a+8|0,b);a=v[b>>2];if((a|0)!=v[b+4>>2]){while(1){VT(a);a=v[b>>2]+12|0;v[b>>2]=a;if(v[b+4>>2]!=(a|0)){continue}break}}_c(b);gb=c+16|0}function SI(a,b){a=a|0;b=b|0;var c=0;c=gb-16|0;gb=c;b=zI(c,a+8|0,b);a=v[b>>2];if((a|0)!=v[b+4>>2]){while(1){iI(a);a=v[b>>2]+16|0;v[b>>2]=a;if(v[b+4>>2]!=(a|0)){continue}break}}_c(b);gb=c+16|0}function Nh(a,b){var c=0,d=0;a=v[a>>2];b=Wd(b);c=b;d=a+8|0;if(Nb(d)>>>0>b>>>0){c=v[Mb(d,c)>>2]!=0}else{c=0}if(!c){a=ba(4)|0;Fm(a);v[a>>2]=89560;ia(a|0,89608,2327);L()}return v[Mb(a+8|0,b)>>2]}function Nca(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=wg(4332);if(!d){return 0}v[22656]=0;a=fa(1696,d|0,a|0,b|0,c|0,0)|0;b=v[22656];v[22656]=0;if((b|0)!=1){return a|0}a=P()|0;O()|0;Yb(d);S(a|0);L()}function Ki(a){var b=0,c=0,d=0,e=0;e=Ae(a);b=e&63;a:{if(!(e&64)){break a}c=6;while(1){d=Ae(a);b=(d&127)<<c|b;if(!(d&128)){break a}d=c>>>0<25;c=c+7|0;if(d){continue}break}}return e&128?0-b|0:b}function BT(a,b){a=a|0;b=b|0;var c=0;c=gb-16|0;gb=c;b=yT(c,a+8|0,b);a=v[b>>2];if((a|0)!=v[b+4>>2]){while(1){$B(a);a=v[b>>2]+32|0;v[b>>2]=a;if(v[b+4>>2]!=(a|0)){continue}break}}_c(b);gb=c+16|0}function ov(a,b){a=a|0;b=b|0;var c=0;c=gb-16|0;gb=c;b=Tk(c,a+8|0,b);a=v[b>>2];if((a|0)!=v[b+4>>2]){while(1){ak(a);a=v[b>>2]+4|0;v[b>>2]=a;if(v[b+4>>2]!=(a|0)){continue}break}}_c(b);gb=c+16|0}function eU(a,b){var c=0,d=0,e=0,f=0;c=b+4|0;e=v[a>>2];d=v[a+4>>2]-e|0;f=v[c>>2]+B((d|0)/-12|0,12)|0;v[c>>2]=f;if((d|0)>0){hc(f,e,d)}wc(a,c);wc(a+4|0,b+8|0);wc(wb(a),dc(b));v[b>>2]=v[b+4>>2]}function cc(a,b,c){var d=0,e=0,f=0,g=0;d=gb-16|0;gb=d;e=v[b>>2];f=v[b+8>>2];b=v[c+4>>2];c=v[c>>2];v[d+8>>2]=c;v[d+12>>2]=b;g=v[v[e>>2]+28>>2];v[d>>2]=c;v[d+4>>2]=b;kb[g|0](a,e,f,d);gb=d+16|0}function RV(a,b){a=a|0;b=b|0;var c=0;c=gb-16|0;gb=c;b=Fn(c,a+8|0,b);a=v[b>>2];if((a|0)!=v[b+4>>2]){while(1){Pk(a);a=v[b>>2]+2|0;v[b>>2]=a;if(v[b+4>>2]!=(a|0)){continue}break}}_c(b);gb=c+16|0}function JC(a,b,c){a=a|0;b=b|0;c=c|0;a=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);t[b|0]=a;t[b+1|0]=a>>>8;t[b+2|0]=a>>>16;t[b+3|0]=a>>>24;a=w[c+4|0]|w[c+5|0]<<8;t[b+4|0]=a;t[b+5|0]=a>>>8}function Aba(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=wg(86224);if(!d){return 0}v[22656]=0;a=da(1887,d|0,a|0,b|0,c|0)|0;b=v[22656];v[22656]=0;if((b|0)!=1){return a|0}a=P()|0;O()|0;Yb(d);S(a|0);L()}function yda(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=wg(4304);if(!d){return 0}v[22656]=0;a=da(1594,d|0,a|0,b|0,c|0)|0;b=v[22656];v[22656]=0;if((b|0)!=1){return a|0}a=P()|0;O()|0;Yb(d);S(a|0);L()}function wR(a,b){var c=0,d=0;c=v[a+24>>2];v[22656]=0;c=me(c+484344|0,b);d=v[22656];v[22656]=0;if((d|0)!=1){if(c){a=v[_b(v[a+24>>2]+484344|0,b)+12>>2]}else{a=1}return a}V(0)|0;O()|0;Bb();L()}function uca(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=wg(4276);if(!d){return 0}v[22656]=0;a=da(1754,d|0,a|0,b|0,c|0)|0;b=v[22656];v[22656]=0;if((b|0)!=1){return a|0}a=P()|0;O()|0;Yb(d);S(a|0);L()}function sx(a,b,c,d){var e=0;e=gb-16|0;gb=e;v[e+12>>2]=d;d=vi(e+8|0,e+12|0);v[22656]=0;a=ql(a,b,c);b=v[22656];v[22656]=0;if((b|0)!=1){hf(d);gb=e+16|0;return a}a=P()|0;O()|0;hf(d);S(a|0);L()}function nca(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=wg(4268);if(!d){return 0}v[22656]=0;a=da(1777,d|0,a|0,b|0,c|0)|0;b=v[22656];v[22656]=0;if((b|0)!=1){return a|0}a=P()|0;O()|0;Yb(d);S(a|0);L()}function mw(a,b){a=a|0;b=b|0;var c=0;c=gb-32|0;gb=c;a:{if(!Pb(b,2)){t[c+16|0]=0;pE(a,c+16|0);break a}Cn(c+24|0,a);a=v[c+28>>2];v[c+8>>2]=v[c+24>>2];v[c+12>>2]=a;kd(c+16|0,b,c+8|0)}gb=c+32|0}function ip(a,b){a=a|0;b=b|0;var c=0,d=0;c=gb-32|0;gb=c;d=Pb(a,4);a:{if(!d){EW(b);break a}zi(c+24|0,b);b=v[c+28>>2];v[c+8>>2]=v[c+24>>2];v[c+12>>2]=b;kd(c+16|0,a,c+8|0)}gb=c+32|0;return d|0}function cA(a){var b=0,c=0,d=0;b=gb-16|0;gb=b;yc(b+8|0,a+116|0);v[22656]=0;c=Na(1328,a|0)|0;a=O()|0;c=c|0;d=v[22656];v[22656]=0;if((d|0)!=1){gb=b+16|0;jb=a;return c}a=P()|0;O()|0;S(a|0);L()}function a9(a,b){a=a|0;b=b|0;var c=0;c=gb-16|0;gb=c;a=v[a+24>>2];CL(c,b);v[22656]=0;U(560,a|0,1,c|0);a=v[22656];v[22656]=0;if((a|0)!=1){vb(c);gb=c+16|0;return}a=P()|0;O()|0;vb(c);S(a|0);L()}function _ba(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=wg(4228);if(!d){return 0}v[22656]=0;a=da(1814,d|0,a|0,b|0,c|0)|0;b=v[22656];v[22656]=0;if((b|0)!=1){return a|0}a=P()|0;O()|0;Yb(d);S(a|0);L()}function Xca(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=wg(4236);if(!d){return 0}v[22656]=0;a=da(1665,d|0,a|0,b|0,c|0)|0;b=v[22656];v[22656]=0;if((b|0)!=1){return a|0}a=P()|0;O()|0;Yb(d);S(a|0);L()}function Sda(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=wg(4268);if(!d){return 0}v[22656]=0;a=da(1531,d|0,a|0,b|0,c|0)|0;b=v[22656];v[22656]=0;if((b|0)!=1){return a|0}a=P()|0;O()|0;Yb(d);S(a|0);L()}function Qba(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=wg(5048);if(!d){return 0}v[22656]=0;a=da(1837,d|0,a|0,b|0,c|0)|0;b=v[22656];v[22656]=0;if((b|0)!=1){return a|0}a=P()|0;O()|0;Yb(d);S(a|0);L()}function QM(a,b){var c=0,d=0;c=v[a+4>>2];a:{while(1){if((b|0)==(c|0)){break a}wb(a);v[22656]=0;c=c-2048|0;d=v[22656];v[22656]=0;if((d|0)!=1){continue}break}V(0)|0;O()|0;Bb();L()}v[a+4>>2]=b}function Npa(){var a=0,b=0,c=0,d=0;a=gb-16|0;gb=a;b=sf(1);v[22656]=0;c=T(39,b|0)|0;d=v[22656];v[22656]=0;if((d|0)!=1){b=v[Wi(a+8|0,c)>>2];gb=a+16|0;return b|0}a=P()|0;O()|0;Yb(b);S(a|0);L()}function Hba(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=wg(4276);if(!d){return 0}v[22656]=0;a=da(1864,d|0,a|0,b|0,c|0)|0;b=v[22656];v[22656]=0;if((b|0)!=1){return a|0}a=P()|0;O()|0;Yb(d);S(a|0);L()}function GD(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;b=b-a>>2;if((b|0)>0){while(1){d=v[c>>2];t[a|0]=d;t[a+1|0]=d>>>8;t[a+2|0]=d>>>16;t[a+3|0]=d>>>24;a=a+4|0;d=b>>>0>1;b=b-1|0;if(d){continue}break}}}function Cca(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=wg(4280);if(!d){return 0}v[22656]=0;a=da(1730,d|0,a|0,b|0,c|0)|0;b=v[22656];v[22656]=0;if((b|0)!=1){return a|0}a=P()|0;O()|0;Yb(d);S(a|0);L()}function dfa(a,b){a=a|0;b=b|0;var c=0;b=gb-16|0;gb=b;c=-1;a:{if(!ek(a,b+8|0)){break a}c=0;if(!PN(b+8|0)){break a}c=b;a=DT(a,b);if(!a){ak(c)}c=-1;if(!a){break a}c=ON(b)}gb=b+16|0;return c|0}function VQ(a,b){var c=0,d=0,e=0,f=0;c=b+4|0;e=v[a>>2];d=v[a+4>>2]-e|0;f=v[c>>2]+B((d|0)/-7|0,7)|0;v[c>>2]=f;if((d|0)>0){hc(f,e,d)}wc(a,c);wc(a+4|0,b+8|0);wc(wb(a),dc(b));v[b>>2]=v[b+4>>2]}function Oca(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;c=v[b>>2];a:{if((yb(b)|0)!=8){break a}d=c;if((w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24))!=1869112133){break a}hc(a+4228|0,c,yb(b));Mt(a)}}function OH(a,b,c,d){a:{if(!a){break a}b:{switch(b+2|0){case 0:t[a|0]=c;return;case 1:u[a>>1]=c;return;case 2:case 3:v[a>>2]=c;return;case 5:break b;default:break a}}v[a>>2]=c;v[a+4>>2]=d}}function Gda(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;c=v[b>>2];a:{if((yb(b)|0)!=8){break a}d=c;if((w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24))!=1869112133){break a}hc(a+4260|0,c,yb(b));Ut(a)}}function EX(a){var b=0,c=0;a:{if(sd(a,18715,11)){break a}b=a+215|0;a=a+63|0;while(1){if(w[a+16|0]>3|w[a+17|0]>3|w[a+18|0]>=16){break a}a=a+19|0;if((b|0)!=(a|0)){continue}break}c=1}return c}function $L(a,b,c,d){var e=0;e=v[b+4>>2];v[a>>2]=v[b>>2];v[a+4>>2]=e;e=v[b+12>>2];v[a+8>>2]=v[b+8>>2];v[a+12>>2]=e;b=v[a+8>>2];d=v[a+12>>2]-(d+(b>>>0<c>>>0)|0)|0;v[a+8>>2]=b-c;v[a+12>>2]=d}function zka(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=gb-32|0;gb=d;ST(b,c);if(Pb(a,c<<8)){bc(d+24|0,v[b>>2],dh(b)<<8);b=v[d+28>>2];v[d+8>>2]=v[d+24>>2];v[d+12>>2]=b;kd(d+16|0,a,d+8|0)}gb=d+32|0}function tpa(a){a=a|0;var b=0,c=0,d=0;b=gb-16|0;gb=b;c=Tb(b,7535);v[22656]=0;a=Q(46,a|0,c|0)|0;d=v[22656];v[22656]=0;if((d|0)!=1){vb(c);gb=b+16|0;return a|0}a=P()|0;O()|0;vb(c);S(a|0);L()}function mz(a,b,c){b=(b+9|0)%12|0;a=((b<<24>>24)/-10<<24>>24)+a|0;return(((((((a|0)/4|0)+c|0)+B(a,365)|0)+((a|0)/-100|0)|0)+((a|0)/400|0)|0)+((B(b,20054016)+327680>>16)/10<<16>>16)|0)-1|0}function kY(a,b){var c=0,d=0;c=v[a+4>>2];a:{while(1){if((b|0)==(c|0)){break a}wb(a);v[22656]=0;c=c-48|0;d=v[22656];v[22656]=0;if((d|0)!=1){continue}break}V(0)|0;O()|0;Bb();L()}v[a+4>>2]=b}function jca(a,b,c){a=a|0;b=b|0;c=C(c);var d=0;d=gb-16|0;gb=d;z[d+12>>2]=c;if((b|0)<=4){Hi(d+12|0);c=z[d+12>>2];if((b|0)==4){c=fe(c);z[d+12>>2]=c}z[((b<<2)+a|0)+4220>>2]=c;jM(a)}gb=d+16|0}function Wba(a,b,c){a=a|0;b=b|0;c=C(c);var d=0;d=gb-16|0;gb=d;z[d+12>>2]=c;if((b|0)<=1){Hi(d+12|0);c=z[d+12>>2];if((b|0)==1){c=fe(c);z[d+12>>2]=c}z[((b<<2)+a|0)+4208>>2]=c;gM(a)}gb=d+16|0}function Ti(a){var b=0,c=0;b=gb-16|0;gb=b;v[b+12>>2]=a;v[22656]=0;v[b+8>>2]=2147483647;a=Fb(b+12|0,b+8|0);c=v[22656];v[22656]=0;if((c|0)!=1){gb=b+16|0;return v[a>>2]}V(0)|0;O()|0;Bb();L()}function O1(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;if((b|0)!=(c|0)){while(1){d=b;a=v[b>>2];if(a>>>0<=127){a=v[Ks()+(v[b>>2]<<2)>>2]}v[d>>2]=a;b=b+4|0;if((c|0)!=(b|0)){continue}break}}return c|0}function Nx(a,b,c,d,e,f,g,h,i){var j=0;j=gb-16|0;gb=j;yg(j,b,c,d,e,f,g,h,i^-2147483648);d=v[j>>2];c=v[j+4>>2];b=v[j+12>>2];v[a+8>>2]=v[j+8>>2];v[a+12>>2]=b;v[a>>2]=d;v[a+4>>2]=c;gb=j+16|0}function M1(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;if((b|0)!=(c|0)){while(1){d=b;a=v[b>>2];if(a>>>0<=127){a=v[Js()+(v[b>>2]<<2)>>2]}v[d>>2]=a;b=b+4|0;if((c|0)!=(b|0)){continue}break}}return c|0}function LI(a,b){var c=0,d=0;c=v[a+4>>2];a:{while(1){if((b|0)==(c|0)){break a}wb(a);v[22656]=0;c=c-16|0;d=v[22656];v[22656]=0;if((d|0)!=1){continue}break}V(0)|0;O()|0;Bb();L()}v[a+4>>2]=b}function uU(a,b){var c=0,d=0;c=v[a+4>>2];a:{while(1){if((b|0)==(c|0)){break a}wb(a);v[22656]=0;c=c-4|0;d=v[22656];v[22656]=0;if((d|0)!=1){continue}break}V(0)|0;O()|0;Bb();L()}v[a+4>>2]=b}function uK(a,b){var c=0,d=0;c=v[a+4>>2];a:{while(1){if((b|0)==(c|0)){break a}wb(a);v[22656]=0;c=c-1|0;d=v[22656];v[22656]=0;if((d|0)!=1){continue}break}V(0)|0;O()|0;Bb();L()}v[a+4>>2]=b}function rH(a){var b=0;a:{b:{a=v[a>>2];if(a>>>0>=18285141){if(a>>>0>18350591){break b}b=1;if((a|0)!=18350080){break a}}return 0}b=0;if((a|0)==18350592){break a}b=(a|0)!=(a&-256)}return b}function kF(a,b){var c=0,d=0;c=v[a+4>>2];a:{while(1){if((b|0)==(c|0)){break a}wb(a);v[22656]=0;c=c-2|0;d=v[22656];v[22656]=0;if((d|0)!=1){continue}break}V(0)|0;O()|0;Bb();L()}v[a+4>>2]=b}function h$(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=gb-32|0;gb=d;HF(b,c);c=Pb(a,c<<3);if(c){GF(d+24|0,b);b=v[d+28>>2];v[d+8>>2]=v[d+24>>2];v[d+12>>2]=b;kd(d+16|0,a,d+8|0)}gb=d+32|0;return c|0}function aqa(){var a=0;a:{b:{if(t[90660]&1){break b}if(!Qd(90660)){break b}v[22656]=0;X(34);a=v[22656];v[22656]=0;if((a|0)==1){break a}Pd(90660)}return}a=P()|0;O()|0;$e(90660);S(a|0);L()}function VW(a,b){var c=0,d=0;c=v[a+4>>2];a:{while(1){if((b|0)==(c|0)){break a}wb(a);v[22656]=0;c=c-6|0;d=v[22656];v[22656]=0;if((d|0)!=1){continue}break}V(0)|0;O()|0;Bb();L()}v[a+4>>2]=b}function US(a){var b=0,c=0;a:{b:{c=a&240;if((c|0)!=192){if((c|0)==240){break b}b=3;if((c|0)!=208){break a}}b=2;break a}a=a+15&255;b=1;if(a>>>0>2){break a}b=131842>>>(a<<3)|0}return b&255}function Ig(a){var b=0,c=0;b=gb-16|0;gb=b;v[a>>2]=0;v[a+4>>2]=0;v[b+12>>2]=0;v[22656]=0;Pf(a+8|0,b+12|0,b+8|0);c=v[22656];v[22656]=0;if((c|0)!=1){gb=b+16|0;return a}V(0)|0;O()|0;Bb();L()}function Dt(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;a=gb-16|0;gb=a;if(Nb(b)){while(1){v[a+8>>2]=0;Ui(a+8|0);d=Mb(b,c),e=v[a+8>>2],v[d>>2]=e;c=c+1|0;if(Nb(b)>>>0>c>>>0){continue}break}}gb=a+16|0}function CB(a){var b=0,c=0;b=gb-16|0;gb=b;v[a>>2]=0;v[a+4>>2]=0;v[b+12>>2]=0;v[22656]=0;ff(a+8|0,b+12|0,b+8|0);c=v[22656];v[22656]=0;if((c|0)!=1){gb=b+16|0;return a}V(0)|0;O()|0;Bb();L()}function wj(a,b){var c=0,d=0;c=w[a|0];d=w[b|0];a:{if(!c|(d|0)!=(c|0)){break a}while(1){d=w[b+1|0];c=w[a+1|0];if(!c){break a}b=b+1|0;a=a+1|0;if((c|0)==(d|0)){continue}break}}return c-d|0}function hF(a){var b=0,c=0;b=v[a+4>>2];a:{while(1){if(v[a+8>>2]==(b|0)){break a}v[a+8>>2]=v[a+8>>2]-2;v[22656]=0;c=v[22656];v[22656]=0;if((c|0)!=1){continue}break}V(0)|0;O()|0;Bb();L()}}function gba(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0;f=gb-16|0;gb=f;v[f+8>>2]=v[a+8>>2];g=v[a+4>>2];v[f>>2]=v[a>>2];v[f+4>>2]=g;a=JL(f,b,c,d,0,0,0,0,e);gb=f+16|0;return a|0}function gC(a){var b=0,c=0;b=v[a+4>>2];a:{while(1){if(v[a+8>>2]==(b|0)){break a}v[a+8>>2]=v[a+8>>2]-4;v[22656]=0;c=v[22656];v[22656]=0;if((c|0)!=1){continue}break}V(0)|0;O()|0;Bb();L()}}function XT(a){var b=0,c=0,d=0;b=a;c=v[b+8>>2];d=v[b+4>>2];if((c|0)!=(d|0)){while(1){c=c-12|0;v[b+8>>2]=c;ZT(c);c=v[b+8>>2];if((d|0)!=(c|0)){continue}break}}b=v[a>>2];if(b){Yu(b,Mp(a))}}function VS(a){var b=0,c=0;c=v[a+4>>2];a:{while(1){b=v[a+8>>2];if((b|0)==(c|0)){break a}v[a+8>>2]=b-4;v[22656]=0;b=v[22656];v[22656]=0;if((b|0)!=1){continue}break}V(0)|0;O()|0;Bb();L()}}function N4(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;e=v[a+84>>2];d=c+256|0;f=it(e,0,d);d=f?f-e|0:d;c=c>>>0>d>>>0?d:c;hc(b,e,c);b=e+d|0;v[a+84>>2]=b;v[a+8>>2]=b;v[a+4>>2]=c+e;return c|0}function Im(a,b){var c=0,d=C(0),e=0;e=u[a+28>>1];c=a+4|0;Nb(c);d=C(1);a:{if((b|0)<(e|0)){break a}if((x[a+28>>1]+Nb(c)<<16)-65536>>16<(b|0)){break a}d=z[Mb(c,b-u[a+28>>1]|0)>>2]}return d}function HY(a){var b=0,c=0,d=0;b=a;c=v[b+8>>2];d=v[b+4>>2];if((c|0)!=(d|0)){while(1){c=c-28|0;v[b+8>>2]=c;ed(c);c=v[b+8>>2];if((d|0)!=(c|0)){continue}break}}b=v[a>>2];if(b){DD(b,GY(a))}}function w3(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0;g=gb-16|0;gb=g;v[g+8>>2]=624576549;v[g+12>>2]=1394948685;h=a;a=g+16|0;b=kk(h,b,c,d,e,f,g+8|0,a);gb=a;return b|0}function qe(a,b){var c=0;a:{c=Nf(b);if((c|0)==(Ab(a)|0)){v[22656]=0;a=fa(552,a|0,0,-1,b|0,c|0)|0;b=v[22656];v[22656]=0;if((b|0)==1){break a}a=!a}else{a=0}return a}V(0)|0;O()|0;Bb();L()}function AO(a){a=a|0;var b=0,c=0,d=0,e=0,f=0;d=a;b=v[a+112>>2];if((b|0)>=11){e=a;b=378;while(1){zO(e);c=f-!b|0;b=b-1|0;f=c;if(b|c){continue}break}b=0}v[d+112>>2]=b+1;a=zO(a);return a|0}function ZQ(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;a:{if(w[b+30|0]!=4){break a}d=b+31|0;if(w[d|0]&4|w[d|0]&2){break a}Rc(a,8,1,0,10);return}d=a;a=b+31|0;Rc(d,w[a|0]&4?16:8,w[a|0]&2|1,0,c^1)}function WX(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=gb-32|0;gb=d;Ok(b,c);c=Pb(a,c);if(c){QD(d+24|0,b);b=v[d+28>>2];v[d+8>>2]=v[d+24>>2];v[d+12>>2]=b;kd(d+16|0,a,d+8|0)}gb=d+32|0;return c|0}function Fda(a,b,c){a=a|0;b=b|0;c=C(c);var d=0,e=0,f=C(0);d=gb-16|0;gb=d;e=d,f=C(C(kb[v[v[a>>2]+48>>2]](a,b))+c),z[e+12>>2]=f;Hi(d+12|0);kb[v[v[a>>2]+44>>2]](a,b,z[d+12>>2]);gb=d+16|0}function y_(a,b){a=a|0;b=b|0;var c=0;c=gb-32|0;gb=c;a=Kn(c+8|0,a);v[22656]=0;a=W(272,a|0,b|0,10441)|0;b=v[22656];v[22656]=0;if((b|0)!=1){gb=c+32|0;return a|0}a=P()|0;O()|0;S(a|0);L()}function pN(a){var b=0,c=0;b=gb-16|0;gb=b;v[b+12>>2]=a;v[22656]=0;v[b+8>>2]=32767;a=Fb(b+12|0,b+8|0);c=v[22656];v[22656]=0;if((c|0)!=1){gb=b+16|0;return u[a>>1]}V(0)|0;O()|0;Bb();L()}function Xh(a){var b=0;a=fe(a);b=2147483647;a:{if(a>=C(2147483648)){break a}b=-2147483648;if(a<=C(-2147483648)){break a}b=~~a;if(C(D(a))<C(2147483648)){break a}b=-2147483648}return b}function Qv(a){var b=0,c=0;b=gb-16|0;gb=b;v[b+12>>2]=a;v[22656]=0;v[b+8>>2]=65535;a=Fb(b+12|0,b+8|0);c=v[22656];v[22656]=0;if((c|0)!=1){gb=b+16|0;return x[a>>1]}V(0)|0;O()|0;Bb();L()}function G1(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;if((b|0)!=(c|0)){while(1){d=b;a=t[b|0];if((a|0)>=0){a=v[Ks()+(t[b|0]<<2)>>2]}t[d|0]=a;b=b+1|0;if((c|0)!=(b|0)){continue}break}}return c|0}function E1(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;if((b|0)!=(c|0)){while(1){d=b;a=t[b|0];if((a|0)>=0){a=v[Js()+(t[b|0]<<2)>>2]}t[d|0]=a;b=b+1|0;if((c|0)!=(b|0)){continue}break}}return c|0}function qh(a,b){var c=0,d=0;c=gb-16|0;gb=c;v[c+12>>2]=b;d=b;b=hK(a);if(d>>>0<=b>>>0){a=dg(a);if(a>>>0<b>>>1>>>0){v[c+8>>2]=a<<1;b=v[Lc(c+8|0,c+12|0)>>2]}gb=c+16|0;return b}Sc();L()}function jD(a,b){var c=0,d=0;c=gb-16|0;gb=c;v[c+12>>2]=b;d=b;b=lE(a);if(d>>>0<=b>>>0){a=em(a);if(a>>>0<b>>>1>>>0){v[c+8>>2]=a<<1;b=v[Lc(c+8|0,c+12|0)>>2]}gb=c+16|0;return b}Sc();L()}function hd(a,b,c){var d=0,e=0,f=0,g=0;d=gb-16|0;gb=d;f=v[b+12>>2];e=v[c+4>>2];c=v[c>>2];v[d+8>>2]=c;v[d+12>>2]=e;g=v[v[b>>2]+28>>2];v[d>>2]=c;v[d+4>>2]=e;kb[g|0](a,b,f,d);gb=d+16|0}function fh(a,b){var c=0,d=0;c=gb-16|0;gb=c;v[c+12>>2]=b;d=b;b=oC(a);if(d>>>0<=b>>>0){a=pe(a);if(a>>>0<b>>>1>>>0){v[c+8>>2]=a<<1;b=v[Lc(c+8|0,c+12|0)>>2]}gb=c+16|0;return b}Sc();L()}function bx(a,b){var c=0,d=0;c=gb-16|0;gb=c;v[c+12>>2]=b;d=b;b=nG(a);if(d>>>0<=b>>>0){a=ug(a);if(a>>>0<b>>>1>>>0){v[c+8>>2]=a<<1;b=v[Lc(c+8|0,c+12|0)>>2]}gb=c+16|0;return b}Sc();L()}function Vk(a,b){var c=0,d=0;c=gb-16|0;gb=c;v[c+12>>2]=b;d=b;b=jF(a);if(d>>>0<=b>>>0){a=Pg(a);if(a>>>0<b>>>1>>>0){v[c+8>>2]=a<<1;b=v[Lc(c+8|0,c+12|0)>>2]}gb=c+16|0;return b}Sc();L()}function OL(a,b,c,d,e){a=a|0;b=b|0;c=+c;d=d|0;e=e|0;var f=0,g=0;f=gb-16|0;gb=f;v[f+8>>2]=v[a+8>>2];g=v[a+4>>2];v[f>>2]=v[a>>2];v[f+4>>2]=g;c=NL(f,b,c,d,e,0,0,0,0);gb=f+16|0;return+c}function O0(){var a=0;a:{if(t[465416]&1){break a}if(!Qd(465416)){break a}a=465392;while(1){a=Kb(a)+12|0;if((a|0)!=465416){continue}break}Pd(465416)}Xc(465392,11162);Xc(465404,11141)}function L0(){var a=0;a:{if(t[465448]&1){break a}if(!Qd(465448)){break a}a=465424;while(1){a=Kb(a)+12|0;if((a|0)!=465448){continue}break}Pd(465448)}ld(465424,86544);ld(465436,86556)}function Iv(a){var b=0,c=0;b=gb-16|0;gb=b;u[b+14>>1]=a;v[22656]=0;u[b+12>>1]=255;a=Pc(b+14|0,b+12|0);c=v[22656];v[22656]=0;if((c|0)!=1){gb=b+16|0;return w[a|0]}V(0)|0;O()|0;Bb();L()}function IC(a,b){var c=0,d=0;c=gb-16|0;gb=c;v[c+12>>2]=b;d=b;b=MW(a);if(d>>>0<=b>>>0){a=Yj(a);if(a>>>0<b>>>1>>>0){v[c+8>>2]=a<<1;b=v[Lc(c+8|0,c+12|0)>>2]}gb=c+16|0;return b}Sc();L()}function Dma(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;if(EV()>>>0<b>>>0){Sc();L()}c=b;if(c>>>0>=178956971){rd(8445);L()}c=Mc(B(c,24),4);v[a>>2]=c;v[a+4>>2]=c;d=wb(a),e=c+B(b,24)|0,v[d>>2]=e}function yN(a,b){var c=0,d=0;c=gb-16|0;gb=c;v[c+12>>2]=b;d=b;b=vN();if(d>>>0<=b>>>0){a=qk(a);if(a>>>0<b>>>1>>>0){v[c+8>>2]=a<<1;b=v[Lc(c+8|0,c+12|0)>>2]}gb=c+16|0;return b}Sc();L()}function roa(a,b){a=a|0;b=b|0;var c=0;c=gb-32|0;gb=c;v[c+24>>2]=0;v[c+28>>2]=0;v[c+16>>2]=0;v[c+20>>2]=0;v[c+8>>2]=0;v[c+12>>2]=0;v[c>>2]=0;v[c+4>>2]=0;kX(b,c,32);jX(a,c);gb=c+32|0}function lr(a,b){var c=0,d=0;c=gb-16|0;gb=c;v[c+12>>2]=b;d=b;b=np();if(d>>>0<=b>>>0){a=pe(a);if(a>>>0<b>>>1>>>0){v[c+8>>2]=a<<1;b=v[Lc(c+8|0,c+12|0)>>2]}gb=c+16|0;return b}Sc();L()}function hs(a,b){var c=0,d=0;c=gb-16|0;gb=c;v[c+12>>2]=b;d=b;b=Lw();if(d>>>0<=b>>>0){a=tg(a);if(a>>>0<b>>>1>>>0){v[c+8>>2]=a<<1;b=v[Lc(c+8|0,c+12|0)>>2]}gb=c+16|0;return b}Sc();L()}function ho(a){var b=0,c=0;b=gb-16|0;gb=b;a:{if(vK(a)){break a}v[22656]=0;R(2111,b+8|0,a|0);c=v[22656];v[22656]=0;if((c|0)!=1){break a}V(0)|0;O()|0;Bb();L()}t[a+20|0]=255;gb=b+16|0}function fy(a,b){var c=0,d=0;c=gb-16|0;gb=c;v[c+12>>2]=b;d=b;b=FI();if(d>>>0<=b>>>0){a=xi(a);if(a>>>0<b>>>1>>>0){v[c+8>>2]=a<<1;b=v[Lc(c+8|0,c+12|0)>>2]}gb=c+16|0;return b}Sc();L()}function _q(a,b){var c=0,d=0;c=gb-16|0;gb=c;v[c+12>>2]=b;d=b;b=zT();if(d>>>0<=b>>>0){a=bi(a);if(a>>>0<b>>>1>>>0){v[c+8>>2]=a<<1;b=v[Lc(c+8|0,c+12|0)>>2]}gb=c+16|0;return b}Sc();L()}function V_(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=gb-16|0;gb=d;v[d+12>>2]=c;c=0;a=kb[v[v[a>>2]+24>>2]](a)|0;if(a>>>0>b>>>0){v[d+8>>2]=a-b;c=v[Fb(d+12|0,d+8|0)>>2]}gb=d+16|0;return c|0}function TO(a,b){a=a|0;b=b|0;var c=0;c=gb-16|0;gb=c;PO(c,b+80|0);v[22656]=0;U(13,a|0,0,c|0);a=v[22656];v[22656]=0;if((a|0)!=1){vb(c);gb=c+16|0;return}a=P()|0;O()|0;vb(c);S(a|0);L()}function SL(a,b){var c=0,d=0,e=0;if(a>C(.9999989867210388)){d=0}else{a=C(a*a);e=+a;c=Me(31415.926535897932/+b);d=Ro(32768/(1-e)*(1-(c*e+K((1-c)*+C(a+a)-(1-c*c)*+C(a*a)))))}return d}function Qs(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=gb-16|0;gb=e;v[e+12>>2]=d;d=Ab(b);if(d>>>0<c>>>0){Qn();L()}b=Jb(b);v[e+4>>2]=d-c;zs(a,b+c|0,v[Fb(e+12|0,e+4|0)>>2]);gb=e+16|0}function OQ(a){var b=0;b=v[a>>2];v[a>>2]=0;if(b){a:{b:{if(w[fc(a)+4|0]){v[22656]=0;a=v[22656];v[22656]=0;if((a|0)==1){break b}Sm(b+16|0)}if(b){MA(b)}break a}V(0)|0;O()|0;Bb();L()}}}function ON(a){var b=0;a:{if((w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24))!=1179012417){b=0;if((w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24))!=538987841){break a}}b=1}return b}function K7(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;if((a|0)!=(b|0)){d=v[c>>2];while(1){v[d>>2]=v[a>>2];gg(d+4|0,a+4|0);d=v[c>>2]+16|0;v[c>>2]=d;a=a+16|0;if((b|0)!=(a|0)){continue}break}}}function JO(a){a=a|0;var b=0;b=1;a=v[a+480180>>2];a:{b:{if((a|0)<=16383){if((a|0)==4|(a|0)!=32){break b}break a}if((a|0)==16384){break b}if((a|0)==16777216){break a}}b=2}return b|0}function sS(a,b,c,d){var e=0;e=gb-16|0;gb=e;d=li(e,a,d);a=wb(a);v[22656]=0;iS(a,b,c,d+4|0);a=v[22656];v[22656]=0;if((a|0)!=1){$b(d);gb=e+16|0;return}a=P()|0;O()|0;$b(d);S(a|0);L()}function Wy(a){a=a|0;var b=0;a:{if(!a){a=ba(8)|0;v[22656]=0;T(1947,a|0)|0;b=v[22656];v[22656]=0;if((b|0)!=1){break a}b=P()|0;O()|0;ca(a|0);S(b|0);L()}return}ia(a|0,54792,1936);L()}function GL(a){a=a|0;var b=0;a:{if(!a){a=ba(8)|0;v[22656]=0;T(1935,a|0)|0;b=v[22656];v[22656]=0;if((b|0)!=1){break a}b=P()|0;O()|0;ca(a|0);S(b|0);L()}return}ia(a|0,54736,1936);L()}function Bn(a){var b=0,c=0;b=gb-16|0;gb=b;v[b+12>>2]=a;v[22656]=0;v[b+8>>2]=255;a=Fb(b+12|0,b+8|0);c=v[22656];v[22656]=0;if((c|0)!=1){gb=b+16|0;return w[a|0]}V(0)|0;O()|0;Bb();L()}function rJ(a,b){var c=0,d=0,e=0,f=C(0),g=C(0),h=0;h=a+2304|0;while(1){c=d<<2;e=c+a|0;f=z[e>>2];c=c+h|0;g=z[c>>2];z[e>>2]=f+g;z[c>>2]=f-g;d=d+1|0;if((d|0)!=(b|0)){continue}break}}function mW(a,b){var c=0;c=w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24);t[a|0]=c;t[a+1|0]=c>>>8;t[a+2|0]=c>>>16;t[a+3|0]=c>>>24;b=w[b+4|0]|w[b+5|0]<<8;t[a+4|0]=b;t[a+5|0]=b>>>8}function ZG(a){a=a|0;var b=0,c=0,d=0;v[a>>2]=81272;b=a+8|0;if(Nb(b)){while(1){d=v[Mb(b,c)>>2];if(d){Nn(d)}c=c+1|0;if(Nb(b)>>>0>c>>>0){continue}break}}vb(a+152|0);wx(b);return a|0}function nj(a,b){var c=0,d=0;c=gb-16|0;gb=c;if(De(a)){ai(a,v[a>>2],gk(a))}v[a+8>>2]=v[b+8>>2];d=v[b+4>>2];v[a>>2]=v[b>>2];v[a+4>>2]=d;_e(b,0);v[c+12>>2]=0;Ge(b,c+12|0);gb=c+16|0}function IS(a,b){var c=0;c=w[a+800|0];a:{if(c){break a}c=Xi(w[a+797|0]-u[a+770>>1]|0);if(!b|(!v[a+656>>2]|!c|c>>>0>=129)){break a}c=w[ic(v[a+656>>2]+108|0,c-1|0)|0]}return c&255}function qz(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=gb-16|0;gb=e;d=Br(e,a,d);wb(a);a=c-b|0;if((a|0)>0){hc(v[d+4>>2],b,a);v[d+4>>2]=v[d+4>>2]+B((a>>>0)/6|0,6)}$b(d);gb=e+16|0}function p4(a){a=a|0;var b=0,c=0;b=gb-16|0;gb=b;jT(b,0,a);v[22656]=0;a=T(143,b|0)|0;c=v[22656];v[22656]=0;if((c|0)!=1){vb(b);gb=b+16|0;return a|0}a=P()|0;O()|0;vb(b);S(a|0);L()}function i0(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=gb-16|0;gb=d;e=d+8|0;kb[v[v[a>>2]+12>>2]](e,a,b);if(Ie(v[e+4>>2],v[c+4>>2])){a=v[e>>2]==v[c>>2]}else{a=0}gb=d+16|0;return a|0}function Vy(a,b){var c=0,d=0;c=gb-16|0;gb=c;u[b>>1]=0;t[c+15|0]=0;Uh(a,c+15|0);d=w[c+15|0];u[b>>1]=d>>>1;if(d&1){t[c+15|0]=0;Uh(a,c+15|0);u[b>>1]=x[b>>1]|w[c+15|0]<<7}gb=c+16|0}function UU(a){var b=0,c=0;a:{if((w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24))!=441273424|w[a+5|0]!=16){break a}b=a+54|0;if(!w[b|0]|w[b|0]>32){break a}c=w[a+4|0]>95}return c}function LX(a){var b=0;a:{if((w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24))!=-28163770){break a}if(sd(a+44|0,14921,3)){break a}a=a+47|0;b=(w[a|0]|w[a+1|0]<<8)>>>0>97}return b}function Eb(a,b){var c=0,d=0;c=gb-16|0;gb=c;if(De(a)){al(a,v[a>>2],gk(a))}v[a+8>>2]=v[b+8>>2];d=v[b+4>>2];v[a>>2]=v[b>>2];v[a+4>>2]=d;_e(b,0);t[c+15|0]=0;Bd(b,c+15|0);gb=c+16|0}function y4(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;a=0;if((b|0)!=(c|0)){while(1){a=v[b>>2]+(a<<4)|0;d=a&-268435456;a=(d|d>>>24)^a;b=b+4|0;if((c|0)!=(b|0)){continue}break}}return a|0}function xN(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=65535;a:{if(!me(a,b)){break a}c=nz(a,v[bf(a,b)+12>>2],c);d=65535;if((c|0)==65535){break a}b=bf(a,b);IN(bf(a,c),b);d=c}return d|0}function qea(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=gb-16|0;gb=d;e=x[a+28>>1];u[d+8>>1]=e;f=d,g=(Nb(a+4|0)+e|0)-1|0,u[f+10>>1]=g;a=oN(a,b,c,d+8|0);gb=d+16|0;return a|0}function fpa(a,b){a=a|0;b=b|0;if(!ZX(a,b)){t[b|0]=0;t[b+1|0]=0;t[b+2|0]=0;t[b+3|0]=0;t[b+4|0]=0;t[b+5|0]=0;t[b+6|0]=0;t[b+7|0]=0;t[b+8|0]=0;t[b+9|0]=0;t[b+10|0]=0;t[b+11|0]=0}}function W6(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=gb-16|0;gb=d;v[d+12>>2]=c;zy(a,b,c);c=0;a=v[a+16>>2];if(a>>>0>b>>>0){v[d+8>>2]=a-b;c=v[Fb(d+8|0,d+12|0)>>2]}gb=d+16|0;return c|0}function QC(a,b){var c=0;a:{if(b){QC(a,v[b>>2]);QC(a,v[b+4>>2]);a=fc(a);v[22656]=0;c=v[22656];v[22656]=0;if((c|0)==1){break a}Gk(b+16|0);Yk(a,b,1)}return}V(0)|0;O()|0;Bb();L()}function Kq(a,b){var c=0;a:{if(b){Kq(a,v[b>>2]);Kq(a,v[b+4>>2]);a=fc(a);v[22656]=0;c=v[22656];v[22656]=0;if((c|0)==1){break a}jR(b+16|0);ls(a,b,1)}return}V(0)|0;O()|0;Bb();L()}function G7(a,b){a=a|0;b=b|0;var c=0,d=0;c=gb-16|0;gb=c;d=v[13850];v[c+8>>2]=v[13849];v[c+12>>2]=d;d=v[13848];v[c>>2]=v[13847];v[c+4>>2]=d;kb[v[Rh(c,Yg(b))>>2]](a,b);gb=c+16|0}function pi(a,b){var c=0,d=0,e=0;c=gb-16|0;gb=c;d=c,e=ce(b),v[d+12>>2]=e;v[22656]=0;ff(a,c+12|0,b);b=v[22656];v[22656]=0;if((b|0)!=1){gb=c+16|0;return a}V(0)|0;O()|0;Bb();L()}function fR(a,b,c,d){var e=0,f=0;e=gb-16|0;gb=e;if(c){a=wb(a);while(1){f=Nl(a,c+16|0,b);d=f?d:c;c=v[(f?4:0)+c>>2];if(c){continue}break}}a=v[yc(e+8|0,d)>>2];gb=e+16|0;return a}function PA(a,b){var c=0,d=0;c=gb-16|0;gb=c;d=c+8|0;Eg(d,b);v[22656]=0;a=wB(a,d);b=v[22656];v[22656]=0;a:{if((b|0)!=1){gb=c+16|0;break a}V(0)|0;O()|0;Bb();L()}return a>>>31|0}function B4(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;a=0;if((b|0)!=(c|0)){while(1){a=t[b|0]+(a<<4)|0;d=a&-268435456;a=(d|d>>>24)^a;b=b+1|0;if((c|0)!=(b|0)){continue}break}}return a|0}function Up(a){var b=0,c=0;b=v[22654];c=a+3&-4;a=b+c|0;a:{if(a>>>0<=b>>>0?c:0){break a}if(dx()>>>0<a>>>0){if(!(va(a|0)|0)){break a}}v[22654]=a;return b}v[115137]=48;return-1}function Kt(a){var b=0,c=0,d=0;if(v[a>>2]){d=a;b=v[a+4>>2];c=v[a>>2];if((b|0)!=(c|0)){while(1){b=b-16|0;Gk(b);if((b|0)!=(c|0)){continue}break}}v[d+4>>2]=c;CK(v[a>>2],xi(a))}}function KU(a){var b=0,c=0,d=0;if(v[a>>2]){d=a;b=v[a+4>>2];c=v[a>>2];if((b|0)!=(c|0)){while(1){b=b-56|0;dv(b);if((b|0)!=(c|0)){continue}break}}v[d+4>>2]=c;av(v[a>>2],HU(a))}}function fma(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=gb-32|0;gb=d;HF(b,c);if(Pb(a,c<<3)){GF(d+24|0,b);b=v[d+28>>2];v[d+8>>2]=v[d+24>>2];v[d+12>>2]=b;kd(d+16|0,a,d+8|0)}gb=d+32|0}function $5(a,b){a=a|0;b=b|0;var c=0,d=0;c=gb-16|0;gb=c;d=v[b+4>>2];b=v[b>>2];v[c>>2]=b;v[c+4>>2]=d;v[c+8>>2]=b;v[c+12>>2]=d;EG(a,c,6074);v[a>>2]=74356;gb=c+16|0;return a|0}function ur(a){var b=0,c=0;c=v[a+4>>2];b=v[c>>2];v[a+4>>2]=b;if(b){gp(b,a)}v[c+8>>2]=v[a+8>>2];a:{if(ng(a)){b=v[a+8>>2];break a}b=v[a+8>>2]+4|0}v[b>>2]=c;v[c>>2]=a;gp(a,c)}function tr(a){var b=0,c=0;c=v[a>>2];b=v[c+4>>2];v[a>>2]=b;if(b){gp(b,a)}v[c+8>>2]=v[a+8>>2];a:{if(ng(a)){b=v[a+8>>2];break a}b=v[a+8>>2]+4|0}v[b>>2]=c;v[c+4>>2]=a;gp(a,c)}function lna(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=gb-16|0;gb=c;v[c+8>>2]=b;d=c,e=Vb(a),v[d>>2]=e;b=rv(c+8|0,c);b=v[a>>2]+(b<<2)|0;hj(a,Rg(b+4|0,v[a+4>>2],b));Hg(b);gb=c+16|0}function Wp(a,b){var c=0,d=0,e=0;c=0;a:{if(!a){break a}d=kqa(a,0,b,0);e=jb;c=d;if((a|b)>>>0<65536){break a}c=e?-1:d}b=c;a=Cd(b);if(!(!a|!(w[a-4|0]&3))){Qb(a,0,b)}return a}function Qha(a,b){a=a|0;b=b|0;var c=0;c=dd(a);t[a+16|0]=0;v[a+12>>2]=b;v[22656]=0;_(1088,a|0);b=v[22656];v[22656]=0;if((b|0)!=1){return a|0}a=P()|0;O()|0;Ju(c);S(a|0);L()}function DE(a){var b=0,c=0;a:{if(sd(a,11426,3)){break a}b=a+3|0;if(w[b|0]<=7&w[b|0]!=1|w[b|0]>14){break a}a=a+40|0;if(!(w[a|0]<33?w[a|0]:0)&w[b|0]>8){break a}c=1}return c}function W_(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;a=kb[v[v[a>>2]+24>>2]](a)|0;a:{if((a|0)==(b|0)){d=1;if(!c){break a}}d=0;if(a>>>0<=b>>>0){break a}d=a-b>>>0>=c>>>0}return d|0}function J1(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;if((b|0)!=(c|0)){while(1){a=v[b>>2];t[e|0]=a>>>0<128?a:d;e=e+1|0;b=b+4|0;if((c|0)!=(b|0)){continue}break}}return c|0}function FT(a){var b=0;if(v[a>>2]){Od(a);b=v[a>>2];a=(v[wb(a)>>2]-v[a>>2]|0)/872|0;v[22656]=0;Oc(b,B(a,872),8);a=v[22656];v[22656]=0;if((a|0)==1){V(0)|0;O()|0;Bb();L()}}}function Bm(a){a=a<<8&16711680|a<<24|(a>>>8&65280|a>>>24);a=a>>>4&252645135|(a&252645135)<<4;a=a>>>2&858993459|(a&858993459)<<2;return a>>>1&1431655765|(a&1431655765)<<1}function uW(a){var b=0,c=0,d=0;b=a;c=v[a+8>>2];d=v[a+4>>2];if((c|0)!=(d|0)){v[b+8>>2]=B(((c-d|0)-33>>>0)/33^-1,33)+c}b=v[a>>2];if(b){tW(b,(v[dc(a)>>2]-v[a>>2]|0)/33|0)}}function fv(a){var b=0,c=0,d=0;d=a+32|0;a:{while(1){c=w[a|0];if(!((c-1&255)>>>0<31|((b^1)&1?0:c))){b=!c|b;a=a+1|0;if((d|0)!=(a|0)){continue}break a}break}b=0}return b&1}function DW(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=gb-16|0;gb=d;if((b|0)!=(c|0)){while(1){v[d+12>>2]=v[b>>2];fD(a,d+12|0);b=b+4|0;if((c|0)!=(b|0)){continue}break}}gb=d+16|0}function CA(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;v[b+56>>2]=0;d=b,e=Qm(a,x[b+70>>1],v[b+48>>2],c,0),u[d+68>>1]=e;if(!(!(v[a+480180>>2]&5)|v[b+60>>2]==-1)){v[b+60>>2]=0}}function Al(a,b,c){var d=0,e=0;e=gb-16|0;gb=e;d=e+8|0;Bl(d,a+24|0,b);a=v[d+4>>2];a:{if(c){b=v[d>>2];v[b>>2]=a|v[b>>2];break a}b=v[d>>2];v[b>>2]=v[b>>2]&(a^-1)}gb=e+16|0}function sJ(a){var b=0,c=0;a:{if(w[a|0]!=255){break a}b=w[a+1|0];if((b&240)!=240&(b&254)!=226|!(b&6)){break a}a=w[a+2|0];if((a&240)==240){break a}c=(a&12)!=12}return c}function qt(a){var b=0,c=0;b=a;a:{if((Ne(b)|0)!=79){break a}if((Ne(b)|0)!=103){break a}if((Ne(b)|0)!=103){break a}c=(Ne(b)|0)==83}if(!c){ec(a,30);return 0}return hJ(a)}function mea(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=gb-16|0;gb=c;d=c,e=Ti(v[b>>2]),v[d+12>>2]=e;v[c+8>>2]=0;d=a,e=v[dj(c+12|0,c+8|0,49672)>>2],v[d+36>>2]=e;nq(a);gb=c+16|0}function k_(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=gb-16|0;gb=d;v[a>>2]=0;v[a+4>>2]=0;v[d+12>>2]=0;ff(a+8|0,d+12|0,d+8|0);if(b){Yr(a,b);$E(a,b,w[c|0])}gb=d+16|0;return a|0}function jma(a,b){a=a|0;b=b|0;var c=0;a:{if(a>>>0>=515){a=sg(b);sg(b);break a}a=Og(b);Og(b)}if(a){while(1){if(a&1){Rb(b,260)}c=a>>>0>1;a=a>>>1|0;if(c){continue}break}}}function Y5(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=a;a=b+28|0;d=_p(d,a);YG(a,c);v[22656]=0;R(2293,b|0,1);a=v[22656];v[22656]=0;if((a|0)==1){a=P()|0;O()|0;Wb(d);S(a|0);L()}}function KK(a,b){a=a|0;b=b|0;var c=0;c=-1;a:{if((b|0)<0){break a}a=a+24|0;if(Ri(Sb(v[a>>2]+484360|0))>>>0<=b>>>0){break a}c=x[sc(Sb(v[a>>2]+484360|0),b)>>1]}return c|0}function Gc(a,b){var c=0,d=0;c=gb-16|0;gb=c;if(v[a+4>>2]==v[b+4>>2]){d=v[b+4>>2];b=v[b>>2];v[c>>2]=b;v[c+4>>2]=d;v[c+8>>2]=b;v[c+12>>2]=d;d=!HW(a,c)}gb=c+16|0;return d}function B1(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;if((b|0)!=(c|0)){while(1){a=t[b|0];t[e|0]=(a|0)>=0?a:d;e=e+1|0;b=b+1|0;if((c|0)!=(b|0)){continue}break}}return c|0}function sba(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0;if(b){f=v[b+24>>2];g=v[b+8>>2];h=v[b+4>>2];i=v[b>>2];e=v[b+12>>2]}else{e=0}QL(a,i,h,g,e,f,b,c,d)}function Gj(a,b,c){var d=0;d=v[b+4>>2];v[a>>2]=v[b>>2];v[a+4>>2]=d;d=v[b+12>>2];v[a+8>>2]=v[b+8>>2];v[a+12>>2]=d;A[a>>3]=A[a>>3]-A[c>>3];A[a+8>>3]=A[a+8>>3]-A[c+8>>3]}function BG(a,b,c,d){var e=0,f=0,g=0;f=v[a+4>>2];e=0;a:{if(!c){break a}g=f>>8;e=g;if(!(f&1)){break a}e=hx(v[c>>2],g)}a=v[a>>2];kb[v[v[a>>2]+28>>2]](a,b,c+e|0,f&2?d:2)}function zZ(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=gb-16|0;gb=d;v[d+12>>2]=c;c=0;if(Ng(a,d+8|0)){v[d+4>>2]=w[d+8|0];c=SD(a,b,v[Fb(d+4|0,d+12|0)>>2])}gb=d+16|0;return c|0}function sf(a){a=a|0;var b=0;a=a?a:1;a:{while(1){b=Cd(a);if(!b){b=v[116505];if(!b){break a}kb[b|0]();continue}break}return b|0}a=ba(4)|0;nm(a);ia(a|0,89116,1928);L()}function dE(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=gb-16|0;gb=d;v[d+12>>2]=c;c=0;if(Ng(a,d+8|0)){v[d+4>>2]=w[d+8|0];c=TD(a,b,v[Fb(d+4|0,d+12|0)>>2])}gb=d+16|0;return c|0}function VB(a){var b=0;if(v[a>>2]){Od(a);b=v[a>>2];a=(v[wb(a)>>2]-v[a>>2]|0)/9|0;v[22656]=0;Oc(b,B(a,9),1);a=v[22656];v[22656]=0;if((a|0)==1){V(0)|0;O()|0;Bb();L()}}}function TT(a){if((w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24))==1299020115){a=a+4|0;a=(Xb(w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24))|0)==1}else{a=0}return a}function Jma(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;a:{d=mc(a+8|0);v[22656]=0;U(393,a|0,b|0,c|0);a=v[22656];v[22656]=0;if((a|0)!=1){break a}a=P()|0;O()|0;gc(d);S(a|0);L()}}function B_(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=gb-16|0;gb=d;v[d+12>>2]=c;c=0;a=v[a+16>>2];if(a>>>0>b>>>0){v[d+8>>2]=a-b;c=v[Fb(d+12|0,d+8|0)>>2]}gb=d+16|0;return c|0}function i6(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=gb-16|0;gb=e;a=ht(Qa(v[a+60>>2],b|0,c|0,d&255,e+8|0)|0);gb=e+16|0;jb=a?-1:v[e+12>>2];return(a?-1:v[e+8>>2])|0}function Zi(a,b){var c=0;c=v[b+4>>2];b=v[b>>2];t[a|0]=b;t[a+1|0]=b>>>8;t[a+2|0]=b>>>16;t[a+3|0]=b>>>24;b=c;t[a+4|0]=b;t[a+5|0]=b>>>8;t[a+6|0]=b>>>16;t[a+7|0]=b>>>24}function X_(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=gb-16|0;gb=d;v[d+12>>2]=c;c=0;a=v[a+8>>2];if(a>>>0>b>>>0){v[d+8>>2]=a-b;c=v[Fb(d+12|0,d+8|0)>>2]}gb=d+16|0;return c|0}function X6(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;zy(a,b,c);a=v[a+16>>2];a:{if((a|0)==(b|0)){d=1;if(!c){break a}}d=0;if(a>>>0<=b>>>0){break a}d=a-b>>>0>=c>>>0}return d|0}function UQ(a){var b=0,c=0,d=0;b=a;c=v[a+8>>2];d=v[a+4>>2];if((c|0)!=(d|0)){v[b+8>>2]=B(((c-d|0)-7>>>0)/7^-1,7)+c}b=v[a>>2];if(b){MQ(b,(v[dc(a)>>2]-v[a>>2]|0)/7|0)}}function Rx(a,b){var c=0;c=ju(a+4|0);v[a>>2]=74724;v[c>>2]=74744;v[22656]=0;R(2396,c|0,b|0);a=v[22656];v[22656]=0;if((a|0)!=1){return}a=P()|0;O()|0;oh(c);S(a|0);L()}function RS(a){var b=0,c=0;a:{if(w[a|0]!=255){break a}b=w[a+1|0];if((b&224)!=224|(b&24)==8|!(b&6)){break a}a=w[a+2|0];if((a&12)==12){break a}c=(a&240)!=240}return c}function Qx(a,b){var c=0;c=_H(a+4|0);v[a>>2]=74772;v[c>>2]=74792;v[22656]=0;R(2397,c|0,b|0);a=v[22656];v[22656]=0;if((a|0)!=1){return}a=P()|0;O()|0;oh(c);S(a|0);L()}function Qfa(a,b){a=a|0;b=b|0;var c=0;c=gb-16|0;gb=c;v[22656]=0;a=Q(1314,a|0,b|0)|0;b=v[22656];v[22656]=0;if((b|0)!=1){gb=c+16|0;return a|0}a=P()|0;O()|0;S(a|0);L()}function PU(a){if(!((w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24))!=541938512|(w[a+8|0]|w[a+9|0]<<8|(w[a+10|0]<<16|w[a+11|0]<<24))!=1162627398)){return 1}return 0}function Ee(a,b){var c=0;c=v[a>>2];v[a>>2]=b;a:{if(!c){break a}a=v[fc(a)>>2];v[22656]=0;_(a|0,c|0);a=v[22656];v[22656]=0;if((a|0)!=1){break a}V(0)|0;O()|0;Bb();L()}}function uI(a,b){var c=0,d=0,e=0,f=0;c=v[a+24>>2];if((c|0)==v[a+28>>2]){return e=a,f=Mg(b),d=v[v[a>>2]+52>>2],kb[d](e|0,f|0)|0}v[a+24>>2]=c+1;t[c|0]=b;return Mg(b)}function XP(a,b,c,d){var e=0,f=0,g=0,h=0;f=a;a:{b:{e=c-b|0;if((e|0)<=2){if((IA(d)|0)>(e|0)){break b}}g=a,h=HA(d,b),v[g>>2]=h;a=0;break a}v[a>>2]=c;a=61}v[f+4>>2]=a}function JA(a,b,c,d){var e=0,f=0,g=0,h=0;f=a;a:{b:{e=c-b|0;if((e|0)<=9){if((IA(d)|0)>(e|0)){break b}}g=a,h=HA(d,b),v[g>>2]=h;a=0;break a}v[a>>2]=c;a=61}v[f+4>>2]=a}function AA(a,b,c,d){var e=0,f=0,g=0,h=0;f=a;a:{b:{e=c-b|0;if((e|0)<=4){if((IA(d)|0)>(e|0)){break b}}g=a,h=HA(d,b),v[g>>2]=h;a=0;break a}v[a>>2]=c;a=61}v[f+4>>2]=a}function op(a,b){var c=0,d=0,e=0;Hv(a);lp(a,b);v[a>>2]=v[b>>2];v[a+4>>2]=v[b+4>>2];c=v[wb(b)>>2];d=wb(a),e=c,v[d>>2]=e;d=wb(b),e=0,v[d>>2]=e;v[b>>2]=0;v[b+4>>2]=0}function fu(a,b){a=a|0;b=b|0;v[a+20>>2]=0;v[a+24>>2]=b;v[a+12>>2]=0;v[a+4>>2]=4098;v[a+8>>2]=6;v[a+16>>2]=!b;Qb(a+32|0,0,40);vx(a+28|0);v[a+72>>2]=0;v[a+76>>2]=-1}function Rb(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=Pb(a,b);if(c){v[a+8>>2]=v[a+8>>2]+b;return c|0}b=a;a=v[a>>2];d=b,e=kb[v[v[a>>2]+24>>2]](a)|0,v[d+8>>2]=e;return c|0}function OB(a){v[a>>2]=0;v[a+4>>2]=0;v[a+88>>2]=0;v[a+8>>2]=0;v[a+12>>2]=0;ER(a+112|0,48e3);v[a+668>>2]=0;NB(a+724|0);NB(a+732|0);NB(a+740|0);bj(a+788|0);return a}function DX(a){var b=0,c=0;c=kqa(w[a+217|0],0,9,0);b=w[a+216|0];a=b>>>31|0;b=b<<1;c=c+b|0;a=a+jb|0;a=b>>>0>c>>>0?a+1|0:a;b=c+11|0;a=b>>>0<11?a+1|0:a;jb=a;return b}function BS(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;a=a+108|0;c=a+128|0;if((a|0)!=(c|0)){while(1){d=a,e=on(w[a|0]+b|0),t[d|0]=e;a=a+1|0;if((c|0)!=(a|0)){continue}break}}}function Aha(a,b){a=a|0;b=b|0;var c=0;c=zh(a);t[a+530|0]=0;v[22656]=0;R(1104,a|0,b|0);b=v[22656];v[22656]=0;if((b|0)!=1){return a|0}a=P()|0;O()|0;ln(c);S(a|0);L()}function $u(a,b){var c=0,d=0,e=0;wb(b);c=vh(a);v[a>>2]=v[b>>2];v[a+4>>2]=v[b+4>>2];a=v[wb(b)>>2];d=wb(c),e=a,v[d>>2]=e;d=wb(b),e=0,v[d>>2]=e;v[b>>2]=0;v[b+4>>2]=0}function Wq(a){v[a+8>>2]=0;v[a+12>>2]=0;v[a>>2]=128;v[a+4>>2]=256;v[a+32>>2]=363;v[a+36>>2]=952;v[a+16>>2]=48e3;v[a+20>>2]=2;v[a+24>>2]=128;v[a+28>>2]=0;return a}function NA(a,b){a:{if(b){NA(a,v[b>>2]);NA(a,v[b+4>>2]);fc(a);v[22656]=0;a=v[22656];v[22656]=0;if((a|0)==1){break a}Sm(b+16|0);MA(b)}return}V(0)|0;O()|0;Bb();L()}function F$(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=gb-16|0;gb=d;v[d+12>>2]=v[c>>2];a=kb[v[v[a>>2]+16>>2]](a,b,d+12|0)|0;if(a){v[c>>2]=v[d+12>>2]}gb=d+16|0;return a|0}function ama(a,b){a=a|0;b=b|0;var c=0,d=0;d=gb-80|0;gb=d;c=-1;a:{if(!xY(a,d+8|0)){break a}c=0;if(!bV(d+8|0)){break a}c=Oe(a,b,aV(d+8|0),jb)}gb=d+80|0;return c|0}function C2(){var a=0,b=0;a:{Xd(465504);v[116376]=81344;v[22656]=0;a=ga(2448)|0;b=v[22656];v[22656]=0;if((b|0)!=1){v[116378]=a;break a}a=P()|0;O()|0;S(a|0);L()}}function uT(a){var b=0,c=0,d=0;b=a;c=v[a+8>>2];d=v[a+4>>2];if((c|0)!=(d|0)){v[b+8>>2]=(((c-d|0)-256>>>8^-1)<<8)+c}b=v[a>>2];if(b){JB(b,v[dc(a)>>2]-v[a>>2]>>8)}}function b0(a,b,c){a=a|0;b=b|0;c=c|0;b=c;a:{if((c|0)>=257){FG();c=90608;break a}b:{if(t[466012]&1){break b}if(!Qd(466012)){break b}Pd(466012)}c=90604}td(a,b,c)}function Uj(a){var b=0,c=0;c=a;a=v[a>>2];b=v[a+4>>2];a:{if(!b){if(!ng(a)){while(1){a=v[a+8>>2];if(!ng(a)){continue}break}}a=v[a+8>>2];break a}a=SV(b)}v[c>>2]=a}function Roa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=mc(a);v[22656]=0;U(47,a|0,b|0,c|0);b=v[22656];v[22656]=0;if((b|0)!=1){return a|0}a=P()|0;O()|0;Nc(d);S(a|0);L()}function Be(a,b,c){a=a|0;b=b|0;c=c|0;t[a+11|0]=c;t[a+10|0]=b;t[a+12|0]=w[a+12|0]&251;u[a+8>>1]=65535;v[a>>2]=0;v[a+4>>2]=0;t[a+12|0]=w[a+12|0]&252|1;return a|0}function zF(a,b){a=a|0;b=b|0;var c=0,d=0;c=a;a=v[b>>2];d=zb((kb[v[v[a>>2]+20>>2]](a)|0)+v[b+8>>2]|0);a=v[b>>2];wd(c,d,(kb[v[v[a>>2]+24>>2]](a)|0)-v[b+8>>2]|0)}function p0(a,b){a=a|0;b=b|0;Fm(a);v[a>>2]=89156;b=Jb(b);v[22656]=0;Q(2808,a+4|0,b|0)|0;b=v[22656];v[22656]=0;if((b|0)!=1){return a|0}a=P()|0;O()|0;S(a|0);L()}function os(a,b){var c=0;c=gb-16|0;gb=c;v[c+12>>2]=b;v[22656]=0;ff(a,c+12|0,c+8|0);b=v[22656];v[22656]=0;if((b|0)!=1){gb=c+16|0;return a}V(0)|0;O()|0;Bb();L()}function HA(a,b){var c=0,d=0;a:{if(a>>>0<=99999999){a=by(b,a);break a}c=(a>>>0)/1e8|0;d=a-B(c,1e8)|0;a=(d>>>0)/1e4|0;a=vj(vj(NI(b,c),a),d-B(a,1e4)|0)}return a}function DV(a,b){var c=0;c=gb-32|0;gb=c;a:{if(!Wf(a,4)){EW(b);break a}zi(c+24|0,b);b=v[c+28>>2];v[c+8>>2]=v[c+24>>2];v[c+12>>2]=b;dC(c+16|0,a,c+8|0)}gb=c+32|0}function BK(a,b){var c=0;c=v[b+4>>2];v[a>>2]=v[b>>2];v[a+4>>2]=c;c=v[b+20>>2];v[a+16>>2]=v[b+16>>2];v[a+20>>2]=c;c=v[b+12>>2];v[a+8>>2]=v[b+8>>2];v[a+12>>2]=c}function AE(a,b){var c=0,d=0;c=gb-16|0;gb=c;a:{if(De(a)){d=v[a>>2];t[c+15|0]=0;Bd(b+d|0,c+15|0);de(a,b);break a}t[c+14|0]=0;Bd(a+b|0,c+14|0);_e(a,b)}gb=c+16|0}function ZL(a){a=a|0;var b=0;v[a+4240>>2]=0;v[a+4244>>2]=0;b=a+4264|0;v[b>>2]=0;v[b+4>>2]=0;b=a+4256|0;v[b>>2]=0;v[b+4>>2]=0;a=a+4248|0;v[a>>2]=0;v[a+4>>2]=0}function TB(a,b){var c=0,d=0,e=0,f=0;d=vh(a);v[a>>2]=v[b>>2];v[a+4>>2]=v[b+4>>2];c=wb(b);e=wb(d),f=v[c>>2],v[e>>2]=f;v[c>>2]=0;v[b>>2]=0;v[b+4>>2]=0;return a}function Ns(a){a=a|0;var b=0;b=ba(8)|0;v[22656]=0;Q(1981,b|0,a|0)|0;a=v[22656];v[22656]=0;if((a|0)!=1){ia(b|0,89464,206);L()}a=P()|0;O()|0;ca(b|0);S(a|0);L()}function Bda(a,b){a=a|0;b=b|0;var c=0;PM(a);c=b+4|0;Dk(wb(a),v[a>>2],v[a+4>>2],c);xc(a,c);xc(a+4|0,b+8|0);xc(wb(a),dc(b));v[b>>2]=v[b+4>>2];Vf(a);Dl(a);Dl(a)}function p3(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0;g=a;a=kb[v[v[a+8>>2]+20>>2]](a+8|0)|0;return jk(g,b,c,d,e,f,Jb(a),Jb(a)+(Ab(a)<<2)|0)|0}function T6(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;if((a|0)!=(b|0)){d=v[c>>2];while(1){$f(d,a);d=v[c>>2]+12|0;v[c>>2]=d;a=a+12|0;if((b|0)!=(a|0)){continue}break}}}function Av(a){var b=0,c=0;b=gb-16|0;gb=b;c=b+8|0;td(c,a,0);v[22656]=0;yp(c,117,0);a=v[22656];v[22656]=0;if((a|0)!=1){gb=b+16|0;return}V(0)|0;O()|0;Bb();L()}function rB(a,b,c,d,e){var f=0;if(d){while(1){z[b>>2]=C(v[a>>2])*e;z[c>>2]=C(v[a+4>>2])*e;c=c+4|0;a=a+8|0;b=b+4|0;f=f+1|0;if((f|0)!=(d|0)){continue}break}}}function hm(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=gb-16|0;gb=d;t[d+15|0]=b;t[d+14|0]=127;e=a,f=w[ac(d+15|0,d+14|0)|0]|(c?-128:0),t[e+21|0]=f;gb=d+16|0}function gm(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=gb-16|0;gb=d;t[d+15|0]=b;t[d+14|0]=127;e=a,f=w[ac(d+15|0,d+14|0)|0]|(c?-128:0),t[e+22|0]=f;gb=d+16|0}function ti(a){var b=0,c=0;b=a*a;c=b*a;return C(c*(b*b)*(b*2718311493989822e-21+-.00019839334836096632)+(c*(b*.008333329385889463+-.16666666641626524)+a))}function gA(a){var b=0;b=gb-16|0;gb=b;v[b+12>>2]=0;v[22656]=0;ff(a,b+12|0,b+8|0);a=v[22656];v[22656]=0;if((a|0)!=1){gb=b+16|0;return}V(0)|0;O()|0;Bb();L()}function X7(a,b,c){a=a|0;b=b|0;c=c|0;a:{b=gg(a,b);v[22656]=0;Q(69,a+12|0,c|0)|0;a=v[22656];v[22656]=0;if((a|0)!=1){break a}a=P()|0;O()|0;vb(b);S(a|0);L()}}function C_(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;a=v[a+16>>2];a:{if((a|0)==(b|0)){d=1;if(!c){break a}}d=0;if(a>>>0<=b>>>0){break a}d=a-b>>>0>=c>>>0}return d|0}function BA(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;a:{if(d>>>0>=64){d=-1;if(v[a+480180>>2]&2){break a}}v[b+56>>2]=0;d=Qm(a,x[b+70>>1],v[b+48>>2],c,0)}return d|0}function AS(a,b,c,d){v[d+8>>2]=b;v[d>>2]=0;v[d+4>>2]=0;v[c>>2]=d;if(v[v[a>>2]>>2]){v[a>>2]=v[v[a>>2]>>2]}$W(v[fc(a)>>2],v[c>>2]);a=wb(a);v[a>>2]=v[a>>2]+1}function yt(a){var b=0,c=0,d=0;c=v[a+4>>2];b=((c<<2)+(ww(v[a>>2],1)^270549120)|0)+2019860093|0;d=ww(b,16);v[a>>2]=b;b=a;a=B(d,5)+c|0;v[b+4>>2]=a;return a}function ry(a,b){var c=0;while(1){c=(b|0)<120?b:120;a=C(a*C(z[((c&3)<<2)+62832>>2]*C(1073741824>>>(c>>2)|0)));b=b-c|0;if((b|0)>0){continue}break}return a}function jg(a,b,c){a:{switch(b-1|0){case 0:if(c){return Jj(a,1)}return Jj(a,0);case 1:if(c){return Jj(a,3)}return Jj(a,2);default:break a}}return Jj(a,4)}function ch(a){a=C(a);var b=0;a=fe(a);b=255;a:{if(a>=C(255)){break a}b=0;if(a<=C(0)){break a}b=~~a>>>0;if(a<C(4294967296)&a>=C(0)){break a}b=0}return b|0}function Z5(a,b){a=a|0;b=b|0;var c=0,d=0;c=v[a+40>>2];if(c){while(1){c=c-1|0;d=c<<2;kb[v[v[a+32>>2]+d>>2]](b,a,v[d+v[a+36>>2]>>2]);if(c){continue}break}}}function Y_(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;a=v[a+8>>2];a:{if((a|0)==(b|0)){d=1;if(!c){break a}}d=0;if(a>>>0<=b>>>0){break a}d=a-b>>>0>=c>>>0}return d|0}function co(a,b){var c=0,d=0;b=b+7&-8;d=v[a+80>>2];a:{if(d){b=v[a+92>>2]-b|0;c=0;if((b|0)<v[a+88>>2]){break a}v[a+92>>2]=b;return b+d|0}c=Cd(b)}return c}function UI(a){var b=0,c=0,d=0;if(Qh(t[v[a>>2]])){while(1){b=v[a>>2];d=t[b|0];v[a>>2]=b+1;c=(B(c,10)+d|0)-48|0;if(Qh(t[b+1|0])){continue}break}}return c}function v3(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0;g=a;a=kb[v[v[a+8>>2]+20>>2]](a+8|0)|0;return kk(g,b,c,d,e,f,Jb(a),Jb(a)+Ab(a)|0)|0}function r1(a){a=a|0;var b=0;a=v[a+8>>2];if(!a){return 1}v[22656]=0;a=T(2548,a|0)|0;b=v[22656];v[22656]=0;if((b|0)!=1){return a|0}V(0)|0;O()|0;Bb();L()}function fU(a,b){a=a|0;b=b|0;var c=0,d=0;u[a+34>>1]=0;c=gb-16|0;gb=c;t[c+15|0]=0;d=a+43|0;Lo(d,d+22|0,c+15|0);gb=c+16|0;v[a+20>>2]=0;ud(a,b);return a|0}function d5(a,b){a=a|0;b=b|0;var c=0,d=0;b=Tx(b);v[a+36>>2]=b;c=a,d=yo(b),v[c+44>>2]=d;c=a,d=Zn(v[a+36>>2]),t[c+53|0]=d;if(v[a+44>>2]>=9){Ns(2655);L()}}function Wc(a,b){a=a|0;b=b|0;var c=0,d=0;a:{if(y[a+8>>2]<b>>>0){d=v[a>>2];c=0;if(kb[v[v[d>>2]+24>>2]](d)>>>0<b>>>0){break a}}v[a+8>>2]=b;c=1}return c|0}function QR(a){var b=0,c=0,d=0;b=a+26|0;c=w[b|0]+27|0;if(w[b|0]){while(1){c=w[(a+d|0)+27|0]+c|0;d=d+1|0;if(d>>>0<w[b|0]){continue}break}}return c&65535}function Lk(a,b,c,d){var e=0,f=0;e=B(b,c);f=e;a:{if(v[d+76>>2]<0){a=kD(a,e,d);break a}a=kD(a,e,d)}if((f|0)==(a|0)){return b?c:0}return(a>>>0)/(b>>>0)|0}function $4(a,b){a=a|0;b=b|0;var c=0,d=0;b=Px(b);v[a+36>>2]=b;c=a,d=yo(b),v[c+44>>2]=d;c=a,d=Zn(v[a+36>>2]),t[c+53|0]=d;if(v[a+44>>2]>=9){Ns(2655);L()}}function jr(a,b){a=a|0;b=b|0;var c=0;Fk(a);c=b+4|0;Dk(wb(a),v[a>>2],v[a+4>>2],c);xc(a,c);xc(a+4|0,b+8|0);xc(wb(a),dc(b));v[b>>2]=v[b+4>>2];dn(a,Nb(a))}function _y(a,b){a=a|0;b=b|0;var c=0;vt(a);c=b+4|0;Dk(wb(a),v[a>>2],v[a+4>>2],c);xc(a,c);xc(a+4|0,b+8|0);xc(wb(a),dc(b));v[b>>2]=v[b+4>>2];ut(a,oc(a))}function V7(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0;h=gb-32|0;gb=h;i=h+8|0;GK(i,b,c,d,e,f,g);Dc(a,h+20|0);Sm(i);gb=h+32|0}function Pd(a){var b=0,c=0,d=0,e=0;b=gb-16|0;gb=b;a=lx(b,a);c=gb-16|0;gb=c;d=v[yc(c+8|0,v[a+4>>2])>>2],e=1,t[d|0]=e;t[v[a+8>>2]]=1;gb=c+16|0;gb=b+16|0}function MG(a,b){a=a|0;b=b|0;Fm(a);v[a>>2]=89156;v[22656]=0;Q(2808,a+4|0,b|0)|0;b=v[22656];v[22656]=0;if((b|0)!=1){return a|0}a=P()|0;O()|0;S(a|0);L()}function Lj(a){var b=0;a=fe(a);b=-1;a:{if(a>=C(4294967296)){break a}b=0;if(a<=C(0)){break a}b=~~a>>>0;if(a<C(4294967296)&a>=C(0)){break a}b=0}return b}function JT(a){var b=0;a=ee(a);b=32767;a:{if(a>=32767){break a}b=-32768;if(a<=-32768){break a}b=~~a;if(D(a)<2147483648){break a}b=-2147483648}return b}function IE(a,b){a=a|0;b=b|0;var c=0;Fp(a);c=b+4|0;Dk(wb(a),v[a>>2],v[a+4>>2],c);xc(a,c);xc(a+4|0,b+8|0);xc(wb(a),dc(b));v[b>>2]=v[b+4>>2];$r(a,tc(a))}function Hk(a,b,c,d){v[d+8>>2]=b;v[d>>2]=0;v[d+4>>2]=0;v[c>>2]=d;b=a;d=v[v[a>>2]>>2];if(d){v[b>>2]=d}$W(v[fc(a)>>2],v[c>>2]);a=wb(a);v[a>>2]=v[a>>2]+1}function yca(a,b,c){a=a|0;b=b|0;c=C(c);var d=0;d=gb-16|0;gb=d;z[d+12>>2]=c;if((b|0)<=5){Hi(d+12|0);z[((b<<2)+a|0)+4208>>2]=z[d+12>>2];sM(a)}gb=d+16|0}function wba(a,b,c){a=a|0;b=b|0;c=C(c);var d=0;d=gb-16|0;gb=d;z[d+12>>2]=c;if((b|0)<=3){Hi(d+12|0);z[((b<<2)+a|0)+4208>>2]=z[d+12>>2];YL(a)}gb=d+16|0}function qca(a,b,c){a=a|0;b=b|0;c=C(c);var d=0;d=gb-16|0;gb=d;z[d+12>>2]=c;if((b|0)<=4){Hi(d+12|0);z[((b<<2)+a|0)+4208>>2]=z[d+12>>2];mM(a)}gb=d+16|0}function q0(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=Nf(b);d=sf(c+13|0);v[d+8>>2]=0;v[d+4>>2]=c;v[d>>2]=c;e=a,f=hc(d+12|0,b,c+1|0),v[e>>2]=f;return a|0}function l8(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;if(nG(a)>>>0<b>>>0){Sc();L()}c=mG(wb(a),b);v[a>>2]=c;v[a+4>>2]=c;d=wb(a),e=B(b,12)+c|0,v[d>>2]=e;ax(a,0)}function jo(a){var b=0;b=ba(8)|0;v[22656]=0;Q(126,b|0,a|0)|0;a=v[22656];v[22656]=0;if((a|0)!=1){ia(b|0,89396,24);L()}a=P()|0;O()|0;ca(b|0);S(a|0);L()}function e4(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;c=gb-16|0;gb=c;v[c+12>>2]=b;v[c+8>>2]=d;b=vi(c,c+12|0);a=NH(a,6419,v[c+8>>2]);hf(b);gb=c+16|0;return a|0}function cj(a,b){var c=0;c=v[v[b>>2]-12>>2];v[22656]=0;b=v[(b+c|0)+24>>2];c=v[22656];v[22656]=0;if((c|0)!=1){v[a>>2]=b;return a}V(0)|0;O()|0;Bb();L()}function Yr(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;if(WE(a)>>>0<b>>>0){Sc();L()}b=(b-1>>>5|0)+1|0;c=Si(wb(a),b);v[a+4>>2]=0;v[a>>2]=c;d=wb(a),e=b,v[d>>2]=e}function QO(a,b){var c=0,d=0;d=gb-32|0;gb=d;c=wb(a);c=xo(d+8|0,lr(a,Nb(a)+1|0),Nb(a),c);xq(v[c+8>>2],b);v[c+8>>2]=v[c+8>>2]+4;Zk(a,c);uO(c);gb=d+32|0}function LZ(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;if(lE(a)>>>0<b>>>0){Sc();L()}c=kE(wb(a),b);v[a>>2]=c;v[a+4>>2]=c;d=wb(a),e=B(b,20)+c|0,v[d>>2]=e;jE(a,0)}function Dba(a,b,c){a=a|0;b=b|0;c=C(c);var d=0;d=gb-16|0;gb=d;z[d+12>>2]=c;if((b|0)<=2){Hi(d+12|0);z[((b<<2)+a|0)+4208>>2]=z[d+12>>2];_L(a)}gb=d+16|0}function Cba(a){a=a|0;var b=0,c=C(0);t[a+4202|0]=1;b=a,c=Ho(C(C(C(C(wf(v[a+16>>2])>>>0)/C(3))+C(-80))/C(15920)),C(0),C(1)),z[b+4272>>2]=c;_L(a);ZL(a)}function yZ(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=gb-16|0;gb=d;v[d+12>>2]=c;if(Ng(a,d+8|0)){v[d+4>>2]=w[d+8|0];RD(a,b,v[Fb(d+4|0,d+12|0)>>2])}gb=d+16|0}function rd(a){var b=0;b=ba(8)|0;v[22656]=0;Q(23,b|0,a|0)|0;a=v[22656];v[22656]=0;if((a|0)!=1){ia(b|0,89344,24);L()}a=P()|0;O()|0;ca(b|0);S(a|0);L()}function pka(a,b){a=a|0;b=b|0;var c=0,d=0;d=gb-48|0;gb=d;c=-1;a:{if(!mU(a,d)){break a}c=0;if(!oT(d)){break a}c=Oe(a,b,nT(d),jb)}gb=d+48|0;return c|0}function lw(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;if(oC(a)>>>0<b>>>0){Sc();L()}c=Si(wb(a),b);v[a>>2]=c;v[a+4>>2]=c;d=wb(a),e=(b<<2)+c|0,v[d>>2]=e;dn(a,0)}function lla(a,b){a=a|0;b=b|0;var c=0,d=0;d=gb-96|0;gb=d;c=-1;a:{if(!VU(a,d)){break a}c=0;if(!sU(d)){break a}c=Oe(a,b,rU(d),jb)}gb=d+96|0;return c|0}function lC(a){var b=0,c=0;c=(w[a+24|0]>15)+(w[a+25|0]>64)|0;b=a+26|0;a=a+22|0;return c+(Ib(w[b|0]|w[b+1|0]<<8)>>>0>Ib(w[a|0]|w[a+1|0]<<8)<<1>>>0)|0}function iX(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;if(MW(a)>>>0<b>>>0){Sc();L()}c=LW(wb(a),b);v[a>>2]=c;v[a+4>>2]=c;d=wb(a),e=B(b,6)+c|0,v[d>>2]=e;KC(a,0)}function g2(){var a=0;a:{Xd(465720);v[22656]=0;T(2534,465728)|0;a=v[22656];v[22656]=0;if((a|0)!=1){v[116430]=84048;break a}a=P()|0;O()|0;S(a|0);L()}}function ela(a,b){a=a|0;b=b|0;var c=0,d=0;d=gb-48|0;gb=d;c=-1;a:{if(!mU(a,d)){break a}c=0;if(!lU(d)){break a}c=Oe(a,b,kU(d),jb)}gb=d+48|0;return c|0}function e2(){var a=0;a:{Xd(465736);v[22656]=0;T(2534,465744)|0;a=v[22656];v[22656]=0;if((a|0)!=1){v[116434]=84204;break a}a=P()|0;O()|0;S(a|0);L()}}function aC(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;if(jF(a)>>>0<b>>>0){Sc();L()}c=iF(wb(a),b);v[a>>2]=c;v[a+4>>2]=c;d=wb(a),e=(b<<1)+c|0,v[d>>2]=e;$r(a,0)}function TY(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=gb-16|0;gb=d;v[d+12>>2]=c;if(RE(a,d+8|0)){v[d+4>>2]=w[d+8|0];NY(a,b,v[Fb(d+4|0,d+12|0)>>2])}gb=d+16|0}function Se(a){var b=0,c=0;b=gb-16|0;gb=b;a:{if(De(a)){c=v[a>>2];t[b+15|0]=0;Bd(c,b+15|0);de(a,0);break a}t[b+14|0]=0;Bd(a,b+14|0);_e(a,0)}gb=b+16|0}function Nla(a,b){a=a|0;b=b|0;var c=0,d=0;d=gb-96|0;gb=d;c=-1;a:{if(!VU(a,d)){break a}c=0;if(!UU(d)){break a}c=Oe(a,b,TU(d),jb)}gb=d+96|0;return c|0}function OO(a){if(w[a+480224|0]==2){return+y[a+1074420>>2]/1e4}return+y[a+24620>>2]/(+y[a+1074404>>2]*+(B(v[a+1074408>>2],v[a+1074416>>2])>>>0))*60}function Kn(a,b){var c=0;v[a>>2]=27764;v[a>>2]=27616;c=v[b+8>>2];v[a+4>>2]=v[b+4>>2];v[a+8>>2]=c;t[a+16|0]=w[b+16|0];v[a+12>>2]=v[b+12>>2];return a}function H$(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;if(Sg(a,v[b+8>>2],f)){gx(b,c,d,e);return}a=v[a+8>>2];kb[v[v[a>>2]+20>>2]](a,b,c,d,e,f)}function BR(a){var b=0;if(v[a>>2]){eX(a);wb(a);b=v[a>>2];a=xi(a);v[22656]=0;Oc(b,a<<4,8);a=v[22656];v[22656]=0;if((a|0)==1){V(0)|0;O()|0;Bb();L()}}}function qV(a){return(w[a+8|0]|w[a+9|0]<<8|(w[a+10|0]<<16|w[a+11|0]<<24))==1279545165&(w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24))==1297239878}function mqa(a,b,c){var d=0;d=b>>31;a=a^d;iqa(a-d|0,(b^d)-((a>>>0<d>>>0)+d|0)|0,c,0);jb=ib;a=d^hb;b=a-d|0;jb=(d^jb)-((a>>>0<d>>>0)+d|0)|0;return b}function bB(a,b,c){var d=0,e=0,f=0;d=Ol(a,b);if((d|0)!=255){e=vd(a+22|0,d),f=c,u[e>>1]=f;a=a+58|0;e=ic(a,b),f=255,t[e|0]=f;e=ic(a,c),f=d,t[e|0]=f}}function O7(a,b){a=a|0;b=b|0;var c=0,d=0;c=gb-32|0;gb=c;d=v[b+4>>2];v[c+8>>2]=v[b>>2];v[c+12>>2]=d;zs(a,v[c+8>>2],v[c+12>>2]);gb=c+32|0;return a|0}function $X(a){t[a+8|0]=0;t[a+9|0]=0;t[a+10|0]=0;t[a+11|0]=0;t[a|0]=0;t[a+1|0]=0;t[a+2|0]=0;t[a+3|0]=0;t[a+4|0]=0;t[a+5|0]=0;t[a+6|0]=0;t[a+7|0]=0}function yx(a,b,c){a:{if((a|0)==(b|0)){break a}c=v[c>>2];while(1){if((c|0)==v[a>>2]){break a}a=a+4|0;if((b|0)!=(a|0)){continue}break}a=b}return a}function gM(a){var b=0;b=(wf(v[a+16>>2])>>>0)/(Lj(C(z[a+4208>>2]*C(999)))+1>>>0)|0;b=b>>>0>2?b:2;v[a+4216>>2]=b;v[a+4220>>2]=b>>>1;qc(a+4224|0,b)}function dU(a){var b=0,c=0,d=0;b=a;c=v[a+8>>2];d=v[a+4>>2];if((c|0)!=(d|0)){v[b+8>>2]=B(((c-d|0)-12>>>0)/12^-1,12)+c}b=v[a>>2];if(b){Yu(b,Mp(a))}}function WD(a){t[a|0]=0;t[a+1|0]=0;t[a+2|0]=0;t[a+3|0]=0;t[a+4|0]=0;t[a+5|0]=0;t[a+6|0]=0;t[a+7|0]=0;t[a+7|0]=0;t[a+8|0]=0;t[a+9|0]=0;t[a+10|0]=0}function W7(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0;h=gb-32|0;gb=h;i=h+8|0;GK(i,b,c,d,e,f,g);Dc(a,i);Sm(i);gb=h+32|0}function QN(a,b){a=a|0;b=b|0;var c=0;if(!(w[b+14|0]&48|w[b+17|0]!=173)){Rc(a,8,1,0,10);return}c=a;a=b+14|0;Rc(c,w[a|0]&16?16:8,w[a|0]&32?3:1,0,2)}function L1(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;if((b|0)!=(c|0)){while(1){v[d>>2]=t[b|0];d=d+4|0;b=b+1|0;if((c|0)!=(b|0)){continue}break}}return c|0}function w5(a,b){a=a|0;b=b|0;v[a+4>>2]=b;t[a|0]=0;if(_f(v[v[b>>2]-12>>2]+b|0)){b=v[(v[v[b>>2]-12>>2]+b|0)+72>>2];if(b){tI(b)}t[a|0]=1}return a|0}function vx(a){var b=0,c=0;v[22656]=0;c=ga(2537)|0;b=v[22656];v[22656]=0;if((b|0)!=1){b=a;a=v[c>>2];v[b>>2]=a;Ln(a);return}V(0)|0;O()|0;Bb();L()}function fq(a,b){var c=0;a:{if(!sJ(b)|(w[b+1|0]^w[a+1|0])>>>0>1){break a}b=w[b+2|0];a=w[a+2|0];if((b^a)&12){break a}c=b>>>0<16^a>>>0>15}return c}function VA(a,b){var c=0;qR(a);wb(a);c=b+4|0;ml(v[a>>2],v[a+4>>2],c);wc(a,c);wc(a+4|0,b+8|0);wc(wb(a),dc(b));v[b>>2]=v[b+4>>2];rf(a);tg(a);tg(a)}function Uea(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=v[b>>2];v[a>>2]=d;v[v[d-12>>2]+a>>2]=v[b+4>>2];v[a+4>>2]=0;fu(v[v[a>>2]-12>>2]+a|0,c);return a|0}function Sx(a){var b=0,c=0;b=gb-16|0;gb=b;c=-1;a:{if(HI(a)){break a}if((kb[v[a+32>>2]](a,b+15|0,1)|0)!=1){break a}c=w[b+15|0]}gb=b+16|0;return c}function PB(a){var b=0;if(v[a>>2]){Od(a);b=v[a>>2];a=$k(a);v[22656]=0;Oc(b,B(a,36),4);a=v[22656];v[22656]=0;if((a|0)==1){V(0)|0;O()|0;Bb();L()}}}function L5(a,b){a=a|0;b=b|0;v[a+4>>2]=b;t[a|0]=0;if(_f(v[v[b>>2]-12>>2]+b|0)){b=v[(v[v[b>>2]-12>>2]+b|0)+72>>2];if(b){bt(b)}t[a|0]=1}return a|0}function D1(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;if((b|0)!=(c|0)){while(1){t[d|0]=w[b|0];d=d+1|0;b=b+1|0;if((c|0)!=(b|0)){continue}break}}return c|0}function xx(a,b){a:{if((a|0)==(b|0)){break a}b=b-4|0;if(b>>>0<=a>>>0){break a}while(1){wc(a,b);a=a+4|0;b=b-4|0;if(a>>>0<b>>>0){continue}break}}}function vk(a,b){var c=0,d=0;a:{b=Ol(a,b);if((b|0)==255){break a}if(wk(a)){break a}c=ic(a+4|0,b);d=w[c|0]&223;t[c|0]=d;Yh(v[a>>2],Hu(b)|176,d)}}function rD(a){var b=0;if(v[a>>2]){Od(a);b=v[a>>2];a=Yj(a);v[22656]=0;Oc(b,B(a,6),1);a=v[22656];v[22656]=0;if((a|0)==1){V(0)|0;O()|0;Bb();L()}}}function qm(a,b){a:{if((a|0)==(b|0)){break a}b=b-1|0;if(b>>>0<=a>>>0){break a}while(1){fi(a,b);a=a+1|0;b=b-1|0;if(a>>>0<b>>>0){continue}break}}}function Xm(a,b,c){a:{if((a|0)==(b|0)){break a}c=w[c|0];while(1){if((c|0)==w[a|0]){break a}a=a+1|0;if((b|0)!=(a|0)){continue}break}a=b}return a}function XA(a){var b=0,c=0,d=0;c=w[a+32|0];d=Pi(v[a+24>>2]+484360|0);b=v[a+24>>2]+484360|0;if(c>>>0>=d>>>0){return Sb(b)}return Tj(b,w[a+32|0])}function Qpa(a){a=a|0;var b=0,c=0,d=0;b=gb-16|0;gb=b;u[b+14>>1]=1;c=b,d=am(a),u[c+12>>1]=d;a=x[Le(b+14|0,b+12|0)>>1];gb=b+16|0;return a-1&65535}function GM(a,b){var c=0;c=gb-16|0;gb=c;v[c+12>>2]=b;v[c+8>>2]=127;b=Fb(c+12|0,c+8|0);z[v[a+20>>2]+144>>2]=C(C(y[b>>2])/C(-127))+C(1);gb=c+16|0}function EW(a){var b=0,c=0,d=0;b=gb-16|0;gb=b;c=gb-16|0;gb=c;d=a+4|0;while(1){Hf(a);a=a+1|0;if((d|0)!=(a|0)){continue}break}gb=c+16|0;gb=b+16|0}function Dn(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;if(hK(a)>>>0<b>>>0){Sc();L()}c=oi(wb(a),b);v[a>>2]=c;v[a+4>>2]=c;d=wb(a),e=b+c|0,v[d>>2]=e;ut(a,0)}function cJ(a,b,c,d,e,f){var g=0,h=0;g=v[a+32>>2];if(!w[a+23|0]){v[(c<<2)+g>>2]=b;return}h=g;g=d<<2;v[h+g>>2]=b;t[v[a+8>>2]+d|0]=e;v[f+g>>2]=c}function bV(a){var b=0;a:{if(sd(a,11130,3)|w[a+3|0]>31|(t[a+27|0]<0|w[a+32|0]>64)){break a}a=a+33|0;if(w[a|0]>32){break a}b=w[a|0]!=0}return b}function wT(a){var b=0,c=0,d=0;b=a;c=v[a+8>>2];d=v[a+4>>2];if((c|0)!=(d|0)){v[b+8>>2]=(((c-d|0)-16>>>4^-1)<<4)+c}b=v[a>>2];if(b){LB(b,Wx(a))}}function mD(a){var b=0;if(v[a>>2]){Od(a);b=v[a>>2];a=pe(a);v[22656]=0;Oc(b,a<<2,2);a=v[22656];v[22656]=0;if((a|0)==1){V(0)|0;O()|0;Bb();L()}}}function Mf(a){var b=0;if(v[a>>2]){Od(a);b=v[a>>2];a=tg(a);v[22656]=0;Oc(b,a<<3,8);a=v[22656];v[22656]=0;if((a|0)==1){V(0)|0;O()|0;Bb();L()}}}function M4(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;e=v[a+20>>2];d=v[a+16>>2]-e|0;d=c>>>0<d>>>0?c:d;hc(e,b,d);v[a+20>>2]=d+v[a+20>>2];return c|0}function Kr(a){a=a|0;var b=0,c=0;b=gb-16|0;gb=b;if(js(a,b+8|0)){c=Xb(w[b+8|0]|w[b+9|0]<<8|(w[b+10|0]<<16|w[b+11|0]<<24))}gb=b+16|0;return c|0}function AT(a){var b=0,c=0,d=0;b=a;c=v[a+8>>2];d=v[a+4>>2];if((c|0)!=(d|0)){v[b+8>>2]=(((c-d|0)-32>>>5^-1)<<5)+c}b=v[a>>2];if(b){MB(b,HB(a))}}function rp(a){var b=0,c=0,d=0;b=a;c=v[a+8>>2];d=v[a+4>>2];if((c|0)!=(d|0)){v[b+8>>2]=(((c-d|0)-2>>>1^-1)<<1)+c}b=v[a>>2];if(b){EY(b,Bw(a))}}function dP(a,b){var c=0,d=0,e=0;d=w[a|0];e=w[b|0];c=1;a:{if(d>>>0<e>>>0){break a}c=0;if(d>>>0>e>>>0){break a}c=x[a+2>>1]<x[b+2>>1]}return c}function Zr(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=gb-16|0;gb=c;e=v[b+4>>2];d=v[b>>2];t[c+15|0]=0;d=Xm(d,d+e|0,c+15|0);Pj(a,v[b>>2],d);gb=c+16|0}function Y7(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0;g=gb-32|0;gb=g;h=g+8|0;IK(h,b,c,d,e,f);Dc(a,g+20|0);Sm(h);gb=g+32|0}function PE(a){var b=0,c=0;c=kqa(w[a+111|0],0,1536,0);b=jb;a=kqa(w[a+110|0],0,25,0);c=c+a|0;b=jb+b|0;b=a>>>0>c>>>0?b+1|0:b;a=c;jb=b;return a}function Nl(a,b,c){var d=0,e=0;a=x[b>>1];e=x[c>>1];d=1;a:{if(a>>>0<e>>>0){break a}d=0;if(a>>>0>e>>>0){break a}d=y[b+4>>2]<y[c+4>>2]}return d}function GW(a,b){var c=0,d=0,e=0;c=gb-16|0;gb=c;e=v[b+4>>2];d=v[b>>2];t[c+15|0]=0;d=Xm(d,d+e|0,c+15|0);e=a;a=v[b>>2];td(e,a,d-a|0);gb=c+16|0}function FF(a){var b=0,c=0,d=0;b=a;c=v[a+8>>2];d=v[a+4>>2];if((c|0)!=(d|0)){v[b+8>>2]=(((c-d|0)-8>>>3^-1)<<3)+c}b=v[a>>2];if(b){KF(b,EF(a))}}function $da(a){a=a|0;var b=0,c=0,d=0;b=gb-16|0;gb=b;if(!nd(a,4)){Uy(a)}c=b,d=Vb(a+44|0),v[c>>2]=d;a=v[Fd(b+8|0,b)>>2];gb=b+16|0;return a|0}
function gn(a){a=+a;var b=0;a=ee(a);b=255;a:{if(a>=255){break a}b=0;if(a<=0){break a}b=~~a>>>0;if(a<4294967296&a>=0){break a}b=0}return b|0}function _da(a){a=a|0;var b=0,c=0,d=0;b=gb-16|0;gb=b;if(!nd(a,4)){Uy(a)}c=b,d=Zb(a+44|0),v[c>>2]=d;a=v[Fd(b+8|0,b)>>2];gb=b+16|0;return a|0}function ZB(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;b=b-a>>2;if((b|0)>0){while(1){v[a>>2]=v[c>>2];a=a+4|0;d=b>>>0>1;b=b-1|0;if(d){continue}break}}}function Bb(){var a=0;a=v[22653];v[22656]=0;X(a|0);a=v[22656];v[22656]=0;if((a|0)!=1){v[22656]=0;L()}a=V(0)|0;O()|0;Z(a|0)|0;v[22656]=0;L()}function A1(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;a=gb-16|0;gb=a;v[a+12>>2]=e;v[a+8>>2]=d-c;b=Fb(a+12|0,a+8|0);gb=a+16|0;return v[b>>2]}
function tfa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=gb-32|0;gb=c;if(pe(a)>>>0<b>>>0){d=wb(a);e=a;a=xo(c+8|0,b,Nb(a),d);UN(e,a);Kz(a)}gb=c+32|0}function nha(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=gb-32|0;gb=c;if(tg(a)>>>0<b>>>0){d=wb(a);e=a;a=WA(c+8|0,b,rf(a),d);VA(e,a);UA(a)}gb=c+32|0}function jU(a,b,c){var d=0;d=mc(a);v[22656]=0;U(55,a|0,b|0,c|0);b=v[22656];v[22656]=0;if((b|0)!=1){return a}a=P()|0;O()|0;Nc(d);S(a|0);L()}function _ga(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=gb-32|0;gb=c;if(LA(a)>>>0<b>>>0){d=wb(a);e=a;a=WQ(c+8|0,b,QA(a),d);VQ(e,a);UQ(a)}gb=c+32|0}function Zka(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=gb-32|0;gb=c;if(ug(a)>>>0<b>>>0){d=wb(a);e=a;a=Zu(c+8|0,b,Ec(a),d);eU(e,a);dU(a)}gb=c+32|0}function WS(a,b){var c=0;Fk(a);wb(a);c=b+4|0;ml(v[a>>2],v[a+4>>2],c);wc(a,c);wc(a+4|0,b+8|0);wc(wb(a),dc(b));v[b>>2]=v[b+4>>2];dn(a,Nb(a))}function UN(a,b){var c=0;Fk(a);wb(a);c=b+4|0;ml(v[a>>2],v[a+4>>2],c);xc(a,c);xc(a+4|0,b+8|0);xc(wb(a),dc(b));v[b>>2]=v[b+4>>2];dn(a,Nb(a))}function Ob(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=gb-16|0;gb=d;if(b>>>0>=117){jo(9396);L()}e=d+8|0;Db(e,a,b);Uf(e,c);gb=d+16|0;return a|0}function LY(a){var b=0,c=0;c=a;b=v[a+4>>2];a=v[a>>2];if((b|0)!=(a|0)){while(1){b=b-28|0;ed(b);if((a|0)!=(b|0)){continue}break}}v[c+4>>2]=a}function Gy(a){var b=0;if(v[a>>2]){Od(a);b=v[a>>2];a=dg(a);v[22656]=0;Oc(b,a,1);a=v[22656];v[22656]=0;if((a|0)==1){V(0)|0;O()|0;Bb();L()}}}function si(a){var b=0;a=a*a;b=a*a;return C(a*-.499999997251031+1+b*.04166662332373906+a*b*(a*2439044879627741e-20+-.001388676377460993))}function gu(a,b){a=a|0;b=b|0;var c=0;c=b>>>0>126;if(!c){We(((b<<5)+a|0)+480280|0);$m((B(b,872)+a|0)+1074992|0,7,a,b,134217728)}return c|0}function Wga(a){a=a|0;var b=0;b=v[a>>2];if(kb[v[v[b>>2]+32>>2]](b,0,32)|0){a=v[a>>2];a=kb[v[v[a>>2]+32>>2]](a,32,1)^1}else{a=0}return a|0}function Oi(a,b,c){a=a|0;b=b|0;c=c|0;a:{if((Ol(a,b)|0)==255){break a}vk(a,b);Qq(a,b,0,0);if(!c){break a}a=ic(a+58|0,b);t[a|0]=w[a|0]|128}}function OT(a){var b=0,c=0;b=gb-16|0;gb=b;if(QV(a,b+8|0)){a=b+8|0;c=Xb(w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24))}gb=b+16|0;return c}function FP(a){a=50-(B(w[(a>>>4|0)+37792|0],a&15)>>>4|0)|0;a=a>>>0>23863?65536:23863/(a>>>0)|0;return Ac((a+119315e4>>>0)/(a<<1>>>0)|0,0)}function uea(a,b){a=a|0;b=b|0;var c=0;c=gb-32|0;gb=c;t[c+16|0]=44;v[c+8>>2]=-1;v[c+12>>2]=0;v[c>>2]=1025;v[c+4>>2]=4;Vt(a,b,c);gb=c+32|0}function pea(a,b){a=a|0;b=b|0;var c=0;c=gb-32|0;gb=c;t[c+16|0]=44;v[c+8>>2]=-1;v[c+12>>2]=0;v[c>>2]=1058;v[c+4>>2]=1;Vt(a,b,c);gb=c+32|0}function noa(a,b){a=a|0;b=b|0;var c=0;c=gb-32|0;gb=c;t[c+16|0]=44;v[c+8>>2]=-1;v[c+12>>2]=0;v[c>>2]=1042;v[c+4>>2]=2;Vt(a,b,c);gb=c+32|0}function nla(a,b){a=a|0;b=b|0;var c=0;c=gb-32|0;gb=c;t[c+16|0]=44;v[c+8>>2]=-1;v[c+12>>2]=0;v[c>>2]=1042;v[c+4>>2]=2;aw(a,b,c);gb=c+32|0}function nea(a,b){a=a|0;b=b|0;var c=0;c=gb-32|0;gb=c;t[c+16|0]=44;v[c+8>>2]=-1;v[c+12>>2]=0;v[c>>2]=1025;v[c+4>>2]=2;Vt(a,b,c);gb=c+32|0}function Uja(a,b){a=a|0;b=b|0;var c=0;c=gb-32|0;gb=c;t[c+16|0]=44;v[c+8>>2]=-1;v[c+12>>2]=0;v[c>>2]=1058;v[c+4>>2]=3;KV(a,b,c);gb=c+32|0}function UX(a){var b=0,c=0,d=0;c=gb-16|0;gb=c;b=c+8|0;Iw(b,a);a=w[ic(b,0)|0];d=w[ic(b,1)|0];b=w[ic(b,2)|0];gb=c+16|0;return a|d<<8|b<<16}function U1(a){a=a|0;var b=0,c=0,d=0;b=v[v[a>>2]>>2];c=v[b+8>>2];a=v[b+4>>2];b=v[b>>2]+(c>>1)|0;d=b;if(c&1){a=v[a+v[b>>2]>>2]}kb[a|0](d)}function GI(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;if(c){d=a;while(1){v[d>>2]=v[b>>2];d=d+4|0;b=b+4|0;c=c-1|0;if(c){continue}break}}return a|0}function pC(a,b){a=a|0;b=b|0;var c=0;c=gb-32|0;gb=c;t[c+16|0]=44;v[c+8>>2]=-1;v[c+12>>2]=0;v[c>>2]=1058;v[c+4>>2]=2;KV(a,b,c);gb=c+32|0}function oZ(a,b){a=a|0;b=b|0;var c=0;c=gb-32|0;gb=c;t[c+16|0]=44;v[c+8>>2]=-1;v[c+12>>2]=0;v[c>>2]=1025;v[c+4>>2]=2;aw(a,b,c);gb=c+32|0}function e6(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=b;b=v[b>>2]+7&-8;v[c>>2]=b+16;d=a,e=ey(v[b>>2],v[b+4>>2],v[b+8>>2],v[b+12>>2]),A[d>>3]=e}function bd(a,b){var c=0,d=0,e=0;c=Wf(a,b);if(c){v[a+12>>2]=v[a+12>>2]+b;return c}d=a,e=kb[v[v[a>>2]+24>>2]](a)|0,v[d+12>>2]=e;return c}function ay(a,b){var c=0;if(b>>>0<=99){return NI(a,b)}if(b>>>0<=999){c=a;a=(b>>>0)/100|0;return gt(MI(c,a),b-B(a,100)|0)}return vj(a,b)}function _m(a){if(a>=2147483647){return 2147483647}if(a<=-2147483648){return-2147483648}if(D(a)<2147483648){return~~a}return-2147483648}function Z7(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0;g=gb-32|0;gb=g;h=g+8|0;IK(h,b,c,d,e,f);Dc(a,h);Sm(h);gb=g+32|0}function Wk(a){var b=0;b=a+28|0;a=b;if((w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24))>>>0>=128){a=w[b|0]^-128}else{a=255}return a&255}function P4(a,b){a=a|0;b=b|0;var c=0;c=gb-32|0;gb=c;t[c+16|0]=44;v[c+8>>2]=-1;v[c+12>>2]=0;v[c>>2]=1058;v[c+4>>2]=2;Qw(a,b,c);gb=c+32|0}function uha(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;if(Lw()>>>0<b>>>0){Sc();L()}c=CR(b);v[a>>2]=c;v[a+4>>2]=c;d=wb(a),e=(b<<3)+c|0,v[d>>2]=e}function pD(a,b){var c=0,d=0;d=gb-16|0;gb=d;c=d+8|0;Zi(c,b);gb=d+16|0;return v[a>>2]==(w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24))}function oda(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;if(!(!ve(c&255)|!d)){NM(a,8,C(0))}a=pk(a);if(a){kb[v[v[a>>2]+92>>2]](a,b,c,d,e)}}function m6(a,b){a=a|0;b=b|0;var c=0;c=gb-32|0;gb=c;t[c+16|0]=44;v[c+8>>2]=-1;v[c+12>>2]=0;v[c>>2]=257;v[c+4>>2]=0;Qw(a,b,c);gb=c+32|0}function lt(a,b){var c=0,d=0;a:{if(b>>>0<=31){d=v[a+4>>2];c=a;break a}b=b-32|0;c=a+4|0}c=v[c>>2];v[a+4>>2]=d>>>b;v[a>>2]=d<<32-b|c>>>b}function bJ(a,b){a:{if(w[a+23|0]){a=1;if((b|0)!=255){break a}aa(11456,10534,1180,2826);L()}if((b|0)==255){return 0}a=b>>>0>10}return a}function _Y(a,b){a=a|0;b=b|0;var c=0;c=gb-32|0;gb=c;t[c+16|0]=44;v[c+8>>2]=-1;v[c+12>>2]=0;v[c>>2]=274;v[c+4>>2]=0;aw(a,b,c);gb=c+32|0}function V4(a,b){a=a|0;b=b|0;var c=0;c=gb-32|0;gb=c;t[c+16|0]=44;v[c+8>>2]=-1;v[c+12>>2]=0;v[c>>2]=290;v[c+4>>2]=0;Qw(a,b,c);gb=c+32|0}function Kb(a){var b=0,c=0;b=gb-16|0;gb=b;v[22656]=0;c=v[22656];v[22656]=0;if((c|0)!=1){RA(a);gb=b+16|0;return a}V(0)|0;O()|0;Bb();L()}function Fs(a,b){Fm(a);v[a>>2]=89136;v[22656]=0;Q(2808,a+4|0,b|0)|0;a=v[22656];v[22656]=0;if((a|0)!=1){return}a=P()|0;O()|0;S(a|0);L()}function sg(a){var b=0,c=0;b=gb-16|0;gb=b;if(js(a,b+8|0)){a=b+8|0;c=w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24)}gb=b+16|0;return c}function hA(a,b){a=a|0;b=b|0;var c=0;c=18726;a:{if(b>>>0>255){break a}a=v[((b<<2)+a|0)+900380>>2];if(!a){break a}c=a+492|0}return c|0}function ex(a,b,c,d,e,f){var g=0,h=0;g=v[a+4>>2];h=g>>8;if(g&1){h=hx(v[d>>2],h)}a=v[a>>2];kb[v[v[a>>2]+20>>2]](a,b,c,d+h|0,g&2?e:2,f)}function e9(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;if(FI()>>>0<b>>>0){Sc();L()}c=bI(b);v[a>>2]=c;v[a+4>>2]=c;d=wb(a),e=(b<<4)+c|0,v[d>>2]=e}function QG(a){a=a|0;var b=0;a=Kb(a);v[22656]=0;Q(157,a|0,10989)|0;b=v[22656];v[22656]=0;if((b|0)==1){b=P()|0;O()|0;vb(a);S(b|0);L()}}function KG(a){var b=0,c=0,d=0;c=Jb(a);b=Ab(a);a=gb-16|0;gb=a;t[a+15|0]=0;d=-1;if(b){b=tp(c,b,a+15|0);d=b?b-c|0:-1}gb=a+16|0;return d}function JV(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;if(np()>>>0<b>>>0){Sc();L()}c=YV(b);v[a>>2]=c;v[a+4>>2]=c;d=wb(a),e=(b<<2)+c|0,v[d>>2]=e}function H7(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;if(np()>>>0<b>>>0){Sc();L()}c=aA(b);v[a>>2]=c;v[a+4>>2]=c;d=wb(a),e=(b<<2)+c|0,v[d>>2]=e}function ww(a,b){var c=0,d=0;if((b|0)<0){b=0-b|0;c=0-b&31;d=(a&-1>>>c)<<c;c=a;a=b&31;return d|(c&-1<<a)>>>a}return oqa(a,(b|0)%32|0)}function Zga(a,b){a=a|0;b=b|0;a=Wv(a,b);if(!a){t[b+6|0]=0;t[b+2|0]=0;t[b+3|0]=0;t[b+4|0]=0;t[b+5|0]=0;t[b|0]=0;t[b+1|0]=0}return a|0}function Sr(a,b){return(w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24))>>>0<(w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24))>>>0?b:a}function Ff(a,b,c,d,e){var f=0;f=gb-16|0;gb=f;v[f+12>>2]=c;v[f+8>>2]=e;c=vi(f,f+12|0);a=Us(a,b,d,v[f+8>>2]);hf(c);gb=f+16|0;return a}function $fa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=v[b>>2];v[a>>2]=d;v[v[d-12>>2]+a>>2]=v[b+4>>2];fu(v[v[a>>2]-12>>2]+a|0,c);return a|0}function yb(a){var b=0;b=v[a+4>>2];a=v[a>>2];v[22656]=0;a=Zh(a,b);b=v[22656];v[22656]=0;if((b|0)!=1){return a}V(0)|0;O()|0;Bb();L()}function ws(a){var b=0;b=v[a+4>>2];a=v[a>>2];v[22656]=0;a=Pp(a,b);b=v[22656];v[22656]=0;if((b|0)!=1){return a}V(0)|0;O()|0;Bb();L()}function kpa(a){a=a|0;var b=0,c=0,d=0;if(np()>>>0<=8191){Sc();L()}b=Mc(32768,2);v[a>>2]=b;v[a+4>>2]=b;c=wb(a),d=b+32768|0,v[c>>2]=d}function jt(a,b){var c=0,d=0;a:{if(b>>>0<=31){d=v[a>>2];c=a+4|0;break a}b=b-32|0;c=a}c=v[c>>2];v[a>>2]=d<<b;v[a+4>>2]=c<<b|d>>>32-b}function Yx(a){a=a|0;var b=0;b=v[a+12>>2];if((b|0)==v[a+16>>2]){return kb[v[v[a>>2]+40>>2]](a)|0}v[a+12>>2]=b+1;return Mg(t[b|0])|0}function QB(a){var b=0;b=v[a+4>>2];a=v[a>>2];v[22656]=0;a=$q(a,b);b=v[22656];v[22656]=0;if((b|0)!=1){return a}V(0)|0;O()|0;Bb();L()}function $0(){var a=0,b=0;a=gb-16|0;gb=a;v[a+8>>2]=19923028;a:{if(rH(a+8|0)){break a}if(iH()){break a}b=eH()^1}gb=a+16|0;return b|0}function pO(a,b,c){var d=0,e=0,f=0;d=t[c+26|0];if(!(!d|!b)){e=a,f=Lb(v[a>>2]+((B((w[c+27|0]^-1)+b|0,d)|0)/2|0)|0,0,256),v[e>>2]=f}}function dda(a){a=a|0;var b=0,c=0;c=gb-16|0;gb=c;v[c+12>>2]=0;b=c+12|0;t[b|0]=0;t[b+1|0]=0;t[b+2|0]=0;t[b+3|0]=0;EM(a,b);gb=c+16|0}function VM(a){a=a|0;a=gb-16|0;gb=a;v[a+12>>2]=1869112133;gb=a+16|0;a=a+12|0;return w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24)}function Rf(a,b){a=a|0;b=b|0;var c=0,d=0;c=gb-16|0;gb=c;if(b>>>0>=117){jo(9361);L()}d=c+8|0;Db(d,a,b);Uf(d,0);gb=c+16|0;return a|0}function Cs(a,b,c,d,e){var f=0,g=0;f=v[a+4>>2];g=f>>8;if(f&1){g=hx(v[c>>2],g)}a=v[a>>2];kb[v[v[a>>2]+24>>2]](a,b,c+g|0,f&2?d:2,e)}function $ca(a){a=a|0;var b=0,c=0,d=0;b=gb-32|0;gb=b;if(pe(a)>>>0<=12){c=wb(a);d=a;a=xo(b+8|0,13,Nb(a),c);Zk(d,a);uO(a)}gb=b+32|0}function yL(a){a=a|0;var b=0,c=0;c=gb-16|0;gb=c;b=sf(8);oL(b);v[b+4>>2]=a;v[b>>2]=55412;a=v[Wi(c+8|0,b)>>2];gb=c+16|0;return a|0}function YB(a,b){var c=0,d=0;v[a>>2]=v[b>>2];v[a+4>>2]=v[b+4>>2];v[a+8>>2]=v[b+8>>2];v[b>>2]=0;v[b+4>>2]=0;c=wb(b),d=0,v[c>>2]=d}function Vj(a,b,c){var d=0;d=gb-16|0;gb=d;v[d+12>>2]=b;Ge(a,d+12|0);b=v[c+4>>2];v[a+4>>2]=v[c>>2];v[a+8>>2]=b;gb=d+16|0;return a}function N6(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;a=Et(a+8|0,b,c,d,2);if(a>>>0<=15){a=w[a+49600|0]}else{a=0}return(a>>>0<5?a+1|0:0)|0}function qH(a,b,c,d,e,f){a=kb[v[v[a+8>>2]+4>>2]](a+8|0)|0;a=Ts(c,d,a,a+288|0,f,e,0)-a|0;if((a|0)<=287){v[b>>2]=((a|0)/12|0)%12}}function pk(a){var b=0,c=0;b=Wk(v[a+20>>2]);if(!(b>>>0>249|w[a+4200|0]>=b>>>0)){c=v[(v[a+16>>2]+B(b,160)|0)+906300>>2]}return c}function nH(a,b,c,d,e,f){a=kb[v[v[a+8>>2]+4>>2]](a+8|0)|0;a=Rs(c,d,a,a+288|0,f,e,0)-a|0;if((a|0)<=287){v[b>>2]=((a|0)/12|0)%12}}function my(a,b,c){var d=0;d=v[a+32>>2];if(y[a+40>>2]<d+c>>>0){v[a+96>>2]=1;return 0}hc(b,d,c);v[a+32>>2]=v[a+32>>2]+c;return 1}function bM(a){a=a|0;var b=0,c=0;b=a+4960|0;c=a+4504|0;while(1){b=b-24|0;Nc(b);if((b|0)!=(c|0)){continue}break}Lf(a);return a|0}function Kd(a){var b=0;a=v[a+4>>2];if(a){if(Nn(a)){a:{b=a+8|0;if(v[b>>2]){if((Tw(b)|0)!=-1){break a}}kb[v[v[a>>2]+16>>2]](a)}}}}function KS(a){var b=0;b=v[a+16>>2];a=v[a+32>>2];b=kqa(b,b>>31,a,a>>31)+5e5|0;a=jb;return Ac(lqa(b,b>>>0<5e5?a+1|0:a,1e6,0),jb)}function JS(a){var b=0;b=v[a+16>>2];a=v[a+36>>2];b=kqa(b,b>>31,a,a>>31)+5e5|0;a=jb;return Ac(lqa(b,b>>>0<5e5?a+1|0:a,1e6,0),jb)}function iH(){var a=0,b=0,c=0;a=gb-16|0;gb=a;b=Tb(a,12139);if(Ab(b)){c=(xg(b,11163)|0)!=-1}else{c=0}vb(b);gb=a+16|0;return c|0}function Jk(a){var b=0,c=0,d=0;b=gb-16|0;gb=b;wr(a+4|0);v[b+12>>2]=0;Ge(a+8|0,b+12|0);c=a,d=fc(a),v[c>>2]=d;gb=b+16|0;return a}function $R(a,b,c,d,e){v[a+12>>2]=e;v[a+8>>2]=d;v[a+4>>2]=c;v[a>>2]=b;if(b){de(b,a)}if(c){de(c,a)}if(d){de(d,a)}if(e){de(e,a)}}function r6(a){a=a|0;var b=0;if(!a){return-2}b=v[a+28>>2];if(!b){return 0}kb[v[a+36>>2]](v[a+40>>2],b);v[a+28>>2]=0;return 0}
function Wl(a,b){var c=0;a:{if(y[a+12>>2]<b>>>0){c=0;if(kb[v[v[a>>2]+24>>2]](a)>>>0<b>>>0){break a}}v[a+12>>2]=b;c=1}return c}function S5(a){a=a|0;var b=0;if((kb[v[v[a>>2]+36>>2]](a)|0)==-1){return-1}b=a;a=v[a+12>>2];v[b+12>>2]=a+1;return Mg(t[a|0])|0}function O$(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;if(Sg(a,v[b+8>>2],0)){ix(b,c,d);return}a=v[a+8>>2];kb[v[v[a>>2]+28>>2]](a,b,c,d)}function Kl(a,b,c){var d=0;d=gb-16|0;gb=d;v[d+12>>2]=c;c=v[b>>2];v[d+8>>2]=v[b+4>>2];td(a,c,v[Fb(d+12|0,d+8|0)>>2]);gb=d+16|0}function sH(a,b,c,d,e,f){a=kb[v[v[a+8>>2]>>2]](a+8|0)|0;a=Ts(c,d,a,a+168|0,f,e,0)-a|0;if((a|0)<=167){v[b>>2]=((a|0)/12|0)%7}}function qg(a,b,c,d){var e=0;a=((b|0)/8|0)+a|0;e=lh(d,a);return((lh(d,a+1|0)<<8|e<<16|lh(d,a+2|0))<<(b&7)&16777215)>>>24-c|0}function oH(a,b,c,d,e,f){a=kb[v[v[a+8>>2]>>2]](a+8|0)|0;a=Rs(c,d,a,a+168|0,f,e,0)-a|0;if((a|0)<=167){v[b>>2]=((a|0)/12|0)%7}}function kU(a){var b=0,c=0;b=w[a+33|0];c=b>>>24|0;a=w[a+31|0]?1120:1056;b=a+(b<<8)|0;c=a>>>0>b>>>0?c+1|0:c;a=b;jb=c;return a}function et(a){v[a>>2]=74504;vx(a+4|0);v[a+24>>2]=0;v[a+28>>2]=0;v[a+16>>2]=0;v[a+20>>2]=0;v[a+8>>2]=0;v[a+12>>2]=0;return a}function eo(a,b,c,d){var e=0;e=gb-16|0;gb=e;bc(e+8|0,zb(c),d);c=v[e+12>>2];v[e>>2]=v[e+8>>2];v[e+4>>2]=c;sy(a,b,e);gb=e+16|0}function Ub(a,b){var c=0,d=0,e=0;c=a;d=v[b>>2];e=d+v[a>>2]|0;a=v[a+4>>2]+v[b+4>>2]|0;v[c>>2]=e;v[c+4>>2]=e>>>0<d>>>0?a+1|0:a}function Qt(a){var b=0;b=A[a+4248>>3]/+(wf(v[a+16>>2])>>>0);A[a+4264>>3]=b;if(w[a+4240|0]){A[a+4264>>3]=b*(A[a+4288>>3]/60)}}function PN(a){var b=0;b=a;if((w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24))==1179011410){a=cn(a)>>>0>80}else{a=0}return a}function Bt(a,b){a=a|0;b=b|0;var c=0;c=gb-16|0;gb=c;a=Ai(c,a,b);b=v[a+8>>2];if((b|0)!=v[a+4>>2]){v[a+4>>2]=b}$b(a);gb=c+16|0}function AI(a){v[a>>2]=74568;vx(a+4|0);v[a+24>>2]=0;v[a+28>>2]=0;v[a+16>>2]=0;v[a+20>>2]=0;v[a+8>>2]=0;v[a+12>>2]=0;return a}function xp(a,b){var c=0;a:{if(!b){break a}if(!Pb(a,b)){break a}if(b>>>0<=3){c=TE(a,b);break a}c=sg(a);Rb(a,b-4|0)}return c}function qw(a,b){var c=0;a:{if(!b){break a}if(!Pb(a,b)){break a}if(b>>>0<=1){c=SE(a,1);break a}c=Og(a);Rb(a,b-2|0)}return c}function qq(a){a=+a;var b=0,c=0,d=0;d=a*a;a=0;b=1;c=1;while(1){a=a+2;c=d*c/(a*a);b=b+c;if(b*1e-7<c){continue}break}return+b}function oq(a){a=a|0;var b=0,c=0;b=Te(a);while(1){c=b;if(c&65535){b=c-1|0;if(!me(a,b&65535)){continue}}break}return c&65535}function hf(a){a:{a=v[a>>2];if(a){v[22656]=0;Jx(a);a=v[22656];v[22656]=0;if((a|0)==1){break a}}return}V(0)|0;O()|0;Bb();L()}function qB(a){a=a|0;v[a+700>>2]=0;u[a+842>>1]=0;v[a+688>>2]=0;v[a>>2]=0;v[a+4>>2]=0;v[a+8>>2]=0;v[a+12>>2]=0;v[a+16>>2]=0}function bC(a){v[a>>2]=0;v[a+4>>2]=0;v[a+24>>2]=0;v[a+28>>2]=0;v[a+16>>2]=0;v[a+20>>2]=0;v[a+8>>2]=0;v[a+12>>2]=0;return a}function _T(a,b){var c=0;c=v[a+4>>2];if((c|0)!=(b|0)){while(1){c=c-12|0;ZT(c);if((b|0)!=(c|0)){continue}break}}v[a+4>>2]=b}function Lz(a,b){var c=0;if(!(w[a|0]!=w[b|0]|A[a+8>>3]!=A[b+8>>3]|w[a+16|0]!=w[b+16|0])){c=v[a+20>>2]==v[b+20>>2]}return c}function Ffa(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;if(!((b|0)==(c|0)|(d|0)>=0)){t[b|0]=45;d=rQ(d);b=b+1|0}gO(a,b,c,d,e)}function DH(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;if(c){d=a;while(1){v[d>>2]=b;d=d+4|0;c=c-1|0;if(c){continue}break}}return a|0}function yi(a,b,c){a:{if(c){v[22656]=0;GI(a,b,c);a=v[22656];v[22656]=0;if((a|0)==1){break a}}return}V(0)|0;O()|0;Bb();L()}function ve(a){var b=0;b=gb-16|0;gb=b;t[b+15|0]=a;t[b+14|0]=1;t[b+13|0]=120;a=Mv(b+15|0,b+14|0,b+13|0);gb=b+16|0;return a}function je(a,b){return(w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24))==(w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24))}function Zd(a,b,c){var d=0;a:{if((b|0)>(c|0)){break a}d=v[a>>2];if((d|0)>=(b|0)){b=c;if((d|0)<=(b|0)){break a}}v[a>>2]=b}}function YS(a,b){b=w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24);t[a|0]=b;t[a+1|0]=b>>>8;t[a+2|0]=b>>>16;t[a+3|0]=b>>>24}function Gp(a,b,c){var d=0;a:{if(b>>>0>c>>>0){break a}d=v[a>>2];if(d>>>0>=b>>>0){b=c;if(d>>>0<=b>>>0){break a}}v[a>>2]=b}}function xS(a,b,c,d,e,f,g){t[a+17|0]=g;t[a+16|0]=f;v[a+12>>2]=e;v[a+8>>2]=d;v[a+4>>2]=c;v[a>>2]=b;if(d){vS(a,1);vS(a,0)}}function wS(a,b,c,d,e,f,g){t[a+17|0]=g;t[a+16|0]=f;v[a+12>>2]=e;v[a+8>>2]=d;v[a+4>>2]=c;v[a>>2]=b;if(d){uS(a,1);uS(a,0)}}function sZ(a){a=a|0;var b=0;a:{if(!Ie(-1,v[a+76>>2])){a=v[a+76>>2];break a}b=a;a=UF(a,32);v[b+76>>2]=a}return a<<24>>24}function oI(a){var b=0;b=v[a+12>>2];if((b|0)==v[a+16>>2]){return kb[v[v[a>>2]+40>>2]](a)|0}v[a+12>>2]=b+4;return v[b>>2]}function kw(a,b){a=a|0;b=b|0;var c=0,d=0;d=gb-16|0;gb=d;c=gb-16|0;gb=c;t[c+15|0]=w[b|0];rR(a,c+15|0);gb=c+16|0;gb=d+16|0}function O5(a){a=a|0;var b=0;if((kb[v[v[a>>2]+36>>2]](a)|0)==-1){return-1}b=a;a=v[a+12>>2];v[b+12>>2]=a+4;return v[a>>2]}function Gl(a,b,c){var d=0;d=v[b+4>>2];v[a>>2]=v[b>>2];v[a+4>>2]=d;d=v[b+12>>2];v[a+8>>2]=v[b+8>>2];v[a+12>>2]=d;Gz(a,c)}function XQ(a){var b=0;a:{if(w[a|0]<24){break a}b:{if(!w[a+3|0]){b=15;break b}b=14;if(w[a+3|0]!=3){break a}}t[a+3|0]=b}}function u$(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0;h=b;b=0;return kb[a|0](h|b,c,d,e,b|f,g)|0}function kga(a,b){a=a|0;b=b|0;var c=0,d=0;c=gb-16|0;gb=c;if(b>>>0>=250){jo(9396);L()}d=c+8|0;Db(d,a,b);er(d);gb=c+16|0}function cT(a){var b=0,c=0,d=0;b=a+68|0;c=w[b+1|0]<<8;if(!(!(w[b|0]|c)|(c|w[b|0])>>>0>127)){d=!sd(a,14778,17)}return d}function Oma(a){a=a|0;var b=0,c=0;b=gb-16|0;gb=b;if(Ep(a,b+8|0)){c=(w[b+8|0]|w[b+9|0]<<8)<<16>>16}gb=b+16|0;return c|0}function Ne(a){var b=0;b=v[a+32>>2];a:{if(b>>>0>=y[a+40>>2]){v[a+96>>2]=1;a=0;break a}v[a+32>>2]=b+1;a=w[b|0]}return a}function Lo(a,b,c){var d=0;b=b-a|0;if((b|0)>0){while(1){t[a|0]=w[c|0];a=a+1|0;d=b>>>0>1;b=b-1|0;if(d){continue}break}}}function BY(a){var b=0,c=0;a:{if(sd(a,28564,20)){break a}b=a+25|0;if(!w[b|0]|w[b|0]>8){break a}c=t[a+47|0]>=0}return c}function rc(a,b){var c=0;Fm(a);v[a+4>>2]=0;v[a>>2]=54916;c=a;a=Cd(Ab(b)+1|0);v[c+4>>2]=a;if(a){hc(a,Jb(b),Ab(b)+1|0)}}function ega(a){a=a|0;var b=0,c=0,d=0,e=0;b=gb-16|0;gb=b;c=b+8|0;d=c,e=cA(a),v[d>>2]=e;Ao(c);gb=b+16|0;return v[c>>2]}function Yv(a,b){a=a|0;b=b|0;var c=0;c=v[b+4>>2];if(c){bc(a,c,v[b>>2]);return}b=b+8|0;if(!cd(b)){Vd(a,b);return}Ud(a)}function iV(a){var b=0,c=0;b=gb-16|0;gb=b;c=a+512|0;while(1){Hf(a);a=a+1|0;if((c|0)!=(a|0)){continue}break}gb=b+16|0}function _U(a){var b=0;a=a+1104|0;a=(w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24))+8|0;b=a>>>0<8?1:b;jb=b;return a}function RF(a){a=a|0;var b=0,c=0;b=gb-16|0;gb=b;Jp(a);v[a>>2]=27812;c=dc(a);Ip(c);v[c>>2]=27944;gb=b+16|0;return a|0}function Fj(a){var b=0;a:{while(1){if(w[b+49616|0]==(a|0)){break a}b=b+1|0;if((b|0)!=45){continue}break}b=0}return b}function rz(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=gb-16|0;gb=e;d=Fg(e,a,d);FW(wb(a),b,c,d+4|0);$b(d);gb=e+16|0}function rr(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=gb-16|0;gb=e;d=Ai(e,a,d);FW(wb(a),b,c,d+4|0);$b(d);gb=e+16|0}function TH(a,b,c,d,e,f,g,h,i){v[a>>2]=b;v[a+4>>2]=c;v[a+8>>2]=d;v[a+12>>2]=e&65535|(i>>>16&32768|e>>>16&32767)<<16}function Lu(a){a=a|0;var b=0,c=0;b=a+68|0;a=0;while(1){c=Fe(b,a);a=a+1|0;v[c>>2]=a<<11;if((a|0)!=9){continue}break}}function Ku(a){a=a|0;var b=0,c=0;b=a+68|0;a=0;while(1){c=Fe(b,a);a=a+1|0;v[c>>2]=a<<16;if((a|0)!=9){continue}break}}function yB(a,b,c){a:{v[22656]=0;Oc(b,B(c,28),4);a=v[22656];v[22656]=0;if((a|0)!=1){break a}V(0)|0;O()|0;Bb();L()}}function mm(a,b,c){a:{v[22656]=0;Oc(b,B(c,12),4);a=v[22656];v[22656]=0;if((a|0)!=1){break a}V(0)|0;O()|0;Bb();L()}}function ls(a,b,c){a:{v[22656]=0;Oc(b,B(c,36),4);a=v[22656];v[22656]=0;if((a|0)!=1){break a}V(0)|0;O()|0;Bb();L()}}function iE(a,b,c){a:{v[22656]=0;Oc(b,B(c,20),4);a=v[22656];v[22656]=0;if((a|0)!=1){break a}V(0)|0;O()|0;Bb();L()}}function fr(a,b,c){if(v[b>>2]<=(Ib(w[a|0]|w[a+1|0]<<8)|0)){a=(Ib(w[a|0]|w[a+1|0]<<8)|0)<=v[c>>2]}else{a=0}return a}function fY(a,b,c){a:{v[22656]=0;Oc(b,B(c,48),4);a=v[22656];v[22656]=0;if((a|0)!=1){break a}V(0)|0;O()|0;Bb();L()}}function dA(a,b,c){a:{v[22656]=0;Oc(b,B(c,52),4);a=v[22656];v[22656]=0;if((a|0)!=1){break a}V(0)|0;O()|0;Bb();L()}}function Zk(a,b){var c=0;c=b+4|0;ml(v[a>>2],v[a+4>>2],c);wc(a,c);wc(a+4|0,b+8|0);wc(wb(a),dc(b));v[b>>2]=v[b+4>>2]}function Th(a){a=a|0;var b=0,c=0;v[v[a+20>>2]>>2]=a;c=v[a+12>>2];b=v[c>>2];v[a+4>>2]=b;if(b){v[b+8>>2]=a}v[c>>2]=a}function OY(a,b,c,d,e){t[a+4|0]=b;t[a|0]=69;t[a+1|0]=99;t[a+2|0]=104;t[a+3|0]=111;t[a+7|0]=e;t[a+6|0]=d;t[a+5|0]=c}function Jda(a,b,c){a=a|0;b=b|0;c=C(c);var d=0,e=0;if((b|0)<=3){d=(a+b|0)+4264|0,e=ch(C(c*C(255))),t[d|0]=e;Ut(a)}}function rS(a){var b=0,c=0;if(v[a>>2]){cm(a);Cw(wb(a),v[a>>2],Pg(a));b=wb(a),c=0,v[b>>2]=c;v[a>>2]=0;v[a+4>>2]=0}}function lM(a){a=a|0;v[a+4244>>2]=0;v[a+4248>>2]=0;v[a+4228>>2]=0;v[a+4232>>2]=0;a=a+4252|0;v[a>>2]=0;v[a+4>>2]=0}function lI(a,b){a=a|0;b=b|0;var c=0;c=v[a>>2];a:{if(!c){break a}if(!Ie(uI(c,b),-1)){break a}v[a>>2]=0}return a|0}function dO(a,b){var c=0,d=0;d=gb-16|0;gb=d;c=bA(d,a);wb(a);xq(v[c+4>>2],b);v[c+4>>2]=v[c+4>>2]+4;$b(c);gb=d+16|0}function VV(a){var b=0,c=0;if(v[a>>2]){Gg(a);sw(wb(a),v[a>>2],pe(a));b=wb(a),c=0,v[b>>2]=c;v[a>>2]=0;v[a+4>>2]=0}}function OP(a,b){var c=0;c=b&15;if(c){t[a+827|0]=c<<2}b=b&240;if(b){t[a+826|0]=b>>>4}v[a+88>>2]=v[a+88>>2]|262144}function OC(a,b,c){a:{v[22656]=0;Oc(b,B(c,6),1);a=v[22656];v[22656]=0;if((a|0)!=1){break a}V(0)|0;O()|0;Bb();L()}}function Il(a,b){var c=0;c=b&15;if(c){t[a+824|0]=c<<2}b=b&240;if(b){t[a+823|0]=b>>>4}v[a+88>>2]=v[a+88>>2]|131072}function Hv(a){var b=0,c=0;if(v[a>>2]){yr(a);al(wb(a),v[a>>2],dg(a));b=wb(a),c=0,v[b>>2]=c;v[a>>2]=0;v[a+4>>2]=0}}function EN(a){var b=0,c=0;if(v[a>>2]){Gg(a);ai(wb(a),v[a>>2],pe(a));b=wb(a),c=0,v[b>>2]=c;v[a>>2]=0;v[a+4>>2]=0}}function DN(a){var b=0,c=0;if(v[a>>2]){JN(a);OC(wb(a),v[a>>2],Yj(a));b=wb(a),c=0,v[b>>2]=c;v[a>>2]=0;v[a+4>>2]=0}}function tW(a,b){a:{v[22656]=0;Oc(a,B(b,33),1);a=v[22656];v[22656]=0;if((a|0)!=1){break a}V(0)|0;O()|0;Bb();L()}}function av(a,b){a:{v[22656]=0;Oc(a,B(b,56),4);a=v[22656];v[22656]=0;if((a|0)!=1){break a}V(0)|0;O()|0;Bb();L()}}function aJ(a,b,c){var d=0,e=0,f=0;e=c*c;A[a>>3]=e;f=c;d=c*134217729;c=d+(c-d);d=f-c;A[b>>3]=d*d+(c*c-e+(c+c)*d)}function aG(a,b){a:{v[22656]=0;Oc(a,B(b,24),4);a=v[22656];v[22656]=0;if((a|0)!=1){break a}V(0)|0;O()|0;Bb();L()}}function ZJ(a,b){a:{v[22656]=0;Oc(a,B(b,52),4);a=v[22656];v[22656]=0;if((a|0)!=1){break a}V(0)|0;O()|0;Bb();L()}}function Yu(a,b){a:{v[22656]=0;Oc(a,B(b,12),4);a=v[22656];v[22656]=0;if((a|0)!=1){break a}V(0)|0;O()|0;Bb();L()}}function Rd(a){a=a|0;var b=0;b=gb-16|0;gb=b;t[b+15|0]=1;t[b+14|0]=120;a=Mv(a,b+15|0,b+14|0);gb=b+16|0;return a|0}function RN(a,b){a=a|0;b=b|0;t[b+38|0]=w[a+202|0];t[b+39|0]=w[a+203|0];t[b+40|0]=w[a+204|0];t[b+41|0]=w[a+205|0]}function OM(a,b,c){a:{v[22656]=0;Oc(b,c<<11,4);a=v[22656];v[22656]=0;if((a|0)!=1){break a}V(0)|0;O()|0;Bb();L()}}function Iy(a,b){a:{v[22656]=0;Oc(a,B(b,24),8);a=v[22656];v[22656]=0;if((a|0)!=1){break a}V(0)|0;O()|0;Bb();L()}}function Hj(a){var b=0,c=0,d=0;b=gb-16|0;gb=b;c=b+8|0;Db(c,a+1074312|0,7);if(Cb(c)){d=_l(a)^1}gb=b+16|0;return d}function DD(a,b){a:{v[22656]=0;Oc(a,B(b,28),4);a=v[22656];v[22656]=0;if((a|0)!=1){break a}V(0)|0;O()|0;Bb();L()}}function zu(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;if(!((b|0)==(c|0)|(d|0)>=0)){t[b|0]=45;d=rQ(d);b=b+1|0}JA(a,b,c,d)}function wu(a){var b=0;b=1;a:{switch(w[a+3|0]-4|0){default:b=w[a+2|0]==11;break;case 0:case 2:break a}}return b}function sw(a,b,c){a:{v[22656]=0;Oc(b,c<<2,2);a=v[22656];v[22656]=0;if((a|0)!=1){break a}V(0)|0;O()|0;Bb();L()}}function nE(a,b,c){a:{v[22656]=0;Oc(b,c<<1,1);a=v[22656];v[22656]=0;if((a|0)!=1){break a}V(0)|0;O()|0;Bb();L()}}function lV(a,b,c){a:{v[22656]=0;Oc(b,c<<5,8);a=v[22656];v[22656]=0;if((a|0)!=1){break a}V(0)|0;O()|0;Bb();L()}}function ai(a,b,c){a:{v[22656]=0;Oc(b,c<<2,4);a=v[22656];v[22656]=0;if((a|0)!=1){break a}V(0)|0;O()|0;Bb();L()}}function _n(a,b,c){a:{v[22656]=0;Oc(b,c<<4,4);a=v[22656];v[22656]=0;if((a|0)!=1){break a}V(0)|0;O()|0;Bb();L()}}function Yk(a,b,c){a:{v[22656]=0;Oc(b,c<<5,4);a=v[22656];v[22656]=0;if((a|0)!=1){break a}V(0)|0;O()|0;Bb();L()}}function X4(a,b){a=a|0;b=b|0;var c=0,d=0;kb[v[v[a>>2]+24>>2]](a)|0;b=Tx(b);v[a+36>>2]=b;c=a,d=Zn(b),t[c+44|0]=d}function TA(a,b,c){a:{v[22656]=0;Oc(b,c<<3,8);a=v[22656];v[22656]=0;if((a|0)!=1){break a}V(0)|0;O()|0;Bb();L()}}function S4(a,b){a=a|0;b=b|0;var c=0,d=0;kb[v[v[a>>2]+24>>2]](a)|0;b=Px(b);v[a+36>>2]=b;c=a,d=Zn(b),t[c+44|0]=d}function NC(a,b,c){a:{v[22656]=0;Oc(b,c<<2,1);a=v[22656];v[22656]=0;if((a|0)!=1){break a}V(0)|0;O()|0;Bb();L()}}function Mr(a){a=a|0;var b=0,c=0;b=gb-16|0;gb=b;if(Ep(a,b+8|0)){c=Ib(w[b+8|0]|w[b+9|0]<<8)}gb=b+16|0;return c|0}function Mh(a){a:{a=v[a+4>>2]&74;if(a){if((a|0)==64){return 8}if((a|0)!=8){break a}return 16}return 0}return 10}function MQ(a,b){a:{v[22656]=0;Oc(a,B(b,7),1);a=v[22656];v[22656]=0;if((a|0)!=1){break a}V(0)|0;O()|0;Bb();L()}}function Cw(a,b,c){a:{v[22656]=0;Oc(b,c<<1,2);a=v[22656];v[22656]=0;if((a|0)!=1){break a}V(0)|0;O()|0;Bb();L()}}function An(a){a=w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24);return a<<24|a<<8&16711680|(a>>>8&65280|a>>>24)}function wK(a){var b=0,c=0,d=0,e=0;b=gb-16|0;gb=b;c=b+8|0;d=c,e=AO(a),v[d>>2]=e;Ao(c);gb=b+16|0;return v[c>>2]}function qS(a,b){var c=0;c=gb-16|0;gb=c;v[c+8>>2]=v[a+4>>2];v[c>>2]=v[b+4>>2];a=Gb(c+8|0,c);gb=c+16|0;return a}function aba(a){a=a|0;var b=0,c=0;b=gb-16|0;gb=b;c=Tb(b,9765);rc(a,c);vb(c);v[a>>2]=54876;gb=b+16|0;return a|0}function Uf(a,b){var c=0;c=v[a+4>>2];if(b){a=v[a>>2];v[a>>2]=v[a>>2]|c;return}a=v[a>>2];v[a>>2]=v[a>>2]&(c^-1)}function Sg(a,b,c){if(!c){return v[a+4>>2]==v[b+4>>2]}if((a|0)==(b|0)){return 1}return!wj(v[a+4>>2],v[b+4>>2])}function Ov(a,b){var c=0;c=gb-16|0;gb=c;v[c+12>>2]=(B(a,b)>>>0)/255;Zd(c+12|0,0,15);gb=c+16|0;return w[c+12|0]}function Maa(a){a=a|0;var b=0,c=0;b=gb-16|0;gb=b;c=Tb(b,5324);rc(a,c);vb(c);v[a>>2]=54896;gb=b+16|0;return a|0}function xC(a,b){a:{v[22656]=0;Oc(a,b<<2,1);a=v[22656];v[22656]=0;if((a|0)!=1){break a}V(0)|0;O()|0;Bb();L()}}function vf(a){a=a|0;var b=0;b=v[18929];v[a>>2]=b;v[v[b-12>>2]+a>>2]=v[18932];eu(a+8|0);oh(a+60|0);return a|0}function o9(a,b){a=a|0;b=b|0;if(a){b=kb[v[v[b>>2]+8>>2]](b)|0;a:{if(b){b=ie(b);break a}b=ie(18726)}v[a>>2]=b}}function kO(a,b){a:{switch(b-1|0){default:return a+724|0;case 0:return a+732|0;case 1:break a}}return a+740|0}function gP(a,b){a:{v[22656]=0;Oc(a,b<<3,4);a=v[22656];v[22656]=0;if((a|0)!=1){break a}V(0)|0;O()|0;Bb();L()}}function _S(a,b){var c=0;c=v[a+4>>2]+b|0;v[a+4>>2]=c&31;v[a>>2]=v[a>>2]+(((b|0)>=0?c>>>5|0:(c-31|0)/32|0)<<2)}function MB(a,b){a:{v[22656]=0;Oc(a,b<<5,1);a=v[22656];v[22656]=0;if((a|0)!=1){break a}V(0)|0;O()|0;Bb();L()}}function LB(a,b){a:{v[22656]=0;Oc(a,b<<4,1);a=v[22656];v[22656]=0;if((a|0)!=1){break a}V(0)|0;O()|0;Bb();L()}}function KF(a,b){a:{v[22656]=0;Oc(a,b<<3,1);a=v[22656];v[22656]=0;if((a|0)!=1){break a}V(0)|0;O()|0;Bb();L()}}function JB(a,b){a:{v[22656]=0;Oc(a,b<<8,1);a=v[22656];v[22656]=0;if((a|0)!=1){break a}V(0)|0;O()|0;Bb();L()}}function EY(a,b){a:{v[22656]=0;Oc(a,b<<1,1);a=v[22656];v[22656]=0;if((a|0)!=1){break a}V(0)|0;O()|0;Bb();L()}}function Cq(a){a=a|0;var b=0;b=v[18884];v[a>>2]=b;v[v[b-12>>2]+a>>2]=v[18887];eu(a+4|0);oh(a+56|0);return a|0}function CK(a,b){a:{v[22656]=0;Oc(a,b<<4,4);a=v[22656];v[22656]=0;if((a|0)!=1){break a}V(0)|0;O()|0;Bb();L()}}function wC(a){var b=0,c=0;c=a;b=v[a+8>>2];a=v[a+4>>2];if((b|0)!=(a|0)){v[c+8>>2]=(((b-a|0)-4>>>2^-1)<<2)+b}}function vI(a){var b=0;b=v[a+12>>2];if((b|0)==v[a+16>>2]){return kb[v[v[a>>2]+36>>2]](a)|0}return Mg(t[b|0])}function pH(a,b,c,d,e){b=pj(b,c,d,e,4);if(!(w[d|0]&4)){v[a>>2]=((b|0)<69?b+2e3|0:(b|0)<100?b+1900|0:b)-1900}}function mH(a,b,c,d,e){b=oj(b,c,d,e,4);if(!(w[d|0]&4)){v[a>>2]=((b|0)<69?b+2e3|0:(b|0)<100?b+1900|0:b)-1900}}function eW(a,b){a=a|0;b=b|0;var c=0;c=gb-16|0;gb=c;u[c+14>>1]=b;if((am(a)|0)!=65535){_D(a,c+14|0)}gb=c+16|0}function al(a,b,c){a:{v[22656]=0;Oc(b,c,1);a=v[22656];v[22656]=0;if((a|0)!=1){break a}V(0)|0;O()|0;Bb();L()}}function VR(a){var b=0;b=v[a+4>>2];u[a+70>>1]=w[((x[b+22>>1]<<4|x[b+20>>1]>>>6)&65535)+35360|0]>>>x[a+68>>1]}function Po(a,b){a=a|0;b=b|0;if(tc(a)>>>0>b>>>0){a=me(v[a+24>>2]+484344|0,x[fj(a,b)>>1])}else{a=0}return a|0}function GN(a){a=a|0;var b=0;b=v[v[a>>2]-12>>2]+a|0;v[b+4>>2]=v[b+4>>2]&-75;v[b+4>>2]=v[b+4>>2]|8;return a|0}function zf(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=gb-16|0;gb=d;if(!xv(a,b)){b=xv(c,a)?c:a}gb=d+16|0;return b|0}function vV(a,b){t[a+6|0]=255;v[a+16>>2]=0;u[a+4>>1]=0;v[a>>2]=0;if(b>=0){A[a+8>>3]=b;v[a+16>>2]=3}return a}function ona(a,b){a=a|0;b=b|0;if(!oW(a,b)){t[b+4|0]=0;t[b+5|0]=0;t[b|0]=0;t[b+1|0]=0;t[b+2|0]=0;t[b+3|0]=0}}function oJ(a,b,c,d){z[d+4>>2]=a+c;a=C(a+C(c*C(-.5)));b=C(b*C(.8660253882408142));z[d+8>>2]=a-b;z[d>>2]=b+a}function dj(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=gb-16|0;gb=d;if(!pt(a,b)){b=pt(c,a)?c:a}gb=d+16|0;return b|0}function by(a,b){var c=0;if(b>>>0<=9999){return ay(a,b)}c=a;a=(b>>>0)/1e4|0;return vj(ay(c,a),b-B(a,1e4)|0)}function a2(){var a=0;if(np()>>>0<=29){Sc();L()}a=OG(px(465776),30);v[116444]=a;v[116445]=a;v[116446]=a+120}function Sh(a,b){var c=0;c=a;b=v[a+16>>2]+b|0;a=v[a+12>>2];b=(b|0)%(a|0)|0;return z[Cc(c,(b>>31&a)+b|0)>>2]}function vy(a,b){var c=0;c=(B(B(ty(a),uy(a)),125)>>>0)/(vJ(a)>>>0)|0;a=(w[a+1|0]&6)==6?c&-4:c;return a?a:b}function vJ(a){var b=0;b=v[(w[a+2|0]&12)+61728>>2];a=w[a+1|0];return b>>>((a>>>3^-1)&1)>>>((a>>>4^-1)&1)|0}function pw(a,b){a:{switch(b-1|0){default:return a+48|0;case 0:return a+68|0;case 1:break a}}return a+88|0}function bna(a,b){a=a|0;b=b|0;var c=0;b=gb-16|0;gb=b;c=-1;if(ek(a,b+8|0)){c=OV(b+8|0)}gb=b+16|0;return c|0}function _t(a){var b=0;b=gb-16|0;gb=b;t[b+15|0]=251;t[b+14|0]=255;a=Mv(a,b+15|0,b+14|0);gb=b+16|0;return a}function Upa(a,b){a=a|0;b=b|0;var c=0;b=gb-80|0;gb=b;c=-1;if(xY(a,b+8|0)){c=wY(b+8|0)}gb=b+80|0;return c|0}function Ao(a){var b=0,c=0,d=0;b=a;a=v[a>>2];c=b,d=zb(B(a,214013)+2531011|0),v[c>>2]=d;return a>>>16&32767}function xw(a,b){a=a|0;b=b|0;if((a&4088)>>>0>=520){b=ww(0-oqa(b^1230262859,25)|0,4)^1247037516}return b|0}function wY(a){return(w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24))==1179468868&(w[a+4|0]-1&255)>>>0<10}function r0(a){a=a|0;a=gb-16|0;gb=a;if(ab(a+12|0,4)|0){Es(v[115137],9957);L()}gb=a+16|0;return v[a+12>>2]}function pz(a,b){mc(a);v[a+20>>2]=0;v[a+12>>2]=0;v[a+16>>2]=0;Io(a+24|0);Kb(a+36|0);v[a+48>>2]=b;return a}function pI(a){var b=0;b=v[a+12>>2];if((b|0)==v[a+16>>2]){return kb[v[v[a>>2]+36>>2]](a)|0}return v[b>>2]}function mL(a){var b=0;while(1){if(!v[(b<<2)+a>>2]){return b}b=b+1|0;if((b|0)!=4){continue}break}return 4}function k$(a,b){a=a|0;b=b|0;var c=0;b=gb-32|0;gb=b;c=-1;if(lG(a,b+8|0)){c=kG(b+8|0)}gb=b+32|0;return c|0}function jv(a,b){a=a|0;b=b|0;var c=0;c=gb-16|0;gb=c;wn(c+8|0,a);v[c+4>>2]=v[c+8>>2];gr(c+4|0,b);gb=c+16|0}function cZ(a,b){a=a|0;b=b|0;var c=0;b=gb-16|0;gb=b;c=-1;if(ek(a,b+8|0)){c=ID(b+8|0)}gb=b+16|0;return c|0}function Zp(){var a=0;v[22656]=0;a=v[22656];v[22656]=0;if((a|0)!=1){return v[19286]}V(0)|0;O()|0;Bb();L()}function WG(a,b,c,d,e,f,g,h){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;v[e>>2]=c;v[h>>2]=f;return 3}function QP(a,b,c,d){if(!((b|0)==(c|0)|(d|0)>=0)){t[b|0]=45;d=0-(d&65535)&65535;b=b+1|0}AA(a,b,c,d&65535)}function Og(a){var b=0,c=0;b=gb-16|0;gb=b;if(Ep(a,b+8|0)){a=b+8|0;c=w[a|0]|w[a+1|0]<<8}gb=b+16|0;return c}function Ks(){var a=0;v[22656]=0;a=v[22656];v[22656]=0;if((a|0)!=1){return v[19868]}V(0)|0;O()|0;Bb();L()}function Js(){var a=0;v[22656]=0;a=v[22656];v[22656]=0;if((a|0)!=1){return v[19480]}V(0)|0;O()|0;Bb();L()}function A_(a,b){a=a|0;b=b|0;var c=0;b=gb-16|0;gb=b;c=-1;if(ek(a,b+8|0)){c=AF(b+8|0)}gb=b+16|0;return c|0}function vO(a,b){v[22656]=0;Oc(a,b<<2,4);a=v[22656];v[22656]=0;if((a|0)!=1){return}V(0)|0;O()|0;Bb();L()}function jq(a,b){var c=0,d=0,e=0;c=gb-16|0;gb=c;d=c,e=ce(b),v[d+12>>2]=e;Ge(a,c+12|0);gb=c+16|0;return a}function hr(a){if(a>=4294967295){return-1}if(a<=0){return 0}if(a<4294967296&a>=0){return~~a>>>0}return 0}function bg(a,b){var c=0,d=0;c=v[a>>2];d=v[b>>2];jb=v[a+4>>2]-(v[b+4>>2]+(c>>>0<d>>>0)|0)|0;return c-d|0}function Jx(a){a=a|0;var b=0;b=v[115196];if(a){v[115196]=(a|0)==-1?460592:a}return((b|0)==460592?-1:b)|0}function xc(a,b){var c=0;c=gb-16|0;gb=c;v[c+12>>2]=v[a>>2];v[a>>2]=v[b>>2];v[b>>2]=v[c+12>>2];gb=c+16|0}function i_(a,b){a=a|0;b=b|0;var c=0,d=0;c=gb-16|0;gb=c;d=c+8|0;Sk(d,a,22);_r(d,b);gb=c+16|0;return a|0}function gZ(a,b){a=a|0;b=b|0;var c=0,d=0;c=gb-16|0;gb=c;d=c+8|0;Sk(d,a,20);_r(d,b);gb=c+16|0;return a|0}function WP(a,b){var c=0,d=0;a:{if(b<0){break a}c=A[a>>3];if(!(c<0)){d=b;if(!(b<c)){break a}}A[a>>3]=d}}function SO(a,b){var c=0;c=gb-16|0;gb=c;a=bA(c,a);xq(v[a+4>>2],b);v[a+4>>2]=v[a+4>>2]+4;$b(a);gb=c+16|0}function Rz(a,b){var c=0;c=gb-16|0;gb=c;u[c+14>>1]=x[a>>1];u[a>>1]=x[b>>1];u[b>>1]=x[c+14>>1];gb=c+16|0}function Rw(a,b,c){var d=0;d=gb-16|0;gb=d;a=Ud(a);v[a+4>>2]=c;v[a>>2]=b;v[d+4>>2]=b;v[d>>2]=b;gb=d+16|0}function SB(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=v[b>>2]+c|0;if((d|0)==-1){d=yb(b)-c|0}wd(a,e,d)}function Dq(a,b,c){a=uk(a+1074376|0)-v[a+1074392>>2]|0;if(a>>>0>=2){c=C(C(C(c-b)/C(a>>>0))+b)}return c}function vh(a){var b=0;b=gb-16|0;gb=b;v[a>>2]=0;v[a+4>>2]=0;v[b+12>>2]=0;Zo(a+8|0);gb=b+16|0;return a}function uy(a){var b=0;b=w[a+1|0];return w[(B(b>>>3&1,45)+B(b>>>1&3,15)+(w[a+2|0]>>>4)|0)+61729|0]<<1}function tT(a){v[22656]=0;Oc(a,48,4);a=v[22656];v[22656]=0;if((a|0)!=1){return}V(0)|0;O()|0;Bb();L()}function n_(a,b){a=a|0;b=b|0;var c=0,d=0;c=gb-16|0;gb=c;d=c+8|0;eF(d,a);_r(d,b);gb=c+16|0;return a|0}function mv(a){v[22656]=0;Oc(a,20,4);a=v[22656];v[22656]=0;if((a|0)!=1){return}V(0)|0;O()|0;Bb();L()}function jm(a){t[a|0]=0;t[a+1|0]=0;t[a+2|0]=0;t[a+3|0]=0;t[a+4|0]=0;t[a+5|0]=0;t[a+6|0]=0;t[a+7|0]=0}function hT(a){zB(a+140|0);xb(a+120|0);xb(a+100|0);xb(a+80|0);xb(a+60|0);xb(a+40|0);xb(a+20|0);xb(a)}function dX(a,b){var c=0;c=v[a>>2];v[a>>2]=b;if(c){XW(c+52|0);vb(c+40|0);Nc(c+16|0);Nc(c+4|0);Yb(c)}}function ZW(a){v[22656]=0;Oc(a,32,4);a=v[22656];v[22656]=0;if((a|0)!=1){return}V(0)|0;O()|0;Bb();L()}function Xv(a){t[a|0]=0;t[a+1|0]=0;t[a+2|0]=0;t[a+3|0]=0;t[a+3|0]=0;t[a+4|0]=0;t[a+5|0]=0;t[a+6|0]=0}function MA(a){v[22656]=0;Oc(a,40,4);a=v[22656];v[22656]=0;if((a|0)!=1){return}V(0)|0;O()|0;Bb();L()}function Hi(a){var b=C(0),c=C(0);a:{b=z[a>>2];if(!(b<C(0))){c=C(1);if(!(b>C(1))){break a}}z[a>>2]=c}}function HK(a,b){var c=0,d=0;c=v[a+4>>2];d=v[b+4>>2];return(c|0)<=(d|0)&y[b>>2]>y[a>>2]|(c|0)<(d|0)}
function CV(a){u[a+10>>1]=0;u[a+12>>1]=0;u[a+8>>1]=1084;v[a>>2]=0;v[a+4>>2]=40;u[a+14>>1]=0;return a}function $N(a){v[22656]=0;Oc(a,28,4);a=v[22656];v[22656]=0;if((a|0)!=1){return}V(0)|0;O()|0;Bb();L()}function vw(a,b){var c=0,d=0;c=v[a+4>>2];d=v[b+4>>2];return(c|0)==(d|0)&y[b>>2]>y[a>>2]|c>>>0<d>>>0}function mda(a,b,c){a=a|0;b=b|0;c=c|0;a=pk(a);if(!a){return 0}return kb[v[v[a>>2]+100>>2]](a,b,c)|0}function OR(a,b,c){if((b|0)!=(c|0)){while(1){MR(a,w[b|0]);b=b+1|0;if((c|0)!=(b|0)){continue}break}}}function Ld(a){var b=0;b=gb-16|0;gb=b;v[b+12>>2]=54992;v[b+8>>2]=55096;Su(a,b+12|0,b+8|0);gb=b+16|0}function uma(a,b){a=a|0;b=b|0;var c=0;b=gb-16|0;gb=b;c=-1;if(oD(a,b)){c=qV(b)}gb=b+16|0;return c|0}function m9(a,b){a=a|0;b=b|0;var c=0;c=v[a+4>>2];b=Jb(b);if(c){kb[c|0](b,v[a+8>>2]);return}Lt(b,a)}function hga(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;kb[v[v[b>>2]+8>>2]](b,c);d=a;a=b+4|0;_p(d,a);YG(a,c)}function e_(a){a=a|0;var b=0;b=gb-16|0;gb=b;a=RE(a,b+15|0);gb=b+16|0;return(a?w[b+15|0]:0)<<24>>24}function T1(a,b,c){a=a|0;b=b|0;c=c|0;if(c>>>0<=127){a=(x[Zp()+(c<<1)>>1]&b)!=0}else{a=0}return a|0}function Ql(a){a=a|0;var b=0;Pl(a);b=Sq(v[a>>2],jj(a));v[a+20>>2]=b;if(!b){return 0}return aj(a)|0}function pr(a,b){a=a|0;b=b|0;var c=0;c=gb-16|0;gb=c;u[c+14>>1]=b;pv(a+236|0,128,c+14|0);gb=c+16|0}function fi(a,b){var c=0;c=gb-16|0;gb=c;t[c+15|0]=w[a|0];t[a|0]=w[b|0];t[b|0]=w[c+15|0];gb=c+16|0}function Yfa(a,b){a=a|0;b=b|0;et(a);v[a>>2]=74808;Kb(a+32|0);v[a+48>>2]=b;v[a+44>>2]=0;return a|0}function NQ(a,b,c){a=a|0;b=b|0;c=c|0;Ge(a,b);b=v[c+4>>2];v[a+4>>2]=v[c>>2];v[a+8>>2]=b;return a|0}function JG(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=Ab(a);if(d>>>0<b>>>0){xs(a,b-d|0,c);return}AE(a,b)}function FE(a){var b=0;b=w[a+35|0];a=b>>>21|0;b=(b<<11)+2624|0;a=b>>>0<2624?a+1|0:a;jb=a;return b}function Bg(a){a=a|0;var b=0,c=0;while(1){c=b&65535;gu(a,c);b=b+1|0;if(c>>>0<126){continue}break}}function y5(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;kb[v[v[a>>2]+44>>2]](a,b,c,d,e,f)|0}function we(a,b){var c=0;c=gb-16|0;gb=c;v[c+8>>2]=v[a>>2];ow(c+8|0,b);gb=c+16|0;return v[c+8>>2]}function uR(a,b){var c=0;c=gb-16|0;gb=c;a=v[yc(c+8|0,fR(a,b,Yd(a),fc(a)))>>2];gb=c+16|0;return a}function Uq(a){a=a|0;var b=0;b=gb-16|0;gb=b;t[b+15|0]=0;Lo(a,a+32|0,b+15|0);gb=b+16|0;return a|0}function I5(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;kb[v[v[a>>2]+12>>2]](a,b,c,d,e,f)|0}function G5(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;kb[v[v[a>>2]+24>>2]](a,b,c,d,e,f)|0}function E5(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;kb[v[v[a>>2]+16>>2]](a,b,c,d,e,f)|0}function CX(a,b){var c=0;c=gb-16|0;gb=c;v[c+8>>2]=v[a>>2];BX(c+8|0,b);gb=c+16|0;return v[c+8>>2]}function C5(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;kb[v[v[a>>2]+28>>2]](a,b,c,d,e,f)|0}function A5(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;kb[v[v[a>>2]+20>>2]](a,b,c,d,e,f)|0}function $o(a,b){var c=0;c=gb-16|0;gb=c;v[c+8>>2]=v[a>>2];TV(c+8|0,b);gb=c+16|0;return v[c+8>>2]}function vq(a,b,c){a=v[a>>2]+1074992|0;return v[(a+B(b,872)|0)+680>>2]>v[(a+B(c,872)|0)+680>>2]}function vfa(a,b){a=a|0;b=b|0;Ki(a);Ki(a);a:{if(b>>>0>=60){Rb(a,4);break a}Ki(a)}return Ki(a)|0}function sN(a,b){b=gb-16|0;gb=b;v[a>>2]=0;v[a+4>>2]=0;v[b+12>>2]=0;Zo(a+8|0);gb=b+16|0;return a}function r8(a){a=a|0;var b=0;b=gb-16|0;gb=b;a=v[Wi(b+8|0,TB(sf(12),a))>>2];gb=b+16|0;return a|0}function lZ(a,b){a=a|0;b=b|0;if(!$v(a,b)){t[b+1|0]=0;t[b+2|0]=0;t[b+3|0]=0;t[b+4|0]=0;t[b|0]=0}}function l5(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;kb[v[v[b>>2]+16>>2]](a,b,v[c+8>>2],v[c+12>>2],0,d)}function kda(a,b){a=a|0;b=b|0;b=gb-16|0;gb=b;Vd(b,v[a+20>>2]+4|0);KM(a,ne(b+8|0,b),0);gb=b+16|0}function kJ(a){var b=0;b=+((a&2097151)>>>0);return C(ii(+C((a|0)>=0?b:-b),(a>>>21&1023)-788|0))}function ica(a){a=a|0;var b=0,c=0;t[a+4202|0]=1;b=a,c=wf(v[a+16>>2]),v[b+4256>>2]=c;jM(a);iM(a)}function f_(a){a=a|0;var b=0,c=0;b=gb-16|0;gb=b;if(Ng(a,b+8|0)){c=w[b+8|0]}gb=b+16|0;return c|0}function fV(a){var b=0,c=0;b=1;c=v[a>>2];a:{if((c|0)>0){b=120;if(c>>>0<121){break a}}v[a>>2]=b}}function Vna(a){a=a|0;var b=0;b=gb-16|0;gb=b;a=js(a,b+8|0);gb=b+16|0;return C(a?z[b+8>>2]:C(0))}function Ida(a){a=a|0;var b=0,c=0;t[a+4202|0]=1;b=a,c=wf(v[a+16>>2]),v[b+4232>>2]=c;Ut(a);WM(a)}function G$(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;if(Sg(a,v[b+8>>2],f)){gx(b,c,d,e)}}function qY(a,b){return(Lb((B(a>>>4|0,b)>>>0)/15|0,1,15)<<4|Lb((B(a&15,b)>>>0)/15|0,1,15))&255}function nT(a){var b=0;b=w[a+47|0];a=b>>>27|0;b=(b<<5)+259|0;a=b>>>0<259?a+1|0:a;jb=a;return b}function TX(a,b){var c=0;c=gb-16|0;gb=c;v[c>>2]=b;v[c+8>>2]=a;a=ck(c,c+8|0);gb=c+16|0;return a}function Qo(a,b){a=a|0;b=+b;var c=0,d=0,e=0;c=v[a+24>>2];d=a,e=Ah(Ek(b)*+(c>>>0)),v[d+24>>2]=e}function P6(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;kb[v[v[b>>2]+16>>2]](a,b,c,d,e,f)}function M6(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;a=vz(Et(a+8|0,b,c,d,3));return(a>>>0<5?a+1|0:0)|0}function IA(a){var b=0;b=B(32-E(a|1)|0,1233)>>>12|0;return(b-(y[(b<<2)+27040>>2]>a>>>0)|0)+1|0}function AD(a,b){var c=0;c=gb-16|0;gb=c;v[c>>2]=b;v[c+8>>2]=a;a=sp(c,c+8|0);gb=c+16|0;return a}function ui(a){var b=0;b=gb-16|0;gb=b;a=v[yc(b+8|0,Jb(a)+(Ab(a)<<2)|0)>>2];gb=b+16|0;return a}function nd(a,b){var c=0,d=0;c=gb-16|0;gb=c;d=c+8|0;Bl(d,a+24|0,b);a=Cb(d);gb=c+16|0;return a}function n$(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;a=kb[a|0](b,c,d,e)|0;ma(jb|0);return a|0}function h0(a,b,c){a=a|0;b=b|0;c=c|0;if(Ie(a,v[b+4>>2])){a=v[b>>2]==(c|0)}else{a=0}return a|0}function WT(a,b,c){var d=0;v[a>>2]=v[b>>2];d=v[b>>2];v[a+8>>2]=b;v[a+4>>2]=B(c,12)+d;return a}function Df(a,b){a=a|0;b=b|0;var c=0,d=0;c=gb-16|0;gb=c;d=a;a=Tb(c,b);Dc(d,a);vb(a);gb=c+16|0}function AW(a){return(w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24))==1279544644&w[a+4|0]<32}function zI(a,b,c){var d=0;v[a>>2]=v[b>>2];d=v[b>>2];v[a+8>>2]=b;v[a+4>>2]=(c<<4)+d;return a}function zE(a){var b=0;b=gb-16|0;gb=b;a=Ng(a,b+15|0);gb=b+16|0;return(a?w[b+15|0]:0)<<24>>24}function yT(a,b,c){var d=0;v[a>>2]=v[b>>2];d=v[b>>2];v[a+8>>2]=b;v[a+4>>2]=(c<<5)+d;return a}function t5(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=+e;return kb[v[v[a>>2]+32>>2]](a,b,c,d,e)|0}function c8(a,b){a=a|0;b=b|0;var c=0,d=0;c=gb-16|0;gb=c;d=c+8|0;uw(d,b,20);Zr(a,d);gb=c+16|0}function XG(a){a=a|0;var b=0;v[a>>2]=81292;b=v[a+8>>2];if(!(!b|!w[a+12|0])){Yb(b)}return a|0}function Tk(a,b,c){var d=0;v[a>>2]=v[b>>2];d=v[b>>2];v[a+8>>2]=b;v[a+4>>2]=(c<<2)+d;return a}function JH(a){var b=0,c=0;c=a;while(1){b=c;c=b+4|0;if(v[b>>2]){continue}break}return b-a>>2}function Fn(a,b,c){var d=0;v[a>>2]=v[b>>2];d=v[b>>2];v[a+8>>2]=b;v[a+4>>2]=(c<<1)+d;return a}function Bma(a){a=a|0;var b=0,c=0;b=gb-32|0;gb=b;c=a;a=Jh(b+8|0);NV(c,a,0,0);xb(a);gb=b+32|0}function yA(a){var b=0;v[a+84>>2]=0;v[a+88>>2]=0;b=v[a+80>>2];v[a+92>>2]=b;v[a+96>>2]=b<<12}function vr(a,b){var c=0;c=Ab(a);if((c|0)==(Ab(b)|0)){a=Wo(Jb(a),Jb(b),c)}else{a=1}return!a}function pd(a,b){a=a|0;b=b|0;var c=0,d=0;c=gb-16|0;gb=c;d=pt(b,a);gb=c+16|0;return(d?b:a)|0}function iba(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;QL(a,b,c,d,e,0,0,f,g)}function ema(a){a=a|0;var b=0;b=gb-16|0;gb=b;a=kj(a,b+8|0);gb=b+16|0;return+(a?A[b+8>>3]:0)}function df(a,b){a=a|0;b=b|0;var c=0,d=0;c=gb-16|0;gb=c;d=nL(a,b);gb=c+16|0;return(d?b:a)|0}function cS(a,b,c,d){var e=0;e=gb-16|0;gb=e;d=li(e,a,d);wb(a);nv(b,c,d+4|0);$b(d);gb=e+16|0}function ac(a,b){a=a|0;b=b|0;var c=0,d=0;c=gb-16|0;gb=c;d=nL(b,a);gb=c+16|0;return(d?b:a)|0}function _O(a){v[a+20>>2]=0;t[a+16|0]=7;v[a+8>>2]=1889785610;v[a+12>>2]=1072630333;t[a|0]=3}function WV(a,b,c,d){var e=0;e=gb-16|0;gb=e;d=Fg(e,a,d);wb(a);nv(b,c,d+4|0);$b(d);gb=e+16|0}function Uk(a,b){a=a|0;b=b|0;var c=0,d=0;c=gb-16|0;gb=c;d=vw(b,a);gb=c+16|0;return(d?b:a)|0}function Py(a,b){a=a|0;b=b|0;var c=0,d=0;c=gb-16|0;gb=c;d=HK(a,b);gb=c+16|0;return(d?b:a)|0}function Pr(a,b){a=a|0;b=b|0;var c=0,d=0;c=gb-16|0;gb=c;d=HK(b,a);gb=c+16|0;return(d?b:a)|0}function Pc(a,b){a=a|0;b=b|0;var c=0,d=0;c=gb-16|0;gb=c;d=Hn(b,a);gb=c+16|0;return(d?b:a)|0}function Pb(a,b){a=a|0;b=b|0;var c=0;c=v[a>>2];return kb[v[v[c>>2]+32>>2]](c,v[a+8>>2],b)|0}function Le(a,b){a=a|0;b=b|0;var c=0,d=0;c=gb-16|0;gb=c;d=Hn(a,b);gb=c+16|0;return(d?b:a)|0}function Lc(a,b){a=a|0;b=b|0;var c=0,d=0;c=gb-16|0;gb=c;d=zn(a,b);gb=c+16|0;return(d?b:a)|0}function KL(a,b,c){a=a|0;b=b|0;c=c|0;Ry(a);v[a+8>>2]=c;v[a+4>>2]=b;v[a>>2]=54812;return a|0}function ID(a){return(w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24))==810369604&w[a+4|0]<4}function Gf(a,b){a=a|0;b=b|0;var c=0,d=0;c=gb-16|0;gb=c;d=pt(a,b);gb=c+16|0;return(d?b:a)|0}function Fb(a,b){a=a|0;b=b|0;var c=0,d=0;c=gb-16|0;gb=c;d=zn(b,a);gb=c+16|0;return(d?b:a)|0}function xoa(a){a=a|0;var b=0,c=0;b=gb-16|0;gb=b;c=a;a=Tb(b,13290);Dc(c,a);vb(a);gb=b+16|0}function rda(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;a=pk(a);if(a){kb[v[v[a>>2]+76>>2]](a,b,c,d)}}function qda(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;a=pk(a);if(a){kb[v[v[a>>2]+84>>2]](a,b,c,d)}}function pda(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;a=pk(a);if(a){kb[v[v[a>>2]+88>>2]](a,b,c,d)}}function gh(a){var b=0;b=a+44|0;Zx(b);if(v[b>>2]){eX(b);_n(wb(b),v[b>>2],xi(b))}gc(a+32|0)}function fM(a,b){var c=0;c=v[a+12>>2];if((c|0)>0){v[a+20>>2]=(v[a+16>>2]+(b+c|0)|0)%(c|0)}}function fI(a){var b=0;b=v[a>>2];if(b){if(!Ie(vI(b),-1)){return!v[a>>2]}v[a>>2]=0}return 1}function eI(a){var b=0;b=v[a>>2];if(b){if(!Ie(pI(b),-1)){return!v[a>>2]}v[a>>2]=0}return 1}function bG(a,b){var c=0,d=0;Ip(a);v[a>>2]=27616;v[a+4>>2]=v[b>>2];c=a,d=yb(b),v[c+8>>2]=d}function _N(a){var b=0;b=v[a>>2];v[a>>2]=0;if(b){if(w[fc(a)+4|0]){Hb(b+16|0)}if(b){$N(b)}}}function Xk(a){var b=0;if(a>>>0>=11){b=a+16&-16;a=b-1|0;a=(a|0)==11?b:a}else{a=10}return a}function Rv(a,b){a=a|0;b=b|0;var c=0;c=gb-16|0;gb=c;Ke(c,1,a);dF(c,b);gb=c+16|0;return a|0}function Pj(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=gb-16|0;gb=d;FS(a,b,c);gb=d+16|0;return a|0}function Jr(a,b){a=a|0;b=b|0;var c=0;c=gb-16|0;gb=c;Gr(c,1,a);dF(c,b);gb=c+16|0;return a|0}function Ema(a){a=a|0;var b=0,c=0;b=gb-16|0;gb=b;c=a;a=Tb(b,13893);Dc(c,a);vb(a);gb=b+16|0}function Dc(a,b){var c=0;c=v[b+4>>2];v[a>>2]=v[b>>2];v[a+4>>2]=c;v[a+8>>2]=v[b+8>>2];RA(b)}function Bz(a,b){a=a|0;b=b|0;b=b-1|0;if(b>>>0<=4){b=v[(b<<2)+18828>>2]}else{b=6884}Tb(a,b)}function toa(a){a=a|0;var b=0,c=0;b=gb-16|0;gb=b;c=a;a=Tb(b,1580);Dc(c,a);vb(a);gb=b+16|0}function oqa(a,b){var c=0,d=0;c=b&31;d=(-1>>>c&a)<<c;c=a;a=0-b&31;return d|(c&-1<<a)>>>a}
function opa(a){a=a|0;var b=0,c=0;b=gb-16|0;gb=b;c=a;a=Tb(b,1040);Dc(c,a);vb(a);gb=b+16|0}function o$(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;kb[a|0](b,c,d,e,f,g)}function mt(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=(b|0)/(c|0)|0;v[a>>2]=d;v[a+4>>2]=b-B(c,d)}function l_(a,b){a=a|0;b=b|0;var c=0,d=0;c=gb-16|0;gb=c;d=c+8|0;zw(d,b);Zr(a,d);gb=c+16|0}function jla(a){a=a|0;var b=0,c=0;b=gb-16|0;gb=b;c=a;a=Tb(b,1274);Dc(c,a);vb(a);gb=b+16|0}function hU(a){var b=0;b=443250/+(a>>>0)*1e4;if(b<4294967296&b>=0){return~~b>>>0}return 0}function Xma(a){a=a|0;var b=0,c=0;b=gb-16|0;gb=b;c=a;a=Tb(b,1983);Dc(c,a);vb(a);gb=b+16|0}function Wma(a){a=a|0;var b=0,c=0;b=gb-16|0;gb=b;c=a;a=Tb(b,1031);Dc(c,a);vb(a);gb=b+16|0}function Sy(a){a=a|0;var b=0;v[a>>2]=54916;b=v[a+4>>2];if(b){Yb(b);v[a+4>>2]=0}return a|0}function Q$(a){a=a|0;var b=0,c=0;b=gb-16|0;gb=b;c=a;a=Tb(b,13920);Dc(c,a);vb(a);gb=b+16|0}function Mx(a,b,c,d){var e=0;e=gb-16|0;gb=e;v[e+12>>2]=d;a=Us(a,b,c,d);gb=e+16|0;return a}function IW(a,b,c,d){a=c-b|0;c=v[d>>2]+B((a|0)/-6|0,6)|0;v[d>>2]=c;if((a|0)>0){hc(c,b,a)}}function Fma(a){a=a|0;var b=0,c=0;b=gb-16|0;gb=b;c=a;a=Tb(b,1116);Dc(c,a);vb(a);gb=b+16|0}function tda(a,b){a=a|0;b=b|0;a=pk(a);if(!a){return 1}return kb[v[v[a>>2]+68>>2]](a,b)|0}function qP(a,b){var c=0;c=w[a+851|0];if(c&1){t[a+851|0]=c|32;v[a+852>>2]=v[a+852>>2]+b}}function pv(a,b,c){if(b){while(1){u[a>>1]=x[c>>1];a=a+2|0;b=b-1|0;if(b){continue}break}}}function pZ(a){a=a|0;var b=0,c=0;b=gb-16|0;gb=b;c=a;a=Tb(b,1467);Dc(c,a);vb(a);gb=b+16|0}function lN(a,b,c){if(b){while(1){z[a>>2]=z[c>>2];a=a+4|0;b=b-1|0;if(b){continue}break}}}function gf(a){var b=0;b=gb-16|0;gb=b;a=v[yc(b+8|0,Jb(a)+Ab(a)|0)>>2];gb=b+16|0;return a}function ge(a,b,c){var d=0;d=gb-16|0;gb=d;v[d+12>>2]=b;uH(a,d+12|0,c);gb=d+16|0;return a}function a6(a,b,c){a=a|0;b=b|0;c=c|0;if(!((c|0)==1|(c|0)>256)){ox(a,c);return}Tb(a,5018)}function Zw(){var a=0,b=0;a=gb-16|0;gb=a;b=os(a+8|0,mc(sf(12)));gb=a+16|0;return v[b>>2]}function Z$(a){a=a|0;var b=0,c=0;b=gb-16|0;gb=b;c=a;a=Tb(b,1628);Dc(c,a);vb(a);gb=b+16|0}function Sd(a){a=a|0;var b=0,c=0;b=gb-16|0;gb=b;c=b+8|0;Or(c,a);gb=b+16|0;return v[c>>2]}function Cea(a,b,c){a=a|0;b=b|0;c=c|0;if(!((c|0)!=4&(c|0)!=-1)){Ik(a,b);return}_M(a,b,c)}function Bi(a){if(vK(a)){a=ba(4)|0;v[a>>2]=0;Fm(a);v[a>>2]=88988;ia(a|0,89024,1928);L()}}function Ae(a){var b=0;b=gb-16|0;gb=b;a=Ng(a,b+15|0);gb=b+16|0;return(a?w[b+15|0]:0)&255}function hn(a,b,c){a=a|0;b=b|0;c=c|0;a=x[c>>1]|x[c+2>>1]<<16;u[b>>1]=a;u[b+2>>1]=a>>>16}function bj(a){t[a|0]=0;t[a+1|0]=0;t[a+2|0]=0;t[a+3|0]=0;t[a+4|0]=0;t[a+5|0]=0;return a}function bh(a,b,c){var d=0;d=gb-16|0;gb=d;if(!dT(a,b)){b=dT(c,a)?c:a}gb=d+16|0;return b}function QI(a){var b=0;b=jqa(v[a>>2]-1|0);if(!b){a=jqa(v[a+4>>2]);b=a?a+32|0:0}return b}function Nn(a){var b=0;b=Tw(a+4|0);if((b|0)==-1){kb[v[v[a>>2]+8>>2]](a)}return(b|0)==-1}function NT(a,b,c){var d=0;d=v[b>>2];if((c|0)==-1){c=br(b)}v[a>>2]=d;v[a+4>>2]=(c<<2)+d}function F_(a){a=a|0;var b=0;b=v[a+4>>2];return(kb[v[v[b>>2]+20>>2]](b)|0)+v[a+12>>2]|0}function Cy(a,b,c){var d=0;v[a>>2]=v[b>>2];d=v[b>>2];v[a+8>>2]=b;v[a+4>>2]=c+d;return a}function yH(a,b){var c=0;c=gb-16|0;gb=c;v[c+12>>2]=0;uH(a,c+12|0,b);gb=c+16|0;return a}function pG(a){var b=0;b=a+48|0;while(1){b=vb(b-12|0);if((b|0)!=(a|0)){continue}break}}function ni(a,b,c){if(b){while(1){t[a|0]=w[c|0];a=a+1|0;b=b-1|0;if(b){continue}break}}}function hB(a,b){$u(a,b);Dc(a+12|0,b+12|0);u[a+28>>1]=x[b+28>>1];v[a+24>>2]=v[b+24>>2]}function dl(a){var b=0;b=a+36|0;while(1){b=vb(b-12|0);if((b|0)!=(a|0)){continue}break}}function Tb(a,b){a=a|0;b=b|0;var c=0;c=gb-16|0;gb=c;zs(a,b,Nf(b));gb=c+16|0;return a|0}function RR(a,b){return(a>>>0<=62?63-(B((b^-1)&63,(a?a+1|0:0)&255)>>>6|0)|b&192:b)&255}function MH(a,b){var c=0;c=gb-16|0;gb=c;v[c+12>>2]=b;a=NH(a,8351,b);gb=c+16|0;return a}function LE(a){var b=0,c=0;b=gb-16|0;gb=b;c=Yp(a);t[b+15|0]=0;Lo(a,c,b+15|0);gb=b+16|0}function LD(a,b,c){t[a+2|0]=1;b=b&15;if(c){b=w[b+28512|0]}else{b=(b<<2)+4|0}t[a+4|0]=b}function Cf(a){var b=0;b=a+24|0;while(1){b=vb(b-12|0);if((b|0)!=(a|0)){continue}break}}function $e(a){var b=0,c=0,d=0;b=gb-16|0;gb=b;c=v[lx(b,a)+8>>2],d=0,t[c|0]=d;gb=b+16|0}function $O(a){Kb(a);Kb(a+12|0);Kb(a+24|0);Kb(a+36|0);Kb(a+48|0);v[a+60>>2]=0;return a}function om(a){var b=0;if(a>>>0>=2){b=a+4&-4;a=b-1|0;a=(a|0)==2?b:a}else{a=1}return a}function n6(a,b){a=a|0;b=b|0;a=x[a>>1];b=x[b>>1];return(a>>>0<b>>>0?-1:a>>>0>b>>>0)|0}function ml(a,b,c){var d=0;d=c;b=b-a|0;c=v[c>>2]-b|0;v[d>>2]=c;if((b|0)>0){hc(c,a,b)}}function l6(a,b){a=a|0;b=b|0;a=v[a>>2];b=v[b>>2];return(a>>>0<b>>>0?-1:a>>>0>b>>>0)|0}function e3(a,b){a=a|0;b=b|0;var c=0;c=Yx(v[b>>2])<<24;v[a+4>>2]=v[b>>2];t[a|0]=c>>24}function du(a,b){if(!(t[b+851|0]&1&v[a+480180>>2]==8)){Sz(a,b,0);Sz(a,b,1);Sz(a,b,2)}}function bv(a,b){a:{if(b){break a}if(a>>>0<=3){a=a|-16;break a}a=a>>>2|0}return a&255}function Z0(a){a=a|0;a=464600;while(1){a=vb(a-12|0);if((a|0)!=464432){continue}break}}function W0(a){a=a|0;a=464776;while(1){a=Hc(a-12|0);if((a|0)!=464608){continue}break}}function T0(a){a=a|0;a=465072;while(1){a=vb(a-12|0);if((a|0)!=464784){continue}break}}function Q0(a){a=a|0;a=465376;while(1){a=Hc(a-12|0);if((a|0)!=465088){continue}break}}function N0(a){a=a|0;a=465416;while(1){a=vb(a-12|0);if((a|0)!=465392){continue}break}}function Lt(a,b){a=a|0;b=b|0;b=gb-16|0;gb=b;v[b>>2]=a;ZI(14929,b);nt(90160);gb=b+16|0}function K0(a){a=a|0;a=465448;while(1){a=Hc(a-12|0);if((a|0)!=465424){continue}break}}function nf(a){a=a|0;var b=0;b=v[a>>2];return(kb[v[v[b>>2]+24>>2]](b)|0)-v[a+8>>2]|0}function gi(a){t[a|0]=0;t[a+1|0]=0;t[a+2|0]=0;t[a+3|0]=0;t[a+4|0]=0;t[a+5|0]=0;bj(a)}function cba(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;return HL(a,b,c,d,0,0,0,0,e)|0}function Wi(a,b){var c=0;c=gb-16|0;gb=c;v[c+12>>2]=b;xq(a,c+12|0);gb=c+16|0;return a}function Vja(a,b){a=a|0;b=b|0;var c=0;c=gb-16|0;gb=c;zs(a,b,12);gb=c+16|0;return a|0}function UT(a,b){var c=0;c=v[b+4>>2];v[a>>2]=v[b>>2];v[a+4>>2]=c;v[a+8>>2]=v[b+8>>2]}function Sca(a,b){a=a|0;b=b|0;return C((b|0)<=2?C(C(w[(a+b|0)+4232|0])/C(127)):C(0))}function OG(a,b){a:{if(!(w[a+120|0]|b>>>0>30)){t[a+120|0]=1;break a}a=aA(b)}return a}function Kda(a,b){a=a|0;b=b|0;return C((b|0)<=3?C(C(w[(a+b|0)+4264|0])/C(255)):C(0))}function Hg(a){a=a|0;var b=0;b=gb-16|0;gb=b;a=v[yc(b+8|0,a)>>2];gb=b+16|0;return a|0}function H1(a,b){a=a|0;b=b|0;if((b|0)>=0){b=v[Ks()+((b&255)<<2)>>2]}return b<<24>>24}function F1(a,b){a=a|0;b=b|0;if((b|0)>=0){b=v[Js()+((b&255)<<2)>>2]}return b<<24>>24}function r$(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;a=kb[a|0](b,c,d)|0;ma(jb|0);return a|0}function Xf(a,b){v[a>>2]=v[b>>2];v[a+4>>2]=v[b+4>>2];v[b>>2]=0;v[b+4>>2]=0;return a}function zh(a){var b=0;b=gb-16|0;gb=b;v[b+12>>2]=0;xq(a,b+12|0);gb=b+16|0;return a}function zC(a){var b=0;b=gb-16|0;gb=b;a=v[yc(b+8|0,v[a>>2])>>2];gb=b+16|0;return a}function rT(a,b,c,d,e,f){yc(a,b);yc(a+4|0,c);yc(a+8|0,d);yc(a+12|0,e);yc(a+16|0,f)}function lJ(a,b){b=v[a+32>>2]+b|0;v[a+32>>2]=b;if(b>>>0>=y[a+40>>2]){v[a+96>>2]=1}}function fj(a,b){a=a|0;b=b|0;if(tc(a)>>>0<=b>>>0){mx();L()}return v[a>>2]+(b<<1)|0}function aX(a){var b=0,c=0;b=gb-16|0;gb=b;c=b+8|0;YW(c,a);gb=b+16|0;return v[c>>2]}function Si(a,b){a=a|0;b=b|0;if(b>>>0>1073741823){rd(8445);L()}return Mc(b<<2,4)|0}function NP(a,b){var c=0;c=b&15;if(c){t[a+830|0]=c}b=b&240;if(b){t[a+829|0]=b>>>4}}function jY(a,b,c){v[a>>2]=b;b=v[b+4>>2];v[a+4>>2]=b;v[a+8>>2]=b+B(c,48);return a}function gw(a,b,c){v[a>>2]=b;b=v[b+4>>2];v[a+4>>2]=b;v[a+8>>2]=b+B(c,20);return a}function gs(a,b,c){v[a>>2]=b;b=v[b+4>>2];v[a+4>>2]=b;v[a+8>>2]=b+(c<<3);return a}
function bp(a,b){a=hc(a,b,34);u[a+34>>1]=x[b+34>>1];hc(a+36|0,b+36|0,68);return a}function Nw(a,b,c){v[a>>2]=b;b=v[b+4>>2];v[a+4>>2]=b;v[a+8>>2]=b+B(c,36);return a}function Np(a,b,c){v[a>>2]=b;b=v[b+4>>2];v[a+4>>2]=b;v[a+8>>2]=b+B(c,12);return a}function Jw(a,b){var c=0;v[a>>2]=v[b>>2];c=a;a=v[b+4>>2];v[c+4>>2]=a;if(a){Ln(a)}}function zd(a){var b=0;b=gb-16|0;gb=b;a=v[yc(b+8|0,Jb(a))>>2];gb=b+16|0;return a}function or(a){var b=0;b=gb-16|0;gb=b;a=v[yc(b+8|0,zC(a))>>2];gb=b+16|0;return a}function li(a,b,c){v[a>>2]=b;b=v[b+4>>2];v[a+4>>2]=b;v[a+8>>2]=b+(c<<1);return a}function cq(a,b,c){v[a>>2]=b;b=v[b+4>>2];v[a+4>>2]=b;v[a+8>>2]=b+(c<<4);return a}function bP(a){a=a|0;t[a+8|0]=0;v[a>>2]=0;v[a+4>>2]=4194432;LE(a+9|0);return a|0}function ZI(a,b){var c=0;c=gb-16|0;gb=c;v[c+12>>2]=b;VI(90160,a,b,0,0);gb=c+16|0}function NF(a,b,c){a=a|0;b=b|0;c=c|0;Dc(b,c);ks(b+12|0,c+12|0);pi(b+32|0,c+32|0)}function IB(a,b,c){v[a>>2]=b;b=v[b+4>>2];v[a+4>>2]=b;v[a+8>>2]=b+(c<<5);return a}function Fg(a,b,c){v[a>>2]=b;b=v[b+4>>2];v[a+4>>2]=b;v[a+8>>2]=b+(c<<2);return a}function Dh(a){var b=0;b=gb-16|0;gb=b;a=v[yc(b+8|0,Ch(a))>>2];gb=b+16|0;return a}function Ch(a){var b=0;b=gb-16|0;gb=b;a=v[yc(b+8|0,fc(a))>>2];gb=b+16|0;return a}function CD(a){a=a+4|0;return Xb(w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24))}function Br(a,b,c){v[a>>2]=b;b=v[b+4>>2];v[a+4>>2]=b;v[a+8>>2]=b+B(c,6);return a}function $j(a,b){var c=0;c=v[b+4>>2];v[a>>2]=v[b>>2];v[a+4>>2]=c;ks(a+8|0,b+8|0)}function z4(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;b=gb-16|0;gb=b;zH(a,c,d);gb=b+16|0}function q$(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;kb[a|0](b,c,d,e,f)}function oT(a){if((w[a+14|0]-49&255)>>>0<=3){a=sd(a,12667,14)}else{a=1}return!a}function Yca(a,b){a=a|0;b=b|0;if(v[a+4>>2]!=v[wb(a)>>2]){SO(a,b);return}QO(a,b)}function MR(a,b){var c=0;c=a;a=v[a>>2];v[c>>2]=a<<8^v[((a>>>24^b)<<2)+35500>>2]}function LJ(a,b){a=a|0;b=b|0;return v[b+8>>2]==v[a+8>>2]&v[a+12>>2]==v[b+12>>2]}function w6(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=+d;e=+e;return zJ(a-88|0,b,c,d,e)|0}function t$(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;return kb[a|0](b,c,d,e)|0}function mP(a,b){a=a|0;b=b|0;v[(v[v[a>>2]-12>>2]+a|0)+8>>2]=v[b>>2];return a|0}function ap(a){t[a|0]=0;t[a+1|0]=0;t[a+2|0]=0;t[a+3|0]=0;t[a+4|0]=0;t[a+5|0]=0}function Ufa(a,b){a=a|0;b=b|0;if(y[a+4>>2]<y[wb(a)>>2]){SO(a,b);return}QO(a,b)}function Nba(a,b){a=a|0;b=b|0;return C((b|0)<=12?z[((b<<2)+a|0)+4208>>2]:C(0))}function Mu(a,b){return Ah(Ek((+(a|0)*128+ +(b|0))*.0006510416666666666)*8363)}function zca(a,b){a=a|0;b=b|0;return C((b|0)<=5?z[((b<<2)+a|0)+4208>>2]:C(0))}function xj(a,b,c){if(v[a+80>>2]){v[a+92>>2]=v[a+92>>2]+(c+7&-8);return}Yb(b)}function xba(a,b){a=a|0;b=b|0;return C((b|0)<=3?z[((b<<2)+a|0)+4208>>2]:C(0))}function wF(a,b){var c=0;c=gb-16|0;gb=c;b=im(c+8|0,b);dG(b,a);Kd(b);gb=c+16|0}function to(a,b){if((a|0)>=0){return(a|0)%(b|0)|0}return((a^-1)%(b|0)^-1)+b|0}function rca(a,b){a=a|0;b=b|0;return C((b|0)<=4?z[((b<<2)+a|0)+4208>>2]:C(0))}function kz(a,b){if((a|0)>=0){return(a|0)/(b|0)|0}return((a+1|0)/(b|0)|0)-1|0}function kca(a,b){a=a|0;b=b|0;return C((b|0)<=4?z[((b<<2)+a|0)+4220>>2]:C(0))}function im(a,b){v[a>>2]=v[b>>2];b=v[b+4>>2];v[a+4>>2]=b;if(b){Ln(b)}return a}function f0(a,b,c){a=a|0;b=b|0;c=c|0;if((c|0)>=257){Tb(a,5054);return}ox(a,c)}function eG(a,b){var c=0;c=gb-16|0;gb=c;b=Xf(c+8|0,b);dG(b,a);Kd(b);gb=c+16|0}function c0(a,b,c){a=a|0;b=b|0;c=c|0;if((c|0)>=257){Tb(a,4984);return}ox(a,c)}function aR(a){v[a>>2]=0;v[a+4>>2]=0;v[a>>2]=-2078137563;v[a+4>>2]=-873292572}function ZU(a,b){var c=0,d=0;c=gb-16|0;gb=c;d=c+8|0;zw(d,b);GW(a,d);gb=c+16|0}function Xba(a,b){a=a|0;b=b|0;return C((b|0)<=1?z[((b<<2)+a|0)+4208>>2]:C(0))}function UP(a,b){var c=0,d=0;c=gb-16|0;gb=c;d=c+8|0;Bl(d,a,b);er(d);gb=c+16|0}function RB(a){return(+y[a>>2]+ +v[a+4>>2]*4294967296)*2.3283064365386963e-10}function P$(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;if(Sg(a,v[b+8>>2],0)){ix(b,c,d)}}function Lca(a,b){a=a|0;b=b|0;return C((b|0)<=6?z[((b<<2)+a|0)+4208>>2]:C(0))}function Jl(a,b){var c=0,d=0;c=gb-16|0;gb=c;d=c+8|0;Db(d,a,b);er(d);gb=c+16|0}function Eba(a,b){a=a|0;b=b|0;return C((b|0)<=2?z[((b<<2)+a|0)+4208>>2]:C(0))}function EA(a){var b=0;if(!(w[a+2|0]|(w[a|0]|w[a+1|0]))){b=!w[a+3|0]}return b}function $y(a){a=a|0;v[a>>2]=50968;Nc(a+4276|0);Nc(a+4264|0);Lf(a);return a|0}function wH(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;kb[v[v[a>>2]+32>>2]](a,b,c,d)|0}function vj(a,b){var c=0;c=a;a=(b>>>0)/100|0;return gt(gt(c,a),b-B(a,100)|0)}function vH(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;kb[v[v[a>>2]+48>>2]](a,b,c,d)|0}function iA(a,b){a=a|0;b=b|0;return(b>>>0<4e3?((b<<5)+a|0)+946304|0:18726)|0}function fH(a,b){var c=0,d=0;Ee(a,ce(b));b=v[fc(b)>>2];c=fc(a),d=b,v[c>>2]=d}function dz(a,b){var c=0,d=0;c=gb-16|0;gb=c;d=xv(a,b);gb=c+16|0;return d?b:a}function cn(a){a=a+4|0;return w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24)}function ar(a){var b=0;b=gb-16|0;gb=b;a=v[qT(b+8|0,a)>>2];gb=b+16|0;return a}function Td(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=v[b+8>>2];Rb(b,c);Ww(a,b,d,c)}function Gm(a,b){var c=0,d=0;c=gb-16|0;gb=c;d=xv(b,a);gb=c+16|0;return d?b:a}function FG(){a:{if(t[466016]&1){break a}if(!Qd(466016)){break a}Pd(466016)}}function $l(a){var b=0;b=gb-16|0;gb=b;v[b+8>>2]=a;gb=b+16|0;return v[b+8>>2]}function xz(a,b){a=a|0;b=b|0;return(b>>>0<=15?t[v[a+88>>2]+b|0]:63)<<24>>24}function wz(a,b){a=a|0;b=b|0;return(b>>>0<=44?t[v[a+84>>2]+b|0]:63)<<24>>24}function uw(a,b,c){v[a+4>>2]=c;v[a>>2]=b;if(!c){aa(12826,6210,85,7806);L()}}function rs(a,b){a=a|0;b=b|0;a=v[a>>2];return kb[v[v[a>>2]+32>>2]](a,0,b)|0}function kT(a,b){DU(a,b);t[a+16|0]=w[b+16|0];v[a+12>>2]=v[b+12>>2];return a}function jI(a,b,c,d,e,f,g,h){return kb[v[v[a>>2]+16>>2]](a,b,c,d,e,f,g,h)|0}function Ys(a,b,c,d,e,f,g,h){return kb[v[v[a>>2]+12>>2]](a,b,c,d,e,f,g,h)|0}function Wu(a,b,c){var d=0;d=gb-16|0;gb=d;yc(d+8|0,Mn(a,b,$l(c)));gb=d+16|0}function Sk(a,b,c){v[a+4>>2]=c;v[a>>2]=b;if(!c){aa(12826,6210,48,7806);L()}}function SV(a){var b=0;while(1){b=a;a=v[a>>2];if(a){continue}break}return b}function KR(a,b){b=1/(1/(b*6.283185307179586/3546895)+1);GR(a,b,0,0,b+-1,0)}function FW(a,b,c,d){a=c-b|0;if((a|0)>0){hc(v[d>>2],b,a);v[d>>2]=v[d>>2]+a}}function Dk(a,b,c,d){a=c-b|0;c=v[d>>2]-a|0;v[d>>2]=c;if((a|0)>0){hc(c,b,a)}}function Ai(a,b,c){v[a>>2]=b;b=v[b+4>>2];v[a+4>>2]=b;v[a+8>>2]=b+c;return a}function sh(a,b,c){v[a+8>>2]=b;v[a+12>>2]=c;v[a>>2]=0;v[a+4>>2]=0;return a}function ro(a,b){a=v[a+4316>>2];return(((a<<12&b>>31)+b|0)/4096|0)%(a|0)|0}function pg(a,b){var c=0;c=a;a=v[a+8>>2];b=a-b|0;v[c+8>>2]=a>>>0<b>>>0?0:b}function me(a,b){a=a|0;b=b|0;if(dm(a,b)){a=hi(bf(a,b))}else{a=0}return a|0}function lx(a,b){v[a+12>>2]=0;v[a+4>>2]=b;v[a>>2]=b;v[a+8>>2]=b+1;return a}function gt(a,b){b=x[(b<<1)+74112>>1];t[a|0]=b;t[a+1|0]=b>>>8;return a+2|0}function _Q(a,b,c){var d=0;d=v[b+4>>2];v[a>>2]=v[b>>2];v[a+4>>2]=d;_S(a,c)}function P1(a,b){a=a|0;b=b|0;if(b>>>0<=127){b=v[Ks()+(b<<2)>>2]}return b|0}function N1(a,b){a=a|0;b=b|0;if(b>>>0<=127){b=v[Js()+(b<<2)>>2]}return b|0}function KY(a,b){v[a>>2]=b;b=v[b+4>>2];v[a+4>>2]=b;v[a+8>>2]=b+28;return a}function x5(a,b,c){a=a|0;b=b|0;c=c|0;return kb[v[v[a>>2]+32>>2]](a,b,c)|0}function wV(a,b){t[a+6|0]=255;v[a+16>>2]=b;u[a+4>>1]=0;v[a>>2]=0;return a}function un(a,b,c){a=a|0;b=b|0;c=c|0;return kb[v[v[a>>2]+48>>2]](a,b,c)|0}function nv(a,b,c){b=b-a|0;if((b|0)>0){hc(v[c>>2],a,b);v[c>>2]=b+v[c>>2]}}function koa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=c,e=xp(a,b),v[d>>2]=e}function kl(a,b,c){a=a|0;b=b|0;c=c|0;return kb[v[v[a>>2]+12>>2]](a,b,c)|0}function hoa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=c,e=qw(a,b),u[d>>1]=e}function gda(a,b){a=a|0;b=b|0;a=v[a+20>>2]+24|0;t[a|0]=w[a|0]&253|(b?2:0)}function bR(a,b){v[a>>2]=b;b=v[b+4>>2];v[a+4>>2]=b;v[a+8>>2]=b+8;return a}function bA(a,b){v[a>>2]=b;b=v[b+4>>2];v[a+4>>2]=b;v[a+8>>2]=b+4;return a}function Zl(a,b){var c=0;c=v[b+4>>2];v[a>>2]=v[b>>2];v[a+4>>2]=c;return a}function Rc(a,b,c,d,e){t[a+3|0]=e;t[a+2|0]=d;t[a+1|0]=c;t[a|0]=b;return a}function Q_(a){a=a|0;var b=0;b=gb-16|0;gb=b;dc(a);_n(b+8|0,a,1);gb=b+16|0}function K_(a){a=a|0;var b=0;b=gb-16|0;gb=b;dc(a);Yk(b+8|0,a,1);gb=b+16|0}function Iea(a,b,c){a=a|0;b=b|0;c=c|0;if(Ab(b)>>>0>c>>>0){xu(b,c)}Dc(a,b)}function uE(a,b){return(w[a|0]|w[a+1|0]<<8)>>>0<(w[b|0]|w[b+1|0]<<8)>>>0}function eg(a){var b=0;b=v[a>>2];v[a>>2]=0;if(b){kb[v[v[b>>2]+4>>2]](b)}}function FY(a){return Xb(w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24))}function DI(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;sh(a,-1,-1)}function uc(a,b){var c=0,d=0;v[a>>2]=b;c=a,d=Nf(b),v[c+4>>2]=d;return a}function tx(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;v[e>>2]=c;return 3}function le(a,b){im(a,b);v[a+8>>2]=v[b+8>>2];im(a+12|0,b+12|0);return a}function iy(a){return((ph(a)+(ph(a)<<8)|0)+(ph(a)<<16)|0)+(ph(a)<<24)|0}function _R(a,b){v[a+4>>2]=0;v[a+8>>2]=0;v[a>>2]=b?b:49716;v[a+12>>2]=0}function Yf(a){var b=0;b=a;if(v[b>>2]){Od(b);Iy(v[b>>2],kv(b))}return a}function Vc(a,b){eG(a,b);v[a+8>>2]=v[b+8>>2];eG(a+12|0,b+12|0);return a}function SR(a){if(a>>>0<=8){return w[a+35488|0]}return w[a+35479|0]|256}function ML(a){u[a+12>>1]=0;v[a+8>>2]=-1;v[a>>2]=0;v[a+4>>2]=0;return a}function IJ(a){a=a|0;return+(+y[v[a+32>>2]+480240>>2]*152587890625e-16)}function zo(a,b){v[a>>2]=v[b>>2];u[a+4>>1]=x[b+4>>1];t[a+6|0]=w[b+6|0]}function yF(a){v[a>>2]=0;v[a+4>>2]=0;v[a+8>>2]=0;v[a+12>>2]=0;return a}function mG(a,b){if(b>>>0>357913941){rd(8445);L()}return Mc(B(b,12),4)}function kE(a,b){if(b>>>0>214748364){rd(8445);L()}return Mc(B(b,20),4)}function hl(a,b){a=a|0;b=b|0;t[a|0]=2;t[a+1|0]=3;t[a+2|0]=0;t[a+3|0]=4}function fx(a,b,c){if(!(v[a+28>>2]==1|v[a+4>>2]!=(b|0))){v[a+28>>2]=c}}function W5(a){a=a|0;v[a+16>>2]=v[a+16>>2]|1;if(t[a+20|0]&1){ua();L()}}function PC(a,b){if(b){PC(a,v[b>>2]);PC(a,v[b+4>>2]);Gk(b+16|0);ZW(b)}}function Jz(a,b){if(b){Jz(a,v[b>>2]);Jz(a,v[b+4>>2]);Hb(b+16|0);$N(b)}}function Gz(a,b){A[a>>3]=A[b>>3]+A[a>>3];A[a+8>>3]=A[b+8>>3]+A[a+8>>3]}function Cc(a,b){if(Nb(a)>>>0<=b>>>0){mx();L()}return v[a>>2]+(b<<2)|0}function $h(a){a=a|0;a=AB(a)?a+172|0:a+156|0;return w[a|0]|w[a+1|0]<<8}function wL(a,b){var c=0;c=v[a>>2];v[a>>2]=b;if(c){ho(c+120|0);Yb(c)}}function pF(a){return(w[v[a+104>>2]+34|0]&8)>>>3&(v[a+88>>2]&2050)==2}function nh(a,b,c){return(x[v[a+8>>2]+((c&255)<<1)>>1]&b)!=0&(c|0)>=0}function j1(a,b){a=a|0;b=b|0;var c=0;c=gb-16|0;gb=c;XH(a,b);gb=c+16|0}function WO(a,b,c,d,e){v[a+12>>2]=e;v[a+8>>2]=d;v[a+4>>2]=c;v[a>>2]=b}function Rj(a,b){return(v[a+4>>2]-v[b+4>>2]|0)+(v[a>>2]-v[b>>2]<<3)|0}function QD(a,b){var c=0;c=gb-16|0;gb=c;bc(a,v[b>>2],oc(b));gb=c+16|0}function LW(a,b){if(b>>>0>715827882){rd(8445);L()}return Mc(B(b,6),1)}function LC(a,b){a=a|0;b=b|0;var c=0;c=gb-16|0;gb=c;kR(a,b);gb=c+16|0}function Kh(a,b){a=a|0;b=b|0;var c=0;c=gb-16|0;gb=c;$f(a,b);gb=c+16|0}function E$(a){a=a|0;if(!a){return 0}return(jx(a,89656,89800)|0)!=0|0}function um(a,b){return b?a<<8&16711680|a<<24|(a>>>8&65280|a>>>24):a}function uN(a){if(a>>>0>=82595525){rd(8445);L()}return Mc(B(a,52),4)}function sz(a,b,c){b=b-a|0;if(b){yh(c,a,b)}return B((b|0)/6|0,6)+c|0}function s$(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;return kb[a|0](b,c,d)|0}function rC(a){var b=0;b=v[a>>2];v[a>>2]=0;if(b){fc(a);if(b){mv(b)}}}function nW(a,b){v[a>>2]=v[b>>2];u[a+4>>1]=x[b+4>>1];ks(a+8|0,b+8|0)}function kB(a,b){mc(a);Kb(a+12|0);u[a+28>>1]=0;v[a+24>>2]=b;return a}function iF(a,b){if(b>>>0>2147483647){rd(8445);L()}return Mc(b<<1,2)}function XE(a,b){if(b>>>0>1073741823){rd(8445);L()}return Mc(b<<2,2)}function V1(a){a=a|0;var b=0;b=v[116047]+1|0;v[116047]=b;v[a+4>>2]=b}function NG(a,b,c){a:{if((a|0)==(b|0)){t[a+120|0]=0;break a}vO(b,c)}}function Kz(a){var b=0;VS(a);b=v[a>>2];if(b){ai(v[a+16>>2],b,Ck(a))}}function K2(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;gg(a,f)}function BB(a,b){xc(a,b);xc(a+4|0,b+4|0);xc(wb(a),wb(b));wb(a);wb(b)}function As(a,b,c,d,e){b=Ea(a|0,b|0,c|0,d|0,e|0)|0;jb=O()|0;return b}function yz(a,b){a=a|0;b=b|0;return w[v[a+88>>2]+b|0]!=63&b>>>0<=15}function wG(a,b,c,d,e,f,g){return Ma(a|0,b|0,c|0,d|0,e|0,f|0,g|0)|0}function uC(a,b){if(b){uC(a,v[b>>2]);uC(a,v[b+4>>2]);_n(fc(a),b,1)}}function pq(a,b){a=a|0;b=b|0;return w[v[a+84>>2]+b|0]!=63&b>>>0<=44}function pW(a){t[a+4|0]=0;t[a|0]=0;t[a+1|0]=0;t[a+2|0]=0;t[a+3|0]=0}function pT(a,b,c,d,e){yc(a,b);yc(a+4|0,c);yc(a+8|0,d);yc(a+12|0,e)}function pP(a,b){v[a+852>>2]=v[a+852>>2]+b;t[a+851|0]=w[a+851|0]|32}function oy(a){a=a|0;var b=0;b=v[a+100>>2];v[a+100>>2]=0;return b|0}function ioa(a,b){a=a|0;b=b|0;Pj(a,zb(v[b>>2]),zb(v[b>>2])+oc(b)|0)}function aA(a){if(a>>>0>=1073741824){rd(8445);L()}return Mc(a<<2,4)}function YV(a){if(a>>>0>=1073741824){rd(8445);L()}return Mc(a<<2,1)}function PO(a,b){var c=0;c=gb-16|0;gb=c;Gr(c,1,b);Bc(a,c);gb=c+16|0}function Bfa(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;gO(a,b,c,d,e)}function $_(a){a=a|0;var b=0;b=gb-16|0;gb=b;dc(a);aG(a,1);gb=b+16|0}function lja(a,b){a=a|0;b=b|0;if(!v[22656]){v[22657]=b;v[22656]=a}}function iT(a,b){YB(a,b);t[a+16|0]=w[b+16|0];v[a+12>>2]=v[b+12>>2]}function go(a,b,c){return v[v[a>>2]+(b<<2)>>2]+(v[a+12>>2]+c<<1)|0}function dS(a){if(a>>>0>=134217728){rd(8445);L()}return Mc(a<<5,4)}function bI(a){if(a>>>0>=268435456){rd(8445);L()}return Mc(a<<4,4)}function Yc(a,b,c){a=a|0;b=b|0;c=c|0;return ad(a,B(Ji(a),b)+c|0)|0}function RW(a){if(a>>>0>1073741823){rd(8445);L()}return Mc(a<<2,1)}function K1(a,b,c){a=a|0;b=b|0;c=c|0;return(b>>>0<128?b:c)<<24>>24}function EH(a,b,c){a=a|0;b=b|0;c=c|0;return aq(0,a,b,c?c:463992)|0}function CR(a){if(a>>>0>=536870912){rd(8445);L()}return Mc(a<<3,8)}function wU(a){a=a+34|0;a=kqa(w[a|0]|w[a+1|0]<<8,0,80,0);return a}function wE(a){if(v[a>>2]){hE(a,v[a>>2]);iE(wb(a),v[a>>2],em(a))}}function vi(a,b){var c=0,d=0;c=a,d=Jx(v[b>>2]),v[c>>2]=d;return a}function ty(a){a=w[a+1|0];return(a&6)==6?384:1152>>>((a&14)==2)|0}function nn(a){a=a|0;return v[a+20>>2]+(v[a+8>>2]-v[a+24>>2]|0)|0}function Oc(a,b,c){a=a|0;b=b|0;c=c|0;if(fF(c)){Yb(a);return}Yb(a)}function Mj(a){a=v[a+656>>2];if(!a){return 0}return v[a+44>>2]!=0}function Lp(a,b){a=a|0;b=b|0;kc(a,b);Qb(a+20|0,0,1040);return a|0}function KX(a){jb=0;a=a+47|0;a=(w[a|0]|w[a+1|0]<<8)-98|0;return a}function H_(a){a=a|0;a=v[a+4>>2];return kb[v[v[a>>2]+12>>2]](a)|0}function G_(a){a=a|0;a=v[a+4>>2];return kb[v[v[a>>2]+16>>2]](a)|0}function GJ(a){a=a|0;return+(+v[v[a+32>>2]+1074456>>2]*.00390625)}function t0(a){a=a|0;var b=0,c=0;b=a,c=xe(),v[b>>2]=c;return a|0}function mu(a){vb(a+48|0);vb(a+36|0);vb(a+24|0);vb(a+12|0);vb(a)}function jba(a,b){a=a|0;b=b|0;if(!b){return 3}v[b>>2]=a;return 0}function id(a,b){return((a^-2147483648)>>>b)-(-2147483648>>>b)|0}function I_(a){a=a|0;a=v[a+4>>2];return kb[v[v[a>>2]+8>>2]](a)|0}function Ft(a,b,c){a=v[a>>2];return(a|0)>=x[b>>1]&(a|0)<=x[c>>1]}function $Q(a,b){var c=0;c=v[b+4>>2];v[a>>2]=v[b>>2];v[a+4>>2]=c}function zB(a){fT(a);if(v[a>>2]){eT(a);yB(wb(a),v[a>>2],$i(a))}}function xR(a){$p(a);if(v[a>>2]){mR(a);mm(wb(a),v[a>>2],ug(a))}}function vM(a){a=a|0;return C(C(C(z[a+4228>>2]*C(198))+C(-99)))}function v$(a,b){a=a|0;b=b|0;a=kb[a|0](b)|0;ma(jb|0);return a|0}function rA(a){gY(a);if(v[a>>2]){sY(a);fY(wb(a),v[a>>2],mn(a))}}function qn(a,b){a=a|0;b=b|0;return kb[v[v[a>>2]+28>>2]](a,b)|0}function pA(a){DO(a);if(v[a>>2]){CO(a);dA(wb(a),v[a>>2],qk(a))}}function mg(a,b,c,d){v[a+8>>2]=d;v[a+4>>2]=c;v[a>>2]=b;return a}function lm(a){a=a|0;a=v[a>>2];return kb[v[v[a>>2]+24>>2]](a)|0}function kA(a){OF(a);if(v[a>>2]){hG(a);ls(wb(a),v[a>>2],$k(a))}}function hfa(a,b){a=a|0;b=b|0;a=dY(a,b);if(!a){Jv(b)}return a|0}function dp(a){Fk(a);if(v[a>>2]){cr(a);sw(wb(a),v[a>>2],pe(a))}}function di(a){Fk(a);if(v[a>>2]){cr(a);NC(wb(a),v[a>>2],pe(a))}}function Xs(a,b){a=a|0;b=b|0;return kb[v[v[a>>2]+44>>2]](a,b)|0}function XO(a,b){var c=0;c=v[a>>2];v[a>>2]=b;if(c){ln(c);Yb(c)}}function Vi(a,b,c){a=a|0;b=b|0;c=c|0;return Mn($l(a),$l(b),c)|0}function Qk(a){Fp(a);if(v[a>>2]){Dw(a);nE(wb(a),v[a>>2],Pg(a))}}function Ox(a,b){a=a|0;b=b|0;return(Qh(a)|0)!=0|(a|32)-97>>>0<6}function Ot(a){PM(a);if(v[a>>2]){TM(a);OM(wb(a),v[a>>2],Dl(a))}}function NV(a,b,c,d){le(a,b);u[a+22>>1]=d;u[a+20>>1]=c;return a}function Lq(a){qR(a);if(v[a>>2]){eR(a);TA(wb(a),v[a>>2],tg(a))}}function Kw(a,b,c){Xf(a,b);v[a+8>>2]=0;Xf(a+12|0,c);Kd(c);Kd(b)}function Ju(a){hv(a);if(v[a>>2]){gS(a);Yk(wb(a),v[a>>2],bi(a))}}function Ex(a,b){a=a|0;b=b|0;return kb[v[v[a>>2]+12>>2]](a,b)|0}function $ga(a,b){a=a|0;b=b|0;a=lW(a,b);if(!a){kW(b)}return a|0}function w$(a,b){a=a|0;b=+b;a=kb[a|0](b)|0;ma(jb|0);return a|0}function sF(a,b){a=a|0;b=b|0;a=rF(a,b);if(!a){Gw(b)}return a|0}function mE(a){hF(a);if(v[a>>2]){nE(v[a+16>>2],v[a>>2],Bw(a))}}function gj(a){gC(a);if(v[a>>2]){sw(v[a+16>>2],v[a>>2],Ck(a))}}function fC(a,b){a=a|0;b=b|0;a=YX(a,b);if(!a){nD(b)}return a|0}function eu(a){a=a|0;v[a>>2]=74808;vb(a+32|0);Am(a);return a|0}function es(a){a=a|0;a=v[a>>2];return kb[v[v[a>>2]+8>>2]](a)|0}function eh(a){gC(a);if(v[a>>2]){ai(v[a+16>>2],v[a>>2],Ck(a))}}function bs(a,b){var c=0;c=b+1|0;v[a>>2]=v[a>>2]>(c|0)?c:b+2|0}function aE(a,b){a=a|0;b=b|0;a=Wv(a,b);if(!a){Xv(b)}return a|0}function Xw(a,b){a=a|0;b=b|0;a=JF(a,b);if(!a){IF(b)}return a|0}function Xb(a){return a<<8&16711680|a<<24|(a>>>8&65280|a>>>24)}function Wf(a,b){return kb[v[v[a>>2]+32>>2]](a,v[a+12>>2],b)|0}function Uw(a,b){Xf(a,b);v[a+8>>2]=v[b+8>>2];Xf(a+12|0,b+12|0)}function SW(a){gC(a);if(v[a>>2]){NC(v[a+16>>2],v[a>>2],Ck(a))}}function Ol(a,b){a=t[ic(a+58|0,b)|0];return((a|0)>=0?a:-1)&255}function Mv(a,b,c){a=w[a|0];return a>>>0>=w[b|0]&a>>>0<=w[c|0]}function MC(a,b){var c=0;c=gb-16|0;gb=c;bc(a,b,4896);gb=c+16|0}function Ih(a,b){a=a|0;b=b|0;a=kj(a,b);if(!a){jm(b)}return a|0}function Hw(a,b){wF(a,b);v[a+8>>2]=v[b+8>>2];wF(a+12|0,b+12|0)}function Hh(a){hF(a);if(v[a>>2]){Cw(v[a+16>>2],v[a>>2],Bw(a))}}function Dv(a){a=a|0;a=w[a|0];return ve(a)^1|(a-49&255)>>>0<36}function BC(a,b){a=a|0;b=b|0;a=QV(a,b);if(!a){ak(b)}return a|0}function AL(a,b,c,d){u[a+4>>1]=c;t[a+6|0]=b;v[a>>2]=d;return a}function $w(a,b){a=a|0;b=b|0;a=XF(a,b);if(!a){Pw(b)}return a|0}function yy(a,b){a=(a+b|0)-1|0;return a-((a>>>0)%(b>>>0)|0)|0}function vG(a,b,c){b=Ja(1997,a|0,b|0,c|0)|0;jb=O()|0;return b}function o_(a,b){a=a|0;b=b|0;Fs(a,b);v[a>>2]=89312;return a|0}function ne(a,b){v[a>>2]=v[b>>2];v[a+4>>2]=v[b+4>>2];return a}function nR(a,b){return v[a>>2]==v[b>>2]&v[a+4>>2]==v[b+4>>2]}function hO(a){a=a|0;v[a+12>>2]=1065353216;fO(a,4);return a|0}function gG(a,b){var c=0;c=v[a>>2];v[a>>2]=b;if(c){Yb(gc(c))}}function ft(a,b){b=v[b>>2];v[a>>2]=b;v[a+4>>2]=b>>31;return a}function fna(a,b,c){a=a|0;b=b|0;c=c|0;Dc(a,LG(c,Jb(b),Ab(b)))}function d8(a,b){a=a|0;b=b|0;Fs(a,b);v[a>>2]=89364;return a|0}function _8(a,b,c){a=a|0;b=b|0;c=c|0;IT(a,0,Kk(v[b+24>>2]),c)}function Um(a,b,c){u[a>>1]=x[b>>1];v[a+4>>2]=v[c>>2];return a}function Su(a,b,c){v[a>>2]=v[b>>2];v[a+4>>2]=v[c>>2];return a}function Qi(a,b){a=a|0;b=b|0;if(ze(a)>>>0>b>>>0){t[a+16|0]=b}}function MS(a,b){a=a|0;b=b|0;Fs(a,b);v[a>>2]=89176;return a|0}function Kha(a,b,c){a=a|0;b=b|0;c=c|0;return yv(a,b,c,1096)|0}function Fr(a,b){b=w[b|0]|w[b+1|0]<<8;t[a|0]=b;t[a+1|0]=b>>>8}function Fea(a,b,c){a=a|0;b=b|0;c=c|0;return yv(a,b,c,1485)|0}function wc(a,b){var c=0;c=v[a>>2];v[a>>2]=v[b>>2];v[b>>2]=c}function uF(a,b){var c=0;c=gb-16|0;gb=c;bc(a,b,36);gb=c+16|0}function tp(a,b,c){if(!b){return 0}return it(a,Mg(t[c|0]),b)}function nda(a){a=a|0;a=pk(a);if(a){kb[v[v[a>>2]+96>>2]](a)}}function gz(a){a=a|0;v[a+32>>2]=0;v[a+28>>2]=v[a+28>>2]&-7|2}function foa(a,b,c){a=a|0;b=b|0;c=c|0;return yv(a,b,c,644)|0}function aP(a){v[a>>2]=0;mc(a+4|0);Qb(a+16|0,0,144);return a}function OW(a,b){var c=0;c=gb-16|0;gb=c;bc(a,b,12);gb=c+16|0}function KJ(a){a=a|0;return+(65536/+y[v[a+32>>2]+480244>>2])}function Gs(){var a=0;a=ba(4)|0;nm(a);ia(a|0,89116,1928);L()}function zi(a,b){var c=0;c=gb-16|0;gb=c;bc(a,b,4);gb=c+16|0}function zD(a,b){var c=0;c=gb-16|0;gb=c;bc(a,b,8);gb=c+16|0}function xl(a){var b=0;b=v[a>>2];v[a>>2]=0;if(b){Yb(Yf(b))}}function tC(a,b){if(b){tC(a,v[b>>2]);tC(a,v[b+4>>2]);mv(b)}}function nu(a,b){if(b){nu(a,v[b>>2]);nu(a,v[b+4>>2]);mv(b)}}function mB(a){dd(a);v[a+12>>2]=0;u[a+16>>1]=65280;return a}function bU(a){if(v[a>>2]){_T(a,v[a>>2]);Yu(v[a>>2],ug(a))}}function Wr(a,b){var c=0;c=gb-16|0;gb=c;bc(a,b,1);gb=c+16|0}function Tw(a){var b=0;b=a;a=v[a>>2]-1|0;v[b>>2]=a;return a}function QF(a){var b=0;b=v[a+8>>2];if(b){_n(a,b,v[a+4>>2])}}function NI(a,b){if(b>>>0<=9){return MI(a,b)}return gt(a,b)}function FB(a,b){if(b){FB(a,v[b>>2]);FB(a,v[b+4>>2]);tT(b)}}function EB(a,b){if(b){EB(a,v[b>>2]);EB(a,v[b+4>>2]);mv(b)}}function DF(a){var b=0;b=v[a+8>>2];if(b){Yk(a,b,v[a+4>>2])}}function Cn(a,b){var c=0;c=gb-16|0;gb=c;bc(a,b,2);gb=c+16|0}function C1(a,b,c){a=a|0;b=b|0;c=c|0;return((b|0)>=0?b:c)|0}function vF(a){var b=0;b=gb-16|0;gb=b;Qb(a,0,36);gb=b+16|0}function lg(a,b){a=lqa(v[a>>2],v[a+4>>2],b,b>>31);return a}function g5(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;jb=0;return 0}function er(a){var b=0;b=v[a>>2];v[b>>2]=v[b>>2]|v[a+4>>2]}function _fa(a){a=a|0;Fs(a,18726);v[a>>2]=89256;return a|0}function ZK(a){a=a|0;return y[v[a+24>>2]+1074420>>2]/1e4|0}function Z8(a){a=a|0;BL(a,2,100);Qi(v[a+24>>2]+484360|0,0)}function Vd(a,b){a=a|0;b=b|0;td(a,v[b>>2],v[b>>2]+oc(b)|0)}function Ab(a){if(De(a)){return v[a+4>>2]}return w[a+11|0]}function AB(a){a=a+156|0;return(w[a|0]|w[a+1|0]<<8)==65534}function $n(a,b,c,d){v[a+16>>2]=d;v[a+12>>2]=c;v[a+8>>2]=b}function zv(a){if(v[a>>2]){WW(a);OC(wb(a),v[a>>2],Yj(a))}}function zp(a,b,c){td(a,v[b>>2]+(c>>>3&536870908)|0,c&31)}function wx(a){if(v[a>>2]){Od(a);NG(px(a),v[a>>2],pe(a))}}function vv(a){if(v[a>>2]){cr(a);ai(wb(a),v[a>>2],pe(a))}}function vL(a,b){var c=0;c=v[a>>2];v[a>>2]=b;if(c){EL(c)}}function uO(a){var b=0;wC(a);b=v[a>>2];if(b){wO(b,Ck(a))}}function tk(a){a=v[a+656>>2];if(!a){return 0}return Kj(a)}function s_(a){a=a|0;fG(a,10671);v[a>>2]=28324;return a|0}function ny(a,b){return v[((a>>>24^b)<<2)+459504>>2]^a<<8}function nX(a,b){var c=0;c=v[a>>2];v[a>>2]=b;if(c){EU(c)}}function km(a){if(v[a>>2]){MF(a);al(wb(a),v[a>>2],dg(a))}}function jJ(a){while(1){if((rt(a)|0)!=-1){continue}break}}function cs(a){if(v[a>>2]){Dw(a);Cw(wb(a),v[a>>2],Pg(a))}}function cG(a){var b=0;b=v[a+8>>2];if(b){aG(b,v[a+4>>2])}}function _J(a){var b=0;b=v[a+8>>2];if(b){ZJ(b,v[a+4>>2])}}function Zq(a){return((a-65&255)>>>0<26?a+32|0:a)<<24>>24}function ZV(a){var b=0;wC(a);b=v[a>>2];if(b){xC(b,Ck(a))}}function Ye(a){if(v[a>>2]){ai(wb(a),v[a>>2],v[wb(a)>>2])}}function Xg(a,b,c){return v[a>>2]+(B(v[a+4>>2],c)+b<<2)|0}function Wg(a,b,c){return v[a>>2]+(B(v[a+4>>2],c)+b<<3)|0}function WJ(a){var b=0;b=v[a+8>>2];if(b){av(b,v[a+4>>2])}}function Ux(a,b,c){v[a+28>>2]=c;v[a+20>>2]=b;v[a+24>>2]=b}function QX(a,b){var c=0;c=v[a>>2];v[a>>2]=b;if(c){Yb(c)}}function OK(a){a=a|0;return Ri(Sb(v[a+24>>2]+484360|0))|0}function OD(a,b){var c=0;c=gb-16|0;gb=c;rR(a,b);gb=c+16|0}function GV(a,b,c){return v[a>>2]+(B(v[a+4>>2],c)+b<<1)|0}function Ce(a,b,c){td(a,v[b>>2]+(c>>>3&536870908)|0,1<<c)}function zb(a){var b=0;b=gb-16|0;gb=b;gb=b+16|0;return a}function yj(a){return Ne(a)|Ne(a)<<8|Ne(a)<<16|Ne(a)<<24}function xA(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;JA(a,b,c,d)}function u6(a,b,c){a=a|0;b=b|0;c=c|0;return Cd(B(b,c))|0}function sv(a){dp(a+88|0);dp(a+68|0);dp(a+48|0);return a}function l$(a){a=a|0;MS(a,5089);v[a>>2]=27324;return a|0}function goa(a,b){a=a|0;b=b|0;Tb(a,b?b:18726);return a|0}function g9(a,b,c){a=a|0;b=b|0;c=c|0;Dc(a,LG(c,b,Nf(b)))}function f$(a,b,c){a=a|0;b=b|0;c=c|0;Ww(a,b,v[b+8>>2],c)}function d$(a){a=a|0;fG(a,5835);v[a>>2]=27432;return a|0}function ak(a){t[a|0]=0;t[a+1|0]=0;t[a+2|0]=0;t[a+3|0]=0}function aD(a){a=a|0;if(!w[a|0]){return 1}return Rd(a)|0}function ZA(a,b){A[a>>3]=A[a>>3]*b;A[a+8>>3]=A[a+8>>3]*b}function YG(a,b){Ln(v[b>>2]);Nn(v[a>>2]);v[a>>2]=v[b>>2]}function Xe(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;pf(a,c,d,b)}function XJ(a){a=a|0;v[a>>2]=59180;gc(a+12|0);return a|0}function Vba(a){a=a|0;gM(a);t[a+4202|0]=1;v[a+4224>>2]=0}function SG(a){a=a|0;v[a>>2]=81392;vb(a+12|0);return a|0}function RG(a){a=a|0;v[a>>2]=81432;vb(a+16|0);return a|0}function Lpa(a,b,c){a=a|0;b=b|0;c=c|0;return SD(a,b,c)|0}function Jn(a,b,c){a=lqa(v[a>>2],v[a+4>>2],b,c);return a}function CI(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;sh(a,-1,-1)}function CG(a){a=v[a>>2]-12|0;if((Tw(a+8|0)|0)<0){Yb(a)}}function uJ(a,b,c){v[a+4>>2]=0;v[a>>2]=b;v[a+8>>2]=c<<3}function qG(a,b,c){a=a|0;b=b|0;c=c|0;return xs(a,b,c)|0}function kx(a){a=a|0;v[a>>2]=89136;CG(a+4|0);return a|0}function ir(a,b,c){return v[v[a>>2]+(b<<2)>>2]+(c<<2)|0}function hP(a){var b=0;b=v[a>>2];v[a>>2]=0;if(b){EU(b)}}function ff(a,b,c){a=a|0;b=b|0;c=c|0;Ge(a,b);return a|0}function dM(a){return C(C(z[a+4208>>2]*C(1e4))+C(-1e4))}function cM(a){return C(C(z[a+4252>>2]*C(19980))+C(20))}function bq(a){a=a|0;v[a>>2]=74568;Wb(a+4|0);return a|0}function _G(a){var b=0;b=v[a>>2];v[a>>2]=0;if(b){Nn(b)}}function YC(a,b,c){a=a|0;b=b|0;c=c|0;return TD(a,b,c)|0}function W4(a,b){a=a|0;b=b|0;return ZF(a,Jb(b),Ab(b))|0}function Uv(a,b,c){a=a|0;b=b|0;c=c|0;return NY(a,b,c)|0}function UJ(a){a=a|0;v[a>>2]=59596;gc(a+4|0);return a|0}function Ss(a,b,c){return tG(Jb(a),Ab(a),Jb(b),c,Ab(b))}function Mn(a,b,c){b=b-a|0;if(b){yh(c,a,b)}return b+c|0}function Md(a,b,c){return a>>>0<b>>>0?b:a>>>0>c>>>0?c:a}function Kp(a){var b=0;b=v[a+8>>2];v[a+8>>2]=0;return b}function Kc(a){if(De(a)){a=gk(a)-1|0}else{a=10}return a}function KH(a){return(a|0)!=0&(a|0)!=77024&(a|0)!=77048}function It(a){a=a|0;v[a>>2]=55140;Kt(a+4|0);return a|0}function Ds(a){a=a|0;v[a>>2]=89156;CG(a+4|0);return a|0}function Dj(a){var b=0;b=v[a>>2];v[a>>2]=0;if(b){EL(b)}}function Cv(a,b,c){a=a|0;b=b|0;c=c|0;return it(a,b,c)|0}function BF(a){a=a|0;v[a>>2]=28184;Kd(a+4|0);return a|0}function Am(a){a=a|0;v[a>>2]=74504;Wb(a+4|0);return a|0}function AH(a,b,c,d){a=BH(a,b,c,0,-2147483648);return a}function yI(a){a=a|0;return ct(v[v[a>>2]-12>>2]+a|0)|0}function tj(a,b){v[a+16>>2]=!v[a+24>>2]|(v[a+16>>2]|b)}function tM(a){a=a|0;return Lj(C(z[a+4224>>2]*C(4)))|0}function ph(a){var b=0;b=rt(a);v[a+1396>>2]=0;return b}function p$(a){a=a|0;a=kb[a|0]()|0;ma(jb|0);return a|0}function nI(a){a=a|0;return at(v[v[a>>2]-12>>2]+a|0)|0}function k5(a){a=a|0;return Cq(v[v[a>>2]-12>>2]+a|0)|0}function i5(a){a=a|0;return vf(v[v[a>>2]-12>>2]+a|0)|0}function eq(a){return w[a+2|0]&2?(w[a+1|0]&6)==6?4:1:0}function eha(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;return 0}function cL(a,b){a=a|0;b=b|0;v[v[a+24>>2]+480272>>2]=b}function Xp(a){if(De(a)){a=gk(a)-1|0}else{a=1}return a}function X2(a,b){a=a|0;b=b|0;td(a,oI(v[b>>2]),v[b>>2])}function WR(a,b){u[a+20>>1]=x[a+20>>1]&768|b&255;dB(a)}function Ug(a,b){a=a|0;b=b|0;kb[v[v[b>>2]+20>>2]](a,b)}function SP(a,b){a=a|0;b=b|0;return y[a+12>>2]>b>>>0|0}function Ph(a,b){a=a|0;b=b|0;kb[v[v[b>>2]+24>>2]](a,b)}function Pca(a,b,c){a=a|0;b=b|0;c=c|0;wd(a,b+4228|0,7)}function P_(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;ok(a,d,0)}function Oh(a,b){a=a|0;b=b|0;kb[v[v[b>>2]+28>>2]](a,b)}function Lb(a,b,c){return(a|0)<(b|0)?b:(a|0)>(c|0)?c:a}function Iq(a,b){v[a>>2]=b;v[a+4>>2]=b+223232;return a}function Hda(a,b,c){a=a|0;b=b|0;c=c|0;wd(a,b+4260|0,8)}function Fw(a,b){a=kqa(v[a>>2],v[a+4>>2],b,0);return a}function C4(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;Pj(a,c,d)}function yo(a){a=a|0;return kb[v[v[a>>2]+24>>2]](a)|0}function vs(a,b){a=a|0;b=b|0;v[a>>2]=b;v[a+4>>2]=b+36}function vb(a){if(De(a)){al(a,v[a>>2],gk(a))}return a}function uda(a){a=a|0;t[a+4202|0]=1;Qt(a);ez(a);MM(a)}function rj(a){a=a|0;return kb[v[v[a>>2]+12>>2]](a)|0}function qj(a){a=a|0;return kb[v[v[a>>2]+16>>2]](a)|0}function qi(a,b){a=a|0;b=b|0;v[a>>2]=b;v[a+4>>2]=b+24}function pf(a,b,c,d){t[a+8|0]=d;v[a+4>>2]=c;v[a>>2]=b}function mj(a,b){a=a|0;b=b|0;v[a>>2]=b;v[a+4>>2]=b+12}function dm(a,b){a=a|0;b=b|0;return Te(a)>>>0>b>>>0|0}function cma(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0}function Tn(a,b){return kb[v[v[a>>2]+36>>2]](a,b,0)|0}function Sn(a,b){return kb[v[v[a>>2]+52>>2]](a,b,0)|0}function Pf(a,b,c){a=a|0;b=b|0;c=c|0;Zo(a);return a|0}function PD(a){var b=0;b=gb-16|0;gb=b;Pk(a);gb=b+16|0}function NK(a){a=a|0;return oq(v[a+24>>2]+484344|0)|0}function Hc(a){if(De(a)){ai(a,v[a>>2],gk(a))}return a}function HM(a){Nc(a+36|0);Nc(a+24|0);Ot(a+12|0);Ot(a)}function Dca(a){a=a|0;return C(C(z[a+4232>>2]*C(20)))}function xn(a,b,c){a=a|0;b=b|0;c=c|0;u[b>>1]=x[c>>1]}function uM(a){a=a|0;return C(C(z[a+4216>>2]*C(10)))}function lq(a,b,c){a=a|0;b=b|0;c=c|0;z[b>>2]=z[c>>2]}function jqa(a){if(a){return 31-E(a-1^a)|0}return 32}function ep(a,b,c){a=a|0;b=b|0;c=c|0;v[b>>2]=v[c>>2]}function _K(a){a=a|0;return v[v[a+24>>2]+1074416>>2]}function VK(a){a=a|0;return v[v[a+24>>2]+1074424>>2]}function Dea(a,b){a=a|0;b=b|0;a=a+24|0;HN(a,b);jA(a)}function $ba(a){a=a|0;return C(C(z[a+4232>>2]*C(4)))}function y6(a,b,c){a=a|0;b=b|0;c=c|0;BJ(a-88|0,b,c)}function wl(a){a=a|0;return x[v[a+24>>2]+480192>>1]}function wd(a,b,c){v[a>>2]=b;v[a+4>>2]=b+c;return a}function uX(a){a=a|0;return uz(w[a+3|0],w[a+5|0])|0}function sD(a,b){le(a,b);Qb(a+20|0,0,1040);return a}function ns(a){if(v[a>>2]){Od(a);KF(v[a>>2],tg(a))}}function nka(a,b,c){a=a|0;b=b|0;c=c|0;Dc(a,Is(b,c))}function ke(a){if(v[a>>2]){LY(a);DD(v[a>>2],$i(a))}}function k9(a){a=a|0;a=v[a+4>>2];return(a?a:2107)|0}function jP(a){if(v[a>>2]){Od(a);gP(v[a>>2],tg(a))}}function iu(a){v[a>>2]=38364;v[a>>2]=18736;return a}function io(a){a=a|0;return x[v[a+24>>2]+480188>>1]}function ht(a){if(!a){return 0}v[115137]=a;return-1}function hq(a){a=a|0;return x[v[a+24>>2]+480190>>1]}function fp(a){if(v[a>>2]){Od(a);tW(v[a>>2],sW(a))}}function ci(a){if(v[a>>2]){Od(a);xC(v[a>>2],pe(a))}}function ce(a){var b=0;b=v[a>>2];v[a>>2]=0;return b}function bL(a){a=a|0;return v[v[a+24>>2]+480272>>2]}function _p(a,b){b=v[b>>2];v[a>>2]=b;Ln(b);return a}function ZT(a){if(v[a>>2]){Od(a);Yu(v[a>>2],ug(a))}}function Xu(a){if(v[a>>2]){Od(a);MB(v[a>>2],bi(a))}}function Wo(a,b,c){if(!c){return 0}return sd(a,b,c)}function Vu(a){if(v[a>>2]){Od(a);JB(v[a>>2],KB(a))}}function Uu(a){if(v[a>>2]){Od(a);LB(v[a>>2],xi(a))}}function UK(a){a=a|0;return x[v[a+24>>2]+480214>>1]}function TQ(a){if(v[a>>2]){Od(a);MQ(v[a>>2],LA(a))}}function Spa(a){a=a|0;ln(90656);vD(90648);vb(90636)}function NB(a){t[a+6|0]=0;u[a+4>>1]=65535;v[a>>2]=0}function M5(a,b){a=a|0;b=b|0;return ZF(a,b,Nf(b))|0}function Jea(a,b){a=a|0;b=b|0;ik(a+36|0,b);return 1}function Is(a,b){a=a|0;b=b|0;return Cp(a,b,Nf(b))|0}function IR(a,b){v[a+8>>2]=0;v[a+12>>2]=0;A[a>>3]=b}function Hr(a){if(v[a>>2]){Od(a);EY(v[a>>2],Pg(a))}}function Hq(a){a=a|0;return su(w[a+2|0],w[a+4|0])|0}function Hp(a){a=a|0;a=dc(a);kb[v[v[a>>2]>>2]](a)|0}function Hl(a){if(v[a>>2]){Od(a);wO(v[a>>2],pe(a))}}function Go(a){a=a|0;return su(w[a+3|0],w[a+5|0])|0}function Db(a,b,c){td(a,(c>>>3&536870908)+b|0,1<<c)}function A6(a,b,c){a=a|0;b=b|0;c=c|0;DJ(a-88|0,b,c)}function z6(a,b){a=a|0;b=b|0;return CJ(a-88|0,b)|0}function x6(a,b){a=a|0;b=b|0;return AJ(a-88|0,b)|0}function rl(a,b,c){a=a|0;b=b|0;c=c|0;t[b|0]=w[c|0]}function qM(a){a=a|0;Nc(a+4256|0);Lf(a);return a|0}function on(a){a=(a|0)<120?a:120;return(a|0)>1?a:1}function hD(a,b,c){return a>>>0<c>>>0&a>>>0>=b>>>0}function bu(a){a=a|0;Jh(a);v[a+20>>2]=0;return a|0}function _l(a){return(v[a+480180>>2]&740327453)!=0}function Xj(a,b,c){v[a>>2]=v[b>>2];t[a+4|0]=w[c|0]}function Tt(a){a=a|0;Nc(a+4208|0);Lf(a);return a|0}function Sl(a){a=a+170|0;return w[a|0]|w[a+1|0]<<8}function Pt(a,b,c){a=a|0;b=b|0;c=c|0;Dc(a,VG(b,c))}function Nm(a){Ij(a+724|0);Ij(a+732|0);Ij(a+740|0)}function Nj(a){a=a+158|0;return w[a|0]|w[a+1|0]<<8}function MP(a){return v[a+16>>2]!=(0-v[a+20>>2]|0)}function Jo(a){a=a+168|0;return w[a|0]|w[a+1|0]<<8}function JM(a){a=a|0;gc(a+4208|0);Lf(a);return a|0}function C6(a,b,c){a=a|0;b=b|0;c=+c;FJ(a-88|0,b,c)}function AC(a,b,c){u[a>>1]=x[b>>1];t[a+2|0]=w[c|0]}function zW(a,b,c){a=a|0;b=b|0;c=c|0;pf(a,c,16,b)}function xg(a,b){return tG(Jb(a),Ab(a),b,0,Nf(b))}function ug(a){return(v[wb(a)>>2]-v[a>>2]|0)/12|0}function td(a,b,c){v[a+4>>2]=c;v[a>>2]=b;return a}function sW(a){return(v[wb(a)>>2]-v[a>>2]|0)/33|0}function qk(a){return(v[wb(a)>>2]-v[a>>2]|0)/52|0}function nma(a,b){a=a|0;b=b|0;if(!Wv(a,b)){Xv(b)}}function mn(a){return(v[wb(a)>>2]-v[a>>2]|0)/48|0}function kv(a){return(v[wb(a)>>2]-v[a>>2]|0)/24|0}function jh(a,b){if(De(a)){de(a,b);return}_e(a,b)}function ifa(a,b){a=a|0;b=b|0;if(!XF(a,b)){Pw(b)}}function em(a){return(v[wb(a)>>2]-v[a>>2]|0)/20|0}function eD(a,b,c){a=a|0;b=b|0;c=c|0;pf(a,c,40,b)}function dna(a,b){a=a|0;b=b|0;if(!rF(a,b)){Gw(b)}}function _j(a,b,c){a=a|0;b=b|0;c=c|0;pf(a,c,20,b)}function YI(a,b){if(!a){return 0}return ql(a,b,0)}function Vm(a,b,c){A[a+8>>3]=c;A[a>>3]=b;return a}function Rk(a,b,c){a=a|0;b=b|0;c=c|0;pf(a,c,22,b)}function Nk(a,b,c){a=a|0;b=b|0;c=c|0;pf(a,c,28,b)}function Mp(a){return(v[dc(a)>>2]-v[a>>2]|0)/12|0}function Mk(a,b,c){a=a|0;b=b|0;c=c|0;pf(a,c,12,b)}function Lr(a,b,c){a=a|0;b=b|0;c=c|0;pf(a,c,30,b)}function Kpa(a,b){a=a|0;b=b|0;if(!dY(a,b)){Jv(b)}}function Ke(a,b,c){a=a|0;b=b|0;c=c|0;pf(a,c,32,b)}function Ie(a,b){a=a|0;b=b|0;return(a|0)==(b|0)|0}function HU(a){return(v[wb(a)>>2]-v[a>>2]|0)/56|0}function Gr(a,b,c){a=a|0;b=b|0;c=c|0;pf(a,c,64,b)}function GY(a){return(v[dc(a)>>2]-v[a>>2]|0)/28|0}function GE(a){return!sd(a,28402,25)&w[a+34|0]<65}function Dp(a,b,c){a=a|0;b=b|0;c=c|0;pf(a,c,26,b)}function Cb(a){return(v[a+4>>2]&v[v[a>>2]>>2])!=0}function Ana(a,b){a=a|0;b=b|0;if(!lW(a,b)){kW(b)}}function AN(a,b,c){v[a>>2]=b;v[a+4>>2]=c;return a}function $k(a){return(v[wb(a)>>2]-v[a>>2]|0)/36|0}function $i(a){return(v[wb(a)>>2]-v[a>>2]|0)/28|0}function yR(a){return(v[a+4>>2]-v[a>>2]|0)/872|0}function vY(a,b){a=lY(a,b);if(!a){qD(b)}return a}function qr(a,b,c){t[a+2|0]=c;u[a>>1]=b;return a}function mi(a){return(Vf(a)|0)!=(0-Vf(a+12|0)|0)}function lB(a,b,c){t[a|0]=w[b|0];t[a+1|0]=w[c|0]}function jX(a,b){a=a|0;b=b|0;return Xt(a,b,32)|0}function fo(a,b,c){return GV(a,b,v[a+12>>2]+c|0)}function dB(a){v[a+24>>2]=x[a+20>>1]<<x[a+22>>1]}function c4(a,b){a=a|0;b=b|0;return kb[b|0](a)|0}function bca(a){a=a|0;return z[a+4212>>2]<C(1)|0}function aY(a,b){a=a|0;b=b|0;if(!YX(a,b)){nD(b)}}function Yj(a){return(v[wb(a)>>2]-v[a>>2]|0)/6|0}function Yg(a){a=w[a+20|0];return(a|0)==255?-1:a}function RA(a){v[a>>2]=0;v[a+4>>2]=0;v[a+8>>2]=0}function Pl(a){a=a|0;Tq(v[a+20>>2]);v[a+20>>2]=0}function Mi(a){return v[a+8>>2]!=0|v[a+12>>2]!=0}function LA(a){return(v[wb(a)>>2]-v[a>>2]|0)/7|0}function Jy(a,b){v[a>>2]=v[b>>2];Dc(a+4|0,b+4|0)}function Jb(a){if(De(a)){return v[a>>2]}return a}function Fca(a){a=a|0;return z[a+4220>>2]<C(1)|0}function Ey(a,b,c){return ir(a,b,v[a+12>>2]+c|0)}function EC(a,b){a=a|0;b=b|0;if(!$V(a,b)){yC(b)}}function Dz(a){return B(Nj(a),Sl(a))+7>>>3&65535}function Dpa(a,b,c){a=a|0;b=b|0;c=c|0;hc(b,c,48)}function DS(a,b){yc(a,v[b>>2]);t[a+4|0]=w[b+4|0]}function Cr(a,b){a=a|0;b=b|0;if(!kj(a,b)){jm(b)}}function CY(a,b){t[a|0]=w[b|0];t[a+1|0]=w[b+1|0]}function By(a,b,c){return Xg(a,b,v[a+12>>2]+c|0)}function BZ(a,b){a=a|0;b=b|0;if(!VD(a,b)){Zv(b)}}function B6(a,b){a=a|0;b=b|0;return+EJ(a-88|0,b)}function Ar(a,b){a=ZX(a,b);if(!a){$X(b)}return a}function $J(a,b,c){a=Ud(a);v[a+4>>2]=c;v[a>>2]=b}function $D(a,b){a=a|0;b=b|0;if(!JF(a,b)){IF(b)}}function zr(a,b,c){b=b-a|0;if(b){yh(c-b|0,a,b)}}function xca(a){a=a|0;t[a+4202|0]=1;rM(a);sM(a)}function tv(a){return(v[a+4>>2]-v[a>>2]|0)/33|0}function pl(a){a=a|0;return vI(v[a>>2])<<24>>24}function pca(a){a=a|0;t[a+4202|0]=1;mM(a);lM(a)}function ko(a){return(v[a+4>>2]-v[a>>2]|0)/24|0}function kn(a,b,c){v[a>>2]=b;v[a+4>>2]=(c<<1)+b}function el(a){return kb[v[v[a>>2]+36>>2]](a)|0}function dr(a){return(v[a+4>>2]-v[a>>2]|0)/56|0}function bl(a){return(v[a+4>>2]-v[a>>2]|0)/36|0}function _i(a){return(v[a+4>>2]-v[a>>2]|0)/28|0}function Zn(a){return kb[v[v[a>>2]+28>>2]](a)|0}function Zj(a){return(v[a+4>>2]-v[a>>2]|0)/48|0}function Wm(a,b,c){a=a|0;b=b|0;c=c|0;return a|0}function Tf(a,b){a=a|0;b=b|0;return Yc(a,b,0)|0}function Sf(a){return(v[a+4>>2]-v[a>>2]|0)/52|0}function Pp(a,b){a=a|0;b=b|0;return(b-a|0)/12|0}function Lba(a){a=a|0;eM(a);Yy(a);t[a+4202|0]=1}function LV(a){var b=0;b=v[a>>2];Pe(a);return b}function Je(a){return(v[a+4>>2]-v[a>>2]|0)/20|0}function Iu(a,b){a=a|0;b=b|0;gg(a,b);return a|0}function Hx(a,b,c,d){a=BH(a,b,c,-1,-1);return a}function Ec(a){return(v[a+4>>2]-v[a>>2]|0)/12|0}function vz(a){return a>>>0<=44?w[a+49552|0]:0}function vl(a){return(v[a+4>>2]+v[a>>2]|0)-1|0}function tf(a,b,c){if(!(w[a|0]&32)){kD(b,c,a)}}function lo(a,b,c){a=a|0;b=b|0;c=c|0;td(a,b,c)}function lD(a){return v[a>>2]+(v[a+4>>2]<<2)|0}function j0(a,b,c){a=a|0;b=b|0;c=c|0;td(a,c,b)}function hp(a){a=a|0;return(w[a+1|0]==1?1:2)|0}function bc(a,b,c){a=a|0;b=b|0;c=c|0;wd(a,b,c)}function ZR(a,b){UR(v[a>>2],b);UR(v[a+4>>2],b)}function Yt(a,b){return(v[a>>2]-v[b>>2]|0)/6|0}function Wj(a,b){t[a+4|0]=0;v[a>>2]=b;return a}function S8(a,b){a=a|0;b=b|0;Dc(a,Is(b,14738))}function QA(a){return(v[a+4>>2]-v[a>>2]|0)/7|0}function PR(a){_A(a);Qb(a+27|0,0,255);return a}function Kg(a){return(v[a+4>>2]-v[a>>2]|0)/6|0}function Jp(a){$F(a);v[a+8>>2]=0;v[a>>2]=86704}function Ji(a){a=a|0;return x[uo(a)+480188>>1]}function Jd(a){return v[a+20>>2]!=0&v[a>>2]!=0}function Hu(a){return(a>>>0<9?a:a-9|256)&65535}function Bk(a,b){return(B(b,104)+a|0)+484380|0}function zg(a,b){if(x[a>>1]>b>>>0){u[a>>1]=b}}function ym(a,b){a=a|0;b=b|0;return qI(a,b)^1}function xI(a){a=a|0;_x(v[v[a>>2]-12>>2]+a|0)}function ux(a,b){a=a|0;b=b|0;return Is(a,b)|0}function qc(a,b){if(y[a>>2]>b>>>0){v[a>>2]=b}}function oi(a,b){a=a|0;b=b|0;return Mc(b,1)|0}function og(a,b){a=a|0;b=b|0;return Gb(a,b)|0}function oY(a){t[a+12|0]=w[a+12|0]|2;return a}function nqa(a,b,c,d){a=iqa(a,b,c,d);return a}function nk(a,b){a=a|0;b=b|0;return wI(a,b)^1}function mk(a,b){a=a|0;b=b|0;return wI(a,b)|0}function mI(a){a=a|0;Vx(v[v[a>>2]-12>>2]+a|0)}function jl(a,b){a=a|0;b=b|0;return qI(a,b)|0}function ji(a,b){a=a|0;b=b|0;return pw(a,b)|0}function j5(a){a=a|0;hI(v[v[a>>2]-12>>2]+a|0)}function h5(a){a=a|0;gI(v[v[a>>2]-12>>2]+a|0)}function dk(a,b){if(v[a>>2]>(b|0)){v[a>>2]=b}}function bH(a,b,c){a=a|0;b=b|0;c=c|0;return-1}function _F(a){a=a|0;v[a>>2]=27480;return a|0}function Zh(a,b){a=a|0;b=b|0;return oS(a,b)|0}function YJ(a){a=a|0;v[a>>2]=58824;return a|0}function Wt(a,b){a=a|0;b=b|0;return VG(a,b)|0}function VJ(a){a=a|0;v[a>>2]=59232;return a|0}function Ud(a){v[a>>2]=0;v[a+4>>2]=0;return a}function Ry(a){a=a|0;v[a>>2]=54972;return a|0}function PF(a){a=a|0;v[a>>2]=27812;return a|0}function Kj(a){return(w[a+31|0]-1&255)>>>0<17}function HP(a){jP(a+20|0);iP(a+8|0);hP(a+4|0)}function Gb(a,b){a=a|0;b=b|0;return Sj(a,b)^1}function Dl(a){return v[wb(a)>>2]-v[a>>2]>>11}function CF(a){a=a|0;v[a>>2]=28048;return a|0}function BW(a,b,c){a=a|0;b=b|0;c=c|0;return 0}function xi(a){return v[wb(a)>>2]-v[a>>2]>>4}function uG(a){a=Ga(a|0)|0;jb=O()|0;return a}function tg(a){return v[wb(a)>>2]-v[a>>2]>>3}function pe(a){return v[wb(a)>>2]-v[a>>2]>>2}function ng(a){return v[v[a+8>>2]>>2]==(a|0)}function k6(a){a=a|0;return Ia(v[a+60>>2])|0}function hz(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0}function bi(a){return v[wb(a)>>2]-v[a>>2]>>5}function aca(a){a=a|0;return C(z[a+4220>>2])}function Zy(a){return C(C(a*C(7900))+C(100))}function Z6(a){a=a|0;TJ(a);return v[a+16>>2]}function YK(a){a=a|0;return XK(v[a+24>>2])|0}function Xo(a){a=a|0;vB(a+288|0);Yo(a+800|0)}function Wx(a){return v[dc(a)>>2]-v[a>>2]>>4}function Pn(a,b,c){a=a|0;b=b|0;c=c|0;Dc(b,c)}function Pg(a){return v[wb(a)>>2]-v[a>>2]>>1}function LF(a,b){a=a|0;b=b|0;return(b|0)<6|0}function KB(a){return v[wb(a)>>2]-v[a>>2]>>8}function If(a){return v[a+8>>2]-v[a+12>>2]|0}function HB(a){return v[dc(a)>>2]-v[a>>2]>>5}function Fv(a,b,c){a=a|0;b=b|0;c=c|0;ks(b,c)}function Eca(a){a=a|0;return C(z[a+4212>>2])}function EL(a){if(a){kb[v[v[a>>2]+4>>2]](a)}}function EF(a){return v[dc(a)>>2]-v[a>>2]>>3}function Ck(a){return v[dc(a)>>2]-v[a>>2]>>2}function Bw(a){return v[dc(a)>>2]-v[a>>2]>>1}function Au(a,b,c){a=a|0;b=b|0;c=c|0;$j(b,c)}function yf(a,b){if(w[a|0]>b>>>0){t[a|0]=b}}function yM(a){a=a|0;kb[v[v[a>>2]+4>>2]](a)}function wm(a){a=a|0;oI(v[a>>2]);return a|0}function wM(a){a=a|0;return C(z[a+4208>>2])}function tK(a,b){a=a|0;b=b|0;return oc(b)|0}function sK(a,b){a=a|0;b=b|0;return Nb(b)|0}function ol(a){a=a|0;Yx(v[a>>2]);return a|0}function lL(a){t[a+4|0]=0;t[a|0]=0;return a}function ju(a){RO(a);v[a>>2]=74872;return a}function g6(a,b){a=a|0;b=b|0;return Qh(a)|0}function dg(a){return v[wb(a)>>2]-v[a>>2]|0}function cu(a,b,c){b=b-a|0;if(b){yh(c,a,b)}}function cp(a,b){return v[a>>2]<v[b>>2]?b:a}function cda(a,b,c){a=a|0;b=b|0;c=c|0;Ud(a)}function br(a){return kr(v[a>>2],v[a+4>>2])}function _H(a){RO(a);v[a>>2]=74944;return a}function _6(a){a=a|0;TJ(a);return v[a+4>>2]}function YR(a,b){u[a+22>>1]=b&7;dB(a);eB(a)}function Vf(a){return v[a+4>>2]-v[a>>2]>>11}function T_(a,b){a=a|0;b=b|0;TF(Qb(b,0,36))}function RL(a){return Xh(C(TL(a)*C(32768)))}function Ii(a,b){a=a|0;b=b|0;return C(C(0))}function FH(){return(v[v[115196]>>2]?4:1)|0}function Eda(a,b){a=a|0;b=b|0;t[a+4201|0]=b}function ze(a){return v[a+4>>2]-v[a>>2]>>5}function yea(a,b){a=a|0;b=b|0;gg(a,b+36|0)}function uf(a){return v[a+4>>2]-v[a>>2]>>4}function u5(a){a=a|0;return Nh(a,464028)|0}function tc(a){return v[a+4>>2]-v[a>>2]>>1}function sp(a,b){return v[a>>2]-v[b>>2]>>1}function rv(a,b){return v[a>>2]-v[b>>2]>>2}function rf(a){return v[a+4>>2]-v[a>>2]>>3}function m7(a,b){a=a|0;b=b|0;SQ(v[a>>2],b)}function gl(a,b){kb[v[v[b>>2]+44>>2]](a,b)}function gk(a){return v[a+8>>2]&2147483647}function fl(a,b){kb[v[v[b>>2]+32>>2]](a,b)}function dv(a){Ye(a+24|0);gc(a+12|0);gc(a)}function dh(a){return v[a+4>>2]-v[a>>2]>>8}function cE(a){return w[a+1|0]==2&w[a|0]<3}function __(a){a=a|0;return v[a+4>>2]!=0|0}function Xx(a){a=a|0;return Nh(a,464192)|0}function XR(a,b){t[a+21|0]=b&3;dB(a);eB(a)}function XL(a){return C(C(a*C(96))+C(-96))}function Tx(a){a=a|0;return Nh(a,464208)|0}function Px(a){a=a|0;return Nh(a,464216)|0}function Ow(a){qs(a+32|0);xb(a+12|0);vb(a)}function Ofa(a,b){a=a|0;b=b|0;ik(a+40|0,b)}function Nb(a){return v[a+4>>2]-v[a>>2]>>2}function MT(a,b){return v[a>>2]+B(b,872)|0}function Ls(a,b){kb[v[v[b>>2]+40>>2]](a,b)}function Km(a){vb(a+36|0);Nc(a+24|0);jn(a)}function J5(a){a=a|0;return Nh(a,464012)|0}function Fx(a){a=a|0;return Nh(a,464240)|0}function ED(a){a=a|0;return Nh(a,464200)|0}function Bx(a){a=a|0;return Nh(a,464248)|0}function $q(a,b){a=a|0;b=b|0;return b-a>>1}function $K(a){a=a|0;return+OO(v[a+24>>2])}function xy(a){a=a|0;Gt(a+8|0);return a|0}function xm(a){a=a|0;return pI(v[a>>2])|0}function xW(a,b){return v[a>>2]+B(b,33)|0}function v6(a,b){a=a|0;b=b|0;yJ(a-88|0,b)}function uo(a){return v[v[a+48>>2]+12>>2]}function qo(a,b,c){Pj(a,b,b+c|0);return a}function py(a){a=a|0;if(a){nJ(a);he(a,a)}}function of(a){v[a>>2]=v[a>>2]+2;return a}function oc(a){return v[a+4>>2]-v[a>>2]|0}function oF(a){return(w[a+24|0]&16)>>>4|0}function hS(a){v[a>>2]=v[a>>2]-2;return a}function gka(a){a=a|0;return es(a+20|0)|0}function f1(a,b){a=a|0;b=b|0;gg(a,b+16|0)}function ei(a){return x[a+480190>>1]<3999}function ct(a){a=a|0;oh(a+8|0);return a|0}function ck(a,b){return v[a>>2]-v[b>>2]|0}function bn(a,b){return v[a>>2]+B(b,56)|0}function bf(a,b){return v[a>>2]+B(b,52)|0}function au(a,b){return v[a>>2]+B(b,28)|0}function at(a){a=a|0;oh(a+4|0);return a|0}function YN(a,b){Vm(a,A[b>>3],-A[b+8>>3])}function Xl(a,b){return v[a>>2]+B(b,24)|0}function XY(a,b){a=a|0;b=b|0;ik(a+12|0,b)}function WL(a){a=a|0;Qb(a+4296|0,0,81928)}function VP(a,b){if(z[a>>2]>b){z[a>>2]=b}}function VG(a,b){return Cp(a,Jb(b),Ab(b))}function Qj(a,b){return v[a>>2]+B(b,36)|0}function Qf(a){a=a|0;Jh(a+8|0);return a|0}function Qca(a){a=a|0;t[a+4202|0]=1;AM(a)}function MK(a,b){a=a|0;b=b|0;gg(a,b+12|0)}function MI(a,b){t[a|0]=b+48;return a+1|0}function Lg(a,b){return v[a>>2]+B(b,20)|0}function L6(a,b){a=a|0;b=b|0;OJ(a-88|0,b)}function K6(a,b){a=a|0;b=b|0;NJ(a-88|0,b)}function Jba(a){a=a|0;return v[a+4260>>2]}function In(a,b){return v[a>>2]+(b<<11)|0}function Fd(a,b){v[a>>2]=v[b>>2];return a}function Fc(a,b){a=a|0;b=b|0;_p(a,b+28|0)}function Ad(a,b){return v[a>>2]+B(b,12)|0}function yna(a,b){a=a|0;b=b|0;Xt(a,b,17)}function ye(a,b){return v[a>>2]+(b<<3)|0}function vm(a){return(a|0)==32|a-9>>>0<5}function uL(a){return(Jb(a)+Ab(a)|0)-1|0}function sna(a,b){a=a|0;b=b|0;Sk(a,b,17)}function sc(a,b){return v[a>>2]+(b<<1)|0}function rg(a,b){v[a+8>>2]=b|-2147483648}function nba(a){a=a|0;return(a|0)==277|0}function jj(a){return B(ij(a),fd(a))&255}function dG(a,b){xc(a,b);xc(a+4|0,b+4|0)}function d1(a,b){a=a|0;b=b|0;rx(a,81464)}function cd(a){return v[a>>2]==v[a+4>>2]}function bqa(a,b){a=a|0;b=b|0;Sk(a,b,44)}function bX(a,b){v[a>>2]=b;v[a+4>>2]=b+4}function b1(a,b){a=a|0;b=b|0;rx(a,81484)}function ad(a,b){return v[a>>2]+B(b,6)|0}function _f(a){a=a|0;return!v[a+16>>2]|0}function Yl(a){a=a|0;return v[a>>2]+14|0}function Ul(a,b){return v[a>>2]+(b<<8)|0}function Tc(a,b){return v[a>>2]+(b<<4)|0}function Sj(a,b){return v[a>>2]==v[b>>2]}function Q6(a){a=a|0;return xy(a-88|0)|0}function Mb(a,b){return v[a>>2]+(b<<2)|0}function ME(a,b){return v[a>>2]+(b<<5)|0}function J6(a,b){a=a|0;b=+b;MJ(a-88|0,b)}function Ij(a){u[a+4>>1]=65535;v[a>>2]=0}function H6(a,b){a=a|0;b=+b;JJ(a-88|0,b)}function FM(a){return(w[a+24|0]&8)>>>3|0}function F6(a,b){a=a|0;b=+b;HJ(a-88|0,b)}function Dla(a,b){a=a|0;b=b|0;Sk(a,b,10)}function Dda(a){a=a|0;return w[a+4201|0]}function Cg(a){a=a|0;return GP(w[a|0])|0}function Cda(a){a=a|0;return w[a+4202|0]}function $s(a,b){v[a+24>>2]=v[a+24>>2]+b}function $b(a){v[v[a>>2]+4>>2]=v[a+4>>2]}function $F(a){v[a+4>>2]=0;v[a>>2]=86648}function zw(a,b){a=a|0;b=b|0;uw(a,b,32)}function zn(a,b){return y[a>>2]<y[b>>2]}function xv(a,b){return z[a>>2]<z[b>>2]}function wZ(a,b){a=a|0;b=b|0;Xt(a,b,11)}function uba(a){a=a|0;return-2013527448}function sla(a,b){a=a|0;b=b|0;Sk(a,b,5)}function rW(a,b){a=a|0;b=b|0;return b|0}function pt(a,b){return v[a>>2]<v[b>>2]}function kH(a,b){a=a|0;b=b|0;He(a,1,45)}function jS(a,b){v[a>>2]=v[a>>2]+(b<<1)}function jH(a,b){a=a|0;b=b|0;tH(a,1,45)}function he(a,b){if(!v[a+80>>2]){Yb(b)}}function fZ(a,b){a=a|0;b=b|0;Sk(a,b,11)}function eF(a,b){a=a|0;b=b|0;Sk(a,b,32)}function e1(a,b){a=a|0;b=b|0;Tb(a,8570)}function dT(a,b){return A[a>>3]<A[b>>3]}function c1(a,b){a=a|0;b=b|0;Tb(a,8687)}function ZN(a){v[a+4>>2]=v[a+4>>2]|8192}function Tq(a){a=a|0;if(a){Yb(a+-64|0)}}function TV(a,b){v[a>>2]=v[a>>2]+(b<<2)}function Oj(a,b){return u[a>>1]<u[b>>1]}function Ir(a,b,c){if(b){Qb(a,Mg(c),b)}}function Ib(a){return(a<<8|a>>>8)&65535}function Ho(a,b,c){return a<b?b:a>c?c:a}function Hn(a,b){return x[a>>1]<x[b>>1]}function GF(a,b){bc(a,v[b>>2],rf(b)<<3)}function GA(a,b,c){return a<b?b:a>c?c:a}function Fna(a,b){a=a|0;b=b|0;RD(a,b,8)}function DP(a,b){return(Ol(a,b)|0)!=255}function BX(a,b){v[a>>2]=v[a>>2]+B(b,6)}function Aj(a,b,c){Dc(a,b);Dc(a+12|0,c)}function yk(a,b){return Jb(a)+(b<<2)|0}function xu(a,b){a=a|0;b=b|0;JG(a,b,0)}function wca(a){a=a|0;return-285139079}function uH(a,b,c){Ge(a,b);Ge(a+4|0,c)}function tn(a,b){a=a|0;b=b|0;bc(a,b,7)}function ss(a){bl(a);hG(a);$k(a);bl(a)}function pS(a,b){v[a+4>>2]=b;v[a>>2]=b}function p8(a){a=a|0;return+A[a+16>>3]}function oca(a){a=a|0;return-284078960}function lba(a,b){a=a|0;b=b|0;return 3}function kba(a,b){a=a|0;b=b|0;return 2}function ida(a){a=a|0;return 542066252}function iZ(a){a=a|0;return v[a+12>>2]}function hca(a){a=a|0;return-281111764}function gT(a,b){a=a|0;b=b|0;zk(a,0,b)}function fd(a){return w[a+34|0]&64?2:1}function fG(a,b){MG(a,b);v[a>>2]=89416}function cca(a){a=a|0;return-271958638}function az(a,b){a=a|0;b=b|0;lN(a,3,b)}function as(a){a=a|0;return 2147483647}function aj(a){return B(v[a>>2],jj(a))}function _c(a){v[v[a+8>>2]>>2]=v[a>>2]}function YY(a){a=a|0;return v[a+24>>2]}function WE(a){wb(a);return 2147483647}function Uba(a){a=a|0;return-620920304}function Tja(a){a=a|0;TS(a);return a|0}function Kba(a){a=a|0;return-275227023}function I6(a){a=a|0;return+KJ(a-88|0)}function Gca(a){a=a|0;return-270114148}function G6(a){a=a|0;return+IJ(a-88|0)}function FK(a){return a?(a|0)==2?3:2:1}function E_(a){a=a|0;return v[a+16>>2]}function E6(a){a=a|0;return+GJ(a-88|0)}function Bba(a){a=a|0;return 302837129}function Ah(a){a=+a;return hr(ee(a))|0}function yw(a){return w[a+21|0]>>>7|0}function wy(a){a=a|0;return v[a+8>>2]}function wv(a){a=a|0;return Pb(a,1)^1}function wI(a,b){return fI(a)^fI(b)^1}function vpa(a){a=a|0;return UX(a)|0}
function qI(a,b){return eI(a)^eI(b)^1}function pp(a,b){u[a+8>>1]=b;return a}function oh(a){a=a|0;$x(a);return a|0}function nx(a){a=a|0;Ds(a);return a|0}function nL(a,b){return w[a|0]<w[b|0]}function is(a,b){a=a|0;b=b|0;return 1}function ij(a){return t[a+34|0]&1?2:1}function dt(a,b){a=a|0;b=b|0;return-1}function c5(a){a=a|0;return YH(a,0)|0}function b5(a){a=a|0;return YH(a,1)|0}function aF(a){return w[a+22|0]>>>7|0}function _ca(a,b){a=a|0;b=b|0;Iu(a,b)}function _4(a){a=a|0;return VH(a,0)|0}function Z4(a){a=a|0;return VH(a,1)|0}function XK(a){return x[a+1074448>>1]}function V6(a){a=a|0;return w[a+40|0]}function Ue(a,b){v[a+4>>2]=b;return a}function Tl(a,b){return t[a|0]<t[b|0]}function Sb(a){return ME(a,w[a+16|0])}function QJ(a){v[a>>2]=60084;return a}function Pka(a){a=a|0;return OT(a)|0}
function PQ(a){a=a|0;wr(a);return a|0}function PL(a,b){a=a|0;b=b|0;return 0}function Kx(a){a=a|0;if(KH(a)){Yb(a)}}function Kk(a){return v[a+1298364>>2]}function KI(a){a=a|0;nx(a);return a|0}function Jh(a){a=a|0;SF(a);return a|0}function Fl(a){return(w[a+16|0]&5)!=0}function De(a){return w[a+11|0]>>>7|0}function Ct(a){a=a|0;return v[a+4>>2]}function zV(a,b){if(!nV(a,b)){cC(b)}}function zN(a,b){Sf(a);BO(a,b);wN(a)}function yn(a,b){tc(a);kF(a,b);HE(a)}function yfa(a){a=a|0;return Ki(a)|0}function rG(a,b){a=a|0;b=b|0;Rq(a,b)}function od(a,b){return In(a+12|0,b)}function lj(a){return v[a+4>>2]-36|0}function lS(a,b){ze(a);fS(a,b);eS(a)}function ih(a,b){a=a|0;b=b|0;RY(a,b)}function hj(a,b){Nb(a);uU(a,b);tw(a)}function h1(a){a=a|0;return t[a+8|0]}function g7(a){a=a|0;return w[a+8|0]}function g1(a){a=a|0;return t[a+9|0]}function eoa(a){a=a|0;return Kk(a)|0}function d_(a,b){a=a|0;b=b|0;Oo(a,b)}function aL(a){return v[a+4>>2]-48|0}function WC(a,b){Kg(a);VW(a,b);JW(a)}function Vr(a,b){a=a|0;b=b|0;Iw(a,b)}function UM(a,b,c){a=a|0;b=b|0;c=c|0}function UL(a){v[a>>2]=0;v[a+4>>2]=0}function Tba(a){a=a|0;v[a+4224>>2]=0}function Pu(a){return v[wb(a)>>2]<<5}function Or(a,b){a=a|0;b=b|0;Yv(a,b)}function NU(a){return v[a+4>>2]-56|0}function Ln(a){v[a+4>>2]=v[a+4>>2]+1}function LK(a){return v[a+4>>2]-12|0}function IU(a){return v[a+4>>2]-28|0}function IO(a){return v[a+4>>2]-32|0}function HR(a,b){a=a|0;b=b|0;$f(a,b)}function Gga(a){a=a|0;return lm(a)|0}function GP(a){return(a+5&255)>>>0<2}function Em(a,b){oc(a);uK(a,b);qK(a)}function $f(a,b){a=a|0;b=b|0;gg(a,b)}function zea(a){a=a|0;Xt(a,18726,1)}function zda(a,b){a=a|0;b=b|0;fz(b)}function z2(){_d(465520,Wd(464224))}function yc(a,b){v[a>>2]=b;return a}function y2(){_d(465528,Wd(464232))}function x2(){_d(465536,Wd(464240))}function wo(a){return v[a+4>>2]-4|0}function wf(a){return v[a+24620>>2]}function w2(){_d(465560,Wd(464248))}function v2(){_d(465592,Wd(464012))}function u2(){_d(465600,Wd(464020))}function t2(){_d(465608,Wd(464028))}function s2(){_d(465616,Wd(464036))}function ru(a){return Ao(a)<<24>>24}function r2(){_d(465624,Wd(464076))}function qha(a,b){a=a|0;b=b|0;zR(b)}function p2(){_d(465632,Wd(464084))}function o2(){_d(465640,Wd(464092))}function nF(a){a=a|0;return Og(a)|0}function n2(){_d(465648,Wd(464100))}function m_(a){a=a|0;return sf(a)|0}function m2(){_d(465656,Wd(464108))}function ly(a){return!sd(a,90148,6)}function lc(a,b){return v[a>>2]+b|0}function l2(){_d(465664,Wd(464116))}function kha(a,b){a=a|0;b=b|0;Ye(b)}function k2(){_d(465672,Wd(464124))}function j2(){_d(465680,Wd(464132))}function i2(){_d(465688,Wd(464044))}function i$(a){a=a|0;return sg(a)|0}function h2(){_d(465704,Wd(464052))}function gc(a){vt(a);km(a);return a}function fm(a,b,c){if(c){yh(a,b,c)}}function fka(a,b){a=a|0;b=b|0;ed(b)}function f2(){_d(465720,Wd(464060))}function e$(a){a=a|0;return v[a>>2]}function d2(){_d(465736,Wd(464068))}function cF(a){return w[a+21|0]&127}function c2(){_d(465752,Wd(464140))}function bF(a){return w[a+22|0]&127}function bD(a,b){return CX(a,0-b|0)}function b2(){_d(465760,Wd(464148))}function aB(a,b){return B(b,12)+a|0}function Zb(a){return Hg(v[a+4>>2])}function Xr(a){t[a+2|0]=0;u[a>>1]=0}function VZ(a){a=a|0;return zE(a)|0}function VY(a){a=a|0;return es(a)|0}function V8(a){a=a|0;return ue(a)|0}function Rr(a){a=a|0;return Ae(a)|0}function Rg(a,b,c){return Mn(a,b,c)}function RY(a,b){JI(a,v[a+16>>2]|b)}function Qg(a,b,c){if(c){hc(a,b,c)}}function Ona(a,b){a=a|0;b=b|0;ak(b)}function MV(a,b){return we(a,0-b|0)}function Jfa(a,b){a=a|0;b=b|0;Km(b)}function Ifa(a,b){a=a|0;b=b|0;Jg(b)}function I7(a){a=a|0;return wK(a)|0}function H2(){_d(465456,Wd(463996))}function G2(){_d(465464,Wd(464004))}function F2(){_d(465472,Wd(464200))}function Eha(a,b){a=a|0;b=b|0;Zm(b)}function E2(){_d(465488,Wd(464192))}function D2(){_d(465496,Wd(464208))}function Az(a){a=a|0;return Fl(a)|0}function A2(){_d(465504,Wd(464216))}function vK(a){return(Yg(a)|0)==-1}function uh(a,b){v[a>>2]=v[a>>2]|b}function ue(a){return v[a>>2]+16|0}function tt(a){a=a|0;t[a+6152|0]=0}function tS(a,b){t[v[a>>2]]=w[b|0]}function t6(a,b){a=a|0;b=b|0;Yb(b)}function sG(a,b){a=a|0;b=b|0;vb(b)}function rK(a,b){a=a|0;b=b|0;Gy(b)}function pK(a,b){a=a|0;b=b|0;Hl(b)}function ow(a,b){v[a>>2]=v[a>>2]+b}function ok(a,b,c){wd(a,v[b>>2],c)}function no(a,b){v[a+1298424>>2]=b}function nm(a){Fm(a);v[a>>2]=89044}function kf(a,b){Zo(a);yc(a+4|0,b)}function hH(a){return Nh(a,464084)}function g_(a,b){a=a|0;b=b|0;Xr(b)}function gH(a){return Nh(a,464076)}function fN(a,b){a=a|0;b=b|0;Zo(b)}function dH(a){return Nh(a,464100)}function cU(a){td(a,0,-1);return a}function cH(a){return Nh(a,464092)}function Zs(a){return Ie(a,-1)?0:a}function Xd(a){$F(a);v[a>>2]=81720}function Vl(a,b){zp(a,b,v[b+4>>2])}function U_(a,b){a=a|0;b=b|0;Ow(b)}function T2(a){a=a|0;mo(a,1,10784)}function Pk(a){t[a|0]=0;t[a+1|0]=0}function Lh(a,b){a=a|0;b=b|0;Kb(a)}function Jj(a,b){return(b<<13)+a|0}function JZ(a,b){a=a|0;b=b|0;iw(b)}function HZ(a,b){a=a|0;b=b|0;Pk(b)}function Gi(a){a=a|0;t[a+4202|0]=0}function GZ(a,b){a=a|0;b=b|0;Jh(b)}function Fy(a,b){a=a|0;b=b|0;Hf(b)}function FZ(a,b){a=a|0;b=b|0;xb(b)}function Eg(a,b){td(a,Jb(b),Ab(b))}function Bj(a){return cd(a+36|0)^1}function Bh(a,b){Zo(a);ef(a+4|0,b)}function xr(a,b){return qe(a,b)^1}function vd(a,b){return(b<<1)+a|0}function sr(a){v[a>>2]=v[a>>2]+12}function rV(a,b){return(b<<4)+a|0}function qp(a){v[a>>2]=2;return a}function qT(a,b){DB(a,b);return a}function pn(a){v[a>>2]=v[a>>2]+28}function pc(a,b){return Jb(a)+b|0}function nS(a){v[a>>2]=v[a>>2]+32}function kc(a,b){Uw(a,b);return a}function hx(a,b){return v[a+b>>2]}function g0(a){a=a|0;return 10482}function fE(a){return w[a+1|0]==1}function eN(a,b,c){return Oj(b,c)}function eL(a){v[a>>2]=v[a>>2]+24}function _o(a){v[a>>2]=v[a>>2]+16}function Yd(a){return v[fc(a)>>2]}function Vfa(a){a=a|0;Af(a,Ri(a))}function Vb(a){return Hg(v[a>>2])}function VO(a){v[a>>2]=v[a>>2]+52}function V$(a){a=a|0;return 10368}function Ui(a){v[a>>2]=0;return a}function Te(a){return Sf(a)&65535}function SC(a,b,c){return Hn(b,c)}function Rm(a){u[a>>1]=0;return a}function Qy(a,b){return Lz(a,b)^1}function Qh(a){return a-48>>>0<10}function QT(a){return v[wb(a)>>2]}function My(a){return a+1298368|0}function Ky(a){return Yg(a+120|0)}function Fh(a){v[a>>2]=1;return a}function Fe(a,b){return(b<<2)+a|0}function Ew(a){return t[a+24|0]&1}function Eh(a){v[a>>2]=v[a>>2]+20}function Co(a){return a+1074328|0}function CM(a){return w[a+4232|0]}function Bu(a,b,c){return PA(b,c)}function Bq(a){gc(a+4|0);return a}function Ala(a){a=a|0;eW(a,65535)}function yr(a){oc(a);MF(a);qK(a)}function xD(a){Zj(a);sY(a);rY(a)}function xB(a,b,c){_S(ne(a,b),c)}function vt(a){dg(a);oc(a);dg(a)}function vE(a){em(a);Je(a);em(a)}function qR(a){tg(a);rf(a);tg(a)}function oU(a){return w[a|0]<129}function n9(a){a=a|0;Ry(a);Yb(a)}function hv(a){bi(a);ze(a);bi(a)}function hM(a){a=a|0;$y(a);Yb(a)}function h7(a){a=a|0;XJ(a);Yb(a)}function gY(a){mn(a);Zj(a);mn(a)}function fW(a,b){hc(a,b+4|0,256)}function fT(a){$i(a);_i(a);$i(a)}function d0(a){a=a|0;return 7556}function cm(a){tc(a);Dw(a);HE(a)}function bk(a){v[a>>2]=v[a>>2]+6}function b6(a){a=a|0;return 7676}function aI(a){v[a+72>>2]=463112}function _$(a){a=a|0;return 3923}function Zx(a){xi(a);uf(a);xi(a)}function ZM(a){Vf(a);TM(a);SM(a)}function ZH(a){a=a|0;Am(a);Yb(a)}function Y$(a,b){a=a|0;b=b|0;L()}function WH(a){a=a|0;bq(a);Yb(a)}function W$(a){a=a|0;return 6987}function VC(a){Yj(a);Kg(a);Yj(a)}function Tv(a){v[a>>2]=v[a>>2]+2}function To(a,b){u[a>>1]=x[b>>1]}function TP(a,b,c,d){XP(a,b,c,d)}function Sw(a){a=a|0;Ds(a);Yb(a)}function S$(a){a=a|0;return 2812}function Qe(a){v[a>>2]=v[a>>2]+4}function Pe(a){v[a>>2]=v[a>>2]+1}function PM(a){Dl(a);Vf(a);Dl(a)}function Op(a){a=a|0;kx(a);Yb(a)}function OF(a){$k(a);bl(a);$k(a)}function KP(a,b,c,d){AA(a,b,c,d)}function KA(a){t[a|0]=0;return a}function JN(a){Kg(a);WW(a);JW(a)}function Gg(a){Nb(a);cr(a);tw(a)}function Ge(a,b){v[a>>2]=v[b>>2]}function Fp(a){Pg(a);tc(a);Pg(a)}function Fk(a){pe(a);Nb(a);pe(a)}function Eu(a){v[a>>2]=v[a>>2]+8}function Dr(a){return Qb(a,0,48)}function Dd(a){return v[a>>2]!=0}function DO(a){qk(a);Sf(a);qk(a)}function DL(a){a=a|0;Sy(a);Yb(a)}function Cl(a){a=a|0;Lf(a);Yb(a)}function $p(a){ug(a);Ec(a);ug(a)}function $H(a){v[a+72>>2]=463196}function $6(a){a=a|0;UJ(a);Yb(a)}function y0(a){a=a|0;Hc(464384)}function xb(a){Kd(a+12|0);Kd(a)}function wq(a){u[a+480214>>1]=0}function w0(a){a=a|0;vb(464400)}function u0(a){a=a|0;Hc(464416)}function rw(a,b){return TE(a,b)}function rk(a){return!v[a+4>>2]}function px(a){return wb(a+8|0)}function mO(a,b){return kO(a,b)}function lf(a,b){return Ng(a,b)}function kr(a,b){return UV(a,b)}function ki(a,b,c){pf(a,c,13,b)}function hg(a){return Wh(Mg(a))}function dN(a,b){return Oj(a,b)}function am(a){return Qv(tc(a))}function af(a){a=a|0;return a|0}function _b(a,b){return bf(a,b)}function Zm(a){vb(a+12|0);Ze(a)}function Xy(a,b){return ah(a,b)}function Wh(a){return a<<24>>24}function VE(a,b){return SE(a,b)}function Tj(a,b){return ME(a,b)}function Sm(a){vb(a+12|0);vb(a)}function Ro(a){return _m(ee(a))}function Rh(a,b){return Fe(a,b)}function RC(a,b){return Hn(a,b)}function Pi(a){return ze(a)&255}function O6(a){a=a|0;PJ(a-88|0)}function Nd(a,b){return In(a,b)}function NW(a,b){td(a,b,b+16|0)}function Ms(a){a=a|0;return 127}function Iba(a){a=a|0;return 13}function I0(a){a=a|0;vb(464304)}function Hca(a){a=a|0;Yb($y(a))}function G0(a){a=a|0;Hc(464320)}function Eq(a){sR(a+12|0);xR(a)}function Ej(a,b){return a>>>b&1}function Ef(a){vb(a+20|0);vb(a)}function E0(a){a=a|0;vb(464336)}function C0(a){a=a|0;Hc(464352)}function Bl(a,b,c){td(a,b,1<<c)}function AU(a,b){return Rj(b,a)}function A0(a){a=a|0;vb(464368)}function z1(a){a=a|0;Yb(UG(a))}function vca(a){a=a|0;return 6}function su(a,b){return a<<8|b}function so(a){a=a|0;Yb(Tt(a))}function pM(a){a=a|0;Yb(qM(a))}function m5(a){a=a|0;Yb(eu(a))}function l9(a){a=a|0;Yb(Sy(a))}function k1(a){a=a|0;Yb(SG(a))}function j7(a){a=a|0;Yb(YJ(a))}function i1(a){a=a|0;Yb(RG(a))}function hI(a){a=a|0;Yb(Cq(a))}function gI(a){a=a|0;Yb(vf(a))}function ec(a,b){v[a+100>>2]=b}function cv(a){return a>>>27^a}function b7(a){a=a|0;Yb(VJ(a))}function aM(a){a=a|0;Yb(bM(a))}function a$(a){a=a|0;Yb(_F(a))}function _x(a){a=a|0;Yb(ct(a))}function _5(a){a=a|0;Yb(KI(a))}function Z1(a){a=a|0;Yb(ZG(a))}function X5(a){a=a|0;Yb($x(a))}function Vx(a){a=a|0;Yb(at(a))}function UV(a,b){return b-a>>2}function U5(a){a=a|0;Yb(Am(a))}function U$(a){a=a|0;Yb(kx(a))}function Tka(a){a=a|0;return 9}function T$(a){a=a|0;Yb(Ds(a))}function SS(a){return a+4896|0}function R_(a){a=a|0;Yb(PF(a))}function Q5(a){a=a|0;Yb(bq(a))}function PJ(a){a=a|0;Yb(xy(a))}function PG(a){a=a|0;Yb(qx(a))}function N7(a){a=a|0;Yb(It(a))}function Ly(a,b){return b-a>>3}function L_(a){a=a|0;Yb(CF(a))}function J_(a){a=a|0;Yb(BF(a))}function IM(a){a=a|0;Yb(JM(a))}function II(){return(fb()|0)>0}function I1(a){a=a|0;Yb(XG(a))}function ET(a){OB(Qb(a,0,872))}function EI(a){a=a|0;Yb(oh(a))}function Bd(a,b){t[a|0]=w[b|0]}function $$(a){a=a|0;Yb(nx(a))}function xM(a){a=a|0;return 7}function wr(a){Ui(a);return a}function wk(a){return Dd(a)^1}function vp(a){return a>>>0<5}function tl(a){return a+120|0}function te(a){a=a|0;return 1}function tR(a){Uj(a);return a}function sA(a){yF(a);return a}function re(a){a=a|0;return 2}function qC(){return Mc(20,4)}function oS(a,b){return b-a|0}function oG(a){a=a|0;return 3}function mc(a){Ig(a);return a}function kM(a){a=a|0;return 5}function jc(a){a=a|0;return 0}function ic(a,b){return a+b|0}function i9(){return 19923028}function hi(a){return cd(a)^1}function hh(a){dd(a);return a}function fF(a){return a>>>0>8}function eC(a,b){bc(a,b,1024)}function dx(){return lb()<<16}function dd(a){vh(a);return a}function cf(a,b){u[a+28>>1]=b}function cR(){return Mc(36,4)}function bw(a){return!v[a>>2]}function _W(){return Mc(32,4)}function YU(a,b){bc(a,b,1108)}function Y1(){_p(464176,$G())}function Sv(a){a=a|0;return 4}function PW(a){Dr(Qb(a,0,48))}function Ou(a){return a+256|0}function Mo(a,b){v[a+36>>2]=b}function MU(a,b){pf(a,b,33,1)}function KD(a,b){bc(a,b,1954)}function Jt(a,b){v[a+32>>2]=b}function Io(a){mc(a);return a}function BI(a){a=a|0;return-1}function $g(a){return D(a)==N}function zY(a,b){bc(a,b,610)}function zU(a,b){bc(a,b,146)}function zS(a,b,c){Yq(a,c,b)}function yX(a,b){bc(a,b,157)}function yS(a,b,c){Xq(a,c,b)}function vU(a,b){bc(a,b,608)}function v5(a){a=a|0;RY(a,1)}function ut(a,b){dg(a);dg(a)}function uq(a,b){z[a+8>>2]=b}function tX(a,b){bc(a,b,576)}function tN(a,b){qk(a);qk(a)}function sq(a,b){z[a+4>>2]=b}function sY(a){kY(a,v[a>>2])}function rq(a,b){t[a+33|0]=b}function rn(a,b){le(a,b+8|0)}function rI(a,b){xi(a);xi(a)}function qU(a){return a+48|0}function oL(a){v[a>>2]=55220}function nK(a,b,c){yK(a,b,c)}function mV(a,b){bc(a,b,130)}function mR(a){lR(a,v[a>>2])}function lp(a,b){wb(b);wb(a)}function lX(a){return a+36|0}function kV(a,b){bc(a,b,600)}function jE(a,b){em(a);em(a)}function iB(a,b){bi(a);bi(a)}function i7(a){a=a|0;ZJ(a,1)}function gp(a,b){v[a+8>>2]=b}function gS(a){fS(a,v[a>>2])}function eX(a){LI(a,v[a>>2])}function eV(a,b){bc(a,b,126)}function dn(a,b){pe(a);pe(a)}function de(a,b){v[a+4>>2]=b}function dc(a){return a+12|0}function cr(a){uU(a,v[a>>2])}function cD(a,b){pf(a,b,8,2)}function ax(a,b){ug(a);ug(a)}function aU(a,b){bc(a,b,204)}function a7(a){a=a|0;av(a,1)}function _s(a,b){_p(a,b+4|0)}function _e(a,b){t[a+11|0]=b}function _C(a,b){nX(a,ce(b))}function ZS(a,b){bc(a,b,263)}function Yw(a,b){gG(a,ce(b))}function Yp(a){return a+20|0}function WW(a){VW(a,v[a>>2])}function Vv(a,b){bc(a,b,512)}function UW(a,b){bc(a,b,674)}function TM(a){QM(a,v[a>>2])}function RO(a){v[a>>2]=74376}function RJ(a){v[a>>2]=60060}function Qr(a,b){bc(a,b,192)}function Pz(a,b){t[a+34|0]=b}function Oz(a,b){t[a+32|0]=b}function Od(a){de(a,v[a>>2])}function Nz(a,b){t[a+35|0]=b}function MF(a){uK(a,v[a>>2])}function KE(a,b){bc(a,b,497)}function KC(a,b){Yj(a);Yj(a)}function Ip(a){v[a>>2]=27764}function Fm(a){v[a>>2]=89064}function Dw(a){kF(a,v[a>>2])}function CW(a,b){bc(a,b,128)}function CO(a){BO(a,v[a>>2])}function BM(a,b,c){Mn(a,b,c)}function At(a){v[a>>2]=56292}function AX(a,b){bc(a,b,218)}function AR(a){return D(a)<N}function $r(a,b){Pg(a);Pg(a)}function $c(a,b){a=a|0;b=b|0}function yD(a,b){bc(a,b,64)}function wb(a){return a+8|0}function vC(a,b){bc(a,b,40)}function tE(a,b){bc(a,b,38)}function rka(a){a=a|0;ET(a)}function rQ(a){return 0-a|0}function rE(a,b){bc(a,b,41)}function qd(a){return a+1|0}function oV(a,b){bc(a,b,30)}function jw(a,b){bc(a,b,16)}function j9(){return 393216}function hw(a,b){bc(a,b,65)}function h6(){return 460548}function gd(a){return!Ab(a)}function fz(a){Qb(a,0,2048)}function fc(a){return a+4|0}function ej(a){return a+3|0}function ds(a,b){bc(a,b,36)}function cga(a){a=a|0;qA(a)}function cV(a,b){bc(a,b,32)}function bW(a,b){bc(a,b,52)}function _X(a,b){bc(a,b,12)}function _V(a,b){bc(a,b,80)}function _E(a,b){uw(a,b,22)}function ZO(a){Qb(a,0,1024)}function Yo(a){Qb(a,0,4096)}function YF(a,b){bc(a,b,24)}function XD(a,b){bc(a,b,11)}function XB(a){v[a+12>>2]=0}function Ve(a){return a+2|0}function UD(a,b){bc(a,b,17)}function Sja(a){a=a|0;Yo(a)}function Sba(){return 65535}function QU(a,b){bc(a,b,96)}function NR(a,b){bc(a,b,27)}function Mg(a){return a&255}function Lv(a,b){bc(a,b,66)}function JD(a){Qb(a,0,1954)}function IX(a,b){bc(a,b,98)}function Gv(a,b){bc(a,b,22)}function GC(a,b){bc(a,b,33)}function FX(a,b){bc(a,b,48)}function EU(a){if(a){Yb(a)}}function Bp(a,b){t[a+1|0]=b}function Bla(){return 65534}function Bf(a,b){t[a+3|0]=b}function Aq(a){Qb(a,0,8192)}function yd(a){$p(a);xF(a)}function yY(a){Qb(a,0,610)}function yU(a){Qb(a,0,146)}function xX(a){Qb(a,0,157)}function wN(a){qk(a);Sf(a)}function vg(){rd(8267);L()}function vc(a){v[a+8>>2]=0}function vB(a){Qb(a,0,512)}function tw(a){pe(a);Nb(a)}function tq(a,b){z[a>>2]=b}function tU(a){Qb(a,0,608)}function sX(a){Qb(a,0,576)}function sR(a){Kq(a,Yd(a))}function sC(a,b){bc(a,b,4)}function rY(a){mn(a);Zj(a)}function qv(a){tC(a,Yd(a))}function qK(a){dg(a);oc(a)}function pE(a,b){ni(a,2,b)}function nr(a){uC(a,Yd(a))}function mx(){jo(4782);L()}function jn(a){VC(a);zv(a)}function jd(a){vE(a);wE(a)}function jV(a){Qb(a,0,600)}function iR(a){ug(a);Ec(a)}function iP(a){nu(a,Yd(a))}function fs(a,b){bc(a,b,8)}function fX(a){t[a+31|0]=0}function ef(a,b){v[a>>2]=b}function eY(a,b){bc(a,b,3)}function eS(a){bi(a);ze(a)}function dV(a){Qb(a,0,126)}function cX(a){PC(a,Yd(a))}function cC(a){Qb(a,0,130)}function bO(a){Jz(a,Yd(a))}function _v(a,b){bc(a,b,5)}function Ze(a){Fp(a);cs(a)}function Zc(a){a=a|0;Yb(a)}function XW(a){QC(a,Yd(a))}function Wb(a){Nn(v[a>>2])}function TW(a){Qb(a,0,192)}function Ska(a){a=a|0;gb=a}function Sc(){rd(4782);L()}function SM(a){Dl(a);Vf(a)}function Qn(){jo(8267);L()}function PV(a,b){bc(a,b,2)}function Nq(a){Zx(a);BR(a)}function Ni(a){return a!=a}function Nc(a){Fk(a);vv(a)}function NX(a,b){bc(a,b,6)}function Ll(a){NA(a,Yd(a))}function JW(a){Yj(a);Kg(a)}function JE(a){Qb(a,0,497)}function J4(){return 77144}function I4(){return 77920}function Hs(a){a=a|0;Os(a)}function HT(a){EB(a,Yd(a))}function HE(a){Pg(a);tc(a)}function H4(){return 79472}function GT(a){FB(a,Yd(a))}function GB(a){Qb(a,0,256)}function Fla(){return gb|0}function Ak(a,b){zp(a,b,0)}function $T(a){Qb(a,0,204)}function yC(a){Qb(a,0,80)}function sE(a){Qb(a,0,38)}function qE(a){Qb(a,0,41)}function qD(a){Qb(a,0,66)}function nD(a){Qb(a,0,64)}function aW(a){Qb(a,0,52)}function Yi(a,b){t[a|0]=b}function RU(a){Qb(a,0,96)}function N8(){return 2048}function HX(a){Qb(a,0,98)}function HC(a){Qb(a,0,33)}function Gw(a){Qb(a,0,36)}function GX(a){Qb(a,0,48)}function zc(a){gc(a+8|0)}function zR(a){Vm(a,0,0)}function xq(a,b){Ge(a,b)}function xO(a,b){ow(a,b)}function wO(a,b){vO(a,b)}function oo(a,b){JI(a,b)}function mp(a,b){Bd(a,b)}function mh(a){a=a|0;L()}function ks(a,b){Uw(a,b)}function jR(a){Lq(a+8|0)}function iz(a,b){pi(a,b)}function iw(a){u[a>>1]=0}function fB(a,b){ag(a,b)}function ed(a){xb(a+8|0)}function _k(a,b){de(a,b)}function Zo(a){v[a>>2]=0}function YW(a,b){ef(a,b)}function XV(a,b){TV(a,b)}function WU(a,b){le(a,b)}function Vh(a,b){Uh(a,b)}function Gk(a){vb(a+4|0)}function FC(a,b){nW(a,b)}function DB(a,b){yc(a,b)}function CN(a,b){mW(a,b)}function BD(a,b){$j(a,b)}function Hpa(){ua();L()}function Hf(a){t[a|0]=0}function vD(a){QX(a,0)}function sO(a){aO(a,0)}function qs(a){gG(a,0)}function lu(a){YO(a,0)}function ln(a){nX(a,0)}function ku(a){XO(a,0)}function iq(a){wL(a,0)}function Jg(a){dX(a,0)}function Ic(a){Ee(a,0)}function Di(a){xL(a,0)}function Ci(a){vL(a,0)}function mf(a){a=a|0}function iI(a){ML(a)}function gR(a){CB(a)}function VT(a){dd(a)}function Hb(a){vb(a)}function X$(){L()}
// EMSCRIPTEN_END_FUNCS
e=w;var kb=c([null,Wm,Tb,Pt,gg,IL,mo,m6,M5,jT,W4,c4,$2,sT,Wm,L5,sZ,vn,ih,W5,$,ED,qn,o_,kx,Oc,Ie,YY,un,af,Zc,LF,is,Gfa,Vpa,Spa,Npa,Hpa,Epa,tpa,fD,Roa,Ooa,aqa,ypa,WB,s0,Rna,Qna,DW,Pf,ep,jr,Fb,$c,DW,r0,qka,mT,MS,Rq,Oo,m0,k0,Wm,Rq,Oo,oi,Bha,gg,Tb,IL,HR,zu,xf,JG,xu,$f,jga,$G,iga,Hg,mP,s5,gga,HR,Kfa,xA,xA,hha,aha,Ffa,Bfa,Rga,Oga,$fa,Yfa,Y5,hga,$f,ofa,H5,Az,F5,GN,D5,Uea,Oea,r5,Wm,B5,z5,uea,Wt,nea,eea,aN,Cp,Wm,Pf,_y,rl,SI,Hy,lo,Zh,d8,Fy,$c,Zh,Gf,lo,Zh,$c,V4,P4,O4,L4,E4,p4,Qs,$f,T3,G3,Kh,qi,m$,i3,iH,eH,T2,Qs,B2,Rn,ux,Hs,ik,Xc,Df,n0,Rn,vs,j1,$0,e0,q2,Z$,DG,Q$,DG,W1,QG,L$,D$,C$,Kh,xG,Pf,Pn,On,mj,sG,rG,qG,Wt,l$,ia,Pp,Op,Ct,Wc,Pb,i$,Xw,h$,lm,g$,iG,f$,Lp,cl,iG,Vd,ps,Zh,d$,Ds,Vw,T_,S_,ff,e$,c$,b$,U_,Jh,ff,RF,ff,Mw,lo,O_,N_,M_,lo,Sw,Ct,_F,a$,Hp,PL,$_,af,Zc,__,te,te,Ct,wy,Z_,Y_,X_,mh,X$,W_,V_,PF,R_,Hp,Q_,Zc,jc,te,te,jc,jc,P_,CF,L_,Hp,K_,BF,J_,I_,H_,G_,F_,E_,D_,C_,B_,Ty,zfa,ufa,rfa,es,TF,w_,NF,sG,$c,zF,t_,s_,Sw,Pf,Pf,nF,Td,q_,p_,Pf,$c,$c,$c,Hy,_y,Fy,rl,h_,jr,n_,Fb,i_,Uk,g_,$c,nF,ji,f_,e_,d_,$Z,IE,xn,$c,WZ,BE,Rb,UZ,TZ,SZ,RZ,Ke,Bc,QZ,PZ,OZ,NZ,Dg,Ag,wh,MZ,lw,yE,LZ,xE,Pf,KZ,ep,Pf,Pf,GZ,JZ,$c,IZ,IE,HZ,FZ,CZ,BZ,AZ,dE,zZ,We,yZ,xZ,wZ,vZ,Zz,IT,QS,uZ,me,tZ,kw,aE,Gd,ik,xh,pZ,oZ,dw,Le,Rr,df,FO,nZ,mZ,lZ,ac,$D,kZ,_D,pd,fw,Ql,Pr,Py,Dn,En,Sd,Xe,hZ,Pf,Hy,_y,Fy,$c,gZ,fZ,_r,Yc,mw,aZ,Nr,$Y,Bg,Pc,Ob,Rf,Df,_Y,Uv,ZY,Xc,Mr,Oha,XY,WY,Qi,VY,HD,Lr,ud,UY,Kr,TY,Jea,Tf,Be,Jm,vo,uz,hqa,PY,DM,GD,Rv,Jr,Ok,Df,gqa,fqa,eF,eqa,kh,dqa,cqa,bm,bqa,DY,mj,$pa,kj,Qf,rG,qG,Wt,Pp,Ypa,Xpa,Wpa,uY,Rpa,bm,wD,nf,Qpa,Ppa,Opa,Mpa,Po,tB,Lpa,Kpa,Jpa,Ipa,Gf,Rd,mt,uD,Nv,tD,Dpa,Cpa,Fpa,mY,Dn,En,nY,nn,rl,$c,Of,aY,zpa,Nk,upa,spa,rpa,Vd,Af,AY,vpa,Ku,WX,qpa,VX,ppa,uB,opa,SX,npa,mpa,lpa,Vw,kpa,Dn,gq,hpa,Nr,kp,gpa,fpa,HD,epa,Rk,dpa,cpa,bpa,apa,wn,gr,$oa,_oa,Zoa,Yoa,bm,gD,kj,Qf,Fv,Ev,MX,nz,Rha,_j,Dv,yz,pq,$t,o0,aD,uX,Gh,Loa,Koa,Mfa,Hoa,aga,Cv,Dp,Goa,Foa,Eoa,Cr,YE,Doa,Nu,Xo,Coa,Boa,Noa,pX,j_,Aoa,So,ZE,Bv,zoa,Df,yoa,Lc,xoa,woa,oX,voa,c_,uoa,toa,soa,roa,mX,qoa,_u,poa,Df,ooa,noa,xw,tY,Moa,Df,moa,loa,gq,yp,koa,joa,ioa,EO,ZC,hoa,ZC,ZC,YC,iX,XC,Hm,goa,dba,foa,eoa,doa,coa,boa,aoa,$na,aea,hX,Pf,QW,kd,ip,Vna,zf,LC,Nna,Or,_na,Pf,JC,Mna,Zna,Yna,Xna,ag,bea,Pfa,Tda,Wna,Pt,Una,Tna,Sna,ff,$f,af,$c,$c,$c,Pna,jr,Ona,rr,Ina,Hna,Gna,Fna,Ena,Dna,Cna,Bna,Ana,zW,yW,zna,yna,xna,wna,vna,una,tna,sna,vW,hn,oW,Qf,gW,EC,pna,DC,ona,pr,BS,Cr,nna,mna,lna,kna,eD,ES,Gb,Yl,CC,jna,VZ,ina,hna,eW,dW,zw,Zr,BC,gna,He,fna,Pt,Cr,ena,Cr,dna,Vr,cna,Df,uY,ov,RV,$ma,_ma,Vd,Zma,Yma,Xma,pC,Wma,lv,Vma,Uma,Tma,Sma,Rma,Qma,CE,Pma,Oma,Vha,Nma,Mma,Lma,Kma,Rja,gha,eha,Jma,o6,TC,p6,Ima,Hma,oy,py,Lfa,Gma,Df,kX,jX,oB,Fma,Ema,dw,Vw,JV,mr,Dma,Cma,Kh,qi,Bma,Pv,jv,Pj,Ih,fC,sma,rma,zma,wv,$c,oma,nma,YD,mma,GO,lma,kma,xN,ip,jma,gV,ima,hma,hm,gm,gv,FA,gma,fma,Qo,ema,dm,dma,bma,aC,up,Mw,Yla,_B,Xla,Wla,Vla,Pl,Ula,bm,kj,Qf,Ih,Rla,Qla,Pla,Ola,Lu,DC,Lla,Mk,xk,gv,Lc,Kla,Mea,JV,mr,ov,Hla,Gla,wD,XU,_B,fw,Ela,Dla,Cla,Sba,Bla,Ala,zla,ev,yla,ev,xla,rs,k_,rla,bm,tla,qla,fC,ula,sla,kj,Qf,FU,DU,nla,EC,mla,jla,ila,TS,gV,pX,iha,ZQ,fla,dw,ala,$ka,$D,gU,_ka,Zka,Yka,Xka,gn,fU,Wka,Vka,Uka,YT,Pka,Oka,Nka,Mka,Lka,Kka,Jka,an,Qja,ST,Ika,Hka,Gka,Fka,Eka,Dka,Cka,ch,Sha,gu,Xga,dha,bha,Bka,Nea,Vd,Aka,DC,zka,yka,xka,wv,SB,wka,LT,Ah,vka,uka,vT,tka,ska,$q,rka,BT,ov,xT,nka,mka,kka,lka,ff,jka,ika,BU,ff,Yr,hka,fka,Tha,bka,aka,ffa,$ja,_ja,Zja,QN,Yja,efa,RN,Xja,Wja,Vja,F4,XH,Uha,iv,Df,Tfa,Sfa,aT,$S,Pf,$c,wB,Pja,Oja,Nja,Mja,Lja,Kja,Jja,Ija,Hja,Gja,Fja,Eja,Dja,Cja,Bja,Aja,zja,yja,xja,wja,vja,uja,tja,sja,rja,qja,pja,oja,nja,mja,kja,jja,ija,hja,gja,fja,eja,dja,cja,bja,aja,$ia,_ia,Zia,Yia,Xia,Wia,Via,Uia,Tia,Sia,Ria,Qia,Pia,Oia,Nia,Mia,Lia,Kia,Jia,Iia,Hia,Gia,Fia,Eia,Dia,Cia,Bia,Aia,zia,yia,xia,wia,via,uia,tia,sia,ria,qia,pia,oia,nia,mia,lia,kia,jia,iia,hia,gia,fia,eia,dia,cia,bia,aia,$ha,_ha,Zha,Xha,Uq,Yha,iS,fj,oE,mS,Pha,Dha,Nha,Mha,Lha,Kha,Jha,kS,Iha,Hha,Gha,Fha,Iu,Cha,Eha,TR,zha,yha,Yv,LR,Afa,wha,vha,qq,Hz,Fz,Ez,YA,uha,DR,tha,sha,Pf,qha,$c,Ko,oq,vR,nha,mha,Ji,lha,Tf,jha,kha,af,$c,tt,q6,dj,fha,Qfa,Vi,Wha,_h,YQ,gka,$h,lfa,cha,Nr,$ga,Ih,Xw,_ga,Zga,Yga,Nr,Wga,Xw,Mga,Lga,PQ,ff,Jga,bm,xG,Pn,On,Wt,Kh,Iga,bm,Kga,Qf,Au,RQ,Pf,af,NQ,kj,Qf,Pf,kj,Qf,hp,Hga,r_,Re,jZ,KQ,Gga,Gpa,JQ,IQ,HQ,GQ,FQ,EQ,DQ,CQ,BQ,AQ,zQ,yQ,xQ,wQ,vQ,uQ,tQ,sQ,qQ,pQ,oQ,nQ,mQ,lQ,kQ,jQ,iQ,hQ,gQ,fQ,eQ,dQ,cQ,bQ,aQ,$P,_P,ZP,YP,Fga,Ega,Dga,Cga,Bga,Aga,zga,yga,xga,wga,vga,uga,tga,sga,rga,qga,pga,pha,SP,Wz,Du,oR,oga,nga,Vz,Cg,Go,Hq,mga,RP,Uo,CA,BA,Qm,Yz,HO,Xz,Fo,tu,LP,Om,lga,zA,qB,pB,JP,cB,Gu,Oi,kga,bP,Qha,Tja,cY,ega,hO,dga,Sja,cga,sf,bga,_fa,k$,A_,v_,y_,Xfa,u_,z_,j$,x_,$m,Wfa,CS,UO,yq,Vfa,qfa,bda,Ufa,TO,nA,Aha,Rfa,oea,sea,Ofa,qea,mea,ff,ff,Is,Nfa,GS,Jfa,Ifa,Hfa,AO,eka,cka,Joa,Ioa,lla,kla,ela,dla,rna,qna,ama,$la,Kna,Jna,cZ,bZ,Xoa,Woa,EZ,DZ,rZ,qZ,Tla,Sla,pla,ola,pka,oka,Upa,Tpa,Bpa,Apa,_Z,ZZ,YZ,XZ,Jla,Ila,wla,vla,qma,pma,Lna,BW,Toa,Soa,Qoa,Poa,_pa,Zpa,jpa,ipa,Nla,Mla,dfa,cfa,Rea,Qea,uma,tma,Rka,Qka,_la,Zla,Voa,Uoa,hla,gla,cla,bla,xpa,wpa,Ama,wma,vma,b_,a_,eZ,dZ,bna,ana,yma,xma,mh,Dfa,Cfa,cP,$c,$f,wB,yfa,xs,wfa,xfa,SQ,tfa,vfa,sfa,bu,pfa,Tga,Tm,Vga,Uga,nfa,mfa,Tr,Pga,Qga,kfa,dka,l_,jfa,sF,$w,Cz,aE,ifa,ZB,hfa,Sga,gfa,bfa,afa,wD,$ea,Gr,_B,_ea,Zea,Yea,fC,Xea,Ih,Wea,Vea,Tea,Sea,Pea,bm,xJ,s6,r6,kj,Qf,Tq,Lea,Iea,yv,Gea,Fea,Eea,Dea,_f,Uh,zm,Cea,FN,Bea,wea,Aea,Kea,zea,tea,xea,Hea,vea,qz,rz,qN,Pf,cea,jr,gN,pea,XS,lq,kea,jea,iea,hea,gea,oN,rea,nq,ag,nN,dea,zl,Uh,fN,$da,_da,Zda,Yda,Xda,Wda,Zf,Vda,Uda,fea,lea,Rda,Qda,Th,Pda,Oda,RM,Bda,fn,jr,mN,Ada,gN,zda,$c,fN,$c,Tt,so,so,VM,jc,mf,jc,jc,jc,$c,Sv,Jda,Kda,Mda,Lda,Nda,Ii,is,is,hz,UM,hz,hz,cma,mf,BW,Fda,Eda,Dda,Cda,Ida,Gi,WM,gda,jc,jc,te,gz,re,re,te,Hda,Gda,$c,mf,$c,mf,xda,jda,JM,IM,IM,ida,jc,mf,jc,jc,jc,$c,Tka,NM,vda,lda,kda,wda,Ii,tda,sda,rda,qda,pda,oda,nda,mda,uda,Gi,MM,jc,jc,te,re,re,te,LM,KM,hda,dda,EM,Zg,Lf,mh,eda,cz,fda,jc,cda,UM,ada,$f,NS,$ca,_ca,Zca,Yca,Iu,Nca,Cca,uca,nca,gca,_ba,Qba,Hba,Aba,eca,Sda,yda,Xca,Wca,tn,yO,Tt,so,so,VM,jc,mf,jc,jc,jc,$c,oG,Rca,Sca,Uca,Tca,Vca,Ii,Qca,Gi,AM,jc,jc,te,re,re,te,Pca,Oca,zM,az,$y,Hca,yM,Gca,jc,mf,jc,jc,jc,$c,xM,Kca,Lca,Mca,Ii,Jca,Gi,Ica,jc,jc,te,re,re,$c,mf,wM,Fca,Eca,vM,Dca,uM,tM,Bca,qM,pM,pM,wca,jc,mf,jc,jc,jc,$c,vca,yca,zca,Aca,Ii,xca,Gi,rM,jc,jc,te,re,re,tca,Cl,Cl,oca,jc,mf,jc,jc,jc,$c,kM,qca,rca,sca,Ii,pca,Gi,lM,jc,jc,te,re,re,mca,Tt,so,so,hca,jc,mf,jc,jc,jc,$c,kM,jca,kca,lca,Ii,ica,Gi,iM,jc,jc,te,re,re,fca,hM,hM,cca,xM,dca,wM,bca,aca,vM,$ba,uM,tM,Zba,Cl,Cl,Uba,jc,mf,jc,jc,jc,$c,re,Wba,Xba,Yba,Ii,Vba,Gi,Tba,jc,jc,te,re,re,Pba,Rba,bM,aM,aM,Kba,jc,mf,jc,jc,Jba,$c,Iba,Mba,Nba,Oba,Ii,Lba,Gi,Yy,jc,jc,te,re,re,$c,mf,Gba,Cl,Cl,Bba,jc,mf,jc,jc,jc,$c,oG,Dba,Eba,Fba,Ii,Cba,Gi,ZL,jc,jc,te,re,re,zba,Cl,Cl,uba,jc,mf,jc,jc,jc,$c,Sv,wba,xba,yba,Ii,vba,Gi,WL,jc,jc,te,re,re,j9,sba,p9,a9,i9,h9,Q8,ux,iL,Lt,LL,M8,iba,KL,N8,hL,I8,H8,af,fba,eba,LL,G8,E8,GL,aba,Sy,dL,wy,cL,bL,s8,o8,p8,q8,Wy,D8,Maa,BL,C8,B8,A8,z8,y8,x8,w8,v8,u8,t8,n8,Wy,h8,$K,_K,ZK,YK,WK,VK,UK,TK,SK,RK,QK,PK,g8,io,OK,NK,wl,hq,f8,MG,e8,b8,a8,$7,_7,KK,JK,Et,Z7,Y7,W7,V7,U7,T7,S7,R7,Q7,P7,U8,sL,rL,qL,pL,S6,R6,GL,Wy,H9,G9,F9,E9,D9,C9,B9,A9,z9,y9,x9,w9,v9,u9,t9,s9,r9,q9,ua,o9,Ry,n9,m9,DL,k9,DL,l9,Mq,g9,Nga,yl,ys,gT,Rl,e9,d9,K7,b9,zk,mT,vu,Y8,fga,T8,GG,S8,K5,xha,O7,Pt,rha,oha,Zfa,X8,f9,$8,Bz,og,V8,Efa,P8,zL,yL,hL,L8,O8,gL,K8,J8,ff,W8,R8,Z8,bc,F8,r8,NO,m8,l8,k8,T6,hA,iA,_8,JO,j8,i8,po,MK,yea,c8,Ri,X7,Yc,KO,xz,Uja,wz,J7,I7,H7,xK,G7,oK,Bt,oK,Bt,aa,m7,l7,c7,k7,mh,It,N7,c9,af,mh,af,Zc,M7,L7,mh,tK,sK,tK,sK,$c,Dt,$c,Dt,rK,pK,rK,pK,Zc,F7,af,Zc,E7,D7,Zc,mK,lK,mh,C7,kK,B7,kK,A7,jK,z7,jK,Zc,y7,x7,Zc,iK,gK,xt,xt,xt,xt,w7,Dy,Dy,Dy,Zc,v7,u7,Zc,fK,eK,t7,dK,s7,dK,r7,cK,q7,cK,Zc,p7,o7,Zc,bK,aK,wt,wt,wt,wt,n7,Ay,Ay,Ay,YJ,j7,Hp,i7,XJ,h7,te,te,g7,f7,Ct,e7,d7,mh,VJ,b7,Hp,a7,UJ,$6,te,jc,te,_6,Z6,Y6,X6,W6,V6,U6,mh,$c,Dt,$c,Dt,xy,PJ,N6,M6,OJ,NJ,MJ,KJ,JJ,IJ,HJ,GJ,FJ,EJ,DJ,CJ,BJ,AJ,zJ,yJ,Q6,O6,L6,K6,J6,I6,H6,G6,F6,E6,C6,B6,A6,z6,y6,x6,w6,v6,af,mh,af,mh,u6,t6,n6,l6,k6,j6,i6,f6,e6,d6,c6,mf,Z5,$5,KI,af,Zc,b6,j0,i0,h0,a6,_5,$x,X5,GI,yo,Fc,J5,I5,G5,E5,C5,A5,y5,Yx,x5,P6,D6,LJ,w5,yo,v5,u5,t5,lI,af,Am,U5,$c,Wm,DI,CI,jc,jc,T5,BI,S5,dt,R5,dt,bq,Q5,$c,Wm,DI,CI,jc,jc,P5,BI,O5,dt,N5,dt,ct,_x,yI,xI,ct,_x,yI,xI,at,Vx,nI,mI,at,Vx,nI,mI,eu,m5,n5,l5,q5,p5,o5,oh,EI,oh,EI,Cq,hI,k5,j5,vf,gI,i5,h5,V5,jc,g5,f5,e5,fu,fu,Tx,Px,bt,tI,ZH,d5,c5,b5,a5,WH,$4,_4,Z4,Y4,ZH,X4,UH,U4,T4,WH,S4,UH,R4,Q4,N4,M4,Fx,Ph,Oh,Ts,Yb,Gs,nk,mk,pl,Ex,ol,v4,qj,Ug,t4,r4,xH,xH,m4,k4,wH,rj,i4,g4,xe,e4,K4,Jx,Xx,Bx,Ph,Oh,Rs,ym,jl,xm,qn,wm,qj,Ug,vH,rj,Q3,L3,K3,G4,Ox,g6,kI,E3,Xs,un,z3,Un,Ix,mf,g3,Ns,f3,e3,d3,c3,a3,Cp,Z2,Y2,kl,X2,W2,U2,l0,R2,Q2,N2,M2,I2,H2,G2,F2,E2,D2,C2,A2,z2,y2,x2,w2,v2,u2,t2,s2,r2,p2,o2,n2,m2,l2,k2,j2,i2,h2,g2,f2,e2,d2,c2,b2,a2,V1,_1,t0,$1,Y1,X1,U1,J4,H4,I4,Kx,IH,ql,HH,aq,u1,t1,GH,FH,EH,_0,Z0,X0,W0,U0,T0,R0,Q0,O0,N0,L0,K0,I0,rx,G0,E0,C0,A0,y0,w0,u0,DH,CH,ZG,Z1,yM,XG,I1,H1,G1,F1,E1,rW,D1,C1,B1,UG,z1,y1,x1,w1,v1,jc,s1,r1,SG,k1,h1,g1,MK,e1,c1,RG,i1,wy,iZ,f1,d1,b1,af,Zc,Zc,T1,S1,R1,Q1,P1,O1,N1,M1,rW,L1,K1,J1,Zc,WG,WG,tx,te,te,A1,te,Zc,q1,p1,tx,jc,jc,o1,Sv,Zc,n1,m1,tx,jc,jc,l1,Sv,af,Zc,D4,C4,B4,af,Zc,A4,z4,y4,Zc,x4,w4,u4,s4,q4,o4,n4,l4,j4,h4,f4,Zc,d4,b4,a4,$3,_3,Z3,Y3,X3,W3,V3,U3,Zc,S3,R3,P3,O3,N3,M3,J3,I3,Zc,H3,F3,D3,C3,B3,A3,y3,x3,af,Zc,re,w3,v3,u3,t3,s3,r3,a1,V0,P0,B0,x0,J0,F0,af,Zc,re,q3,p3,o3,n3,m3,l3,Y0,S0,M0,z0,v0,H0,D0,qx,PG,k3,qx,PG,j3,Zc,Ms,Ms,Lh,Lh,Lh,kH,jc,hl,hl,Zc,Ms,Ms,Lh,Lh,Lh,kH,jc,hl,hl,Zc,as,as,Lh,Lh,Lh,jH,jc,hl,hl,Zc,as,as,Lh,Lh,Lh,jH,jc,hl,hl,Zc,h3,b3,Zc,_2,V2,Zc,S2,P2,Zc,O2,L2,Zc,bH,K2,$c,Zc,bH,J2,$c,af,mh,mh,jc,jc,jc,m_,Es,q0,Si,aN,a0,p0,EG,nx,Zc,g0,f0,Zc,d0,b0,c0,$$,Zc,_$,Da,Y$,Zc,V$,Zc,W$,U$,T$,Op,Op,Op,Op,Sw,Zc,S$,af,Zc,mf,mf,R$,G$,J$,P$,Zc,H$,K$,O$,Zc,I$,M$,N$]);function lb(){return s.byteLength/65536|0}function qb(rb){rb=rb|0;var mb=lb()|0;var nb=mb+rb|0;if(mb<nb&&nb<65536){var ob=new ArrayBuffer(B(nb,65536));var pb=new Int8Array(ob);pb.set(t);t=new Int8Array(ob);u=new Int16Array(ob);v=new Int32Array(ob);w=new Uint8Array(ob);x=new Uint16Array(ob);y=new Uint32Array(ob);z=new Float32Array(ob);A=new Float64Array(ob);s=ob;r.buffer=s;e=w}return mb}return{"va":SY,"wa":tba,"xa":rba,"ya":Zc,"za":Yb,"Aa":qba,"Ba":pba,"Ca":oba,"Da":Lt,"Ea":$c,"Fa":nba,"Ga":mba,"Ha":lba,"Ia":is,"Ja":kba,"Ka":PL,"La":jba,"Ma":af,"Na":OL,"Oa":NL,"Pa":OL,"Qa":hba,"Ra":B$,"Sa":A$,"Ta":z$,"Ua":gba,"Va":JL,"Wa":cba,"Xa":HL,"Ya":bba,"Za":$aa,"_a":_aa,"$a":Zaa,"ab":Yaa,"bb":Xaa,"cb":Waa,"db":Vaa,"eb":Uaa,"fb":Taa,"gb":Saa,"hb":Raa,"ib":Qaa,"jb":Paa,"kb":Oaa,"lb":Naa,"mb":Laa,"nb":Kaa,"ob":Jaa,"pb":Iaa,"qb":Haa,"rb":Gaa,"sb":Faa,"tb":Eaa,"ub":Daa,"vb":Caa,"wb":Baa,"xb":Aaa,"yb":zaa,"zb":yaa,"Ab":xaa,"Bb":waa,"Cb":vaa,"Db":uaa,"Eb":taa,"Fb":saa,"Gb":raa,"Hb":qaa,"Ib":paa,"Jb":oaa,"Kb":naa,"Lb":maa,"Mb":laa,"Nb":kaa,"Ob":jaa,"Pb":iaa,"Qb":haa,"Rb":gaa,"Sb":faa,"Tb":eaa,"Ub":daa,"Vb":caa,"Wb":baa,"Xb":aaa,"Yb":$9,"Zb":_9,"_b":Z9,"$b":Y9,"ac":X9,"bc":W9,"cc":V9,"dc":U9,"ec":T9,"fc":y$,"gc":S9,"hc":R9,"ic":Q9,"jc":P9,"kc":x$,"lc":O9,"mc":N9,"nc":M9,"oc":L9,"pc":K9,"qc":J9,"rc":I9,"sc":Cd,"tc":h6,"uc":Fla,"vc":Ska,"wc":lja,"xc":F$,"yc":E$,"zc":kb,"Ac":q$,"Bc":w$,"Cc":v$,"Dc":u$,"Ec":t$,"Fc":s$,"Gc":r$,"Hc":q$,"Ic":p$,"Jc":o$,"Kc":n$}}return sb(ub)}
// EMSCRIPTEN_END_ASM




)(asmLibraryArg);
  },

  instantiate: /** @suppress{checkTypes} */ function(binary, info) {
    return {
      then: function(ok) {
        var module = new WebAssembly.Module(binary);
        ok({
          'instance': new WebAssembly.Instance(module)
        });
        // Emulate a simple WebAssembly.instantiate(..).then(()=>{}).catch(()=>{}) syntax.
        return { catch: function() {} };
      }
    };
  },

  RuntimeError: Error
};

// We don't need to actually download a wasm binary, mark it as present but empty.
wasmBinary = [];


